--
-- PostgreSQL database dump
--

SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = public, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: bezugspegel; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE bezugspegel (
    bezugspegelid bigint NOT NULL,
    gewaesserid bigint NOT NULL,
    km double precision NOT NULL,
    name character varying(50) NOT NULL,
    nullpunkt double precision NOT NULL,
    kennung character varying(16),
    einzugsgebiet double precision,
    inbetrieb timestamp without time zone,
    fliesscharakter character varying(3),
    laufentwicklung double precision,
    mnq double precision,
    mq double precision,
    mhq double precision,
    nnq double precision,
    hhq double precision,
    nnqdatum timestamp without time zone,
    hhqdatum timestamp without time zone,
    jahresreihe character varying(12),
    bemerkung character varying(240)
);


--
-- Name: TABLE bezugspegel; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE bezugspegel IS 'Bezugspegel';


--
-- Name: COLUMN bezugspegel.bezugspegelid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.bezugspegelid IS 'Interne ID des Bezugspegels (PK)';


--
-- Name: COLUMN bezugspegel.gewaesserid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.gewaesserid IS 'Interne ID des Gewassers des Bezugspegels (FK Gewaesser)';


--
-- Name: COLUMN bezugspegel.km; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.km IS 'Kilometerangabe fur den Bezugspegel, bezogen auf die Stationierung des Gewassers; Einheit: km';


--
-- Name: COLUMN bezugspegel.name; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.name IS 'Bezeichnung des Pegels';


--
-- Name: COLUMN bezugspegel.nullpunkt; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.nullpunkt IS 'Hohe des Pegelnullpunktes; Einheit: m u.NN';


--
-- Name: COLUMN bezugspegel.kennung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.kennung IS 'Gewasserkundliche Nummer des Pegels; Einheit: ';


--
-- Name: COLUMN bezugspegel.einzugsgebiet; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.einzugsgebiet IS 'Gro?e des Einzugsgebiets bis zum Bezugspegel; Einheit: km^2';


--
-- Name: COLUMN bezugspegel.inbetrieb; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.inbetrieb IS 'Datums, an dem der Bezugspegel in Betrieb genommen wurde';


--
-- Name: COLUMN bezugspegel.fliesscharakter; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.fliesscharakter IS 'Angabe zur Flie?charakteristik des Abschnitts, fur den der Bezugspegel als reprasentativ angesehen wird';


--
-- Name: COLUMN bezugspegel.laufentwicklung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.laufentwicklung IS 'Kennzahl eF zur Beschreibung der Laufentwicklung des Abschnitts';


--
-- Name: COLUMN bezugspegel.mnq; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.mnq IS 'Hauptwert einer Jahresreihe am Pegel; Einheit: m^3/s';


--
-- Name: COLUMN bezugspegel.mq; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.mq IS 'Hauptwert einer Jahresreihe am Pegel; Einheit: m^3/s';


--
-- Name: COLUMN bezugspegel.mhq; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.mhq IS 'Hauptwert einer Jahresreihe am Pegel; Einheit: m^3/s';


--
-- Name: COLUMN bezugspegel.nnq; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.nnq IS 'Hauptwert einer Jahresreihe am Pegel; Einheit: m^3/s';


--
-- Name: COLUMN bezugspegel.hhq; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.hhq IS 'Hauptwert einer Jahresreihe am Pegel; Einheit: m^3/s';


--
-- Name: COLUMN bezugspegel.nnqdatum; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.nnqdatum IS 'Datum, an dem NNQ registriert worden ist.';


--
-- Name: COLUMN bezugspegel.hhqdatum; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.hhqdatum IS 'Datum, an dem HHQ registriert worden ist.';


--
-- Name: COLUMN bezugspegel.jahresreihe; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.jahresreihe IS 'Zeitraum, auf den sich die Hauptwerte beziehen';


--
-- Name: COLUMN bezugspegel.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN bezugspegel.bemerkung IS 'Bemerkungen zum Pegel';


--
-- Name: gewaesser; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE gewaesser (
    gewaesserid bigint NOT NULL,
    name character varying(20) NOT NULL,
    kennung character varying(11),
    laenge double precision,
    einzugsgebiet double precision,
    bemerkung character varying(240)
);


--
-- Name: TABLE gewaesser; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE gewaesser IS 'Gewasser';


--
-- Name: COLUMN gewaesser.gewaesserid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gewaesser.gewaesserid IS 'Interne ID des Gewassers (PK)';


--
-- Name: COLUMN gewaesser.name; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gewaesser.name IS 'Name/Bezeichnung des Gewassers';


--
-- Name: COLUMN gewaesser.kennung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gewaesser.kennung IS 'Kennung/Nummer der Gewassers';


--
-- Name: COLUMN gewaesser.laenge; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gewaesser.laenge IS 'Gesamtlange des Gewassers; Einheit: km';


--
-- Name: COLUMN gewaesser.einzugsgebiet; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gewaesser.einzugsgebiet IS 'Gro?e des Einzugsgebiets der Bundeswasserstra?e, des Gewassers; Einheit: km^2';


--
-- Name: COLUMN gewaesser.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gewaesser.bemerkung IS 'Bemerkungen zum Gewasser';


--
-- Name: bezugspegelgew; Type: VIEW; Schema: public; Owner: -
--

CREATE VIEW bezugspegelgew AS
    SELECT bezugspegel.bezugspegelid, bezugspegel.gewaesserid, bezugspegel.km, bezugspegel.name, bezugspegel.nullpunkt, bezugspegel.kennung, bezugspegel.einzugsgebiet, bezugspegel.inbetrieb, bezugspegel.fliesscharakter, bezugspegel.laufentwicklung, bezugspegel.mnq, bezugspegel.mq, bezugspegel.mhq, bezugspegel.nnq, bezugspegel.hhq, bezugspegel.nnqdatum, bezugspegel.hhqdatum, bezugspegel.jahresreihe, bezugspegel.bemerkung, gewaesser.name AS gewname FROM (bezugspegel JOIN gewaesser ON ((bezugspegel.gewaesserid = gewaesser.gewaesserid)));


--
-- Name: gfaenger; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE gfaenger (
    gfaengerid bigint NOT NULL,
    istaktiv smallint NOT NULL,
    name character varying(30) NOT NULL,
    breite real NOT NULL,
    maschenweite double precision NOT NULL,
    bemerkung character varying(240)
);


--
-- Name: TABLE gfaenger; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE gfaenger IS 'Geschiebefanger';


--
-- Name: COLUMN gfaenger.gfaengerid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gfaenger.gfaengerid IS 'Interne ID des Geschiebefangers';


--
-- Name: COLUMN gfaenger.istaktiv; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gfaenger.istaktiv IS 'Gibt an, ob der Fanger in Auswahllisten angezeigt werden soll (0 oder 1)';


--
-- Name: COLUMN gfaenger.name; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gfaenger.name IS 'Kurzbezeichnung des Fangers';


--
-- Name: COLUMN gfaenger.breite; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gfaenger.breite IS 'Breite des Fanger-Mauls (Korbbreite); Einheit: m';


--
-- Name: COLUMN gfaenger.maschenweite; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gfaenger.maschenweite IS 'Maschenweite; Einheit: mm';


--
-- Name: COLUMN gfaenger.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gfaenger.bemerkung IS 'Bemerkungen zum Geschiebfanger';


--
-- Name: glotrechte; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE glotrechte (
    glotrechteid bigint NOT NULL,
    messungid bigint NOT NULL,
    uferabst double precision NOT NULL,
    tgeschiebe double precision,
    dm double precision,
    sk double precision,
    so double precision,
    u double precision,
    d90 double precision,
    d84 double precision,
    d80 double precision,
    d75 double precision,
    d70 double precision,
    d60 double precision,
    d50 double precision,
    d40 double precision,
    d30 double precision,
    d25 double precision,
    d20 double precision,
    d16 double precision,
    d10 double precision,
    dmin double precision,
    durchdmin real,
    dmax double precision,
    durchdmax real,
    stdabw double precision,
    stdfehler double precision,
    bemerkung character varying(240),
    uferablinks double precision
);


--
-- Name: TABLE glotrechte; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE glotrechte IS 'Lotrechte der Geschiebe-Messung';


--
-- Name: COLUMN glotrechte.glotrechteid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.glotrechteid IS 'Interne ID der Geschiebe-Lotrechten (PK)';


--
-- Name: COLUMN glotrechte.messungid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.messungid IS 'Interne ID der Messung (FK Messung)';


--
-- Name: COLUMN glotrechte.uferabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.uferabst IS 'Horizontaler Abstand der Lotrechten vom linken oder rechten Hektometerstein.; Einheit: m';


--
-- Name: COLUMN glotrechte.tgeschiebe; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.tgeschiebe IS 'Mittlerer Geschiebetrieb in der Lotrechten; Einheit: g/(s*m)';


--
-- Name: COLUMN glotrechte.dm; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.dm IS 'Mittlerer Korndurchmesser (dm) nach Meyer-Peter und Muller der Geschiebeprobe in der Lotrechten; Einheit: mm';


--
-- Name: COLUMN glotrechte.sk; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.sk IS 'Schiefekoeffizient (Sk) als Ma? fur die Abweichung einer Haufigkeitsverteilung von der Symmetrie';


--
-- Name: COLUMN glotrechte.so; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.so IS 'Sortierungskoeffizient (S0) als Kennwert zur Charakterisierung der Verteilung des Korngemisches';


--
-- Name: COLUMN glotrechte.u; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.u IS 'Ungleichformigkeitszahl (U) als Ma? fur die Steilheit der Summenlinie im Bereich d10 bis d60 (entsprechend DIN 18196)';


--
-- Name: COLUMN glotrechte.d90; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.d90 IS 'Charakteristische Korngro?e D90, d.h. die Korngro?e, die von 90 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN glotrechte.d84; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.d84 IS 'Charakteristische Korngro?e D84, d.h. die Korngro?e, die von 84 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN glotrechte.d80; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.d80 IS 'Charakteristische Korngro?e D80, d.h. die Korngro?e, die von 80 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN glotrechte.d75; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.d75 IS 'Charakteristische Korngro?e D75, d.h. die Korngro?e, die von 75 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN glotrechte.d70; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.d70 IS 'Charakteristische Korngro?e D70, d.h. die Korngro?e, die von 70 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN glotrechte.d60; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.d60 IS 'Charakteristische Korngro?e D60, d.h. die Korngro?e, die von 60 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN glotrechte.d50; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.d50 IS 'Charakteristische Korngro?e D50, d.h. die Korngro?e, die von 50 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN glotrechte.d40; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.d40 IS 'Charakteristische Korngro?e D40, d.h. die Korngro?e, die von 40 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN glotrechte.d30; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.d30 IS 'Charakteristische Korngro?e D30, d.h. die Korngro?e, die von 30 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN glotrechte.d25; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.d25 IS 'Charakteristische Korngro?e D25, d.h. die Korngro?e, die von 25 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN glotrechte.d20; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.d20 IS 'Charakteristische Korngro?e D20, d.h. die Korngro?e, die von 20 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN glotrechte.d16; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.d16 IS 'Charakteristische Korngro?e D16, d.h. die Korngro?e, die von 16 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN glotrechte.d10; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.d10 IS 'Charakteristische Korngro?e D10, d.h. die Korngro?e, die von 10 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN glotrechte.dmin; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.dmin IS 'Letzter (kleinster) Siebdurchmesser, durch den noch Korner hindurchgegangen sind. Auf dem nachst kleineren Siebdurchmesser ist damit der Siebdurchgang = 0; Einheit: mm';


--
-- Name: COLUMN glotrechte.durchdmin; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.durchdmin IS 'Anteiliger Korndurchgang auf DMIN; Einheit: %';


--
-- Name: COLUMN glotrechte.dmax; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.dmax IS 'Erster (gro?ter) Siebdurchmesser, auf dem Korner liegengeblieben sind. Auf dem nachst gro?eren Siebdurchmesser ist damit der Siebruckstand = 0 bzw. der -durchgang = 100%; Einheit: mm';


--
-- Name: COLUMN glotrechte.durchdmax; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.durchdmax IS 'Anteiliger Korndurchgang auf DMAX; Einheit: %';


--
-- Name: COLUMN glotrechte.stdabw; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.stdabw IS 'Standardabweichung des Geschiebetriebs; Einheit: g/(s*m)';


--
-- Name: COLUMN glotrechte.stdfehler; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.stdfehler IS 'Standardfehler des Geschiebetriebs; Einheit: g/(s*m)';


--
-- Name: COLUMN glotrechte.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.bemerkung IS 'Bemerkungen zur Geschiebemessung in der Lotrechten';


--
-- Name: COLUMN glotrechte.uferablinks; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN glotrechte.uferablinks IS 'Abstand der Lotrechte vom Nullpunkt am linken Ufer; Einheit: m';


--
-- Name: gprobe; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE gprobe (
    glotrechteid bigint NOT NULL,
    lfdnr integer NOT NULL,
    messdauer integer NOT NULL,
    menge double precision NOT NULL,
    gtrieb double precision,
    faktor real,
    menge_f double precision,
    gtrieb_f double precision
);


--
-- Name: TABLE gprobe; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE gprobe IS 'Probe der Geschiebemessung einer Lotrechten';


--
-- Name: COLUMN gprobe.glotrechteid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gprobe.glotrechteid IS 'Interne ID der Geschiebe-Lotrechten (PK, FK GLotrechte)';


--
-- Name: COLUMN gprobe.lfdnr; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gprobe.lfdnr IS 'Lfd. Nr. der Probe in der Lotrechten (PK)';


--
-- Name: COLUMN gprobe.messdauer; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gprobe.messdauer IS 'Messdauer der Probenahme; Einheit: s';


--
-- Name: COLUMN gprobe.menge; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gprobe.menge IS 'Wahrend der Messdauer im Fanger gesammelte Geschiebemenge; Einheit: g';


--
-- Name: COLUMN gprobe.gtrieb; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gprobe.gtrieb IS 'Berechneter Geschiebetrieb der Probenahme; Einheit: g/(s*m)';


--
-- Name: COLUMN gprobe.faktor; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gprobe.faktor IS 'Korrekturfaktor';


--
-- Name: COLUMN gprobe.menge_f; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gprobe.menge_f IS 'Korrigierte Geschiebemenge; Einheit: g';


--
-- Name: COLUMN gprobe.gtrieb_f; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gprobe.gtrieb_f IS 'Korrigierter Geschiebetrieb; Einheit: g/(s*m)';


--
-- Name: gsiebsatz; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE gsiebsatz (
    gsiebsatzid bigint NOT NULL,
    name character varying(20) NOT NULL,
    istaktiv smallint NOT NULL,
    sieb01 double precision,
    sieb02 double precision,
    sieb03 double precision,
    sieb04 double precision,
    sieb05 double precision,
    sieb06 double precision,
    sieb07 double precision,
    sieb08 double precision,
    sieb09 double precision,
    sieb10 double precision,
    sieb11 double precision,
    sieb12 double precision,
    sieb13 double precision,
    sieb14 double precision,
    sieb15 double precision,
    sieb16 double precision,
    sieb17 double precision,
    sieb18 double precision,
    sieb19 double precision,
    sieb20 double precision,
    sieb21 double precision,
    bemerkung character varying(240)
);


--
-- Name: TABLE gsiebsatz; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE gsiebsatz IS 'Siebsatz';


--
-- Name: COLUMN gsiebsatz.gsiebsatzid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.gsiebsatzid IS 'Interne ID (PK)';


--
-- Name: COLUMN gsiebsatz.name; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.name IS 'Bezeichnung (Name) des Siebsatzes';


--
-- Name: COLUMN gsiebsatz.istaktiv; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.istaktiv IS 'Gibt an, ob der Siebsatz in der Auswahlliste beim Anlegen einer neuen Siebanalyse zur Auswahl angeziegt werden soll (0 oder 1)';


--
-- Name: COLUMN gsiebsatz.sieb01; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb01 IS 'Maschenweite des Siebs 01; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb02; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb02 IS 'Maschenweite des Siebs 02; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb03; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb03 IS 'Maschenweite des Siebs 03; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb04; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb04 IS 'Maschenweite des Siebs 04; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb05; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb05 IS 'Maschenweite des Siebs 05; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb06; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb06 IS 'Maschenweite des Siebs 06; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb07; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb07 IS 'Maschenweite des Siebs 07; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb08; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb08 IS 'Maschenweite des Siebs 08; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb09; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb09 IS 'Maschenweite des Siebs 09; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb10; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb10 IS 'Maschenweite des Siebs 10; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb11; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb11 IS 'Maschenweite des Siebs 11; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb12; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb12 IS 'Maschenweite des Siebs 12; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb13; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb13 IS 'Maschenweite des Siebs 13; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb14; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb14 IS 'Maschenweite des Siebs 14; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb15; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb15 IS 'Maschenweite des Siebs 15; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb16; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb16 IS 'Maschenweite des Siebs 16; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb17; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb17 IS 'Maschenweite des Siebs 17; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb18; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb18 IS 'Maschenweite des Siebs 18; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb19; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb19 IS 'Maschenweite des Siebs 19; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb20; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb20 IS 'Maschenweite des Siebs 20; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.sieb21; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.sieb21 IS 'Maschenweite des Siebs 21; Einheit: mm';


--
-- Name: COLUMN gsiebsatz.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebsatz.bemerkung IS 'Bemerkungen zum Siebsatz';


--
-- Name: gsiebung; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE gsiebung (
    glotrechteid bigint NOT NULL,
    gmasse double precision,
    rsieb01 double precision,
    rsieb02 double precision,
    rsieb03 double precision,
    rsieb04 double precision,
    rsieb05 double precision,
    rsieb06 double precision,
    rsieb07 double precision,
    rsieb08 double precision,
    rsieb09 double precision,
    rsieb10 double precision,
    rsieb11 double precision,
    rsieb12 double precision,
    rsieb13 double precision,
    rsieb14 double precision,
    rsieb15 double precision,
    rsieb16 double precision,
    rsieb17 double precision,
    rsieb18 double precision,
    rsieb19 double precision,
    rsieb20 double precision,
    rsieb21 double precision,
    rest double precision,
    bemerkung character varying(240),
    CONSTRAINT gsi_sieb01 CHECK ((rsieb01 = (0)::double precision))
);


--
-- Name: TABLE gsiebung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE gsiebung IS 'Siebanalyse der Geschiebe-Lotrechten';


--
-- Name: COLUMN gsiebung.glotrechteid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.glotrechteid IS 'Interne ID der Geschiebe-Lotrechten (PK, FK GLotrechte)';


--
-- Name: COLUMN gsiebung.gmasse; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.gmasse IS 'Gesamtgewicht der Probe ("Einwaage"); Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb01; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb01 IS 'Siebruckstand (Masse) auf Sieb 01; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb02; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb02 IS 'Siebruckstand (Masse) auf Sieb 02; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb03; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb03 IS 'Siebruckstand (Masse) auf Sieb 03; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb04; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb04 IS 'Siebruckstand (Masse) auf Sieb 04; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb05; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb05 IS 'Siebruckstand (Masse) auf Sieb 05; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb06; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb06 IS 'Siebruckstand (Masse) auf Sieb 06; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb07; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb07 IS 'Siebruckstand (Masse) auf Sieb 07; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb08; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb08 IS 'Siebruckstand (Masse) auf Sieb 08; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb09; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb09 IS 'Siebruckstand (Masse) auf Sieb 09; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb10; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb10 IS 'Siebruckstand (Masse) auf Sieb 10; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb11; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb11 IS 'Siebruckstand (Masse) auf Sieb 11; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb12; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb12 IS 'Siebruckstand (Masse) auf Sieb 12; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb13; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb13 IS 'Siebruckstand (Masse) auf Sieb 13; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb14; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb14 IS 'Siebruckstand (Masse) auf Sieb 14; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb15; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb15 IS 'Siebruckstand (Masse) auf Sieb 15; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb16; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb16 IS 'Siebruckstand (Masse) auf Sieb 16; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb17; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb17 IS 'Siebruckstand (Masse) auf Sieb 17; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb18; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb18 IS 'Siebruckstand (Masse) auf Sieb 18; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb19; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb19 IS 'Siebruckstand (Masse) auf Sieb 19; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb20; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb20 IS 'Siebruckstand (Masse) auf Sieb 20; Einheit: g';


--
-- Name: COLUMN gsiebung.rsieb21; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rsieb21 IS 'Siebruckstand (Masse) auf Sieb 21; Einheit: g';


--
-- Name: COLUMN gsiebung.rest; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.rest IS 'Siebungsrest. Differenz aus den aufsummierten Siebruckstanden und der "Einwaage" (Gesamtgewicht der Probe); Einheit: g';


--
-- Name: COLUMN gsiebung.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN gsiebung.bemerkung IS 'Bemerkungen zur Siebanalyse';


--
-- Name: hpeilpunkt; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE hpeilpunkt (
    hpeilungid bigint NOT NULL,
    punktnr integer NOT NULL,
    y double precision NOT NULL,
    z double precision NOT NULL
);


--
-- Name: TABLE hpeilpunkt; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE hpeilpunkt IS 'Koordinaten der Hauptpeilung';


--
-- Name: COLUMN hpeilpunkt.hpeilungid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilpunkt.hpeilungid IS 'Interne ID der Hauptpeilung (PK, FK HPeilung)';


--
-- Name: COLUMN hpeilpunkt.punktnr; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilpunkt.punktnr IS 'Laufende Punkt-Nummer (PK)';


--
-- Name: COLUMN hpeilpunkt.y; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilpunkt.y IS 'Y-Koordinate (horizontale Entfernung vom Nullpunkt) des Profilpunktes. Die y-Koordinate muss aufsteigend (nicht streng) sein.; Einheit: m';


--
-- Name: COLUMN hpeilpunkt.z; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilpunkt.z IS 'Z-Koordinate (Hohe) des Profilpunktes.; Einheit: m u.NN';


--
-- Name: hpeilung; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE hpeilung (
    hpeilungid bigint NOT NULL,
    stationid bigint NOT NULL,
    km double precision NOT NULL,
    datum timestamp without time zone NOT NULL,
    glwname character varying(8),
    glwhoehe double precision,
    buliabst double precision,
    bulihoehe double precision,
    bulifuss double precision,
    buliruecken double precision,
    bureabst double precision,
    burehoehe double precision,
    burefuss double precision,
    bureruecken double precision,
    fahrliabst double precision,
    fahrreabst double precision,
    fahrtief double precision,
    ausbliabst double precision,
    ausbreabst double precision,
    achseabst double precision,
    teilvonabst double precision,
    teilbisabst double precision,
    hmabst double precision,
    lgkrechts double precision,
    lgkhoch double precision,
    lgkhoehe double precision,
    rgkrechts double precision,
    rgkhoch double precision,
    rgkhoehe double precision,
    bemerkung character varying(240),
    lastupdated timestamp without time zone NOT NULL,
    oldprfid bigint,
    mitteabst double precision
);


--
-- Name: TABLE hpeilung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE hpeilung IS 'Hauptpeilung';


--
-- Name: COLUMN hpeilung.hpeilungid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.hpeilungid IS 'Interne ID der Hauptpeilung (PK)';


--
-- Name: COLUMN hpeilung.stationid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.stationid IS 'Interne ID der Messstelle (FK Station)';


--
-- Name: COLUMN hpeilung.km; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.km IS 'Kilometerangabe der Hauptpeilung, bezogen auf die Stationierung des Gewassers, ggf. abweichend von Station.Km; Einheit: km';


--
-- Name: COLUMN hpeilung.datum; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.datum IS 'Datum der Hauptpeilung';


--
-- Name: COLUMN hpeilung.glwname; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.glwname IS 'Name des Gleichwertigen Wasserstandes';


--
-- Name: COLUMN hpeilung.glwhoehe; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.glwhoehe IS 'Hohe des Gleichwertigen Wasserstandes; Einheit: m u.NN';


--
-- Name: COLUMN hpeilung.buliabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.buliabst IS 'Horizontaler Abstand des linken Buhnenkopfes vom Nullpunkt des Profils; Einheit: m';


--
-- Name: COLUMN hpeilung.bulihoehe; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.bulihoehe IS 'Hohe des linken Buhnenkopfes; Einheit: m u.NN';


--
-- Name: COLUMN hpeilung.bulifuss; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.bulifuss IS 'Neigung zum linken Buhnenfu?';


--
-- Name: COLUMN hpeilung.buliruecken; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.buliruecken IS 'Neigung des linken Buhnenruckens';


--
-- Name: COLUMN hpeilung.bureabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.bureabst IS 'Horizontaler Abstand des rechten Buhnenkopfes vom Nullpunkt des Profils; Einheit: m';


--
-- Name: COLUMN hpeilung.burehoehe; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.burehoehe IS 'Hohe des rechten Buhnenkopfes; Einheit: m u.NN';


--
-- Name: COLUMN hpeilung.burefuss; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.burefuss IS 'Neigung zum rechten Buhnenfu?';


--
-- Name: COLUMN hpeilung.bureruecken; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.bureruecken IS 'Neigung des rechten Buhnenruckens';


--
-- Name: COLUMN hpeilung.fahrliabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.fahrliabst IS 'Horizontaler Abstand der linken Begrenzung des Fahrinnenkastens vom Nullpunkt des Profils; Einheit: m';


--
-- Name: COLUMN hpeilung.fahrreabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.fahrreabst IS 'Horizontaler Abstand der rechten Begrenzung des Fahrinnenkastens vom Profil-Nullpunkt; Einheit: m';


--
-- Name: COLUMN hpeilung.fahrtief; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.fahrtief IS 'Tiefe des Fahrrinnenkasten unter der Hohe des GlW; Einheit: m';


--
-- Name: COLUMN hpeilung.ausbliabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.ausbliabst IS 'Horizontaler Abstand der linken Begrenzung der Ausbaubreite vom Profil-Nullpunkt; Einheit: m';


--
-- Name: COLUMN hpeilung.ausbreabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.ausbreabst IS 'Horizontaler Abstand der rechten Begrenzung der Ausbaubreite rechts vom Profil-Nullpunkt; Einheit: m';


--
-- Name: COLUMN hpeilung.achseabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.achseabst IS 'Horizontaler Abstand der Achse der Ausbaubreite vom Profil-Nullpunkt; Einheit: m';


--
-- Name: COLUMN hpeilung.teilvonabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.teilvonabst IS 'Horizontaler Abstand der linken Begrenzung eines Teilprofils vom Profil-Nullpunkt; Einheit: m';


--
-- Name: COLUMN hpeilung.teilbisabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.teilbisabst IS 'Horizontaler Abstand der rechten Begrenzung eines Teilprofils vom Profil-Nullpunkt; Einheit: m';


--
-- Name: COLUMN hpeilung.hmabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.hmabst IS 'Abstand der Hektometer-Steine (Profil-Nullpunkt und Profil-Gegenpunkt); Einheit: m';


--
-- Name: COLUMN hpeilung.lgkrechts; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.lgkrechts IS 'Koordinaten-Rechtswert des Profil-Nullpunktes in Gau?-Kruger-Koordinaten; Einheit: m';


--
-- Name: COLUMN hpeilung.lgkhoch; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.lgkhoch IS 'Koordinaten-Hochwert des Profil-Null-Punktes in Gau?-Kruger-Koordinaten; Einheit: m';


--
-- Name: COLUMN hpeilung.lgkhoehe; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.lgkhoehe IS 'Hohe des Profil-Nullpunktes; Einheit: m u.NN';


--
-- Name: COLUMN hpeilung.rgkrechts; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.rgkrechts IS 'Koordinaten-Rechtswert des Profil-Gegenpunktes in Gau?-Kruger-Koordinaten; Einheit: m';


--
-- Name: COLUMN hpeilung.rgkhoch; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.rgkhoch IS 'Koordinaten-Hochwert des Profil-Gegenpunktes in Gau?-Kruger-Koordinaten; Einheit: m';


--
-- Name: COLUMN hpeilung.rgkhoehe; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.rgkhoehe IS 'Hohe des Profil-Gegenpunktes; Einheit: m u.NN';


--
-- Name: COLUMN hpeilung.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.bemerkung IS 'Bemerkungen zur Querprofilpeilung';


--
-- Name: COLUMN hpeilung.lastupdated; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN hpeilung.lastupdated IS 'Zeitpunkt der letzten Datensatz-Anderung (automatisch per Trigger)';


--
-- Name: messung; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE messung (
    messungid bigint NOT NULL,
    stationid bigint NOT NULL,
    datum timestamp without time zone NOT NULL,
    hpeilungid bigint,
    mpeilungid bigint,
    gfaengerid bigint,
    gsiebsatzid bigint,
    messnr integer NOT NULL,
    fgue character varying(10),
    uhrvon timestamp without time zone,
    uhrbis timestamp without time zone,
    wspcm double precision,
    q_bpegel double precision,
    wspnn double precision,
    ie real,
    wtemp real,
    gbreite double precision,
    gbreitevon double precision,
    gbreitebis double precision,
    tgeschiebe double precision,
    tsand double precision,
    tschweb double precision,
    cschweb double precision,
    uferliabst double precision,
    uferreabst double precision,
    q double precision,
    a_hpeil real,
    a_mpeil real,
    b double precision,
    hm double precision,
    vm real,
    vsohle real,
    tau double precision,
    tauv double precision,
    teil_q double precision,
    teil_a_hpeil real,
    teil_a_mpeil real,
    teil_b double precision,
    teil_hm double precision,
    teil_vm real,
    teil_vsohle real,
    teil_tau double precision,
    teil_tauv double precision,
    mitteltyp smallint,
    dm double precision,
    sk double precision,
    so double precision,
    u double precision,
    d90 double precision,
    d84 double precision,
    d80 double precision,
    d75 double precision,
    d70 double precision,
    d60 double precision,
    d50 double precision,
    d40 double precision,
    d30 double precision,
    d25 double precision,
    d20 double precision,
    d16 double precision,
    d10 double precision,
    dmin double precision,
    durchdmin real,
    dmax double precision,
    durchdmax real,
    n_geschieb integer DEFAULT 0,
    n_vielpkt integer DEFAULT 0,
    sys_date timestamp without time zone,
    bemerkung character varying(240),
    lastupdated timestamp without time zone NOT NULL,
    km double precision,
    glotabstoffset double precision DEFAULT 0,
    slotabstoffset double precision DEFAULT 0,
    gbreitevonlinks double precision,
    gbreitebislinks double precision,
    glotuferabstistvonlinks smallint,
    slotuferabstistvonlinks smallint
);


--
-- Name: TABLE messung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE messung IS 'Messung';


--
-- Name: COLUMN messung.messungid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.messungid IS 'Interne ID der Messung (PK)';


--
-- Name: COLUMN messung.stationid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.stationid IS 'Interne ID der Messstelle (FK Station)';


--
-- Name: COLUMN messung.datum; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.datum IS 'Datum der Messung';


--
-- Name: COLUMN messung.hpeilungid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.hpeilungid IS 'Interne ID der zugeordneten Hauptpeilung (FK HPeilung)';


--
-- Name: COLUMN messung.mpeilungid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.mpeilungid IS 'Interne ID der zugeordneten Messungs-Peilung (FK MPeilung)';


--
-- Name: COLUMN messung.gfaengerid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.gfaengerid IS 'Interne ID des verwendeten Geschiebefangers (FK GFaenger)';


--
-- Name: COLUMN messung.gsiebsatzid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.gsiebsatzid IS 'Interne ID des verwendeten Siebsatzes (FK GSiebsatz)';


--
-- Name: COLUMN messung.messnr; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.messnr IS 'Nummer der Messung an einer Messstelle (Benutzereingabe, siehe Messprotokoll).';


--
-- Name: COLUMN messung.fgue; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.fgue IS 'Fachgruppenubergreifende Nummer (BfG-intern)';


--
-- Name: COLUMN messung.uhrvon; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.uhrvon IS 'Uhrzeit bei Beginn der Messung';


--
-- Name: COLUMN messung.uhrbis; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.uhrbis IS 'Uhrzeit bei Ende der Messung';


--
-- Name: COLUMN messung.wspcm; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.wspcm IS 'Mittlerer Wasserstand (relativ) am Bezugspegel der Messstelle zum Zeitpunkt der Messung; Einheit: cm';


--
-- Name: COLUMN messung.q_bpegel; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.q_bpegel IS 'Durchfluss am Bezugspegel der Messstelle zum Zeitpunkt der Messung; Einheit: m^3/s';


--
-- Name: COLUMN messung.wspnn; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.wspnn IS 'Wasserstand (absolut) am Bezugspegel der Messstelle zum Zeitpunkt der Messung; Einheit: m u.NN';


--
-- Name: COLUMN messung.ie; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.ie IS 'Wasserspiegel- bzw. Energieliniengefalle ';


--
-- Name: COLUMN messung.wtemp; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.wtemp IS 'Wassertemperatur; Einheit: ?C';


--
-- Name: COLUMN messung.gbreite; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.gbreite IS 'Geschiebefuhrende Breite (wird fur jede Messung neu festgelegt); Einheit: m';


--
-- Name: COLUMN messung.gbreitevon; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.gbreitevon IS 'Horizontaler Abstand der linken Begrenzung der geschiebefuhrenden Breite vom Profil-Nullpunkt gema? Station.IstUferLinks; Einheit: m';


--
-- Name: COLUMN messung.gbreitebis; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.gbreitebis IS 'Horizontaler Abstand der rechten Begrenzung der geschiebefuhrenden Breite vom Profil-Nullpunkt gema? Station.IstUferLinks; Einheit: m';


--
-- Name: COLUMN messung.tgeschiebe; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.tgeschiebe IS 'Geschiebetransport; Einheit: kg/s';


--
-- Name: COLUMN messung.tsand; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.tsand IS 'Schwebstofftransport (Sand). Suspendierter Sandtransport; Einheit: kg/s';


--
-- Name: COLUMN messung.tschweb; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.tschweb IS 'Schwebstofftransport (Gesamt); Einheit: kg/s';


--
-- Name: COLUMN messung.cschweb; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.cschweb IS 'Schwebstoffkonzentration (Gesamt); Einheit: g/m^3';


--
-- Name: COLUMN messung.uferliabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.uferliabst IS 'Horizontaler Abstand vom Nullpunkt am linken Ufer des linken Schnittpunktes der Hauptpeilung mit dem Wasserspiegel; Einheit: m';


--
-- Name: COLUMN messung.uferreabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.uferreabst IS 'Horizontaler Abstand vom Nullpunkt am linken Ufer des rechten Schnittpunktes der Hauptpeilung mit dem Wasserspiegel; Einheit: m';


--
-- Name: COLUMN messung.q; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.q IS 'Durchfluss. Berechnet aus v-Messung und Profil aus Lotrechten; Einheit: m^3/s';


--
-- Name: COLUMN messung.a_hpeil; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.a_hpeil IS 'Durchstromte Querschnittsflache der Hautpeilung; Einheit: m^2';


--
-- Name: COLUMN messung.a_mpeil; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.a_mpeil IS 'Durchstromte Querschnittsflache des resultierenden Gesamtquerschnitt bei Berucksichtigung der aktuellen Peilung (wenn vorhanden); Einheit: m^2';


--
-- Name: COLUMN messung.b; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.b IS 'Breite des Gesamtquerschnitts auf Hohe des Wasserspiegels; Einheit: m';


--
-- Name: COLUMN messung.hm; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.hm IS 'Mittlere Wassertiefe, bezogen auf A_MPeil (wenn vorhanden) sonst A_HPeil; Einheit: m';


--
-- Name: COLUMN messung.vm; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.vm IS 'Mittlere Geschwindigkeit, bezogen auf A_MPeil (wenn vorhanden) sonst A_HPeil.; Einheit: m/s';


--
-- Name: COLUMN messung.vsohle; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.vsohle IS 'Mittlere Geschwindigkeit an der Sohle; Einheit: m/s';


--
-- Name: COLUMN messung.tau; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.tau IS 'Mittlere Sohlschubspannung (r * g * (GesH) * IE; Einheit: N/m^2';


--
-- Name: COLUMN messung.tauv; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.tauv IS 'Schubspannungsgeschwindigkeit; Einheit: m/s';


--
-- Name: COLUMN messung.teil_q; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.teil_q IS 'Durchfluss im Teilquerschnitt Berechnet aus v-Messung und Profil aus Lotrechten; Einheit: m^3/s';


--
-- Name: COLUMN messung.teil_a_hpeil; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.teil_a_hpeil IS 'Querschnittsflache des Teilquerschnitts unter der Hauptpeilung; Einheit: m^2';


--
-- Name: COLUMN messung.teil_a_mpeil; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.teil_a_mpeil IS 'Querschnittsflache des resultierenden Teilquerschnitts bei Berucksichtigung der aktuellen Peilung (wenn vorhanden); Einheit: m^2 ';


--
-- Name: COLUMN messung.teil_b; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.teil_b IS 'Breite des Teilquerschnitts; Einheit: m';


--
-- Name: COLUMN messung.teil_hm; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.teil_hm IS 'Mittlere Tiefe, bezogen auf Teil_A_APeil (wenn vorhanden) bzw. Teil_A_HPeil; Einheit: m';


--
-- Name: COLUMN messung.teil_vm; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.teil_vm IS 'Mittlere Geschwindigkeit bezogen auf Teil_A_APeil (wenn vorhanden) bzw. Teil_A_HPeil; Einheit: m/s';


--
-- Name: COLUMN messung.teil_vsohle; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.teil_vsohle IS 'Mittlere Sohlgeschwindigkeit bezogen auf Teil_A_APeil (wenn vorhanden) bzw. Teil_A_HPeil; Einheit: m/s';


--
-- Name: COLUMN messung.teil_tau; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.teil_tau IS 'Mittlere Sohlschubspannung, bezogen auf Teil_A_APeil (wenn vorhanden) bzw. Teil_A_HPeil; Einheit: N/m^2';


--
-- Name: COLUMN messung.teil_tauv; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.teil_tauv IS 'Sohlschubspannungsgeschwindigkeit, bezogen auf Teil_A_APeil (wenn vorhanden) bzw. Teil_A_HPeil; Einheit: m/s';


--
-- Name: COLUMN messung.mitteltyp; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.mitteltyp IS 'Art der Mittelwertbildung der einzelnen Siebananalysen (0=Massen,1=Prozentgewichtet,2=Triebgewichtet)';


--
-- Name: COLUMN messung.dm; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.dm IS 'Mittlerer Korndurchmesser (dm) in mm nach Meyer-Peter und Muller; Einheit: mm';


--
-- Name: COLUMN messung.sk; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.sk IS 'Schiefekoeffizient (Sk) als Ma? fur die Abweichung einer Haufigkeitsverteilung von der Symmetrie';


--
-- Name: COLUMN messung.so; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.so IS 'Sortierungskoeffizient (S0) als Kennwert zur Charakterisierung der Verteilung des Korngemisches';


--
-- Name: COLUMN messung.u; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.u IS 'Ungleichformigkeitszahl (U) als Ma? fur die Steilheit der Summenlinie im Bereich d10 bis d60 (entsprechend DIN 18196)';


--
-- Name: COLUMN messung.d90; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.d90 IS 'Charakteristische Korngro?e D90, d.h. Korngro?e, die von 90 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN messung.d84; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.d84 IS 'Charakteristische Korngro?e D84, d.h. Korngro?e, die von 84 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN messung.d80; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.d80 IS 'Charakteristische Korngro?e D80, d.h. Korngro?e, die von 80 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN messung.d75; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.d75 IS 'Charakteristische Korngro?e D75, d.h. Korngro?e, die von 75 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN messung.d70; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.d70 IS 'Charakteristische Korngro?e D70, d.h. Korngro?e, die von 70 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN messung.d60; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.d60 IS 'Charakteristische Korngro?e D60, d.h. Korngro?e, die von 60 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN messung.d50; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.d50 IS 'Charakteristische Korngro?e D50, d.h. Korngro?e, die von 50 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN messung.d40; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.d40 IS 'Charakteristische Korngro?e D40, d.h. Korngro?e, die von 40 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN messung.d30; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.d30 IS 'Charakteristische Korngro?e D30, d.h. Korngro?e, die von 30 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN messung.d25; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.d25 IS 'Charakteristische Korngro?e D25, d.h. Korngro?e, die von 25 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN messung.d20; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.d20 IS 'Charakteristische Korngro?e D20, d.h. Korngro?e, die von 20 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN messung.d16; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.d16 IS 'Charakteristische Korngro?e D16, d.h. Korngro?e, die von 16 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN messung.d10; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.d10 IS 'Charakteristische Korngro?e D10, d.h. Korngro?e, die von 10 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN messung.dmin; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.dmin IS 'Letzter (kleinster) Siebdurchmesser, durch den noch Korner hindurchgegangen sind. Auf dem nachst kleineren Siebdurchmesser ist damit der Siebdruchgang = 0; Einheit: mm';


--
-- Name: COLUMN messung.durchdmin; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.durchdmin IS 'Korndurchgang auf DMIN in %; Einheit: %';


--
-- Name: COLUMN messung.dmax; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.dmax IS 'Erster (gro?ter) Siebdurchmesser, auf dem Korner liegengeblieben sind. Auf dem nachst gro?eren Siebdurchmesser ist damit der Siebruckstand = 0 bzw. der -durchgang = 100%; Einheit: mm';


--
-- Name: COLUMN messung.durchdmax; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.durchdmax IS 'Korndurchgang auf DMAX in %; Einheit: %';


--
-- Name: COLUMN messung.n_geschieb; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.n_geschieb IS 'Anzahl der Lotrechten der Geschiebemessung .Wenn keine Messung, dann Feld leer ';


--
-- Name: COLUMN messung.n_vielpkt; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.n_vielpkt IS 'Anzahl der Lotrechten der Schwebstoffmessung. Wenn keine Messung, dann Feld leer';


--
-- Name: COLUMN messung.sys_date; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.sys_date IS 'Systemdatum, an dem der Datensatz zuletzt gespeichert wurde';


--
-- Name: COLUMN messung.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.bemerkung IS 'Bemerkungen zur Messung';


--
-- Name: COLUMN messung.lastupdated; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.lastupdated IS 'Zeitpunkt der letzten Datensatz-Anderung (automatisch per Trigger)';


--
-- Name: COLUMN messung.glotabstoffset; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.glotabstoffset IS 'Beim Import der GLotrechten auf die Abstandsangaben aufgeschlagener Offset; Einheit: m';


--
-- Name: COLUMN messung.slotabstoffset; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.slotabstoffset IS 'Beim Import der SLotrechten auf die Abstandsangaben aufgeschlagener Offset; Einheit: m';


--
-- Name: COLUMN messung.gbreitevonlinks; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.gbreitevonlinks IS 'Horizontaler Abstand der linken Begrenzung der geschiebefuhrenden Breite vom Profil-Nullpunkt am linken Ufer; Einheit: m';


--
-- Name: COLUMN messung.gbreitebislinks; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.gbreitebislinks IS 'Horizontaler Abstand der rechten Begrenzung der geschiebefuhrenden Breite vom Profil-Nullpunkt am linken Ufer; Einheit: m';


--
-- Name: COLUMN messung.glotuferabstistvonlinks; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.glotuferabstistvonlinks IS 'Gibt an, ob der GLotrechte-Abstand-Bezugspunkt am linken (1) oder rechten (0) Ufer liegt';


--
-- Name: COLUMN messung.slotuferabstistvonlinks; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN messung.slotuferabstistvonlinks IS 'Gibt an, ob der SLotrechte-Abstand-Bezugspunkt am linken (1) oder rechten (0) Ufer liegt';


--
-- Name: station; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE station (
    stationid bigint NOT NULL,
    gewaesserid bigint NOT NULL,
    km double precision NOT NULL,
    bezugspegelid bigint,
    name character varying(50) NOT NULL,
    uferistlinks smallint NOT NULL,
    teil_von double precision,
    teil_bis double precision,
    abst_hmst double precision,
    l_hochwert double precision,
    l_rechwert double precision,
    l_nn double precision,
    r_hochwert double precision,
    r_rechwert double precision,
    r_nn double precision,
    bemerkung character varying(240),
    oldmstid bigint,
    istfeststoff smallint DEFAULT 1
);


--
-- Name: TABLE station; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE station IS 'Messstelle';


--
-- Name: COLUMN station.stationid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.stationid IS 'Interne ID der Messstelle (PK)';


--
-- Name: COLUMN station.gewaesserid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.gewaesserid IS 'Interne ID des Gewassers (FK Gewaesser)';


--
-- Name: COLUMN station.km; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.km IS 'Kilometerangabe der Messstelle, bezogen auf die Stationierung des Gewassers';


--
-- Name: COLUMN station.bezugspegelid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.bezugspegelid IS 'Interne ID des Bezugspegels (FK Bezugspegel)';


--
-- Name: COLUMN station.name; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.name IS 'Name der Messstelle';


--
-- Name: COLUMN station.uferistlinks; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.uferistlinks IS 'Angabe, ob der Profil-Nullpunkt am linken (1) oder rechten Ufer (0) liegt';


--
-- Name: COLUMN station.teil_von; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.teil_von IS 'Horizontaler Abstand der linken Begrenzung eines Teilprofils vom Profil-Nullpunkt; Einheit: m';


--
-- Name: COLUMN station.teil_bis; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.teil_bis IS 'Horizontaler Abstand der rechten Begrenzung eines Teilprofils vom Profil-Nullpunkt; Einheit: m';


--
-- Name: COLUMN station.abst_hmst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.abst_hmst IS 'Abstand der Hektometer-Steine (zwischen Profil-Nullpunkt und Profil-Gegenpunkt); Einheit: m';


--
-- Name: COLUMN station.l_hochwert; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.l_hochwert IS 'Angabe des Koordinaten-Hochwertes des ProfilNullpunktes in Gau?-Kruger-Koordinaten; Einheit: m';


--
-- Name: COLUMN station.l_rechwert; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.l_rechwert IS 'Angabe des Koordinaten-Rechtswertes des Profil-Null-Punktes in Gau?-Kruger-Koordinaten; Einheit: m';


--
-- Name: COLUMN station.l_nn; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.l_nn IS 'Hohe des Profil-Nullpunktes; Einheit: m u.NN';


--
-- Name: COLUMN station.r_hochwert; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.r_hochwert IS 'Angabe des Koordinaten- Hochwertes des Profil-Gegenpunktes in Gau?-Kruger-Koordinaten; Einheit: m';


--
-- Name: COLUMN station.r_rechwert; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.r_rechwert IS 'Angabe des Koordinaten-Rechtswertes des Profil-Gegenpunktes in Gau?-Kruger-Koordinaten; Einheit: m';


--
-- Name: COLUMN station.r_nn; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.r_nn IS 'Hohe des Profil-Gegenpunktes; Einheit: m u.NN';


--
-- Name: COLUMN station.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.bemerkung IS 'Bemerkungen zur Messtelle';


--
-- Name: COLUMN station.istfeststoff; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN station.istfeststoff IS 'Angabe, ob es sich um eine Feststoff- (1) oder Sohlprobe-Messstelle (0) handelt';


--
-- Name: messunguferbezug; Type: VIEW; Schema: public; Owner: -
--

CREATE VIEW messunguferbezug AS
    SELECT messung.messungid, station.uferistlinks, hpeilung.hmabst FROM ((messung JOIN station ON ((messung.stationid = station.stationid))) LEFT JOIN hpeilung ON ((messung.hpeilungid = hpeilung.hpeilungid)));


--
-- Name: mpeilpunkt; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE mpeilpunkt (
    mpeilungid bigint NOT NULL,
    punktnr integer NOT NULL,
    y double precision NOT NULL,
    z double precision NOT NULL
);


--
-- Name: TABLE mpeilpunkt; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE mpeilpunkt IS 'Koordinaten der Messungs-Querprofil-Peilung';


--
-- Name: COLUMN mpeilpunkt.mpeilungid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN mpeilpunkt.mpeilungid IS 'Interne ID der Messungs-Peilung (PK, FK MPeilung)';


--
-- Name: COLUMN mpeilpunkt.punktnr; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN mpeilpunkt.punktnr IS 'Lfd. Nummer des Punkts (PK)';


--
-- Name: COLUMN mpeilpunkt.y; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN mpeilpunkt.y IS 'Y-Koordinate (horizontale Entfernung vom Nullpunkt) des Profilpunktes. Die y-Koordinate muss aufsteigend (nicht streng) sein.; Einheit: m';


--
-- Name: COLUMN mpeilpunkt.z; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN mpeilpunkt.z IS 'Z-Koordinate (Hohe) des Profilpunktes.; Einheit: m u.NN';


--
-- Name: mpeilung; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE mpeilung (
    mpeilungid bigint NOT NULL,
    stationid bigint NOT NULL,
    datum timestamp without time zone NOT NULL,
    km double precision NOT NULL,
    bemerkung character varying(240),
    lastupdated timestamp without time zone NOT NULL,
    oldapeilid bigint
);


--
-- Name: TABLE mpeilung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE mpeilung IS 'Querprofil-Peilung wahrend einer Messung';


--
-- Name: COLUMN mpeilung.mpeilungid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN mpeilung.mpeilungid IS 'Interne ID der Messungs-Peilung (PK)';


--
-- Name: COLUMN mpeilung.stationid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN mpeilung.stationid IS 'Interne ID der Messstelle (FK Station)';


--
-- Name: COLUMN mpeilung.datum; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN mpeilung.datum IS 'Datum der Peilung';


--
-- Name: COLUMN mpeilung.km; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN mpeilung.km IS 'Kilometerangabe der Peilung, bezogen auf die Stationierung des Gewassers, ggf. abweichend von Station.Km; Einheit: km';


--
-- Name: COLUMN mpeilung.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN mpeilung.bemerkung IS 'Bemerkungen zur Querprofilpeilung';


--
-- Name: COLUMN mpeilung.lastupdated; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN mpeilung.lastupdated IS 'Zeitpunkt der letzten Datensatz-Anderung (automatisch per Trigger)';


--
-- Name: siebanalyse; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE siebanalyse (
    siebanalyseid bigint NOT NULL,
    sohlprobeid bigint NOT NULL,
    istdigital smallint NOT NULL,
    standort character varying(50),
    dm double precision,
    so double precision,
    sk double precision,
    u double precision,
    d90 double precision,
    d84 double precision,
    d80 double precision,
    d75 double precision,
    d70 double precision,
    d60 double precision,
    d50 double precision,
    d40 double precision,
    d30 double precision,
    d25 double precision,
    d20 double precision,
    d16 double precision,
    d10 double precision,
    dmin double precision,
    durchdmin real,
    dmax double precision,
    durchdmax real,
    bemerkung character varying(240)
);


--
-- Name: TABLE siebanalyse; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE siebanalyse IS 'Hauptdaten der Probenahme-Siebanalyse';


--
-- Name: COLUMN siebanalyse.siebanalyseid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.siebanalyseid IS 'Interne ID der Siebanalyse (PK)';


--
-- Name: COLUMN siebanalyse.sohlprobeid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.sohlprobeid IS 'Interne ID der Probenahme (FK Sohlprobe)';


--
-- Name: COLUMN siebanalyse.istdigital; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.istdigital IS 'Gibt an, ob die Siebanalyse digital erfasst ist (1) oder analog (0)';


--
-- Name: COLUMN siebanalyse.standort; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.standort IS 'Bezeichnung des Standorts im Archiv (nur bei IstDigital=0)';


--
-- Name: COLUMN siebanalyse.dm; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.dm IS 'Mittlerer Korndurchmesser (dm) der Sohlprobe nach Meyer-Peter und Muller; Einheit: mm';


--
-- Name: COLUMN siebanalyse.so; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.so IS 'Schiefekoeffizient (Sk) als Ma? fur die Abweichung einer Haufigkeitsverteilung von der Symmetrie';


--
-- Name: COLUMN siebanalyse.sk; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.sk IS 'Sortierungskoeffizient (S0) als Kennwert zur Charakterisierung der Verteilung des Korngemisches';


--
-- Name: COLUMN siebanalyse.u; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.u IS 'Ungleichformigkeitszahl (U) als Ma? fur die Steilheit der Summenlinie im Bereich d10 bis d60 (entsprechend DIN 18196)';


--
-- Name: COLUMN siebanalyse.d90; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.d90 IS 'Charakteristische Korngro?e D90, d.h. die Korngro?e, die von 90 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN siebanalyse.d84; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.d84 IS 'Charakteristische Korngro?e D84, d.h. die Korngro?e, die von 84 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN siebanalyse.d80; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.d80 IS 'Charakteristische Korngro?e D80, d.h. die Korngro?e, die von 80 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN siebanalyse.d75; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.d75 IS 'Charakteristische Korngro?e D75, d.h. die Korngro?e, die von 75 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN siebanalyse.d70; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.d70 IS 'Charakteristische Korngro?e D70, d.h. die Korngro?e, die von 70 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN siebanalyse.d60; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.d60 IS 'Charakteristische Korngro?e D60, d.h. die Korngro?e, die von 60 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN siebanalyse.d50; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.d50 IS 'Charakteristische Korngro?e D50, d.h. die Korngro?e, die von 50 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN siebanalyse.d40; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.d40 IS 'Charakteristische Korngro?e D40, d.h. die Korngro?e, die von 40 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN siebanalyse.d30; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.d30 IS 'Charakteristische Korngro?e D30, d.h. die Korngro?e, die von 30 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN siebanalyse.d25; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.d25 IS 'Charakteristische Korngro?e D25, d.h. die Korngro?e, die von 25 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN siebanalyse.d20; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.d20 IS 'Charakteristische Korngro?e D20, d.h. die Korngro?e, die von 20 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN siebanalyse.d16; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.d16 IS 'Charakteristische Korngro?e D16, d.h. die Korngro?e, die von 16 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN siebanalyse.d10; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.d10 IS 'Charakteristische Korngro?e D10, d.h. die Korngro?e, die von 10 Prozent der Probenmasse unterschritten wird.; Einheit: mm';


--
-- Name: COLUMN siebanalyse.dmin; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.dmin IS 'Letzter (kleinster) Siebdurchmesser, durch den noch Korner hindurchgegangen sind. Auf dem nachst kleineren Siebdurchmesser ist damit der Siebdurchgang = 0; Einheit: mm';


--
-- Name: COLUMN siebanalyse.durchdmin; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.durchdmin IS 'Anteiliger Korndurchgang auf DMIN; Einheit: %';


--
-- Name: COLUMN siebanalyse.dmax; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.dmax IS 'Erster (gro?ter) Siebdurchmesser, auf dem Korner liegengeblieben sind. Auf dem nachst gro?eren Siebdurchmesser ist damit der Siebruckstand = 0 bzw. der -durchgang = 100%; Einheit: mm';


--
-- Name: COLUMN siebanalyse.durchdmax; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.durchdmax IS 'Anteiliger Korndurchgang auf DMAX; Einheit: %';


--
-- Name: COLUMN siebanalyse.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN siebanalyse.bemerkung IS 'Bemerkungen zur Siebanalyse';


--
-- Name: slotrechte; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE slotrechte (
    slotrechteid bigint NOT NULL,
    messungid bigint NOT NULL,
    uferabst double precision NOT NULL,
    tsand double precision,
    tschweb double precision,
    fv real,
    vm real,
    tiefe double precision,
    vsohle real,
    bemerkung character varying(240),
    uferablinks double precision
);


--
-- Name: TABLE slotrechte; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE slotrechte IS 'Lotrechte der Schwebstoff-Messung';


--
-- Name: COLUMN slotrechte.slotrechteid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN slotrechte.slotrechteid IS 'Interne ID der Geschiebe-Lotrechten (PK)';


--
-- Name: COLUMN slotrechte.messungid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN slotrechte.messungid IS 'Interne ID der Messung (FK Messung)';


--
-- Name: COLUMN slotrechte.uferabst; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN slotrechte.uferabst IS 'Horizontaler Abstand der Lotrechten vom linken oder rechten Hektometerstein.; Einheit: m';


--
-- Name: COLUMN slotrechte.tsand; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN slotrechte.tsand IS 'Sandtrieb (Anteil der Sandfraktion am Schwebstofftrieb); Einheit: g/(s*m)';


--
-- Name: COLUMN slotrechte.tschweb; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN slotrechte.tschweb IS 'Schwebstofftrieb einer Lotrechten; Einheit: g/(s*m)';


--
-- Name: COLUMN slotrechte.fv; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN slotrechte.fv IS 'Geschwindiglkeitsflache einer Lotrechte; Einheit: m^2/s';


--
-- Name: COLUMN slotrechte.vm; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN slotrechte.vm IS 'Mittlere Geschwindigkeit in einer Lotrechten; Einheit: m/s';


--
-- Name: COLUMN slotrechte.tiefe; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN slotrechte.tiefe IS 'Wassertiefe in der Lotrechten; Einheit: m';


--
-- Name: COLUMN slotrechte.vsohle; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN slotrechte.vsohle IS 'Berechnete Geschwindigkeit an der Sohle einer Lotrechten; Einheit: m/s';


--
-- Name: COLUMN slotrechte.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN slotrechte.bemerkung IS 'Bemerkungen zur Lotrechten';


--
-- Name: COLUMN slotrechte.uferablinks; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN slotrechte.uferablinks IS 'Abstand der Lotrechte vom Nullpunkt am linken Ufer; Einheit: m';


--
-- Name: sohlprobe; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE sohlprobe (
    sohlprobeid bigint NOT NULL,
    sohltestid bigint NOT NULL,
    probenahmeartid bigint NOT NULL,
    tiefevon double precision,
    tiefebis double precision,
    beschreibung character varying(1024),
    lastupdated timestamp without time zone NOT NULL
);


--
-- Name: TABLE sohlprobe; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE sohlprobe IS 'Sohlprobe';


--
-- Name: COLUMN sohlprobe.sohlprobeid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohlprobe.sohlprobeid IS 'Interne ID der Sohlprobe (PK)';


--
-- Name: COLUMN sohlprobe.sohltestid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohlprobe.sohltestid IS 'Interne ID der Punktuntersuchung (FK Sohltest)';


--
-- Name: COLUMN sohlprobe.probenahmeartid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohlprobe.probenahmeartid IS 'ID der Art der Probenahme (FK zzProbenahmeArt)';


--
-- Name: COLUMN sohlprobe.tiefevon; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohlprobe.tiefevon IS 'Abstand der Oberkante des Probenahme-Bereichs von der Gewassersohle; Einheit: m';


--
-- Name: COLUMN sohlprobe.tiefebis; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohlprobe.tiefebis IS 'Abstand der Unterkante des Probenahme-Bereichs von der Gewassersohle; Einheit: m';


--
-- Name: COLUMN sohlprobe.beschreibung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohlprobe.beschreibung IS 'Beschreibung der Sohlprobe';


--
-- Name: COLUMN sohlprobe.lastupdated; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohlprobe.lastupdated IS 'Zeitpunkt der letzten Anderung des Datensatzes (per Trigger gesetzt)';


--
-- Name: sohltest; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE sohltest (
    sohltestid bigint NOT NULL,
    stationid bigint NOT NULL,
    sondierungartid bigint,
    archivid bigint,
    datum timestamp without time zone NOT NULL,
    istnurjahr smallint NOT NULL,
    km double precision,
    abstand double precision NOT NULL,
    abstistvonlinks smallint NOT NULL,
    abstbezug smallint NOT NULL,
    abstoffset double precision NOT NULL,
    abstlinks double precision,
    rechts double precision,
    hoch double precision,
    hoehe double precision,
    bemerkung character varying(240),
    sohlebeschreib character varying(1024),
    sondierungbeschreib character varying(1024),
    lastupdated timestamp without time zone NOT NULL
);


--
-- Name: TABLE sohltest; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE sohltest IS 'Sohle-Punktuntersuchung';


--
-- Name: COLUMN sohltest.sohltestid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.sohltestid IS 'Interne ID der Punktuntersuchung (PK)';


--
-- Name: COLUMN sohltest.stationid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.stationid IS 'Interne ID der Messstelle (FK Station)';


--
-- Name: COLUMN sohltest.sondierungartid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.sondierungartid IS 'ID der Art der Sondierung (FK zzSondierungArt)';


--
-- Name: COLUMN sohltest.archivid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.archivid IS 'ID des Archivs der Probenahme-Daten (FK zzArchiv';


--
-- Name: COLUMN sohltest.datum; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.datum IS 'Datum der Punktuntersuchung';


--
-- Name: COLUMN sohltest.istnurjahr; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.istnurjahr IS 'Gibt an, ob im Feld Datum nur das Jahr den Zeitpunkt der Punktuntersuchung angibt (1) oder das komplette Datum gultig ist (0)';


--
-- Name: COLUMN sohltest.km; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.km IS 'Kilometerangabe der Probestelle bezogen auf die Stationierung des Gewassers, ggf. abweichend von Station.Km';


--
-- Name: COLUMN sohltest.abstand; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.abstand IS 'Abstand der Probestelle vom Bezugspunkt gema? AbstIstVonLinks und AbstIstHM; Einheit: m';


--
-- Name: COLUMN sohltest.abstistvonlinks; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.abstistvonlinks IS 'Gibt an, ob der Abstand-Bezugspunkt am linken (1) oder rechten (0) Ufer liegt';


--
-- Name: COLUMN sohltest.abstbezug; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.abstbezug IS 'Abstand-Bezugspunkt: Hektometerstein=1, Sichtzeichen=0, Ordnungsprofilpunkt=2';


--
-- Name: COLUMN sohltest.abstoffset; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.abstoffset IS 'Abstand des Bezugspunkts vom Pegelnullpunkt; Einheit: m';


--
-- Name: COLUMN sohltest.abstlinks; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.abstlinks IS 'Abstand der Probestelle vom Nullpunkt am linken Ufer; Einheit: m';


--
-- Name: COLUMN sohltest.rechts; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.rechts IS 'Koordinaten-Rechtswert der Probenahmestelle in Gau?-Kruger-Koordinaten; Einheit: m';


--
-- Name: COLUMN sohltest.hoch; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.hoch IS 'Koordinaten-Hochwert der Probenahmestelle in Gau?-Kruger-Koordinaten; Einheit: m';


--
-- Name: COLUMN sohltest.hoehe; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.hoehe IS 'Hohe der Probenahmestelle; Einheit: m+NN';


--
-- Name: COLUMN sohltest.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.bemerkung IS 'Anmerkung zur Punktuntersuchung';


--
-- Name: COLUMN sohltest.sohlebeschreib; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.sohlebeschreib IS 'Beschreibung der Sohle';


--
-- Name: COLUMN sohltest.sondierungbeschreib; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.sondierungbeschreib IS 'Beschreibung der Sondierung';


--
-- Name: COLUMN sohltest.lastupdated; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sohltest.lastupdated IS 'Zeitpunkt der letzten Anderung des Datensatzes (per Trigger gesetzt)';


--
-- Name: sprobe; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE sprobe (
    slotrechteid bigint NOT NULL,
    lfdnr integer NOT NULL,
    wprozpkt smallint NOT NULL,
    wpkt double precision NOT NULL,
    vpkt real NOT NULL,
    csandpkt double precision NOT NULL,
    cschwebpkt double precision NOT NULL,
    sandtrieb double precision,
    schwebtrieb double precision
);


--
-- Name: COLUMN sprobe.slotrechteid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sprobe.slotrechteid IS 'Interne ID der Lotrechten (PK, FK SLotrechte)';


--
-- Name: COLUMN sprobe.lfdnr; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sprobe.lfdnr IS 'Lfd. Nr. des Messpunkts (PK)';


--
-- Name: COLUMN sprobe.wprozpkt; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sprobe.wprozpkt IS 'Tiefe des Messpunktes unter dem Wasserspiegel in % der Gesamttiefe (z.B. 60, 80 (evtl. 90) Prozent unter Wasserspiegel ); Einheit: %';


--
-- Name: COLUMN sprobe.wpkt; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sprobe.wpkt IS 'Tiefe des Messpunktes unter dem Wasserspiegel in m; Einheit: m';


--
-- Name: COLUMN sprobe.vpkt; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sprobe.vpkt IS 'Geschwindigkeit im Messpunkt; Einheit: m/s';


--
-- Name: COLUMN sprobe.csandpkt; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sprobe.csandpkt IS 'Konzentration des suspendierten Sandes im Messpunkt; Einheit: g/m^3';


--
-- Name: COLUMN sprobe.cschwebpkt; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sprobe.cschwebpkt IS 'Gesamtschwebstoff-Konzentration im Messpunkt; Einheit: g/m^3';


--
-- Name: COLUMN sprobe.sandtrieb; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sprobe.sandtrieb IS 'Berechneter Sandtrieb; Einheit: g/s*m';


--
-- Name: COLUMN sprobe.schwebtrieb; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN sprobe.schwebtrieb IS 'Berechneter Schwebstofftrieb; Einheit: g/s*m';


--
-- Name: sq_bil; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_bil
    START WITH 10280
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_bil; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_bil', 10280, false);


--
-- Name: sq_bpg; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_bpg
    START WITH 111
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_bpg; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_bpg', 111, false);


--
-- Name: sq_gew; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_gew
    START WITH 628
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_gew; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_gew', 628, false);


--
-- Name: sq_gfn; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_gfn
    START WITH 44
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_gfn; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_gfn', 44, false);


--
-- Name: sq_glo; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_glo
    START WITH 37539
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_glo; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_glo', 37539, false);


--
-- Name: sq_gss; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_gss
    START WITH 360
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_gss; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_gss', 360, false);


--
-- Name: sq_hpe; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_hpe
    START WITH 1454
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_hpe; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_hpe', 1454, false);


--
-- Name: sq_mes; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_mes
    START WITH 11411
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_mes; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_mes', 11411, false);


--
-- Name: sq_mpe; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_mpe
    START WITH 581
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_mpe; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_mpe', 581, false);


--
-- Name: sq_rfu; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_rfu
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_rfu; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_rfu', 1, false);


--
-- Name: sq_sia; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_sia
    START WITH 15227
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_sia; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_sia', 15227, false);


--
-- Name: sq_slo; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_slo
    START WITH 14394
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_slo; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_slo', 14394, false);


--
-- Name: sq_sop; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_sop
    START WITH 25247
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_sop; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_sop', 25247, false);


--
-- Name: sq_sot; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_sot
    START WITH 15463
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_sot; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_sot', 15463, false);


--
-- Name: sq_sta; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_sta
    START WITH 3820
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_sta; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_sta', 3820, false);


--
-- Name: sq_zar; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_zar
    START WITH 10
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_zar; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_zar', 10, false);


--
-- Name: sq_zpa; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_zpa
    START WITH 20
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_zpa; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_zpa', 20, false);


--
-- Name: sq_zsa; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_zsa
    START WITH 10
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_zsa; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_zsa', 10, false);


--
-- Name: sq_zth; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sq_zth
    START WITH 10
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 20;


--
-- Name: sq_zth; Type: SEQUENCE SET; Schema: public; Owner: -
--

SELECT pg_catalog.setval('sq_zth', 10, false);


--
-- Name: ssiebung; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE ssiebung (
    siebanalyseid bigint NOT NULL,
    gsiebsatzid bigint NOT NULL,
    gmasse double precision,
    rsieb01 double precision,
    rsieb02 double precision,
    rsieb03 double precision,
    rsieb04 double precision,
    rsieb05 double precision,
    rsieb06 double precision,
    rsieb07 double precision,
    rsieb08 double precision,
    rsieb09 double precision,
    rsieb10 double precision,
    rsieb11 double precision,
    rsieb12 double precision,
    rsieb13 double precision,
    rsieb14 double precision,
    rsieb15 double precision,
    rsieb16 double precision,
    rsieb17 double precision,
    rsieb18 double precision,
    rsieb19 double precision,
    rsieb20 double precision,
    rsieb21 double precision,
    rest double precision,
    CONSTRAINT ssi_sieb01 CHECK ((rsieb01 = (0)::double precision))
);


--
-- Name: TABLE ssiebung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE ssiebung IS 'Siebdaten der Siebanalyse';


--
-- Name: COLUMN ssiebung.siebanalyseid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.siebanalyseid IS 'Interne ID der Siebanalyse (PK, FK Siebanalyse)';


--
-- Name: COLUMN ssiebung.gsiebsatzid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.gsiebsatzid IS 'Interne ID des Siebsatzes (FK GSiebsatz); Einheit: g';


--
-- Name: COLUMN ssiebung.gmasse; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.gmasse IS 'Gesamtgewicht der Probe ("Einwaage"); Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb01; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb01 IS 'Siebruckstand (Masse) auf Sieb 01 (immer Null); Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb02; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb02 IS 'Siebruckstand (Masse) auf Sieb 02; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb03; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb03 IS 'Siebruckstand (Masse) auf Sieb 03; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb04; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb04 IS 'Siebruckstand (Masse) auf Sieb 04; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb05; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb05 IS 'Siebruckstand (Masse) auf Sieb 05; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb06; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb06 IS 'Siebruckstand (Masse) auf Sieb 06; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb07; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb07 IS 'Siebruckstand (Masse) auf Sieb 07; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb08; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb08 IS 'Siebruckstand (Masse) auf Sieb 08; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb09; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb09 IS 'Siebruckstand (Masse) auf Sieb 09; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb10; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb10 IS 'Siebruckstand (Masse) auf Sieb 10; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb11; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb11 IS 'Siebruckstand (Masse) auf Sieb 11; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb12; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb12 IS 'Siebruckstand (Masse) auf Sieb 12; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb13; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb13 IS 'Siebruckstand (Masse) auf Sieb 13; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb14; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb14 IS 'Siebruckstand (Masse) auf Sieb 14; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb15; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb15 IS 'Siebruckstand (Masse) auf Sieb 15; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb16; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb16 IS 'Siebruckstand (Masse) auf Sieb 16; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb17; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb17 IS 'Siebruckstand (Masse) auf Sieb 17; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb18; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb18 IS 'Siebruckstand (Masse) auf Sieb 18; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb19; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb19 IS 'Siebruckstand (Masse) auf Sieb 19; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb20; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb20 IS 'Siebruckstand (Masse) auf Sieb 20; Einheit: g';


--
-- Name: COLUMN ssiebung.rsieb21; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rsieb21 IS 'Siebruckstand (Masse) auf Sieb 21; Einheit: g';


--
-- Name: COLUMN ssiebung.rest; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN ssiebung.rest IS 'Siebungsrest. Differenz aus den aufsummierten Siebruckstanden und der "Einwaage" (Gesamtgewicht der Probe); Einheit: g';


--
-- Name: stationgew; Type: VIEW; Schema: public; Owner: -
--

CREATE VIEW stationgew AS
    SELECT station.stationid, station.gewaesserid, station.km, station.bezugspegelid, station.name, station.uferistlinks, station.teil_von, station.teil_bis, station.abst_hmst, station.l_hochwert, station.l_rechwert, station.l_nn, station.r_hochwert, station.r_rechwert, station.r_nn, station.bemerkung, station.oldmstid, station.istfeststoff, gewaesser.name AS gewname FROM (station JOIN gewaesser ON ((station.gewaesserid = gewaesser.gewaesserid)));


--
-- Name: tmp_glo_changed; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE tmp_glo_changed (
    glotrechteid bigint NOT NULL
);


--
-- Name: TABLE tmp_glo_changed; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE tmp_glo_changed IS 'Liste der GLotrechteIDs, fur die GProbe-Aggregation zu rechnen ist';


--
-- Name: tmp_mes_achanged; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE tmp_mes_achanged (
    messungid bigint NOT NULL
);


--
-- Name: TABLE tmp_mes_achanged; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE tmp_mes_achanged IS 'Liste der MessungIDs, fur die die geometrischen Parameter zu rechnen sind';


--
-- Name: tmp_mes_gchanged; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE tmp_mes_gchanged (
    messungid bigint NOT NULL
);


--
-- Name: TABLE tmp_mes_gchanged; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE tmp_mes_gchanged IS 'Liste der MessungIDs, fur die GLotrechte-Aggregation zu rechnen ist';


--
-- Name: tmp_mes_qchanged; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE tmp_mes_qchanged (
    messungid bigint NOT NULL
);


--
-- Name: TABLE tmp_mes_qchanged; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE tmp_mes_qchanged IS 'Liste der MessungIDs, fur die SLotrechte-Aggregation der Hydraulik zu rechnen ist';


--
-- Name: tmp_mes_schanged; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE tmp_mes_schanged (
    messungid bigint NOT NULL
);


--
-- Name: TABLE tmp_mes_schanged; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE tmp_mes_schanged IS 'Liste der MessungIDs, fur die SLotrechte-Aggregation zu rechnen ist';


--
-- Name: zzarchiv; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE zzarchiv (
    archivid bigint NOT NULL,
    name character varying(50) NOT NULL,
    istaktiv smallint NOT NULL,
    bemerkung character varying(240)
);


--
-- Name: TABLE zzarchiv; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE zzarchiv IS 'Werteliste der Archive, z.B. BfG Koblenz, WSA Bingen';


--
-- Name: COLUMN zzarchiv.archivid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzarchiv.archivid IS 'Interne ID (PK)';


--
-- Name: COLUMN zzarchiv.name; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzarchiv.name IS 'Bezeichnung des Archivs';


--
-- Name: COLUMN zzarchiv.istaktiv; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzarchiv.istaktiv IS 'Gibt an, ob das Archiv in der Auswahlliste beim Anlegen einer neuen Probenahme zur Auswahl angezeigt werden soll';


--
-- Name: COLUMN zzarchiv.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzarchiv.bemerkung IS 'Anmerkungen zum Archiv';


--
-- Name: zzprobenahmeart; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE zzprobenahmeart (
    probenahmeartid bigint NOT NULL,
    istkern smallint NOT NULL,
    name character varying(50) NOT NULL,
    istaktiv smallint NOT NULL,
    bemerkung character varying(240)
);


--
-- Name: TABLE zzprobenahmeart; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE zzprobenahmeart IS 'Werteliste der Probenahme-Arten, z.B. Taucherschacht, Greifer';


--
-- Name: COLUMN zzprobenahmeart.probenahmeartid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzprobenahmeart.probenahmeartid IS 'Interne ID (PK)';


--
-- Name: COLUMN zzprobenahmeart.istkern; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzprobenahmeart.istkern IS 'Gibt an, ob die Art eine Kernentnahme beschreibt (1) oder eine Probe an der Sohle (0)';


--
-- Name: COLUMN zzprobenahmeart.name; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzprobenahmeart.name IS 'Bezeichnung der Probenahme-Art';


--
-- Name: COLUMN zzprobenahmeart.istaktiv; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzprobenahmeart.istaktiv IS 'Gibt an, ob die Probenahme-Art in der Auswahlliste beim Anlegen einer neuen Probenahme zur Auswahl angezeigt werden soll';


--
-- Name: COLUMN zzprobenahmeart.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzprobenahmeart.bemerkung IS 'Anmerkungen zur Probenahme-Art';


--
-- Name: zzsondierungart; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE zzsondierungart (
    sondierungartid bigint NOT NULL,
    name character varying(50) NOT NULL,
    istaktiv smallint NOT NULL,
    bemerkung character varying(240)
);


--
-- Name: TABLE zzsondierungart; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE zzsondierungart IS 'Werteliste der Sondierungs-Arten, z.B. Ramm, Purckhauer';


--
-- Name: COLUMN zzsondierungart.sondierungartid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzsondierungart.sondierungartid IS 'Interne ID (PK)';


--
-- Name: COLUMN zzsondierungart.name; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzsondierungart.name IS 'Bezeichnung der Sondierungs-Art';


--
-- Name: COLUMN zzsondierungart.istaktiv; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzsondierungart.istaktiv IS 'Gibt an, ob die Sondierugs-Art in der Auswahlliste beim Anlegen einer neuen Probenahme zur Auswahl angezeigt werden soll';


--
-- Name: COLUMN zzsondierungart.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzsondierungart.bemerkung IS 'Anmerkungen zur Sondierungs-Art';


--
-- Name: zzthema; Type: TABLE; Schema: public; Owner: -; Tablespace: 
--

CREATE TABLE zzthema (
    themaid bigint NOT NULL,
    name character varying(50) NOT NULL,
    istaktiv smallint NOT NULL,
    bemerkung character varying(240)
);


--
-- Name: TABLE zzthema; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE zzthema IS 'Werteliste der Bild-Themen, z.B. Sohle-Gesamtsicht, Probe, Kern, Landschaft';


--
-- Name: COLUMN zzthema.themaid; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzthema.themaid IS 'Interne ID (PK)';


--
-- Name: COLUMN zzthema.name; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzthema.name IS 'Bezeichnung des Themas';


--
-- Name: COLUMN zzthema.istaktiv; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzthema.istaktiv IS 'Gibt an, ob das Thema in der Auswahlliste beim Anlegen einer neuen Probenahme zur Auswahl angezeigt werden soll';


--
-- Name: COLUMN zzthema.bemerkung; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN zzthema.bemerkung IS 'Anmerkungen zum Thema';


--
-- Data for Name: bezugspegel; Type: TABLE DATA; Schema: public; Owner: -
--

COPY bezugspegel (bezugspegelid, gewaesserid, km, name, nullpunkt, kennung, einzugsgebiet, inbetrieb, fliesscharakter, laufentwicklung, mnq, mq, mhq, nnq, hhq, nnqdatum, hhqdatum, jahresreihe, bemerkung) FROM stdin;
18	2	46.199999999999989	Torgau	74.989999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
23	2	105.69999999999999	Wittenberg	62.479999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
24	2	166.29999999999998	Aken	50.240000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
\.


--
-- Data for Name: gewaesser; Type: TABLE DATA; Schema: public; Owner: -
--

COPY gewaesser (gewaesserid, name, kennung, laenge, einzugsgebiet, bemerkung) FROM stdin;
2	Beispielfluss	\N	\N	\N	\N
\.


--
-- Data for Name: gfaenger; Type: TABLE DATA; Schema: public; Owner: -
--

COPY gfaenger (gfaengerid, istaktiv, name, breite, maschenweite, bemerkung) FROM stdin;
1	1	BfG-Fänger alt	0.155	1	\N
2	1	BfG-Fänger neu grob	0.16	1.3999999999999999	\N
3	1	BfG-Fänger neu fein	0.16	0.5	\N
\.


--
-- Data for Name: glotrechte; Type: TABLE DATA; Schema: public; Owner: -
--

COPY glotrechte (glotrechteid, messungid, uferabst, tgeschiebe, dm, sk, so, u, d90, d84, d80, d75, d70, d60, d50, d40, d30, d25, d20, d16, d10, dmin, durchdmin, dmax, durchdmax, stdabw, stdfehler, bemerkung, uferablinks) FROM stdin;
10868	2069	80	13.951000000000001	3.0019	1.1970000000000001	2.9260000000000002	4.3570000000000002	7.0933000000000002	5.5823999999999998	4.8464	3.9594	3.4518	2.4365000000000001	1.7432000000000001	1.2927999999999999	0.9304	0.83089999999999997	0.73150000000000004	0.65190000000000003	0.55920000000000003	0.25	0.1	10	96.599998	11.362	6.5599999999999996	\N	80
10869	2069	90	57.558	2.9834999999999998	1.1200000000000001	1.9670000000000001	2.7799999999999998	5.8688000000000002	3.9481000000000002	3.6882999999999999	3.3635999999999999	3.0390000000000001	2.3896000000000002	1.8969	1.6392	1.3814	1.2525999999999999	1.1236999999999999	1.0206	0.85960000000000003	0.25	0.1	10	95.5	115.485	66.674999999999997	\N	90
10870	2069	100	28.812000000000001	3.5322	1.2909999999999999	2.9260000000000002	4.5919999999999996	8.3606999999999996	6.5880999999999998	5.7999999999999998	4.9667000000000003	4.1333000000000002	3.0213000000000001	1.9818	1.5273000000000001	1.0727	0.93679999999999997	0.84379999999999999	0.76939999999999997	0.65790000000000004	0.25	0.1	10	95	22.321999999999999	12.887	\N	100
10871	2069	130	25.427	0.77470000000000006	0.88	1.3779999999999999	1.746	0.65180000000000005	0.60750000000000004	0.5917	0.57189999999999996	0.55220000000000002	0.51259999999999994	0.46999999999999997	0.4259	0.38179999999999997	0.35980000000000001	0.3377	0.3201	0.29370000000000002	0.25	0.1	10	99.699997	74.034000000000006	37.017000000000003	\N	130
10872	2069	140	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	140
10863	2068	71	24.395	4.3575999999999997	1.224	2.899	4.5899999999999999	10.4762	8.4057999999999993	7.1159999999999997	5.7845000000000004	4.7930999999999999	3.4828000000000001	2.6206999999999998	1.8955	1.5224	1.3358000000000001	1.1493	1	0.75870000000000004	0.5	2.5	10	89.5	67.363	33.682000000000002	\N	71
10864	2068	91	37.485999999999997	3.6126999999999998	1.099	2.2189999999999999	3.1400000000000001	7.5673000000000004	6.0007000000000001	5.3704999999999998	4.5829000000000004	3.9133	3.2467000000000001	2.5800000000000001	1.9599	1.6512	1.4968999999999999	1.3426	1.2191000000000001	1.034	0.5	0.5	10	96	19.733000000000001	11.393000000000001	\N	91
10865	2068	101	39.021000000000001	4.2634999999999996	0.89100000000000001	2.3029999999999999	3.7599999999999998	8.7077000000000009	7.0884	6.2000000000000002	5.5750000000000002	4.9500000000000002	3.8571	3.2618999999999998	2.6667000000000001	2.0714000000000001	1.8030999999999999	1.544	1.3368	1.0259	0.5	0.60000002	10	94.199997	79.194000000000003	39.597000000000001	\N	101
10866	2068	131	1.653	7.0948000000000002	0.193	4.5819999999999999	17.745999999999999	15.592599999999999	12.9481	11.1852	9.7249999999999996	9.1300000000000008	7.9244000000000003	6.4259000000000004	5.1604999999999999	3.8609	2.8260999999999998	1.6571	0.61670000000000003	0.4466	0.25	0.41999999	10	77.310997	0.63800000000000001	0.36799999999999999	\N	131
10867	2068	141	2.552	5.7798999999999996	0.25600000000000001	5.5090000000000003	17.300000000000001	15.2706	12.4329	10.5412	9.1388999999999996	8.0221999999999998	6.0010000000000003	4.46	2.4333	0.58779999999999999	0.50609999999999999	0.4516	0.40970000000000001	0.34689999999999999	0.25	0.74599999	10	78.856003	1.016	0.71899999999999997	\N	141
10858	2067	84	3.8260000000000001	4.7999999999999998	0.71599999999999997	3.1850000000000001	6.359	11.837	8.8521999999999998	7.7003000000000004	6.4678000000000004	5.6951000000000001	4.2948000000000004	3.2839999999999998	2.3769999999999998	1.6341000000000001	1.321	1.008	0.87260000000000004	0.6754	0.25	0.090999998	10	87.75	6.7699999999999996	3.9079999999999999	\N	84
10859	2067	98	17.920000000000002	3.0133999999999999	0.88700000000000001	2.3780000000000001	3.8980000000000001	6.0079000000000002	4.9127000000000001	4.1825000000000001	3.7507999999999999	3.4392999999999998	2.8161999999999998	2.1930999999999998	1.7294	1.3372999999999999	1.1412	0.96589999999999998	0.86860000000000004	0.72250000000000003	0.25	0.1	10	97.099998	19.544	11.284000000000001	\N	98
10860	2067	112	29.68	2.4990999999999999	2.75	2.8210000000000002	3.2490000000000001	6.0190999999999999	4.9656000000000002	4.2633999999999999	3.5706000000000002	2.9571000000000001	1.8308	1.0615000000000001	0.89559999999999995	0.78210000000000002	0.72529999999999994	0.66859999999999997	0.624	0.5635	0.25	0.1	10	98.199997	81.171999999999997	40.585999999999999	\N	112
10861	2067	126	5.7530000000000001	1.9044000000000001	4.5270000000000001	3.3580000000000001	2.3639999999999999	5.6807999999999996	4.3537999999999997	3.4483000000000001	2.2989000000000002	1.3621000000000001	0.79120000000000001	0.60940000000000005	0.55649999999999999	0.50370000000000004	0.4632	0.4204	0.3861	0.33479999999999999	0.25	0.1	10	98.599998	5.5540000000000003	3.206	\N	126
10862	2067	140	0.089999999999999997	7.0999999999999996	1.0549999999999999	1.8919999999999999	2.5579999999999998	14.800000000000001	11.68	9.5999999999999996	7.8582999999999998	7.4900000000000002	6.7533000000000003	6.0125000000000002	5.2649999999999997	4.5175000000000001	4.1436999999999999	3.6800000000000002	3.2639999999999998	2.6400000000000001	2	3.846	10	80.768997	0	0	\N	140
10851	2066	72	1.8069999999999999	7.0903999999999998	1.1220000000000001	2.0339999999999998	2.6819999999999999	15.1698	12.271699999999999	10.339600000000001	8.9524000000000008	7.8600000000000003	6.5800000000000001	5.6947000000000001	4.9199999999999999	4.1452999999999998	3.7332999999999998	3.3067000000000002	2.9653	2.4533	1	0.78100002	10	79.296997	0.125	0.088999999999999996	\N	72
10852	2066	81	7.7779999999999996	3.7273999999999998	1.2250000000000001	2.6589999999999998	3.9969999999999999	8.3720999999999997	6.2042999999999999	5.3799999999999999	4.3495999999999997	3.7319	2.9203000000000001	2.1086999999999998	1.6871	1.3258000000000001	1.1452	0.97589999999999999	0.87780000000000002	0.73070000000000002	0.25	0.089000002	20	98.838997	14.205	8.2010000000000005	\N	81
10853	2066	91	38.506999999999998	2.3351000000000002	1.3340000000000001	2.4279999999999999	3.0190000000000001	5.5138999999999996	3.907	3.4419	2.8605	2.2791000000000001	1.7379	1.3931	1.0483	0.87170000000000003	0.79710000000000003	0.72250000000000003	0.66279999999999994	0.57569999999999999	0.25	0.1	10	98.099998	48.734000000000002	28.135999999999999	\N	91
10854	2066	101	33.151000000000003	2.9308999999999998	1.3919999999999999	2.2650000000000001	2.883	6.4545000000000003	4.9856999999999996	4.0468999999999999	3.6113	3.2065000000000001	2.3967999999999998	1.8653999999999999	1.6015999999999999	1.3376999999999999	1.2058	1.0739000000000001	0.97189999999999999	0.83140000000000003	0.5	0.30000001	10	97.900002	129.09100000000001	64.546000000000006	\N	101
10855	2066	121	17.652999999999999	1.5105	3.4340000000000002	2.8490000000000002	1.8560000000000001	5.1677	2.7143000000000002	0.94220000000000004	0.65310000000000001	0.60829999999999995	0.56120000000000003	0.5141	0.46260000000000001	0.40920000000000001	0.38250000000000001	0.35580000000000001	0.33439999999999998	0.3024	0.25	0.2	10	98.400002	8.6940000000000008	5.0199999999999996	\N	121
10856	2066	131	6.7430000000000003	1.9492	4.7210000000000001	3.4409999999999998	2.29	5.6555999999999997	4.4484000000000004	3.6928999999999998	2.8258999999999999	1.9342999999999999	0.75180000000000002	0.59499999999999997	0.54300000000000004	0.4864	0.44690000000000002	0.4073	0.37569999999999998	0.32829999999999998	0.25	0.103	10	98.661003	6.04	3.4870000000000001	\N	131
10857	2066	141	0.091999999999999998	6.8815	0.23499999999999999	5.048	16.219000000000001	16.283799999999999	14.0541	12.567600000000001	10.7095	8.2563999999999993	6.9279000000000002	5.7435999999999998	4.4817999999999998	2.9887999999999999	2.1709999999999998	0.78239999999999998	0.55149999999999999	0.42720000000000002	0.25	0.273	10	73.091003	0	0	\N	141
10846	2065	68	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	68
10847	2065	88	6.4740000000000002	1.1378999999999999	1.3109999999999999	1.577	1.6220000000000001	1.8471	1.6823999999999999	1.5725	1.4353	1.298	1.0235000000000001	0.93140000000000001	0.85629999999999995	0.78120000000000001	0.74370000000000003	0.70609999999999995	0.67610000000000003	0.63109999999999999	0.25	0.14300001	4	99.713997	6.8129999999999997	4.8179999999999996	\N	88
10848	2065	108	1.51	0.99729999999999996	1.2450000000000001	2.0270000000000001	2.4860000000000002	1.9221999999999999	1.5955999999999999	1.3777999999999999	1.1055999999999999	0.96089999999999998	0.83320000000000005	0.7056	0.5958	0.51200000000000001	0.46829999999999999	0.4239	0.38840000000000002	0.33510000000000001	0.25	0.40799999	6.2999999999999998	99.592003	0.83999999999999997	0.59399999999999997	\N	108
10849	2065	128	26.16	3.4283999999999999	3.7989999999999999	4.1369999999999996	5.8769999999999998	9.7317999999999998	7.2859999999999996	6.0789999999999997	4.9527000000000001	3.8649	2.1122999999999998	0.90349999999999997	0.62060000000000004	0.55079999999999996	0.51590000000000003	0.46989999999999998	0.42570000000000002	0.3594	0.25	0.1	10	90.591003	86.909999999999997	50.177	\N	128
10850	2065	148	1.2290000000000001	0.39550000000000002	0.94099999999999995	1.282	1.5009999999999999	0.48230000000000001	0.4662	0.45550000000000002	0.442	0.42859999999999998	0.40179999999999999	0.375	0.34820000000000001	0.32140000000000002	0.308	0.29449999999999998	0.2838	0.26769999999999999	0.25	3.3900001	2	99.434998	0	0	\N	148
10841	2064	76	0.056000000000000001	1.4590000000000001	1.7370000000000001	2.1219999999999999	2.4359999999999999	3.2000000000000002	2.7200000000000002	2.3999999999999999	2	1.7778	1.3332999999999999	0.97260000000000002	0.86299999999999999	0.75329999999999997	0.69850000000000001	0.64370000000000005	0.60399999999999998	0.54730000000000001	0.5	5	2	75	0	0	\N	76
10842	2064	86	1.7290000000000001	1.1989000000000001	1.276	1.6220000000000001	1.8680000000000001	1.9056	1.7488999999999999	1.6444000000000001	1.5139	1.3833	1.1222000000000001	0.95469999999999999	0.86939999999999995	0.78420000000000001	0.74150000000000005	0.69889999999999997	0.66479999999999995	0.6008	0.5	3.404	4	99.149002	0.38300000000000001	0.27100000000000002	\N	86
10843	2064	96	15.978999999999999	1.6125	1.353	1.716	2.1019999999999999	3.3279000000000001	1.9916	1.8741000000000001	1.7272000000000001	1.5803	1.2865	0.99760000000000004	0.90310000000000001	0.80859999999999999	0.76129999999999998	0.71399999999999997	0.67620000000000002	0.61199999999999999	0.5	3.1029999	8	98.498001	57.500999999999998	28.75	\N	96
10844	2064	126	19.367999999999999	0.61680000000000001	0.89500000000000002	1.391	1.754	0.77300000000000002	0.62	0.60260000000000002	0.58079999999999998	0.55900000000000005	0.51539999999999997	0.47139999999999999	0.42699999999999999	0.3826	0.36049999999999999	0.33829999999999999	0.32050000000000001	0.29389999999999999	0.25	0.1	8	99.800003	41.744	24.100999999999999	\N	126
10845	2064	135	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	135
10835	2063	65	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	65
10836	2063	75	0.12	2.1454	1.0620000000000001	1.7849999999999999	2.5019999999999998	3.7111000000000001	3.4043999999999999	3.2000000000000002	2.9443999999999999	2.6888999999999998	2.1778	1.8500000000000001	1.6200000000000001	1.3899999999999999	1.2749999999999999	1.1599999999999999	1.0680000000000001	0.87050000000000005	0.63	4.348	4	95.652	0	0	\N	75
10837	2063	85	1.6040000000000001	1.27	1.258	1.6040000000000001	1.903	1.9331	1.7914000000000001	1.6969000000000001	1.5788	1.4608000000000001	1.2245999999999999	0.99570000000000003	0.90759999999999996	0.8196	0.77559999999999996	0.73150000000000004	0.69630000000000003	0.64349999999999996	0.5	2.6059999	6.2999999999999998	99.674004	0.25	0.17699999999999999	\N	85
10838	2063	95	17.567	3.3119000000000001	1.4339999999999999	2.379	3.3439999999999999	7.4219999999999997	5.5696000000000003	4.7771999999999997	3.9121999999999999	3.5045000000000002	2.6890000000000001	1.9557	1.6702999999999999	1.3849	1.2421	1.0993999999999999	0.98450000000000004	0.80420000000000003	0.5	1.602	10	95.195	24.283999999999999	17.172000000000001	\N	95
10839	2063	124	1.5760000000000001	1.0958000000000001	1.399	1.526	1.522	1.6588000000000001	1.2776000000000001	1.0235000000000001	0.95430000000000004	0.90500000000000003	0.80630000000000002	0.7077	0.62339999999999995	0.59219999999999995	0.5766	0.56100000000000005	0.54849999999999999	0.52980000000000005	0.5	0.463	10	99.073997	1.2769999999999999	0.90300000000000002	\N	124
10840	2063	135	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	135
10830	2062	74	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	74
10831	2062	96	39.093000000000004	2.0400999999999998	2.2690000000000001	2.1349999999999998	1.9690000000000001	5.3658000000000001	3.1149	2.2088999999999999	1.8389	1.6414	1.2464	0.96840000000000004	0.88449999999999995	0.80069999999999997	0.75870000000000004	0.71679999999999999	0.68320000000000003	0.63290000000000002	0.25	0.26100001	10	98.433998	54.622999999999998	38.624000000000002	\N	96
10832	2062	106	138.11500000000001	5.8585000000000003	0.94999999999999996	2.944	5.3810000000000002	14.8207	10.956899999999999	9.3613	8.0912000000000006	6.8144	5.1555999999999997	3.8195000000000001	2.8868	1.9751000000000001	1.7213000000000001	1.4675	1.2645	0.95809999999999995	0.5	1.609	20	98.042999	208.30500000000001	120.265	\N	106
10833	2062	136	64.584000000000003	4.8456999999999999	0.499	4.5549999999999997	12.589	13.258100000000001	9.7189999999999994	8.7560000000000002	7.6215000000000002	6.6036999999999999	4.8627000000000002	3.0217000000000001	0.96399999999999997	0.59570000000000001	0.55479999999999996	0.51380000000000003	0.46839999999999998	0.38629999999999998	0.25	0.043000001	10	85.167	350.536	156.76499999999999	\N	136
10834	2062	146	0.53300000000000003	0.7802	0.97899999999999998	1.397	1.6539999999999999	0.71879999999999999	0.5988	0.57410000000000005	0.54330000000000001	0.51249999999999996	0.4703	0.43309999999999998	0.39589999999999997	0.35870000000000002	0.34010000000000001	0.32150000000000001	0.30659999999999998	0.2843	0.25	0.78100002	8	98.438004	0	0	\N	146
10824	2061	70	52.442	5.2927	1.234	1.97	2.6080000000000001	10.201000000000001	8.2155000000000005	7.1844000000000001	6.1463000000000001	5.6067	4.5275999999999996	3.7538999999999998	3.2725	2.7909999999999999	2.5503	2.3094999999999999	2.1168999999999998	1.736	1	0.043000001	20	98.695	0	0	\N	70
10825	2061	80	21.552	3.5869	1.2909999999999999	2.2589999999999999	3.2639999999999998	7.2172999999999998	5.6456	4.9150999999999998	4.0019999999999998	3.6406000000000001	2.9201000000000001	2.1997	1.7930999999999999	1.5069999999999999	1.3638999999999999	1.2208000000000001	1.1063000000000001	0.89470000000000005	0.25	0.044	20	98.758003	24.969999999999999	17.655999999999999	\N	80
10826	2061	90	37.43	2.5893000000000002	1.214	2.0209999999999999	2.4860000000000002	5.2441000000000004	3.8902000000000001	3.5630000000000002	3.1539000000000001	2.7448000000000001	1.9792000000000001	1.7470000000000001	1.5146999999999999	1.2825	1.1664000000000001	1.0503	0.95230000000000004	0.79620000000000002	0.5	0.78299999	10	97.912003	37.024000000000001	26.18	\N	90
10827	2061	100	37.594999999999999	3.8740999999999999	1.0449999999999999	2.206	3.161	7.8490000000000002	6.2027999999999999	5.6387999999999998	4.9337999999999997	4.2287999999999997	3.4302000000000001	2.75	2.0697999999999999	1.7165999999999999	1.5587	1.4008	1.2745	1.085	0.5	1.087	10	94.084	10.151999999999999	7.1779999999999999	\N	100
10828	2061	130	16.245000000000001	1.1768000000000001	1.1739999999999999	1.4910000000000001	1.696	2.0975999999999999	0.92179999999999995	0.82689999999999997	0.70820000000000005	0.62529999999999997	0.59789999999999999	0.57050000000000001	0.54310000000000003	0.51559999999999995	0.50190000000000001	0.45569999999999999	0.41439999999999999	0.35249999999999998	0.25	0.059	10	99.412003	18.805	13.297000000000001	\N	130
10829	2061	140	1.825	10.840199999999999	0.93999999999999995	1.925	2.9449999999999998	19.092500000000001	17.576899999999998	16.566500000000001	15.3035	14.0405	11.5145	9.4167000000000005	7.9622000000000002	6.5865	5.9192	5.2664999999999997	4.7443999999999997	3.9102999999999999	0.5	1.831	20	93.593002	0	0	\N	140
10817	2060	60	0.68799999999999994	6.0613000000000001	1.3799999999999999	2.77	3.9180000000000001	15.2857	12.457100000000001	10.571400000000001	8.75	7.0819999999999999	5.1346999999999996	3.8275999999999999	3.1448	2.4621	2.1206999999999998	1.8315999999999999	1.6232	1.3105	0.5	1.01	10	78.788002	0	0	\N	60
10818	2060	70	33.311	4.1359000000000004	1.992	3.1309999999999998	3.3159999999999998	11.953799999999999	7.6642000000000001	5.6814999999999998	3.9647999999999999	3.3660999999999999	2.1688000000000001	1.7344999999999999	1.4255	1.1165	0.9738	0.86719999999999997	0.78190000000000004	0.65400000000000003	0.25	0.043000001	20	96.824997	95.153999999999996	54.936999999999998	\N	70
10819	2060	80	85.156000000000006	5.8808999999999996	1.339	3.077	4.4269999999999996	15.5746	12.1433	9.9189000000000007	8.3111999999999995	6.6414999999999997	4.5845000000000002	3.4104000000000001	2.5604	1.8596999999999999	1.6536999999999999	1.4477	1.2828999999999999	1.0357000000000001	0.25	0.043000001	20	97.737999	90.733000000000004	52.384	\N	80
10820	2060	100	149.458	6.2176999999999998	1.0169999999999999	3.468	6.2800000000000002	16.370799999999999	12.843	10.491	8.7060999999999993	7.2103999999999999	5.1382000000000003	3.6732	2.6779000000000002	1.8270999999999999	1.556	1.2848999999999999	1.0680000000000001	0.81820000000000004	0.25	0.043000001	20	96.171997	510.00799999999998	255.00399999999999	\N	100
10821	2060	110	2.2080000000000002	6.5800000000000001	2.306	5.5199999999999996	9.2409999999999997	19.213100000000001	16.0852	14	11.3934	8.6545000000000005	4.1021999999999998	1.9189000000000001	1.0595000000000001	0.71179999999999999	0.60880000000000001	0.56389999999999996	0.52790000000000004	0.44390000000000002	0.5	12.893	20	91.509003	0	0	\N	110
10822	2060	130	1.292	0.62509999999999999	0.96399999999999997	1.399	1.6759999999999999	0.76980000000000004	0.60650000000000004	0.58399999999999996	0.55589999999999995	0.52780000000000005	0.48039999999999999	0.44169999999999998	0.40289999999999998	0.36420000000000002	0.3448	0.32540000000000002	0.30990000000000001	0.28670000000000001	0.25	0.53799999	4	98.387001	0	0	\N	130
10823	2060	140	0.84699999999999998	0.38169999999999998	0.93799999999999994	1.2889999999999999	1.516	0.48170000000000002	0.46539999999999998	0.45450000000000002	0.44080000000000003	0.42720000000000002	0.40000000000000002	0.37280000000000002	0.34549999999999997	0.31830000000000003	0.30470000000000003	0.29110000000000003	0.2802	0.26379999999999998	0.25	4.9180002	1	99.18	0	0	\N	140
10810	2059	62	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	62
10811	2059	77	37.259999999999998	9.1197999999999997	0.42999999999999999	3.6200000000000001	12.236000000000001	19.2803	17.403500000000001	16.1524	14.5884	13.0245	9.9140999999999995	7.3277999999999999	5.0937999999999999	3.2370000000000001	2.4039999999999999	1.7369000000000001	1.3282	0.81030000000000002	0.25	0.043000001	20	92.301003	47.862000000000002	33.844000000000001	\N	77
10812	2059	92	188.96899999999999	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	334.79399999999998	193.29400000000001	\N	92
10813	2059	107	154.89599999999999	5.5007000000000001	0.93999999999999995	2.8140000000000001	5.0999999999999996	13.852	9.7362000000000002	8.5722000000000005	7.3066000000000004	6.2115	4.7262000000000004	3.5680000000000001	2.7227999999999999	1.9278	1.6783999999999999	1.4291	1.2296	0.92669999999999997	0.25	0.086999997	20	98.129997	675.28599999999994	337.64299999999997	\N	107
10814	2059	122	3.7080000000000002	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	1.6499999999999999	1.167	\N	122
10815	2059	137	11.869999999999999	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	15.225	10.766	\N	137
10816	2059	152	1.464	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	1.79	1.266	\N	152
13043	2033	62	4.1529999999999996	1.0736000000000001	1.157	1.6990000000000001	1.9690000000000001	1.7292000000000001	1.0659000000000001	0.94679999999999997	0.86870000000000003	0.79059999999999997	0.63429999999999997	0.58330000000000004	0.53520000000000001	0.47899999999999998	0.43980000000000002	0.40060000000000001	0.36919999999999997	0.32219999999999999	0.125	0.016000001	10	98.796997	7.6900000000000004	4.4400000000000004	\N	62
13044	2033	83	12.451000000000001	1.2473000000000001	1.4350000000000001	1.8460000000000001	1.9930000000000001	1.9319	1.3149	0.98499999999999999	0.9052	0.82540000000000002	0.66579999999999995	0.59470000000000001	0.54930000000000001	0.50380000000000003	0.46400000000000002	0.42070000000000002	0.38600000000000001	0.33410000000000001	0.125	0.011	10	97.383003	13.958	8.0579999999999998	\N	83
13045	2033	103	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	103
12862	2032	28	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	28
12863	2032	39	16.347000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	21.411000000000001	12.362	\N	39
12864	2032	59	4.4770000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5.9429999999999996	3.431	\N	59
12865	2032	89	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	89
12866	2032	99	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	99
12856	2031	24	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	24
12857	2031	34	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	3.25	1.8759999999999999	\N	34
12858	2031	44	0.54900000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	1.587	0.91600000000000004	\N	44
12859	2031	54	12.417	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	34.326999999999998	19.818999999999999	\N	54
12860	2031	84	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	84
12861	2031	94	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	94
11930	2030	28	2.6110000000000002	14.23	0.39500000000000002	3.0590000000000002	9.3450000000000006	27.921600000000002	25.7746	24.3432	22.553999999999998	20.764800000000001	17.186399999999999	13.4138	9.7853999999999992	7.8815	5.1111000000000004	3.4666999999999999	2.7543000000000002	1.839	0.5	0.26699999	16	56.683998	4.806	2.7749999999999999	\N	28
11931	2030	38	4.0140000000000002	20.709599999999998	0.55700000000000005	2.173	6.54	41.579999999999998	31.0471	29.647300000000001	27.897500000000001	26.1477	22.648	19.148399999999999	15.553800000000001	11.107699999999999	9.4527999999999999	8.3622999999999994	6.5768000000000004	3.4632000000000001	0.5	0.17299999	31.5	85.293999	13.724	7.9240000000000004	\N	38
11932	2030	58	7.0140000000000002	6.8642000000000003	1.776	3.2719999999999998	3.762	20.237400000000001	14.2835	11.215199999999999	9.0800000000000001	7.6521999999999997	4.1391	3.2761	2.5224000000000002	1.8803000000000001	1.6853	1.4903	1.3344	1.1004	0.5	1.98	16	86.237999	6.3200000000000003	3.649	\N	58
11933	2030	68	5.3470000000000004	23.182700000000001	0.44900000000000001	3.5379999999999998	10.468	52.253799999999998	45.805999999999997	41.5075	36.134399999999999	31.095300000000002	25.208400000000001	19.321400000000001	13.784599999999999	9.3938000000000006	8.2077000000000009	5.4560000000000004	3.6583999999999999	2.4081000000000001	0.5	0.64899999	31.5	70.686996	17.620999999999999	10.173999999999999	\N	68
11934	2030	108	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	108
11925	2029	28	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	28
11926	2029	49	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	49
11927	2029	58	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	58
11928	2029	87	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	87
11929	2029	98	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	98
11920	2027	36	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	36
11921	2027	45	0.125	1.7764	0.92300000000000004	2.4140000000000001	3.7050000000000001	3.6800000000000002	3.2480000000000002	2.96	2.6000000000000001	2.2400000000000002	1.76	1.3999999999999999	1.04	0.80269999999999997	0.69169999999999998	0.60399999999999998	0.55720000000000003	0.47499999999999998	0.5	11.111	4	94.444	0.433	0.25	\N	45
11922	2027	55	0.014	1.2778	2.6509999999999998	2.8250000000000002	2.8940000000000001	3.2696000000000001	2.8313000000000001	2.5390999999999999	2.1739000000000002	1.7250000000000001	0.89870000000000005	0.61560000000000004	0.53469999999999995	0.45789999999999997	0.42109999999999997	0.38419999999999999	0.35470000000000002	0.3105	0.25	1.786	2	72.619003	0.024	0.014	\N	55
11923	2027	85	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	85
11924	2027	95	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	95
11917	2024	50	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	50
11918	2024	70	0.36799999999999999	0.79020000000000001	1.1000000000000001	1.6930000000000001	2.173	1.5286	1.0743	0.96050000000000002	0.8952	0.82979999999999998	0.69910000000000005	0.60499999999999998	0.55200000000000005	0.49830000000000002	0.45419999999999999	0.40999999999999998	0.37469999999999998	0.32169999999999999	0.25	1.887	2	96.225998	1.2749999999999999	0.73599999999999999	\N	70
11919	2024	90	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	90
10457	2016	31	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	31
10458	2016	45	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	45
10459	2016	55	1.9059999999999999	0.5716	1.05	1.5389999999999999	1.8220000000000001	0.89729999999999999	0.75680000000000003	0.66310000000000002	0.61080000000000001	0.58409999999999995	0.53069999999999995	0.47989999999999999	0.43269999999999997	0.3856	0.36199999999999999	0.33839999999999998	0.3196	0.2913	0.25	1.247	4	99.792	0.97899999999999998	0.56499999999999995	\N	55
10460	2016	85	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	85
10461	2016	95	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	95
10443	2012	33	0.30599999999999999	3.5257000000000001	1.4790000000000001	3.2040000000000002	3.8919999999999999	11.199999999999999	6.2632000000000003	4.6440000000000001	3.5714000000000001	2.9428999999999998	1.9214	1.6071	1.2928999999999999	0.98150000000000004	0.8458	0.71020000000000005	0.61009999999999998	0.49370000000000003	0.25	1.136	10	88.636002	0.61199999999999999	0.35299999999999998	\N	33
10444	2012	53	4.8399999999999999	1.3324	1.105	1.806	2.3929999999999998	2.1463000000000001	1.8564000000000001	1.75	1.617	1.484	1.2181	0.97760000000000002	0.85299999999999998	0.72840000000000005	0.66610000000000003	0.60899999999999999	0.56899999999999995	0.50900000000000001	0.25	0.1	10	99.599998	13.747999999999999	7.9370000000000003	\N	53
10445	2012	72	1.2849999999999999	2.2572000000000001	1.125	2.0819999999999999	2.7869999999999999	4.46	3.6049000000000002	3.2439	2.7927	2.3414999999999999	1.8589	1.6318999999999999	1.4049	1.1778999999999999	1.0644	0.94079999999999997	0.83130000000000004	0.66700000000000004	0.5	3.243	10	98.918999	3.927	2.2669999999999999	\N	72
10446	2012	83	0.083000000000000004	1.9429000000000001	1.1699999999999999	1.639	1.833	3.3999999999999999	3.04	2.7999999999999998	2.5	2.2000000000000002	1.8856999999999999	1.7142999999999999	1.5428999999999999	1.3714	1.2857000000000001	1.2	1.1314	1.0286	1	8.3330002	2	66.667	0.28899999999999998	0.16700000000000001	\N	83
10447	2012	93	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	93
10448	2013	25	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	25
10449	2013	35	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	35
10450	2013	55	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	55
10451	2013	65	0.27400000000000002	0.78039999999999998	1.296	1.829	1.9950000000000001	1.5916999999999999	1.1967000000000001	0.98150000000000004	0.89019999999999999	0.79879999999999995	0.62609999999999999	0.57479999999999998	0.52339999999999998	0.4602	0.42359999999999998	0.38700000000000001	0.35780000000000001	0.31390000000000001	0.25	1.266	2	96.203003	0.94999999999999996	0.54900000000000004	\N	65
10452	2013	95	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	95
10453	2013	105	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	105
10437	2011	24	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	24
10438	2011	34	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	34
10439	2011	53	1.1870000000000001	5.3226000000000004	5.4290000000000003	3.657	2.1909999999999998	27.333300000000001	5.1959999999999997	1.6117999999999999	0.99239999999999995	0.90639999999999998	0.73419999999999996	0.60980000000000001	0.55869999999999997	0.50760000000000005	0.46879999999999999	0.42420000000000002	0.3886	0.3352	0.25	0.43900001	20	84.210999	0.88400000000000001	0.625	\N	53
10440	2011	64	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	64
10441	2011	95	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	95
10442	2011	103	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	103
10431	2010	25	0.021000000000000001	1.4422999999999999	0.93200000000000005	2.0609999999999999	3.3039999999999998	3.5	1.9564999999999999	1.8406	1.6957	1.5507	1.2608999999999999	0.98319999999999996	0.81499999999999995	0.64680000000000004	0.57799999999999996	0.51300000000000001	0.46050000000000002	0.38159999999999999	0.5	19	4	91.5	0.029000000000000001	0.021000000000000001	\N	25
10432	2010	35	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	35
10433	2010	55	0.156	1.1063000000000001	1.381	2.0790000000000002	2.585	2.1985000000000001	1.7873000000000001	1.6214999999999999	1.4144000000000001	1.2072000000000001	0.91049999999999998	0.73150000000000004	0.60160000000000002	0.53620000000000001	0.50349999999999995	0.45440000000000003	0.41349999999999998	0.35220000000000001	0.5	24.466999	4	97.866997	0.221	0.156	\N	55
10434	2010	65	0.083000000000000004	0.79959999999999998	1.345	1.8480000000000001	2.1589999999999998	1.5974999999999999	1.2956000000000001	1.0943000000000001	0.95079999999999998	0.87209999999999999	0.71460000000000001	0.60470000000000002	0.54990000000000006	0.4929	0.45240000000000002	0.41189999999999999	0.37959999999999999	0.33100000000000002	0.5	30.875	2	98	0.11799999999999999	0.083000000000000004	\N	65
10435	2010	95	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	95
10436	2010	105	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	105
10425	2009	24	0.042000000000000003	3.2964000000000002	1.036	3.9319999999999999	8.0540000000000003	8.5992999999999995	7.5164	6.3925000000000001	5.5279999999999996	4.7016	3.1507000000000001	1.8778999999999999	1.3231999999999999	0.85170000000000001	0.67390000000000005	0.55900000000000005	0.48620000000000002	0.39119999999999999	0.25	1.089	8	85.721001	0.16900000000000001	0.085000000000000006	\N	24
10426	2009	34	0.097000000000000003	3.6151	1.6359999999999999	3.5619999999999998	5.0890000000000004	9.2391000000000005	8.7826000000000004	8.4783000000000008	8.0977999999999994	3.8477999999999999	2.8332999999999999	1.9281999999999999	1.5259	1.1235999999999999	0.94569999999999999	0.80489999999999995	0.69230000000000003	0.55669999999999997	0.25	0.28600001	8	73.713997	0.26500000000000001	0.153	\N	34
10427	2009	44	0.74299999999999999	2.1118000000000001	2.4359999999999999	2.798	2.746	4.9966999999999997	2.976	2.1200000000000001	1.7031000000000001	1.3688	0.90129999999999999	0.68140000000000001	0.57389999999999997	0.50070000000000003	0.4577	0.41449999999999998	0.38	0.32819999999999999	0.25	0.935	10	93.458	0.64600000000000002	0.373	\N	44
10428	2009	54	1.986	1.7681	1.0229999999999999	2.1600000000000001	2.9769999999999999	3.5428999999999999	2.7256999999999998	2.181	1.9036999999999999	1.7725	1.5101	1.2477	0.99009999999999998	0.81379999999999997	0.72560000000000002	0.63739999999999997	0.58409999999999995	0.50719999999999998	0.25	0.34999999	10	99.301003	5.4550000000000001	3.1499999999999999	\N	54
10429	2009	84	0.025999999999999999	2.0547	1.179	1.764	2.6219999999999999	3.7179000000000002	3.3332999999999999	3.0769000000000002	2.7564000000000002	2.4359000000000002	1.9370000000000001	1.7402	1.5432999999999999	1.3465	1.248	1.1496	1.0709	0.73880000000000001	0.5	5.4000001	4	94.400002	0.156	0.078	\N	84
10430	2009	94	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	94
10421	2008	32	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	32
10422	2008	52	0.313	0.94879999999999998	1.6459999999999999	2.109	2.3940000000000001	1.9231	1.6462000000000001	1.4615	1.2307999999999999	1	0.77800000000000002	0.60829999999999995	0.54330000000000001	0.47499999999999998	0.4375	0.40000000000000002	0.37	0.32500000000000001	0.5	33.333	2	91.667	1.05	0.52500000000000002	\N	52
10423	2008	62	1.391	0.87649999999999995	1.54	1.9770000000000001	2.0990000000000002	1.768	1.4488000000000001	1.236	0.98839999999999995	0.88590000000000002	0.68089999999999995	0.59060000000000001	0.53820000000000001	0.47910000000000003	0.44040000000000001	0.4017	0.37080000000000002	0.32440000000000002	0.25	0.37599999	4	99.248001	3.5710000000000002	1.7849999999999999	\N	62
10424	2008	92	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	92
10416	2007	26	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	26
10417	2007	36	0.035999999999999997	1.4841	1.0309999999999999	2.4940000000000002	3.9300000000000002	3.2940999999999998	2.7999999999999998	2.4706000000000001	2.0588000000000002	1.8421000000000001	1.4737	1.1052999999999999	0.85770000000000002	0.65849999999999997	0.57579999999999998	0.5	0.45000000000000001	0.375	0.5	20	4	98.570999	0.129	0.064000000000000001	\N	36
10418	2007	56	0.222	1.1216999999999999	1.0920000000000001	2.1320000000000001	3.081	2.2222	1.8465	1.7172000000000001	1.5556000000000001	1.3938999999999999	1.0707	0.82869999999999999	0.622	0.53710000000000002	0.49390000000000001	0.4451	0.40610000000000002	0.34760000000000002	0.5	25.625	2	88.75	0.40500000000000003	0.23400000000000001	\N	56
10419	2007	66	0.91700000000000004	0.85360000000000003	1.4490000000000001	1.913	2.202	1.6865000000000001	1.4011	1.2108000000000001	0.99029999999999996	0.90459999999999996	0.73319999999999996	0.60829999999999995	0.55389999999999995	0.49909999999999999	0.45750000000000002	0.41599999999999998	0.38279999999999997	0.33300000000000002	0.5	30.114	4	99.431999	5.5	2.75	\N	66
10420	2007	96	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	96
10413	2006	27	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	27
10414	2006	47	0.039	1.1299999999999999	1.7689999999999999	2.3149999999999999	3.4369999999999998	2.6000000000000001	1.9399999999999999	1.8	1.625	1.45	1.1000000000000001	0.63	0.53900000000000003	0.46000000000000002	0.42499999999999999	0.39000000000000001	0.36199999999999999	0.32000000000000001	0.5	35.714001	2	85.713997	0.23400000000000001	0.11700000000000001	\N	47
10415	2006	67	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	67
10408	2002	26	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	26
10409	2002	36	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	36
10410	2002	46	0.29199999999999998	0.83740000000000003	1.3160000000000001	1.867	2.294	1.6491	1.3544	1.1578999999999999	0.97550000000000003	0.90690000000000004	0.76970000000000005	0.63249999999999995	0.56989999999999996	0.50870000000000004	0.46839999999999998	0.42409999999999998	0.3886	0.33539999999999998	0.25	0.35699999	2	97.142998	0	0	\N	46
10411	2002	56	3.306	0.78649999999999998	1.05	1.5529999999999999	2.0390000000000001	1.3603000000000001	0.97750000000000004	0.93220000000000003	0.87539999999999996	0.81869999999999998	0.70530000000000004	0.61429999999999996	0.56740000000000002	0.52059999999999995	0.49399999999999999	0.4446	0.40510000000000002	0.34589999999999999	0.25	0.28600001	6.2999999999999998	99.857002	10.214	5.8970000000000002	\N	56
10412	2002	86	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	86
10404	2001	47	0.042000000000000003	0.81840000000000002	1.3400000000000001	1.859	2.2229999999999999	1.625	1.325	1.125	0.96299999999999997	0.88900000000000001	0.74099999999999999	0.61560000000000004	0.55779999999999996	0.5	0.45829999999999999	0.41670000000000001	0.38329999999999997	0.33329999999999999	0.5	30	2	97.5	0.058999999999999997	0.042000000000000003	\N	47
10405	2001	57	0.25700000000000001	0.73140000000000005	1.0409999999999999	1.5649999999999999	2.028	1.2766	0.97119999999999995	0.92469999999999997	0.86670000000000003	0.80869999999999997	0.69269999999999998	0.60809999999999997	0.5605	0.51290000000000002	0.47899999999999998	0.43319999999999997	0.39650000000000002	0.34160000000000001	0.5	27.297001	2	99.189003	0.56899999999999995	0.32800000000000001	\N	57
10406	2001	67	0.075999999999999998	0.90149999999999997	1.3280000000000001	1.827	2.226	1.7142999999999999	1.3999999999999999	1.1904999999999999	0.98270000000000002	0.91910000000000003	0.79190000000000005	0.66469999999999996	0.58999999999999997	0.53500000000000003	0.50749999999999995	0.46150000000000002	0.41920000000000002	0.35580000000000001	0.5	23.636	4	99.091003	0.048000000000000001	0.028000000000000001	\N	67
10407	2001	86	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	86
34746	10837	40	102.73	1.6066	1.4370000000000001	2.351	3.2610000000000001	3.5594000000000001	2.8708999999999998	2.4117999999999999	1.9475	1.7617	1.3902000000000001	1.0185999999999999	0.84419999999999995	0.68010000000000004	0.61040000000000005	0.55979999999999996	0.51939999999999997	0.42630000000000001	0.125	0.0070000002	10	99.804001	192.91900000000001	111.38200000000001	\N	55
34747	10837	60	21.654	0.99129999999999996	1.292	1.782	2.1949999999999998	1.7694000000000001	1.4844999999999999	1.2946	1.0571999999999999	0.95740000000000003	0.84509999999999996	0.7329	0.62519999999999998	0.56730000000000003	0.53839999999999999	0.50949999999999995	0.46760000000000002	0.3851	0.125	0.035	10	99.862	9.4169999999999998	5.4370000000000003	\N	75
34748	10837	80	38.356000000000002	2.1244999999999998	0.97499999999999998	2.4260000000000002	3.4199999999999999	4.5671999999999997	3.6789000000000001	3.3376000000000001	2.9108999999999998	2.4841000000000002	1.8596999999999999	1.5354000000000001	1.2111000000000001	0.92449999999999999	0.81640000000000001	0.70830000000000004	0.62490000000000001	0.54369999999999996	0.125	0.0070000002	10	99.691002	30.212	17.443000000000001	\N	95
34749	10837	100	3617.4479999999999	1.6912	1.0860000000000001	2.0059999999999998	2.6400000000000001	3.4258999999999999	2.6844999999999999	2.1903000000000001	1.913	1.7871999999999999	1.5356000000000001	1.284	1.0324	0.87229999999999996	0.79900000000000004	0.72570000000000001	0.66700000000000004	0.58169999999999999	0.125	0.0020000001	10	99.801003	12326.891	7116.9340000000002	\N	115
34750	10837	120	4.931	7.4015000000000004	1.196	1.6579999999999999	2.2549999999999999	13.3086	11.1046	9.8695000000000004	9.2125000000000004	8.5555000000000003	7.2413999999999996	6.1261999999999999	5.5132000000000003	4.9001000000000001	4.5936000000000003	4.2870999999999997	4.0419	3.2111000000000001	0.25	0.014	16	97.327003	5.7469999999999999	3.3180000000000001	\N	135
29929	10095	40	60.960000000000001	0.95269999999999999	1.3120000000000001	1.823	2.2280000000000002	1.7625999999999999	1.4516	1.2442	0.99650000000000005	0.93620000000000003	0.81569999999999998	0.69520000000000004	0.60429999999999995	0.54830000000000001	0.52029999999999998	0.4839	0.43680000000000002	0.36620000000000003	0.125	0.0049999999	10	99.905998	74.426000000000002	42.969999999999999	\N	58
29930	10095	58	77.945999999999998	0.97330000000000005	1.1910000000000001	1.7070000000000001	2.1499999999999999	1.6451	1.1611	0.97589999999999999	0.91579999999999995	0.85560000000000003	0.73540000000000005	0.62339999999999995	0.57040000000000002	0.51729999999999998	0.48359999999999997	0.43640000000000001	0.3987	0.34200000000000003	0.125	0.011	10	99.469002	108.42400000000001	62.598999999999997	\N	76
29931	10095	76	48.942	1.2445999999999999	1.26	1.8500000000000001	2.198	2.2702	1.8189	1.6701999999999999	1.4843	1.2985	0.97960000000000003	0.87580000000000002	0.77200000000000002	0.66820000000000002	0.61739999999999995	0.5696	0.53129999999999999	0.44569999999999999	0.125	0.001	10	99.865997	25.959	14.987	\N	94
29932	10095	94	180.988	3.3037999999999998	0.90400000000000003	2.0899999999999999	3.234	6.0251000000000001	5.3033000000000001	4.8220999999999998	4.2205000000000004	3.8180999999999998	3.2437	2.6692	2.0948000000000002	1.7063999999999999	1.5306	1.3548	1.2141	1.0031000000000001	0.125	0.0020000001	16	99.603996	188.42400000000001	108.78700000000001	\N	112
29933	10095	114	33.402999999999999	7.1841999999999997	0.92800000000000005	2.0150000000000001	3.1749999999999998	13.7097	11.499700000000001	10.026400000000001	9.2878000000000007	8.5653000000000006	7.1203000000000003	5.9241000000000001	5.0545	4.1849999999999996	3.7174999999999998	3.2259000000000002	2.8327	2.2427000000000001	0.125	0.0020000001	16	96.218002	28.338000000000001	16.361000000000001	\N	132
29924	10094	42	18.472000000000001	0.64759999999999995	0.998	1.5680000000000001	1.9139999999999999	0.94899999999999995	0.86650000000000005	0.8115	0.74280000000000002	0.67400000000000004	0.59889999999999999	0.55320000000000003	0.50749999999999995	0.44479999999999997	0.41189999999999999	0.37890000000000001	0.35249999999999998	0.313	0.125	0.023	10	99.834	9.2279999999999998	5.3280000000000003	\N	46
29925	10094	62	85.308000000000007	1.6153999999999999	1.1140000000000001	2.1019999999999999	2.8239999999999998	3.3378999999999999	2.6027999999999998	2.1126999999999998	1.8839999999999999	1.7418	1.4574	1.1731	0.94099999999999995	0.79010000000000002	0.7147	0.63929999999999998	0.58889999999999998	0.5161	0.125	0.014	10	99.544998	228.78	132.08600000000001	\N	66
29926	10094	82	332.96899999999999	1.5604	1.083	1.992	2.73	3.1943999999999999	2.3940999999999999	1.9715	1.8353999999999999	1.6992	1.4268000000000001	1.1545000000000001	0.93920000000000003	0.79859999999999998	0.72829999999999995	0.65800000000000003	0.60309999999999997	0.52270000000000005	0.125	0.0080000004	16	99.991997	282.38	163.03200000000001	\N	86
29927	10094	102	26.48	2.0465	1.089	2.4940000000000002	3.6909999999999998	4.0597000000000003	3.4211999999999998	3.0247000000000002	2.5289000000000001	2.0331999999999999	1.663	1.3144	0.98119999999999996	0.78969999999999996	0.69389999999999996	0.60650000000000004	0.55010000000000003	0.4506	0.125	0.0089999996	16	99.544998	83.647000000000006	48.293999999999997	\N	106
29928	10094	122	47.000999999999998	3.2292000000000001	0.86099999999999999	2.0369999999999999	3.198	6.0029000000000003	5.2020999999999997	4.6683000000000003	4.0008999999999997	3.7507999999999999	3.2515999999999998	2.7524999999999999	2.2532999999999999	1.8058000000000001	1.6085	1.4113	1.2536	1.0168999999999999	0.25	0.011	10	98.691002	81.069000000000003	46.805	\N	126
27612	9007	37	31.919	0.83109999999999995	1.0329999999999999	1.569	2.105	1.5003	1.1324000000000001	0.98329999999999995	0.93769999999999998	0.89219999999999999	0.80120000000000002	0.71020000000000005	0.62309999999999999	0.5645	0.53520000000000001	0.50590000000000002	0.4602	0.38059999999999999	0.125	0.0040000002	4	99.843002	23.097000000000001	13.335000000000001	\N	54
27613	9007	57	36.667999999999999	1.4261999999999999	1.073	1.851	2.5859999999999999	2.9041999999999999	1.9986999999999999	1.8862000000000001	1.7456	1.6051	1.3239000000000001	1.0427	0.89029999999999998	0.76090000000000002	0.69620000000000004	0.63160000000000005	0.58360000000000001	0.51180000000000003	0.125	0.0040000002	10	99.882004	14.866	8.5830000000000002	\N	74
27614	9007	77	56.667999999999999	1.6513	1.1399999999999999	2.1349999999999998	2.871	3.4336000000000002	2.7746	2.3351999999999999	1.9434	1.7981	1.5074000000000001	1.2168000000000001	0.96240000000000003	0.81430000000000002	0.74029999999999996	0.66620000000000001	0.60840000000000005	0.52510000000000001	0.125	0.0049999999	10	99.774002	64.977000000000004	37.514000000000003	\N	94
27615	9007	97	87.534000000000006	1.7007000000000001	1.123	2.1640000000000001	2.8820000000000001	3.5022000000000002	2.8584000000000001	2.4293	1.9710000000000001	1.8261000000000001	1.5363	1.2464999999999999	0.97699999999999998	0.82269999999999999	0.74550000000000005	0.66839999999999999	0.61050000000000004	0.53300000000000003	0.125	0.003	16	99.891998	274.68099999999998	158.58699999999999	\N	114
27616	9007	117	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	134
34406	9006	32	64.394000000000005	0.74219999999999997	1.0589999999999999	1.607	1.9339999999999999	1.3083	0.96540000000000004	0.90980000000000005	0.84040000000000004	0.77100000000000002	0.63219999999999998	0.5837	0.53669999999999995	0.4829	0.44390000000000002	0.40489999999999998	0.37369999999999998	0.32700000000000001	0.125	0.003	6.2999999999999998	99.832001	10.034000000000001	5.7930000000000001	\N	40
34405	9006	55	68.251999999999995	1.1145	1.2929999999999999	1.843	2.2610000000000001	1.889	1.6123000000000001	1.4278999999999999	1.1973	0.99199999999999999	0.88070000000000004	0.76939999999999997	0.65810000000000002	0.5806	0.54759999999999998	0.51459999999999995	0.47460000000000002	0.38950000000000001	0.125	0.003	10	99.457001	169.70400000000001	97.978999999999999	\N	63
34404	9006	78	69.939999999999998	1.6091	1.2030000000000001	1.996	2.5670000000000002	3.2835999999999999	2.5312999999999999	2.0297999999999998	1.865	1.7232000000000001	1.4397	1.1560999999999999	0.9425	0.81459999999999999	0.75060000000000004	0.68659999999999999	0.63549999999999995	0.56079999999999997	0.125	0.0020000001	10	99.490997	9.2289999999999992	5.3280000000000003	\N	86
34403	9006	101	164.82300000000001	3.0470999999999999	0.97499999999999998	1.929	2.7589999999999999	5.7539999999999996	4.6258999999999997	3.9655999999999998	3.7094999999999998	3.4533999999999998	2.9411999999999998	2.4289999999999998	1.952	1.6567000000000001	1.5089999999999999	1.3613999999999999	1.2432000000000001	1.0661	0.125	0.003	16	99.864998	114.19499999999999	65.930000000000007	\N	109
34402	9006	124	0.40600000000000003	13.196099999999999	0.89900000000000002	1.9530000000000001	4.0949999999999998	25.816700000000001	22.406700000000001	20.133299999999998	17.291699999999999	15.532400000000001	13.817600000000001	12.1029	10.388199999999999	8.6209000000000007	7.7294999999999998	6.8381999999999996	5.8756000000000004	3.3742000000000001	0.125	0.34299999	16	72.726997	0.70599999999999996	0.40799999999999997	\N	132
27606	9005	32	128.00200000000001	0.64339999999999997	0.999	1.5509999999999999	1.8720000000000001	0.93689999999999996	0.83460000000000001	0.76639999999999997	0.68110000000000004	0.62160000000000004	0.57989999999999997	0.53820000000000001	0.49469999999999997	0.43309999999999998	0.40229999999999999	0.3715	0.3468	0.30980000000000002	0.125	0.016000001	6.2999999999999998	99.721001	153.82900000000001	88.813000000000002	\N	45
27605	9005	45	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	58
27604	9005	56	339.92500000000001	1.8763000000000001	1.1080000000000001	2.1680000000000001	2.8479999999999999	3.694	3.1566999999999998	2.7985000000000002	2.3508	1.9683999999999999	1.6759999999999999	1.3836999999999999	1.0913999999999999	0.89190000000000003	0.81330000000000002	0.73470000000000002	0.67179999999999995	0.58850000000000002	0.25	0.029999999	16	99.828003	230.78299999999999	133.24199999999999	\N	69
27603	9005	80	507.36799999999999	1.3468	1.208	1.776	2.234	2.3572000000000002	1.8735999999999999	1.7582	1.6138999999999999	1.4697	1.1812	0.95999999999999996	0.85260000000000002	0.74509999999999998	0.69140000000000001	0.63759999999999994	0.59419999999999995	0.52880000000000005	0.25	0.106	16	99.987999	823.12699999999995	475.23200000000003	\N	93
27602	9005	104	\N	2.6110000000000002	1	1.96	3.0310000000000001	4.8604000000000003	3.8632	3.6372	3.3548	3.0722999999999998	2.5072999999999999	1.9710000000000001	1.6870000000000001	1.4029	1.2608999999999999	1.1189	1.0053000000000001	0.82720000000000005	0.25	0.013	16	99.768997	\N	\N	\N	117
27601	9005	128	36.503	10.8315	0.81799999999999995	1.7849999999999999	2.7799999999999998	19.735800000000001	15.5017	14.795999999999999	13.9138	13.031599999999999	11.267300000000001	9.6028000000000002	8.1928000000000001	6.7827000000000002	6.0862999999999996	5.4085000000000001	4.8662000000000001	4.0528000000000004	0.25	0.037999999	16	86.823997	30.669	17.707000000000001	\N	141
27595	9003	32	112.581	0.88959999999999995	1.0880000000000001	1.542	1.952	1.5607	1.2251000000000001	1.0013000000000001	0.96040000000000003	0.92059999999999997	0.84089999999999998	0.76129999999999998	0.68169999999999997	0.6069	0.57410000000000005	0.5413	0.51500000000000001	0.43090000000000001	0.25	0.26199999	10	99.956001	57.968000000000004	33.468000000000004	\N	45
27594	9003	56	122.089	0.95760000000000001	1.153	1.5920000000000001	1.8540000000000001	1.6559999999999999	1.3537999999999999	1.1524000000000001	0.98470000000000002	0.94610000000000005	0.86890000000000001	0.79159999999999997	0.71430000000000005	0.6371	0.59999999999999998	0.56330000000000002	0.53390000000000004	0.46860000000000002	0.25	0.31299999	10	99.946999	117.846	68.037999999999997	\N	69
27593	9003	80	100.72199999999999	1.1797	1.246	1.8420000000000001	2.2490000000000001	1.9741	1.7536	1.6066	1.4229000000000001	1.2392000000000001	0.96189999999999998	0.85270000000000001	0.74360000000000004	0.63439999999999996	0.5917	0.55010000000000003	0.51680000000000004	0.42770000000000002	0.25	0.20299999	10	99.913002	254.92599999999999	147.18199999999999	\N	93
27592	9003	104	318.72699999999998	2.2660999999999998	1.016	2.0739999999999998	2.8690000000000002	4.0465	3.6027999999999998	3.3311999999999999	2.9918	2.6522999999999999	1.9896	1.724	1.4583999999999999	1.1928000000000001	1.0600000000000001	0.93400000000000005	0.83779999999999999	0.69350000000000001	0.125	0.003	16	99.813004	494.58600000000001	285.54899999999998	\N	117
27591	9003	128	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	141
27590	9002	33	13.614000000000001	1.1556	1.163	1.7430000000000001	2.0859999999999999	1.9092	1.7464999999999999	1.6379999999999999	1.5024999999999999	1.3669	1.0956999999999999	0.92930000000000001	0.81999999999999995	0.7107	0.65600000000000003	0.60829999999999995	0.57509999999999994	0.52529999999999999	0.125	0.0049999999	4	99.407997	10.952999999999999	6.3239999999999998	\N	45
27587	9002	56	110.759	1.1372	1.2110000000000001	1.7130000000000001	1.9179999999999999	1.861	1.6768000000000001	1.554	1.4005000000000001	1.2470000000000001	0.9819	0.88939999999999997	0.79690000000000005	0.70440000000000003	0.65810000000000002	0.61070000000000002	0.57110000000000005	0.51180000000000003	0.125	0.0020000001	10	99.873001	7.8310000000000004	4.5209999999999999	\N	68
27589	9002	79	72.774000000000001	1.2181	1.2909999999999999	1.77	1.921	2.0434999999999999	1.7926	1.6500999999999999	1.472	1.2939000000000001	0.98380000000000001	0.89139999999999997	0.79900000000000004	0.70650000000000002	0.6603	0.61270000000000002	0.57240000000000002	0.5121	0.125	0.0040000002	10	99.955002	86.748999999999995	50.084000000000003	\N	91
27588	9002	99	74.572000000000003	1.6664000000000001	1.0149999999999999	1.982	2.7250000000000001	3.3134000000000001	2.6442000000000001	2.1981999999999999	1.9228000000000001	1.8029999999999999	1.5633999999999999	1.3239000000000001	1.0843	0.89649999999999996	0.81659999999999999	0.73670000000000002	0.67279999999999995	0.57369999999999999	0.125	0.0040000002	16	99.874001	49.283999999999999	28.454000000000001	\N	111
27586	9002	125	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	137
24721	7961	26	124.345	0.81369999999999998	0.98399999999999999	1.4670000000000001	2.0230000000000001	1.4224000000000001	1.0416000000000001	0.97150000000000003	0.92889999999999995	0.88619999999999999	0.80100000000000005	0.71579999999999999	0.63049999999999995	0.57350000000000001	0.54500000000000004	0.51659999999999995	0.48399999999999999	0.39589999999999997	0.125	0.003	6.2999999999999998	99.955002	73.524000000000001	42.448999999999998	\N	46
24722	7961	49	7.218	1.0072000000000001	1.137	1.9079999999999999	2.4359999999999999	1.8168	1.5536000000000001	1.3782000000000001	1.1588000000000001	0.98480000000000001	0.87429999999999997	0.76390000000000002	0.65339999999999998	0.56359999999999999	0.52149999999999996	0.47220000000000001	0.4269	0.3589	0.125	0.018999999	10	99.749001	17.594000000000001	10.157999999999999	\N	69
24723	7961	61	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	81
24724	7961	74	5.3390000000000004	0.9103	1.5369999999999999	2.0379999999999998	2.129	1.8935	1.4421999999999999	1.1413	0.94089999999999996	0.84619999999999995	0.65680000000000005	0.57079999999999997	0.50190000000000001	0.43740000000000001	0.4052	0.373	0.34720000000000001	0.3085	0.25	0.91100001	6.2999999999999998	99.662003	6.3840000000000003	3.6859999999999999	\N	94
24725	7961	99	61.743000000000002	1.8352999999999999	1.141	2.3279999999999998	3.1320000000000001	3.786	3.2296999999999998	2.8586999999999998	2.3950999999999998	1.9750000000000001	1.6368	1.2987	0.98070000000000002	0.81540000000000001	0.73280000000000001	0.6502	0.59599999999999997	0.52249999999999996	0.5	8.158	10	99.741997	123.375	71.230000000000004	\N	119
24726	7961	125	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	145
24705	7941	35	127.759	0.74880000000000002	1.0469999999999999	1.589	1.95	1.2573000000000001	0.95709999999999995	0.90490000000000004	0.8397	0.77449999999999997	0.64400000000000002	0.5887	0.54239999999999999	0.49330000000000002	0.45250000000000001	0.41170000000000001	0.37909999999999999	0.33019999999999999	0.125	0.012	6.2999999999999998	99.762001	22.763999999999999	13.143000000000001	\N	50
24704	7941	54	39.280999999999999	1.0339	1.401	1.8660000000000001	2.242	1.8902000000000001	1.5926	1.3942000000000001	1.1462000000000001	0.97399999999999998	0.84760000000000002	0.72109999999999996	0.61460000000000004	0.5595	0.53190000000000004	0.50429999999999997	0.45750000000000002	0.37809999999999999	0.125	0.012	6.2999999999999998	99.472	88.064999999999998	50.844000000000001	\N	69
24703	7941	73	137.18100000000001	1.2244999999999999	1.325	1.8149999999999999	1.919	2.2536	1.8066	1.6506000000000001	1.4555	1.2605	0.96619999999999995	0.86439999999999995	0.76270000000000004	0.66090000000000004	0.61539999999999995	0.57809999999999995	0.54820000000000002	0.50349999999999995	0.125	0.013	6.2999999999999998	99.410004	169.87799999999999	98.078999999999994	\N	88
24702	7941	96	126.473	1.6177999999999999	0.93000000000000005	1.6539999999999999	2.1779999999999999	2.992	2.2324000000000002	1.9596	1.8662000000000001	1.7727999999999999	1.5860000000000001	1.3993	1.2124999999999999	1.0257000000000001	0.94710000000000005	0.87409999999999999	0.81569999999999998	0.72819999999999996	0.25	0.025	6.2999999999999998	99.599998	239.934	138.52600000000001	\N	111
24701	7941	116	0.41499999999999998	15.377000000000001	0.504	2.427	5.7770000000000001	28.2897	26.363499999999998	25.0794	23.4742	21.869	18.6587	15.302300000000001	11.241899999999999	8.2818000000000005	7.0442999999999998	5.6936	4.4767000000000001	3.2299000000000002	0.5	0.68699998	16	51.717999	1.4379999999999999	0.82999999999999996	\N	131
24685	7921	37	105.217	0.67269999999999996	1.022	1.5900000000000001	1.919	0.96789999999999998	0.87880000000000003	0.81940000000000002	0.74509999999999998	0.67079999999999995	0.59509999999999996	0.54690000000000005	0.49840000000000001	0.43559999999999999	0.4042	0.37280000000000002	0.34770000000000001	0.31	0.25	0.43900001	6.2999999999999998	99.598	307.971	177.80699999999999	\N	47
24684	7921	60	203.61000000000001	0.96289999999999998	1.2889999999999999	1.865	2.286	1.75	1.4155	1.1924999999999999	0.98070000000000002	0.91830000000000001	0.79339999999999999	0.66849999999999998	0.58840000000000003	0.52829999999999999	0.497	0.44700000000000001	0.40699999999999997	0.34699999999999998	0.25	0.30000001	10	99.889999	377.24400000000003	217.80199999999999	\N	70
24683	7921	84	65.575999999999993	1.1819999999999999	1.3999999999999999	2.04	2.4569999999999999	2.3938999999999999	1.7873000000000001	1.5931999999999999	1.3506	1.1080000000000001	0.88639999999999997	0.74019999999999997	0.61419999999999997	0.55010000000000003	0.5181	0.47510000000000002	0.4294	0.36080000000000001	0.125	0.0099999998	10	99.768997	131.67500000000001	76.022999999999996	\N	94
24682	7921	110	214.06700000000001	2.4784000000000002	1.0800000000000001	2.0609999999999999	2.6970000000000001	4.6859000000000002	3.7229999999999999	3.4342999999999999	3.0733999999999999	2.7124999999999999	1.9965999999999999	1.7379	1.4792000000000001	1.2204999999999999	1.0911999999999999	0.96660000000000001	0.87619999999999998	0.74039999999999995	0.25	0.02	16	99.555	273.54899999999998	157.934	\N	120
24681	7921	134	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	144
24090	7322	38	183.85300000000001	1.2508999999999999	1.145	2.0630000000000002	2.798	2.7256999999999998	1.9443999999999999	1.7971999999999999	1.6131	1.429	1.0609	0.88060000000000005	0.73760000000000003	0.60550000000000004	0.55610000000000004	0.50660000000000005	0.45679999999999998	0.37909999999999999	0.063	0.003	6.2999999999999998	99.807999	0	0	\N	38
24089	7322	58	36.606999999999999	0.99250000000000005	1.6020000000000001	1.9490000000000001	2.1389999999999998	1.885	1.5045999999999999	1.2509999999999999	0.98240000000000005	0.89790000000000003	0.72889999999999999	0.6099	0.56159999999999999	0.51319999999999999	0.47910000000000003	0.433	0.39610000000000001	0.34079999999999999	0.063	0.0040000002	6.2999999999999998	98.986	0	0	\N	58
24088	7322	78	151.209	2.7604000000000002	0.98799999999999999	2.4729999999999999	3.972	5.7458	4.4324000000000003	3.8462999999999998	3.4666000000000001	3.0870000000000002	2.3277000000000001	1.8037000000000001	1.4583999999999999	1.1131	0.95569999999999999	0.82750000000000001	0.72489999999999999	0.58609999999999995	0.063	0.0020000001	10	95.68	0	0	\N	78
24087	7322	101	264.28699999999998	3.4085999999999999	0.92400000000000004	2.081	3.125	6.2831999999999999	5.577	5.1063000000000001	4.5178000000000003	3.9647000000000001	3.3759999999999999	2.7873000000000001	2.1985999999999999	1.7710999999999999	1.5984	1.4257	1.2875000000000001	1.0802	0.063	0.0020000001	10	98.218002	0	0	\N	101
24086	7322	118	0.025000000000000001	1.2261	0.70699999999999996	1.859	3.331	1.9399999999999999	1.8240000000000001	1.7466999999999999	1.6499999999999999	1.5532999999999999	1.3600000000000001	1.1667000000000001	0.97040000000000004	0.75580000000000003	0.64849999999999997	0.57799999999999996	0.52769999999999995	0.4083	0.063	0.345	2	93.102997	0	0	\N	118
12987	2098	75	1.736	1.4766999999999999	1.3	2.0819999999999999	2.8490000000000002	3.2633000000000001	2.1854	1.8927	1.712	1.5313000000000001	1.1698999999999999	0.92079999999999995	0.77149999999999996	0.62539999999999996	0.58220000000000005	0.53890000000000005	0.50429999999999997	0.41060000000000002	0.125	0.0089999996	6.2999999999999998	97.360001	1.99	1.149	\N	75
12988	2098	95	1.8759999999999999	0.5444	1.0369999999999999	1.4319999999999999	1.643	0.82609999999999995	0.6179	0.58120000000000005	0.53520000000000001	0.49580000000000002	0.45979999999999999	0.42380000000000001	0.38779999999999998	0.3518	0.33379999999999999	0.31580000000000003	0.3014	0.27979999999999999	0.125	0.035	4	99.365997	0.30099999999999999	0.17399999999999999	\N	95
12989	2098	115	2.4649999999999999	0.44969999999999999	0.97499999999999998	1.3560000000000001	1.587	0.60929999999999995	0.53680000000000005	0.49690000000000001	0.48089999999999999	0.46489999999999998	0.43290000000000001	0.40089999999999998	0.36890000000000001	0.33679999999999999	0.32079999999999997	0.30480000000000002	0.29199999999999998	0.27279999999999999	0.125	0.030999999	2	99.468002	2.04	1.1779999999999999	\N	115
12990	2098	135	6.5759999999999996	1.4802	2.3119999999999998	2.4830000000000001	2.1070000000000002	3.8123999999999998	2.1328	1.645	1.1415	0.90759999999999996	0.65039999999999998	0.56479999999999997	0.49480000000000002	0.43269999999999997	0.4017	0.37069999999999997	0.34589999999999999	0.30859999999999999	0.125	0.012	10	97.630997	7.2290000000000001	4.1740000000000004	\N	135
12991	2098	155	0.371	0.66149999999999998	1.139	1.536	1.7	0.97170000000000001	0.72330000000000005	0.61660000000000004	0.57820000000000005	0.53979999999999995	0.48089999999999999	0.44130000000000003	0.4017	0.36209999999999998	0.34229999999999999	0.32250000000000001	0.30669999999999997	0.28289999999999998	0.125	0.037999999	4	97.907997	0.094	0.053999999999999999	\N	155
12982	2097	82	23.242999999999999	3.7991000000000001	1.1699999999999999	2.5840000000000001	4.3159999999999998	8.5099999999999998	5.8712	5.0949	4.1245000000000003	3.6600999999999999	2.8801000000000001	2.1000999999999999	1.7023999999999999	1.3611	1.1903999999999999	1.0197000000000001	0.87909999999999999	0.66739999999999999	0.125	0.014	16	96.577003	17.425000000000001	10.06	\N	82
12983	2097	113	28.076000000000001	1.7612000000000001	1.609	2.6970000000000001	3.4620000000000002	4.2987000000000002	3.1395	2.4695	1.9045000000000001	1.6873	1.2526999999999999	0.91759999999999997	0.72050000000000003	0.57799999999999996	0.52990000000000004	0.47799999999999998	0.43159999999999998	0.3619	0.125	0.0040000002	10	98.742996	20.946000000000002	12.093	\N	113
12984	2097	122	11.563000000000001	1.0626	1.101	1.653	1.9259999999999999	1.3751	0.92230000000000001	0.84260000000000002	0.7429	0.64329999999999998	0.5827	0.53190000000000004	0.4783	0.41970000000000002	0.39040000000000002	0.36109999999999998	0.3377	0.30249999999999999	0.125	0.0040000002	10	97.108002	30.094999999999999	17.376000000000001	\N	122
12985	2097	151	16.923999999999999	1.6888000000000001	2.802	2.9969999999999999	3.0310000000000001	4.1727999999999996	3.2027999999999999	2.6230000000000002	1.9509000000000001	1.6007	0.95499999999999996	0.63839999999999997	0.53239999999999998	0.45329999999999998	0.41870000000000002	0.38419999999999999	0.35649999999999998	0.315	0.125	0.0049999999	10	97.955002	10.260999999999999	5.9240000000000004	\N	151
12986	2097	160	8.3399999999999999	0.86360000000000003	1.3919999999999999	1.7689999999999999	1.8600000000000001	1.7709999999999999	1.0054000000000001	0.88219999999999998	0.73340000000000005	0.61880000000000002	0.54520000000000002	0.48180000000000001	0.43459999999999999	0.38740000000000002	0.36380000000000001	0.34029999999999999	0.32140000000000002	0.29310000000000003	0.125	0.0089999996	6.2999999999999998	99.036003	6.1890000000000001	3.573	\N	160
12936	2096	52	30.832999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	23.137	13.358000000000001	\N	52
12937	2096	83	12.157	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	23.818000000000001	13.750999999999999	\N	83
12938	2096	113	16.027999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	18.602	10.74	\N	113
12939	2096	143	9.8529999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.91200000000000003	0.52700000000000002	\N	143
12940	2096	173	2.2919999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	1.5569999999999999	0.89900000000000002	\N	173
12931	2095	64	0.38200000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.63600000000000001	0.36699999999999999	\N	64
12932	2095	72	0.93000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	1.056	0.60999999999999999	\N	72
12933	2095	112	2.9020000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2.0870000000000002	1.2050000000000001	\N	112
12934	2095	152	18.933	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	42.712000000000003	24.66	\N	152
12935	2095	162	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	162
10933	2094	41	119.842	2.8409	0.625	2.0550000000000002	3.9550000000000001	5.2449000000000003	4.1908000000000003	3.8742999999999999	3.6587000000000001	3.4430999999999998	3.0118	2.5804999999999998	2.1493000000000002	1.6785000000000001	1.4327000000000001	1.1869000000000001	0.99239999999999995	0.76149999999999995	0.25	0.074000001	10	99.260002	180.66	104.304	\N	41
10934	2094	72	121.88200000000001	3.5644999999999998	0.41799999999999998	2.879	7.5209999999999999	6.9386999999999999	5.9379999999999997	5.5991999999999997	5.1756000000000002	4.7521000000000004	3.9182999999999999	3.1903000000000001	2.4622000000000002	1.6952	1.2779	0.91639999999999999	0.71619999999999995	0.52100000000000002	0.25	0.191	10	98.278999	123.887	71.525999999999996	\N	72
10935	2094	82	39.113	1.6355999999999999	3.5430000000000001	3.1509999999999998	2.714	4.4410999999999996	3.3851	2.8357999999999999	2.1493000000000002	1.617	0.82999999999999996	0.57069999999999999	0.48099999999999998	0.42259999999999998	0.39340000000000003	0.36420000000000002	0.34089999999999998	0.30580000000000002	0.25	0.435	10	99.022003	66.132999999999996	38.182000000000002	\N	82
10936	2094	112	10.292	0.97870000000000001	1.647	2.028	2.0329999999999999	1.9921	1.5295000000000001	1.2211000000000001	0.95799999999999996	0.85940000000000005	0.6623	0.58779999999999999	0.53739999999999999	0.47999999999999998	0.44140000000000001	0.40289999999999998	0.37209999999999999	0.32579999999999998	0.25	0.171	6.2999999999999998	99.487999	24.465	14.125	\N	112
10937	2094	122	5.3470000000000004	0.82889999999999997	1.4259999999999999	1.9350000000000001	2.1120000000000001	1.6861999999999999	1.3511	1.1276999999999999	0.94979999999999998	0.85729999999999995	0.67230000000000001	0.58460000000000001	0.52580000000000005	0.46010000000000001	0.42470000000000002	0.38919999999999999	0.36080000000000001	0.31819999999999998	0.25	0.38100001	4	99.619003	2.5139999999999998	1.4510000000000001	\N	122
10928	2093	47	146.548	9.7660999999999998	0.86099999999999999	1.8979999999999999	3.0590000000000002	17.177299999999999	14.8299	13.9261	12.796200000000001	11.666399999999999	9.6721000000000004	8.4232999999999993	7.1744000000000003	5.9150999999999998	5.2732999999999999	4.6315999999999997	4.1181000000000001	3.1619999999999999	0.63	0.059	16	89.178001	183.59	105.996	\N	47
10929	2093	66	912.02499999999998	3.6756000000000002	0.85699999999999998	1.99	3.097	6.3345000000000002	5.6532999999999998	5.2172000000000001	4.6721000000000004	4.1271000000000004	3.5628000000000002	3.0678999999999998	2.5731000000000002	2.0781999999999998	1.8422000000000001	1.6115999999999999	1.427	1.1501999999999999	0.5	0.193	16	99.614998	1406.0129999999999	811.76199999999994	\N	66
10930	2093	76	262.81599999999997	3.8026	0.84299999999999997	2.097	3.4790000000000001	6.9166999999999996	5.4545000000000003	4.7965999999999998	3.9927999999999999	3.7608999999999999	3.2970999999999999	2.8332999999999999	2.3696000000000002	1.9036999999999999	1.6667000000000001	1.4296	1.24	0.94779999999999998	0.5	1.563	16	97.813004	285.01900000000001	164.55600000000001	\N	76
10931	2093	110	53.753999999999998	5.3651999999999997	0.79900000000000004	1.845	3.2890000000000001	9.3757000000000001	7.9598000000000004	7.0159000000000002	6.1924000000000001	5.9188000000000001	5.3715999999999999	4.8243999999999998	4.2771999999999997	3.5668000000000002	3.1278000000000001	2.6888000000000001	2.3376000000000001	1.633	0.25	0.050999999	16	98.518997	123.959	71.567999999999998	\N	110
10932	2093	150	143.58699999999999	0.85270000000000001	1.46	1.923	2.0609999999999999	1.7302999999999999	1.3669	1.1246	0.9456	0.85329999999999995	0.66849999999999998	0.58819999999999995	0.53539999999999999	0.47520000000000001	0.4375	0.39979999999999999	0.36959999999999998	0.32440000000000002	0.25	0.13500001	4	99.459	368.51400000000001	212.761	\N	150
34854	10863	45	1.762	0.64029999999999998	1.099	1.6359999999999999	1.9399999999999999	0.9889	0.89500000000000002	0.83240000000000003	0.75419999999999998	0.67600000000000005	0.58520000000000005	0.52170000000000005	0.46439999999999998	0.41010000000000002	0.38300000000000001	0.35589999999999999	0.3342	0.30170000000000002	0.25	0.461	4	99.867996	3.1320000000000001	1.8080000000000001	\N	45
34855	10863	65	19.524999999999999	1.3209	1.1399999999999999	1.73	2.044	1.6632	1.0595000000000001	0.94799999999999995	0.87170000000000003	0.7954	0.64290000000000003	0.57369999999999999	0.51219999999999999	0.44690000000000002	0.4138	0.38069999999999998	0.35420000000000001	0.3145	0.25	0.26100001	16	98.577003	58.219000000000001	33.613	\N	65
34856	10863	85	22.013999999999999	2.2624	1.0960000000000001	2.3319999999999999	3.125	3.8643000000000001	3.1766999999999999	2.7183000000000002	2.1453000000000002	1.8900999999999999	1.5955999999999999	1.3010999999999999	1.0065999999999999	0.81950000000000001	0.72719999999999996	0.63490000000000002	0.58420000000000005	0.51049999999999995	0.25	0.052999999	16	97.864998	24.713999999999999	14.269	\N	85
34857	10863	105	134.63300000000001	3.1951999999999998	0.90900000000000003	1.978	2.9820000000000002	5.7667999999999999	4.7065999999999999	4	3.7492000000000001	3.4984999999999999	2.9971000000000001	2.4956999999999998	1.9962	1.6658999999999999	1.5006999999999999	1.3354999999999999	1.2033	1.0051000000000001	0.25	0.013	16	98.920998	197.77600000000001	114.18600000000001	\N	105
34858	10863	125	6.782	11.8386	1.0229999999999999	1.746	2.5640000000000001	22.974299999999999	17.858799999999999	15.663399999999999	14.7385	13.813599999999999	11.963900000000001	10.114100000000001	8.8861000000000008	7.6989999999999998	7.1055000000000001	6.5119999999999996	5.8596000000000004	4.6665000000000001	0.5	0.050999999	16	81.82	11.394	6.5780000000000003	\N	125
34853	10862	41	43.265999999999998	0.99119999999999997	1.161	1.7589999999999999	2.238	1.7410000000000001	1.4766999999999999	1.3005	1.0803	0.96970000000000001	0.87439999999999996	0.77910000000000001	0.68389999999999995	0.59630000000000005	0.55759999999999998	0.51880000000000004	0.4773	0.39079999999999998	0.125	0.0080000004	10	99.865997	68.215000000000003	39.384	\N	41
34852	10862	61	186.91800000000001	2.3597000000000001	1.746	2.298	2.569	6.5214999999999996	2.8525999999999998	1.9413	1.7553000000000001	1.5691999999999999	1.1971000000000001	0.93969999999999998	0.8115	0.68340000000000001	0.62239999999999995	0.57679999999999998	0.54039999999999999	0.46600000000000003	0.125	0.0049999999	16	98.499001	477.36799999999999	275.608	\N	61
34851	10862	81	224.191	2.7374999999999998	0.80800000000000005	2.6190000000000002	4.6390000000000002	5.6143000000000001	4.3700000000000001	3.8450000000000002	3.4952000000000001	3.1454	2.4458000000000002	1.8557999999999999	1.4583999999999999	1.0609999999999999	0.89900000000000002	0.75339999999999996	0.63690000000000002	0.5272	0.125	0.0060000001	16	99.222	162.66200000000001	93.912999999999997	\N	81
34850	10862	101	279.68299999999999	2.5924	1.141	2.2210000000000001	2.8639999999999999	5.4611000000000001	3.9260999999999999	3.5646	3.1128	2.661	1.9268000000000001	1.6544000000000001	1.3818999999999999	1.1094999999999999	0.97989999999999999	0.87749999999999995	0.79559999999999997	0.67269999999999996	0.125	0.0040000002	16	99.399002	817.58500000000004	472.03300000000002	\N	101
34849	10862	121	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	121
24085	7321	33	90.981999999999999	1.5671999999999999	1.2529999999999999	2.3799999999999999	3.496	3.4950999999999999	2.8323	2.3904999999999998	1.9480999999999999	1.7710999999999999	1.4171	1.0630999999999999	0.85399999999999998	0.6764	0.6028	0.54569999999999996	0.5	0.40539999999999998	0.063	0.0020000001	6.2999999999999998	99.102997	0	0	\N	33
24084	7321	53	137.96100000000001	1.1376999999999999	1.7390000000000001	2.0539999999999998	2.2999999999999998	2.4836999999999998	1.7592000000000001	1.5208999999999999	1.2231000000000001	0.97929999999999995	0.81440000000000001	0.64939999999999998	0.58389999999999997	0.53159999999999996	0.50549999999999995	0.4587	0.4168	0.35399999999999998	0.063	0.003	6.2999999999999998	98.969002	0	0	\N	53
24083	7321	73	107.191	2.4756	0.80100000000000005	2.3559999999999999	4.3179999999999996	5.1715	3.9950000000000001	3.7376999999999998	3.4159999999999999	3.0943999999999998	2.4510999999999998	1.8940999999999999	1.5395000000000001	1.1850000000000001	1.0077	0.84719999999999995	0.71950000000000003	0.56759999999999999	0.063	0.0099999998	10	99.697998	0	0	\N	73
24082	7321	92	127.255	3.1869000000000001	1.105	2.5009999999999999	3.9369999999999998	6.6841999999999997	5.5126999999999997	4.9195000000000002	4.1779000000000002	3.6960000000000002	2.8963000000000001	2.0966	1.6847000000000001	1.3261000000000001	1.1467000000000001	0.97799999999999998	0.88109999999999999	0.73570000000000002	0.063	0.0089999996	10	95.972	0	0	\N	92
24081	7321	113	1.357	11.330500000000001	0.66400000000000003	1.7390000000000001	2.7810000000000001	19.039300000000001	15.5212	14.9834	14.311199999999999	13.638999999999999	12.294499999999999	10.949999999999999	9.3653999999999993	7.2024999999999997	6.2018000000000004	5.6078999999999999	5.1327999999999996	4.4200999999999997	0.063	0.026000001	16	87.560997	0	0	\N	113
34864	10865	32	107.16800000000001	1.6138999999999999	1.1819999999999999	2.1110000000000002	2.7709999999999999	3.3559000000000001	2.6619000000000002	2.1993	1.9026000000000001	1.7541	1.4569000000000001	1.1597999999999999	0.93389999999999995	0.79079999999999995	0.71930000000000005	0.64770000000000005	0.59709999999999996	0.52569999999999995	0.125	0.0099999998	16	99.829002	364.27499999999998	210.31399999999999	\N	34
34865	10865	52	10.287000000000001	1.2209000000000001	1.3540000000000001	1.7809999999999999	1.9219999999999999	1.8973	1.675	1.5267999999999999	1.3415999999999999	1.1563000000000001	0.92979999999999996	0.80830000000000002	0.68679999999999997	0.60189999999999999	0.57550000000000001	0.54910000000000003	0.52800000000000002	0.48380000000000001	0.25	0.090000004	10	99.347	11.509	6.6449999999999996	\N	54
34866	10865	72	116.97199999999999	2.2677999999999998	1.069	2.1930000000000001	3	3.9700000000000002	3.3317999999999999	2.9064000000000001	2.3746	1.9635	1.7164999999999999	1.4696	1.2225999999999999	0.9798	0.87739999999999996	0.77500000000000002	0.69299999999999995	0.57210000000000005	0.125	0.0020000001	16	99.134003	217.93299999999999	125.824	\N	74
34867	10865	92	548.57500000000005	2.8698999999999999	1.056	2.2919999999999998	3.5800000000000001	5.7453000000000003	4.4471999999999996	3.8635999999999999	3.5108999999999999	3.1583000000000001	2.4529000000000001	1.8875999999999999	1.5737000000000001	1.2598	1.1028	0.95369999999999999	0.84630000000000005	0.68520000000000003	0.125	0.0020000001	16	99.153999	897.54999999999995	518.20100000000002	\N	94
34868	10865	112	97.518000000000001	4.4276	0.88	2.5110000000000001	4.3109999999999999	9.4300999999999995	7.6627000000000001	6.4843999999999999	5.7617000000000003	5.1463000000000001	3.9521000000000002	3.2532999999999999	2.5546000000000002	1.8991	1.6548	1.4104000000000001	1.2149000000000001	0.91669999999999996	0.25	0.022	16	98.629997	53.468000000000004	30.870000000000001	\N	114
34859	10864	36	179.42500000000001	1.5673999999999999	1.617	2.1779999999999999	2.3940000000000001	3.4310999999999998	2.5619000000000001	1.9951000000000001	1.7939000000000001	1.5928	1.1903999999999999	0.92510000000000003	0.78300000000000003	0.64090000000000003	0.60119999999999996	0.56730000000000003	0.54010000000000002	0.49730000000000002	0.125	0.003	10	99.188004	299.65199999999999	173.00399999999999	\N	38
34860	10864	56	32.625	2.7559	1.4350000000000001	2.899	3.5760000000000001	6.2777000000000003	4.8392999999999997	3.9367999999999999	3.3039000000000001	2.6709000000000001	1.806	1.3934	0.99129999999999996	0.80510000000000004	0.71199999999999997	0.623	0.57579999999999998	0.505	0.125	0.0070000002	16	98.664001	13.257999999999999	7.6550000000000002	\N	58
34861	10864	76	411.78199999999998	2.1543000000000001	0.96999999999999997	2.403	3.5150000000000001	4.2675999999999998	3.5651999999999999	3.2320000000000002	2.8155999999999999	2.3992	1.8311999999999999	1.5069999999999999	1.1827000000000001	0.90820000000000001	0.80310000000000004	0.69799999999999995	0.61770000000000003	0.52100000000000002	0.125	0.0080000004	16	99.918999	315.18299999999999	181.971	\N	78
34862	10864	96	3.488	1.4542999999999999	1.371	2.5720000000000001	3.476	3.4681000000000002	2.5901999999999998	2.0049000000000001	1.7941	1.5868	1.1721999999999999	0.86019999999999996	0.62609999999999999	0.52129999999999999	0.47310000000000002	0.42780000000000001	0.3916	0.3372	0.125	0.034000002	6.2999999999999998	98.191002	6.7679999999999998	3.907	\N	98
34863	10864	116	448.58800000000002	3.3782000000000001	0.72299999999999998	3.1280000000000001	5.8899999999999997	7.4455	5.7035	5.0839999999999996	4.3095999999999997	3.7578999999999998	2.9510999999999998	2.1444000000000001	1.5764	1.0604	0.8488	0.65129999999999999	0.58279999999999998	0.50109999999999999	0.125	0.003	16	98.429001	295.40899999999999	170.554	\N	118
34751	10838	23	112.56999999999999	1.6501999999999999	1.218	2.3370000000000002	3.3610000000000002	3.5606	2.9039999999999999	2.4662999999999999	1.9749000000000001	1.8051999999999999	1.4657	1.1263000000000001	0.89480000000000004	0.72729999999999995	0.64349999999999996	0.57979999999999998	0.53190000000000004	0.43609999999999999	0.125	0.0060000001	10	99.759003	36.311999999999998	20.965	\N	43
34752	10838	43	129.44800000000001	2.1334	1.359	2.5169999999999999	3.2010000000000001	4.9752999999999998	3.7833999999999999	3.3851	2.8873000000000002	2.3895	1.7311000000000001	1.2895000000000001	0.94689999999999996	0.79259999999999997	0.71550000000000002	0.63839999999999997	0.59740000000000004	0.54069999999999996	0.25	0.034000002	10	99.166	166.09	95.891999999999996	\N	63
34753	10838	63	183.089	2.1229	1.0329999999999999	2.1659999999999999	2.9900000000000002	3.9243999999999999	3.4445000000000001	3.1246	2.7246999999999999	2.3248000000000002	1.8378000000000001	1.5645	1.2912999999999999	1.0181	0.91349999999999998	0.81369999999999998	0.7339	0.61460000000000004	0.125	0.003	16	99.779999	182.15000000000001	105.164	\N	83
34754	10838	83	101.23699999999999	3.3742999999999999	0.748	2.419	4.6360000000000001	6.5208000000000004	5.6608999999999998	5.1997999999999998	4.6234999999999999	4.0471000000000004	3.3666999999999998	2.7065000000000001	2.0461999999999998	1.5865	1.3643000000000001	1.1419999999999999	0.96750000000000003	0.72619999999999996	0.125	0.0040000002	10	97.176003	109.66200000000001	63.313000000000002	\N	103
34755	10838	103	97.727999999999994	4.5658000000000003	0.33600000000000002	3.911	9.6899999999999995	9.9160000000000004	8.5586000000000002	7.6536	6.5224000000000002	5.8878000000000004	4.8616999999999999	3.7751000000000001	2.3719000000000001	1.0025999999999999	0.7228	0.59789999999999999	0.55940000000000001	0.50170000000000003	0.125	0.0060000001	16	98.870003	216.255	124.855	\N	123
29939	10097	40	56.189999999999998	0.75149999999999995	0.745	1.9790000000000001	3.0390000000000001	1.3960999999999999	0.96260000000000001	0.89329999999999998	0.80669999999999997	0.72019999999999995	0.60850000000000004	0.56359999999999999	0.51870000000000005	0.42430000000000001	0.3594	0.29459999999999997	0.24579999999999999	0.20019999999999999	0.125	0.083999999	10	99.861	61.100000000000001	35.276000000000003	\N	51
29940	10097	55	47.993000000000002	1.9350000000000001	1.2250000000000001	2.5489999999999999	3.6970000000000001	4.3223000000000003	3.4137	2.9508000000000001	2.3721999999999999	1.9353	1.5726	1.2098	0.92469999999999997	0.74590000000000001	0.65659999999999996	0.58099999999999996	0.5252	0.4254	0.125	0.0060000001	10	99.228996	70.444000000000003	40.670999999999999	\N	66
29941	10097	70	9.0250000000000004	1.6946000000000001	0.95399999999999996	2.3170000000000002	3.516	3.5175999999999998	2.9578000000000002	2.5846	2.1181000000000001	1.8909	1.5987	1.3066	1.0144	0.79949999999999999	0.69399999999999995	0.60389999999999999	0.55089999999999995	0.45469999999999999	0.125	0.023	10	99.799004	11.949	6.899	\N	81
29942	10097	85	3.585	3.9064999999999999	1.5860000000000001	3.6960000000000002	5.2190000000000003	11.3635	8.8219999999999992	7.2816999999999998	5.5559000000000003	4.0376000000000003	2.8795999999999999	1.8955	1.4305000000000001	0.98209999999999997	0.86199999999999999	0.7419	0.64580000000000004	0.55169999999999997	0.125	0.039000001	10	87.058998	1.5429999999999999	0.89100000000000001	\N	96
29943	10097	100	2.4279999999999999	3.9538000000000002	0.90500000000000003	2.1909999999999998	3.407	8.3933	6.4833999999999996	5.8533999999999997	5.2012999999999998	4.5491999999999999	3.6736	3.1097999999999999	2.5459000000000001	1.9856	1.7587999999999999	1.5319	1.3505	1.0783	0.125	0.028999999	10	95.046997	7.2130000000000001	4.165	\N	111
29934	10096	28	86.613	1.0559000000000001	1.6060000000000001	2.032	2.0169999999999999	1.9765999999999999	1.4926999999999999	1.1701999999999999	0.94210000000000005	0.84179999999999999	0.64129999999999998	0.57950000000000002	0.52600000000000002	0.4627	0.42649999999999999	0.39029999999999998	0.3614	0.318	0.125	0.016000001	10	99.532997	148.488	85.728999999999999	\N	53
29935	10096	48	32.319000000000003	1.8101	1.587	2.4060000000000001	3.0089999999999999	3.9834999999999998	3.1772999999999998	2.6398000000000001	1.9910000000000001	1.8025	1.4254	1.0484	0.86629999999999996	0.71299999999999997	0.63629999999999998	0.5867	0.54900000000000004	0.47370000000000001	0.125	0.013	10	99.199997	57.307000000000002	33.085999999999999	\N	73
29936	10096	68	98.805999999999997	1.8011999999999999	1.0029999999999999	2.0819999999999999	2.8879999999999999	3.5305	2.9453	2.5550999999999999	2.0674999999999999	1.8959999999999999	1.6545000000000001	1.4131	1.1716	0.94520000000000004	0.85040000000000004	0.75560000000000005	0.67969999999999997	0.57289999999999996	0.125	0.017000001	10	99.514999	60.463000000000001	34.908999999999999	\N	93
29937	10096	88	144.17099999999999	2.9830000000000001	0.98599999999999999	2.472	4.4169999999999998	6.0629	5.0336999999999996	4.3475000000000001	3.7928999999999999	3.4445999999999999	2.7481	2.0516000000000001	1.6702999999999999	1.3143	1.1363000000000001	0.96009999999999995	0.82410000000000005	0.62219999999999998	0.125	0.0060000001	16	99.685997	129.28	74.640000000000001	\N	113
29938	10096	108	60.442	5.5102000000000002	0.78600000000000003	2.4489999999999998	5.1040000000000001	11.6096	9.2811000000000003	8.4085000000000001	7.3177000000000003	6.2666000000000004	5.2709999999999999	4.2752999999999997	3.4426999999999999	2.6724000000000001	2.2871999999999999	1.8909	1.5477000000000001	1.0327999999999999	0.125	0.028999999	16	97.376999	85.007999999999996	49.079999999999998	\N	133
27658	9048	24	95.781000000000006	1.7870999999999999	1.1799999999999999	2.4079999999999999	3.4460000000000002	3.7725	3.2006999999999999	2.8195999999999999	2.3431000000000002	1.9492	1.5864	1.2236	0.93440000000000001	0.76329999999999998	0.67779999999999996	0.60229999999999995	0.55200000000000005	0.46039999999999998	0.125	0.0049999999	10	99.635002	199.583	115.229	\N	49
27659	9048	44	51.314999999999998	1.6471	1.272	2.2240000000000002	2.976	3.4980000000000002	2.7383999999999999	2.2320000000000002	1.8978999999999999	1.7366999999999999	1.4142999999999999	1.0919000000000001	0.89049999999999996	0.73740000000000006	0.66090000000000004	0.59740000000000004	0.55369999999999997	0.47520000000000001	0.125	0.003	10	99.459999	95.718000000000004	55.262999999999998	\N	69
27660	9048	64	136.22499999999999	1.7068000000000001	1.194	2.282	3.1739999999999999	3.5708000000000002	2.9759000000000002	2.5792999999999999	2.0834999999999999	1.8612	1.5275000000000001	1.1938	0.93520000000000003	0.78069999999999995	0.70350000000000001	0.62660000000000005	0.5716	0.48130000000000001	0.125	0.0060000001	16	99.925003	118.581	68.462999999999994	\N	89
27661	9048	84	116.88	2.8022	1.1080000000000001	2.5089999999999999	3.8519999999999999	6.0606	4.8217999999999996	3.9984000000000002	3.5969000000000002	3.1955	2.3925999999999998	1.8260000000000001	1.4854000000000001	1.1449	0.98209999999999997	0.86199999999999999	0.76600000000000001	0.62119999999999997	0.125	0.0040000002	16	99.906998	110.86499999999999	64.007999999999996	\N	109
27662	9048	104	6.2670000000000003	5.0800999999999998	0.67000000000000004	2.4390000000000001	5.1509999999999998	9.9939	8.7886000000000006	7.9851000000000001	6.9808000000000003	6.1585999999999999	5.2807000000000004	4.4028999999999998	3.5188999999999999	2.6297000000000001	2.1850999999999998	1.7798	1.478	1.0251999999999999	0.125	0.061000001	10	90.029999	18.861000000000001	10.888999999999999	\N	129
27652	9046	20	25.946999999999999	1.5986	1.756	2.7629999999999999	3.0699999999999998	3.9584000000000001	2.7844000000000002	2.0017	1.734	1.4676	0.9738	0.76039999999999996	0.58309999999999995	0.47549999999999998	0.43590000000000001	0.39629999999999999	0.36470000000000002	0.31719999999999998	0.125	0.011	10	98.906998	45.719000000000001	26.396000000000001	\N	35
27651	9046	45	56.289000000000001	1.6309	1.357	1.958	2.3010000000000002	3.2444999999999999	2.0636999999999999	1.8565	1.6614	1.4662999999999999	1.0761000000000001	0.90490000000000004	0.78659999999999997	0.66839999999999999	0.61509999999999998	0.57250000000000001	0.53849999999999998	0.4677	0.125	0.003	16	99.633003	71.549999999999997	41.310000000000002	\N	60
27650	9046	70	34.930999999999997	1.9342999999999999	0.88600000000000001	2.2890000000000001	3.4950000000000001	3.7273999999999998	3.2376999999999998	2.9112	2.5030999999999999	2.0950000000000002	1.7668999999999999	1.5032000000000001	1.2395	0.97609999999999997	0.84660000000000002	0.71709999999999996	0.61799999999999999	0.50560000000000005	0.125	0.0060000001	10	99.411003	15.662000000000001	9.0419999999999998	\N	85
27649	9046	95	199.44200000000001	3.23	1.0289999999999999	2.141	3.238	6.1475999999999997	5.1230000000000002	4.4400000000000004	3.855	3.5558999999999998	2.9575999999999998	2.3593000000000002	1.8741000000000001	1.5589	1.4013	1.2436	1.1174999999999999	0.91349999999999998	0.125	0.0020000001	16	99.401001	241.31200000000001	139.322	\N	110
27648	9046	120	11.435	5.3227000000000002	1.012	1.9319999999999999	2.7269999999999999	9.8132999999999999	8.6837999999999997	7.9306999999999999	6.9893999999999998	6.1851000000000003	5.3266999999999998	4.4683999999999999	3.7336	3.1474000000000002	2.8542999999999998	2.5611999999999999	2.3268	1.9533	0.125	0.012	10	90.990997	17.876999999999999	10.321	\N	135
27647	9045	28	112.187	1.3200000000000001	1.361	1.8340000000000001	1.917	2.6503000000000001	1.8682000000000001	1.7029000000000001	1.4962	1.2896000000000001	0.9708	0.87309999999999999	0.77549999999999997	0.67789999999999995	0.62919999999999998	0.58830000000000005	0.55559999999999998	0.50649999999999995	0.25	0.0099999998	10	99.852997	67.338999999999999	38.878	\N	43
27646	9045	49	173.17599999999999	1.6328	1.448	2.1389999999999998	2.754	3.5453000000000001	2.4956	1.9595	1.7859	1.6123000000000001	1.2650999999999999	0.96960000000000002	0.84079999999999999	0.71209999999999996	0.64770000000000005	0.5897	0.54530000000000001	0.45939999999999998	0.25	0.1	10	99.233002	53.209000000000003	30.719999999999999	\N	64
27645	9045	70	172.69800000000001	1.9482999999999999	2.153	2.351	2.5259999999999998	4.6837999999999997	3.5627	2.9937999999999998	2.2826	1.8734	1.4532	1.0329999999999999	0.90149999999999997	0.79449999999999998	0.74109999999999998	0.68759999999999999	0.64480000000000004	0.57530000000000003	0.25	0.057	16	99.907997	278.46199999999999	160.77000000000001	\N	85
27644	9045	91	\N	2.9508999999999999	0.875	2.077	3.367	5.6247999999999996	4.7706999999999997	4.2012999999999998	3.8060999999999998	3.5358000000000001	2.9952999999999999	2.4546999999999999	1.9444999999999999	1.595	1.4201999999999999	1.2455000000000001	1.1056999999999999	0.88959999999999995	0.125	0.0020000001	16	99.958	\N	\N	\N	106
27643	9045	112	66.144999999999996	3.1065	0.81799999999999995	1.8799999999999999	2.9620000000000002	5.5625	4.7590000000000003	4.2233999999999998	3.8588	3.6469	3.2231999999999998	2.7995000000000001	2.3757000000000001	1.9511000000000001	1.7354000000000001	1.5196000000000001	1.347	1.0882000000000001	0.25	0.0020000001	10	99.314003	86.155000000000001	49.741	\N	127
27634	9043	30	138.97800000000001	2.4394	1.159	2.5630000000000002	3.5219999999999998	5.6002999999999998	3.9649999999999999	3.5630999999999999	3.0607000000000002	2.5581999999999998	1.8266	1.4366000000000001	1.0466	0.84430000000000005	0.75590000000000002	0.66749999999999998	0.60350000000000004	0.51859999999999995	0.125	0.0060000001	16	99.617996	193.619	111.786	\N	45
27635	9043	52	127.834	2.8140000000000001	1.163	2.488	3.5840000000000001	6.0034000000000001	4.8164999999999996	4.0251999999999999	3.5907	3.1707999999999998	2.3308	1.7958000000000001	1.4588000000000001	1.1217999999999999	0.97040000000000004	0.86370000000000002	0.77839999999999998	0.65029999999999999	0.125	0.0020000001	16	99.436996	178.69300000000001	103.169	\N	67
27636	9043	74	147.221	2.8069999999999999	1.2949999999999999	2.6909999999999998	3.4399999999999999	6.6242999999999999	5.0267999999999997	4.0800999999999998	3.5215000000000001	3.0082	1.9937	1.6420999999999999	1.2905	0.96630000000000005	0.86919999999999997	0.77210000000000001	0.69440000000000002	0.5796	0.125	0.022	16	99.601997	241.392	139.36799999999999	\N	89
27637	9043	96	165.56999999999999	2.8647999999999998	1.1319999999999999	2.4460000000000002	3.5600000000000001	5.9875999999999996	4.7015000000000002	3.9418000000000002	3.5413000000000001	3.1408999999999998	2.3399999999999999	1.8066	1.4706999999999999	1.1347	0.97870000000000001	0.87160000000000004	0.78580000000000005	0.65720000000000001	0.125	0.0040000002	16	99.325996	123.898	71.533000000000001	\N	111
27633	9043	128	136.244	3.0924999999999998	0.93700000000000006	1.8120000000000001	2.5790000000000002	5.7058	4.2431000000000001	3.8561000000000001	3.6164999999999998	3.3769	2.8976999999999999	2.4184999999999999	1.9644999999999999	1.6840999999999999	1.544	1.4037999999999999	1.2916000000000001	1.1234	0.125	0.0040000002	16	99.672997	203.54499999999999	117.517	\N	143
27632	9042	33	15.109999999999999	1.7366999999999999	4.5209999999999999	3.3860000000000001	2.9369999999999998	5.0027999999999997	3.7202999999999999	3.1751999999999998	2.4937	1.8520000000000001	0.85960000000000003	0.51680000000000004	0.4521	0.39900000000000002	0.37240000000000001	0.3458	0.3246	0.29270000000000002	0.125	0.074000001	10	99.499001	17.681999999999999	10.209	\N	53
27631	9042	55	184.52600000000001	2.6581999999999999	1.232	2.7789999999999999	3.7610000000000001	6.1980000000000004	4.2815000000000003	3.6453000000000002	3.0767000000000002	2.508	1.782	1.3878999999999999	0.99670000000000003	0.78449999999999998	0.67830000000000001	0.59940000000000004	0.5544	0.4738	0.125	0.0049999999	31.5	99.846001	89.712999999999994	51.795999999999999	\N	75
27630	9042	77	290.358	2.3336999999999999	1.2330000000000001	2.1760000000000002	2.7269999999999999	4.0045000000000002	3.2364999999999999	2.7267999999999999	2.0897000000000001	1.8833	1.6115999999999999	1.3399000000000001	1.0682	0.88980000000000004	0.81620000000000004	0.74270000000000003	0.68379999999999996	0.59089999999999998	0.125	0.0020000001	16	98.411003	208.35400000000001	120.29300000000001	\N	97
27629	9042	98	69.584999999999994	4.6536999999999997	0.45500000000000002	3.754	8.7460000000000004	11.0176	8.3803000000000001	6.9532999999999996	5.9493999999999998	5.3962000000000003	4.2896999999999998	3.3096999999999999	2.3744999999999998	1.4280999999999999	0.97450000000000003	0.72489999999999999	0.59460000000000002	0.49049999999999999	0.125	0.0070000002	16	97.149002	113.215	65.364000000000004	\N	118
27628	9042	121	14.901	7.7018000000000004	0.66900000000000004	2.7149999999999999	6.4930000000000003	15.2159	13.5085	12.3703	10.9475	9.6903000000000006	7.8357999999999999	6.0837000000000003	4.8243999999999998	3.5642999999999998	2.9333999999999998	2.3025000000000002	1.8328	1.2068000000000001	0.125	0.0049999999	16	92.755997	24.963999999999999	14.413	\N	141
24761	8001	27	41.008000000000003	0.56889999999999996	1.028	1.399	1.5980000000000001	0.76659999999999995	0.57520000000000004	0.5171	0.48749999999999999	0.47110000000000002	0.43819999999999998	0.40539999999999998	0.37259999999999999	0.33979999999999999	0.32340000000000002	0.307	0.29389999999999999	0.2742	0.125	0.044	10	99.952003	25.526	14.737	\N	52
24762	8001	49	381.03199999999998	3.1703999999999999	1.278	2.726	3.8410000000000002	7.5438000000000001	5.4542000000000002	4.5452000000000004	3.7565	3.2881999999999998	2.3517999999999999	1.7698	1.4012	1.0325	0.91649999999999998	0.81520000000000004	0.73409999999999997	0.61229999999999996	0.125	0.0040000002	16	98.766998	479.00299999999999	276.55200000000002	\N	74
24763	8001	71	379.88600000000002	2.5114999999999998	1.506	2.419	2.8889999999999998	5.6696	3.6840000000000002	3.1263999999999998	2.4293	1.9335	1.5872999999999999	1.2411000000000001	0.95840000000000003	0.82140000000000002	0.75280000000000002	0.68430000000000002	0.62949999999999995	0.5494	0.125	0.001	16	98.547997	424.702	245.202	\N	96
24764	8001	92	253.08500000000001	3.3986999999999998	0.71499999999999997	2.7749999999999999	5.444	7.1947000000000001	5.6228999999999996	4.9954000000000001	4.2111999999999998	3.7522000000000002	3.0739999999999998	2.3959000000000001	1.7921	1.2927999999999999	1.0431999999999999	0.86280000000000001	0.72999999999999998	0.56469999999999998	0.125	0.0020000001	16	98.823997	320.02100000000002	184.76400000000001	\N	117
24765	8001	115	17.699999999999999	7.6889000000000003	0.85099999999999998	2.4510000000000001	4.6230000000000002	15.3264	13.326499999999999	11.9932	10.326599999999999	9.2827999999999999	7.4989999999999997	5.8959999999999999	4.6639999999999997	3.5587	3.0802	2.6017000000000001	2.2189000000000001	1.6221000000000001	0.125	0.0080000004	16	92.021004	13.582000000000001	7.8419999999999996	\N	140
24750	7982	30	66.385000000000005	0.77769999999999995	1.0620000000000001	1.627	2.0270000000000001	1.4332	0.99250000000000005	0.9375	0.86870000000000003	0.80000000000000004	0.66249999999999998	0.59179999999999999	0.54169999999999996	0.48659999999999998	0.44669999999999999	0.40670000000000001	0.37469999999999998	0.32679999999999998	0.25	0.38999999	6.2999999999999998	99.848999	31.949999999999999	18.446000000000002	\N	55
24749	7982	51	50.219999999999999	1.0374000000000001	1.4910000000000001	2.0259999999999998	2.3719999999999999	1.9048	1.5523	1.3172999999999999	1.0236000000000001	0.92979999999999996	0.77710000000000001	0.62760000000000005	0.56230000000000002	0.49619999999999997	0.45400000000000001	0.41189999999999999	0.37819999999999998	0.32769999999999999	0.25	0.78100002	10	99.558998	8.8900000000000006	5.133	\N	76
24748	7982	71	40.381999999999998	1.228	1.2410000000000001	1.762	1.982	1.9783999999999999	1.7924	1.6684000000000001	1.5134000000000001	1.3584000000000001	1.0485	0.91310000000000002	0.81000000000000005	0.70699999999999996	0.65549999999999997	0.60960000000000003	0.57740000000000002	0.52910000000000001	0.25	0.15099999	10	99.836998	28.273	16.323	\N	96
24747	7982	91	3.0630000000000002	4.5195999999999996	0.67800000000000005	3.0059999999999998	6.2089999999999996	11.192399999999999	8.4145000000000003	6.6128	5.8193999999999999	5.2611999999999997	4.1448999999999998	3.3997999999999999	2.7101999999999999	2.0205000000000002	1.6126	1.2007000000000001	0.93130000000000002	0.66759999999999997	0.125	0.023	10	87.519997	3.5859999999999999	2.0699999999999998	\N	116
24746	7982	111	0.11799999999999999	6.0955000000000004	0.64700000000000002	1.9770000000000001	4.6040000000000001	10	9.3812999999999995	8.9688999999999997	8.4533000000000005	7.9377000000000004	6.9066000000000001	5.8975	4.9199999999999999	3.9355000000000002	3.3871000000000002	2.8386999999999998	2.3999999999999999	1.5	0.25	0.588	10	90	0.13800000000000001	0.080000000000000002	\N	136
24745	7981	27	199.422	1.3096000000000001	1.391	1.994	2.3889999999999998	2.8296999999999999	1.8807	1.6906000000000001	1.4530000000000001	1.2154	0.92920000000000003	0.79979999999999996	0.67030000000000001	0.58279999999999998	0.54849999999999999	0.51429999999999998	0.47310000000000002	0.38890000000000002	0.25	0.1	10	99.679001	210.90600000000001	121.767	\N	57
24744	7981	47	69.134	1.1611	1.351	2.0329999999999999	2.4550000000000001	2.0674000000000001	1.7070000000000001	1.5042	1.2507999999999999	0.99929999999999997	0.86080000000000001	0.72230000000000005	0.60709999999999997	0.53849999999999998	0.50409999999999999	0.45440000000000003	0.41289999999999999	0.35060000000000002	0.25	0.301	10	99.809998	126.83799999999999	73.230000000000004	\N	77
24743	7981	67	202.61099999999999	1.7505999999999999	1.403	2.2709999999999999	2.9940000000000002	3.6835	2.8298000000000001	2.2606999999999999	1.8934	1.7251000000000001	1.3885000000000001	1.0518000000000001	0.87560000000000004	0.72850000000000004	0.65500000000000003	0.59319999999999995	0.54849999999999999	0.46379999999999999	0.25	0.23	10	98.726997	56.018999999999998	32.343000000000004	\N	97
24742	7981	87	176.07300000000001	2.3744999999999998	1.145	2.492	3.343	5.2885999999999997	3.8965000000000001	3.4933999999999998	2.9895	2.4855999999999998	1.8161	1.4612000000000001	1.1064000000000001	0.87549999999999994	0.78659999999999997	0.69769999999999999	0.62729999999999997	0.54330000000000001	0.125	0.0089999996	16	99.718002	154.57900000000001	89.245999999999995	\N	117
24741	7981	107	236.55000000000001	4.1471	0.86699999999999999	2.698	4.6829999999999998	9.4418000000000006	6.8513999999999999	5.899	5.1627999999999998	4.4264999999999999	3.4712000000000001	2.7267999999999999	1.9895	1.5447	1.3222	1.0998000000000001	0.94140000000000001	0.74119999999999997	0.125	0.0049999999	16	97.718002	384.971	222.26300000000001	\N	137
24100	7324	32	53.627000000000002	1.595	1.4259999999999999	2.5059999999999998	3.383	3.6413000000000002	2.7545999999999999	2.1634000000000002	1.8440000000000001	1.6436999999999999	1.2431000000000001	0.92049999999999998	0.71809999999999996	0.57930000000000004	0.5343	0.48599999999999999	0.43859999999999999	0.36749999999999999	0.063	0.0020000001	10	99.259003	0	0	\N	62
24099	7324	51	10.127000000000001	3.7014999999999998	0.73399999999999999	2.2690000000000001	4.4539999999999997	6.8372000000000002	5.7523999999999997	5.3101000000000003	4.7572999999999999	4.2045000000000003	3.5327999999999999	2.9596	2.3862999999999999	1.8331999999999999	1.5774999999999999	1.3217000000000001	1.1172	0.79320000000000002	0.063	0.0040000002	16	98.906998	0	0	\N	81
24098	7324	71	183.98699999999999	1.4277	1.097	1.8200000000000001	2.415	2.8311999999999999	1.9685999999999999	1.8585	1.7209000000000001	1.5832999999999999	1.3081	1.0327999999999999	0.88680000000000003	0.75829999999999997	0.69399999999999995	0.62980000000000003	0.59460000000000002	0.54169999999999996	0.063	0.0020000001	6.2999999999999998	98.959	0	0	\N	101
24097	7324	93	137.86500000000001	3.8799999999999999	0.77000000000000002	2.3540000000000001	4.343	8.0812000000000008	6.1496000000000004	5.6886999999999999	5.1125999999999996	4.5365000000000002	3.6436999999999999	2.9767999999999999	2.3100000000000001	1.7537	1.5236000000000001	1.2935000000000001	1.1094999999999999	0.83899999999999997	0.063	0.003	16	99.120003	0	0	\N	123
24096	7324	112	0.064000000000000001	5.9814999999999996	0.33800000000000002	2.2749999999999999	6.7119999999999997	9.3564000000000007	8.9702000000000002	8.7126999999999999	8.3909000000000002	8.0691000000000006	7.4253999999999998	6.7817999999999996	5.9668999999999999	4.6424000000000003	3.9544999999999999	2.4363999999999999	1.7324999999999999	1.1063000000000001	0.063	0.12	6.2999999999999998	42.514999	0	0	\N	142
24095	7323	28	12.297000000000001	1.4080999999999999	1.2689999999999999	2.2799999999999998	2.8730000000000002	3.2092000000000001	2.0701999999999998	1.8387	1.6164000000000001	1.3942000000000001	0.98029999999999995	0.80630000000000002	0.63229999999999997	0.53290000000000004	0.48420000000000002	0.4365	0.39839999999999998	0.3412	0.063	0.003	10	99.297997	0	0	\N	58
24094	7323	49	62.341000000000001	2.0922999999999998	0.84299999999999997	2.266	3.6120000000000001	3.9300999999999999	3.5482	3.2936000000000001	2.9754	2.6570999999999998	2.0207000000000002	1.7054	1.4008	1.0963000000000001	0.9476	0.80489999999999995	0.69079999999999997	0.55940000000000001	0.063	0.0020000001	6.2999999999999998	99.083	0	0	\N	79
24093	7323	67	112.58499999999999	2.6307	1.004	2.4369999999999998	3.9369999999999998	5.5208000000000004	4.6082000000000001	3.9998999999999998	3.6282999999999999	3.2568000000000001	2.5137	1.887	1.5209999999999999	1.155	0.98250000000000004	0.86780000000000002	0.77600000000000002	0.63839999999999997	0.063	0.0020000001	10	98.842003	0	0	\N	97
24092	7323	84	39.720999999999997	3.9601000000000002	0.77300000000000002	2.2229999999999999	3.899	8.2041000000000004	6.2666000000000004	5.8587999999999996	5.3491	4.8394000000000004	3.8809	3.2069000000000001	2.5327999999999999	1.9047000000000001	1.6774	1.4500999999999999	1.2683	0.99529999999999996	0.063	0.0020000001	10	95.349998	0	0	\N	114
24091	7323	101	7.5220000000000002	7.1749999999999998	1.0229999999999999	1.9690000000000001	2.9500000000000002	13.745100000000001	11.5364	10.0639	9.2167999999999992	8.4054000000000002	6.7824999999999998	5.7939999999999996	5.0739000000000001	4.3537999999999997	3.9902000000000002	3.4264999999999999	2.9754999999999998	2.2989000000000002	0.063	0.001	16	96.125	0	0	\N	131
34874	10867	44	104.83799999999999	3.6911999999999998	0.84999999999999998	2.2349999999999999	3.7509999999999999	7.7666000000000004	5.9907000000000004	5.4706000000000001	4.8204000000000002	4.1700999999999997	3.4918999999999998	2.9073000000000002	2.3226	1.8059000000000001	1.5892999999999999	1.3727	1.1995	0.93079999999999996	0.125	0.0080000004	10	95.514999	164.41999999999999	94.927999999999997	\N	45
34875	10867	64	152.81	3.2023999999999999	0.98099999999999998	2.4660000000000002	4.149	6.7397999999999998	5.3354999999999997	4.5986000000000002	3.8811	3.5415999999999999	2.8626999999999998	2.1837	1.7333000000000001	1.3676999999999999	1.1849000000000001	1.002	0.877	0.68999999999999995	0.125	0.0060000001	16	99.600998	198.84299999999999	114.80200000000001	\N	65
34876	10867	84	14.488	3.6440000000000001	0.65000000000000002	2.6600000000000001	5.7249999999999996	7.9941000000000004	6.1734999999999998	5.6737000000000002	5.0491000000000001	4.4244000000000003	3.5539999999999998	2.8784000000000001	2.2029000000000001	1.6114999999999999	1.3339000000000001	1.0563	0.87260000000000004	0.62080000000000002	0.125	0.032000002	10	95.904999	29.853000000000002	17.234999999999999	\N	85
34877	10867	104	52.749000000000002	2.8769	1.151	2.6080000000000001	3.698	6.2537000000000003	4.7298999999999998	3.9001999999999999	3.4569999999999999	3.0137999999999998	2.1274000000000002	1.6899	1.3278000000000001	0.98070000000000002	0.87870000000000004	0.77680000000000005	0.69520000000000004	0.57530000000000003	0.125	0.0060000001	16	98.973	94.808999999999997	54.738	\N	105
34878	10867	124	96.686999999999998	3.2313000000000001	1.165	1.9910000000000001	2.851	5.9802	4.0206	3.7265999999999999	3.3794	3.0322	2.3378000000000001	1.8707	1.6188	1.367	1.2410000000000001	1.1151	1.0144	0.81989999999999996	0.125	0.0040000002	16	97.268997	199.86199999999999	115.39	\N	125
34869	10866	44	35.143999999999998	3.0045000000000002	0.96699999999999997	2.5990000000000002	4.3620000000000001	6.1646000000000001	4.8795999999999999	4.0229999999999997	3.6444000000000001	3.2810999999999999	2.5543999999999998	1.9095	1.5281	1.1467000000000001	0.96850000000000003	0.83189999999999997	0.72260000000000002	0.58560000000000001	0.125	0.0040000002	16	99.079002	71.182000000000002	41.097000000000001	\N	45
34870	10866	74	359.25999999999999	2.7218	1.022	2.3210000000000002	3.6509999999999998	5.6741000000000001	4.3596000000000004	3.8313999999999999	3.4738000000000002	3.1162999999999998	2.4013	1.8577999999999999	1.5336000000000001	1.2094	1.0472999999999999	0.91049999999999998	0.80940000000000001	0.65769999999999995	0.125	0.0040000002	16	99.667999	386.02800000000002	222.874	\N	75
34871	10866	94	104.675	2.7786	0.99199999999999999	2.3940000000000001	3.8559999999999999	5.7721999999999998	4.3630000000000004	3.8208000000000002	3.4558	3.0907	2.3605999999999998	1.8297000000000001	1.4930000000000001	1.1564000000000001	0.99099999999999999	0.86329999999999996	0.76119999999999999	0.61229999999999996	0.125	0.0049999999	16	99.583	134.30699999999999	77.542000000000002	\N	95
34872	10866	114	150.24299999999999	2.8382000000000001	1.046	2.2370000000000001	3.419	5.7915999999999999	4.1291000000000002	3.7364999999999999	3.3637000000000001	2.9908999999999999	2.2452999999999999	1.8055000000000001	1.5156000000000001	1.2258	1.0809	0.93789999999999996	0.82540000000000002	0.65669999999999995	0.125	0.0020000001	16	99.098	312.18900000000002	180.24299999999999	\N	115
34873	10866	134	89.488	5.1687000000000003	0.312	3.5150000000000001	9.9760000000000009	10.014699999999999	8.9419000000000004	8.234	7.3491999999999997	6.4642999999999997	5.4683000000000002	4.5514999999999999	3.5474999999999999	2.4117999999999999	1.7781	0.98809999999999998	0.72389999999999999	0.54820000000000002	0.125	0.003	16	98.746002	239.083	138.035	\N	135
34756	10839	40	68.774000000000001	2.2675000000000001	1.5469999999999999	2.4239999999999999	2.8690000000000002	5.3964999999999996	3.7124000000000001	3.1644000000000001	2.4792999999999998	1.9462999999999999	1.5887	1.2312000000000001	0.95269999999999999	0.81889999999999996	0.752	0.68510000000000004	0.63160000000000005	0.55369999999999997	0.125	0.003	10	96.579002	166.20500000000001	95.959000000000003	\N	40
34757	10839	60	157.25399999999999	2.5933999999999999	1.157	2.6000000000000001	3.6110000000000002	5.8133999999999997	4.5651000000000002	3.8814000000000002	3.4195000000000002	2.9575999999999998	2.0337999999999998	1.6323000000000001	1.2506999999999999	0.93610000000000004	0.84299999999999997	0.74990000000000001	0.6754	0.56320000000000003	0.125	0.0020000001	16	99.768997	207.809	119.979	\N	60
34758	10839	90	9.6150000000000002	1.7548999999999999	1.095	2.5299999999999998	3.823	3.7864	3.0594000000000001	2.5746000000000002	1.9914000000000001	1.8242	1.4899	1.1556999999999999	0.89590000000000003	0.70099999999999996	0.61009999999999998	0.53659999999999997	0.47789999999999999	0.38979999999999998	0.125	0.015	10	99.361	18.405000000000001	10.625999999999999	\N	90
34759	10839	120	205.172	1.8267	1.1060000000000001	2.161	2.827	3.6743000000000001	3.0388999999999999	2.6152000000000002	2.0855999999999999	1.8851	1.611	1.3369	1.0629	0.876	0.79559999999999997	0.71519999999999995	0.65080000000000005	0.56979999999999997	0.125	0.003	10	99.427002	207.666	119.896	\N	120
34760	10839	140	18.997	2.5158999999999998	0.70599999999999996	2.8479999999999999	5.6509999999999998	5.5056000000000003	4.3385999999999996	3.8414999999999999	3.4906000000000001	3.1398000000000001	2.4380999999999999	1.8129999999999999	1.3150999999999999	0.87960000000000005	0.71560000000000001	0.59440000000000004	0.53469999999999995	0.43149999999999999	0.125	0.0070000002	10	98.424004	56.912999999999997	32.859000000000002	\N	140
29956	10099	41	43.859999999999999	1.3792	1.097	1.6299999999999999	2.0510000000000002	2.1772	1.8815999999999999	1.7899	1.6752	1.5606	1.3312999999999999	1.1020000000000001	0.94520000000000004	0.84650000000000003	0.79710000000000003	0.74770000000000003	0.70830000000000004	0.64900000000000002	0.125	0.0040000002	10	99.813004	132.91	76.736000000000004	\N	56
29957	10099	61	15.789	1.4160999999999999	1.006	1.845	2.7360000000000002	2.7553999999999998	1.9585999999999999	1.8526	1.7202	1.5878000000000001	1.323	1.0582	0.89670000000000005	0.76429999999999998	0.69799999999999995	0.63180000000000003	0.57520000000000004	0.48359999999999997	0.125	0.0089999996	10	99.648003	32.527999999999999	18.780000000000001	\N	76
29958	10099	81	55.029000000000003	1.6027	1.3300000000000001	2.2909999999999999	2.9180000000000001	3.3245	2.2984	1.9057999999999999	1.6970000000000001	1.4881	1.0704	0.86990000000000001	0.71340000000000003	0.58479999999999999	0.53639999999999999	0.48530000000000001	0.43790000000000001	0.3669	0.125	0.0080000004	16	99.244003	67.072999999999993	38.725000000000001	\N	96
29959	10099	101	24.84	1.6551	1.079	2.1520000000000001	2.9750000000000001	3.4039999999999999	2.6928000000000001	2.2185999999999999	1.9108000000000001	1.7695000000000001	1.4867999999999999	1.2041999999999999	0.95569999999999999	0.79610000000000003	0.71630000000000005	0.63649999999999995	0.58130000000000004	0.49980000000000002	0.125	0.039000001	16	99.883003	20.876999999999999	12.054	\N	116
29960	10099	121	26.568999999999999	1.0178	1.103	2.129	3.722	1.8928	1.6449	1.4797	1.2730999999999999	1.0666	0.87939999999999996	0.73550000000000004	0.61339999999999995	0.55100000000000005	0.51990000000000003	0.4572	0.36280000000000001	0.23630000000000001	0.125	0.13600001	6.2999999999999998	99.859001	50.401000000000003	29.099	\N	136
29950	9657	37	209.81	2.9702000000000002	1.1439999999999999	2.2120000000000002	3.1709999999999998	6.0393999999999997	4.4710999999999999	3.8454000000000002	3.4937999999999998	3.1421000000000001	2.4386999999999999	1.8899999999999999	1.5975999999999999	1.3051999999999999	1.1589	1.0126999999999999	0.91390000000000005	0.76910000000000001	0.125	0.003	16	99.211998	25.242000000000001	14.573	\N	45
29951	9657	58	85.573999999999998	2.3795999999999999	1.1659999999999999	2.3780000000000001	3.169	5.2309999999999999	3.8584999999999998	3.4708999999999999	2.9864999999999999	2.5019999999999998	1.8383	1.5027999999999999	1.1673	0.9163	0.83279999999999998	0.74929999999999997	0.6825	0.58020000000000005	0.125	0.0060000001	16	99.609001	83.950000000000003	48.468000000000004	\N	66
29952	9657	78	70.173000000000002	1.9641999999999999	1.274	2.512	3.4780000000000002	4.3883999999999999	3.4965000000000002	3.0703999999999998	2.5377999999999998	2.0051999999999999	1.6174999999999999	1.2331000000000001	0.93310000000000004	0.7631	0.67810000000000004	0.60329999999999995	0.55400000000000005	0.46500000000000002	0.125	0.0070000002	10	99.223	144.43000000000001	83.387	\N	86
29953	9657	98	200.43600000000001	1.6571	1.524	2.2989999999999999	3.1720000000000002	3.6240000000000001	2.8043	2.2578	1.8861000000000001	1.7032	1.3372999999999999	0.98819999999999997	0.83660000000000001	0.68510000000000004	0.6169	0.56889999999999996	0.53059999999999996	0.42159999999999997	0.063	0.0020000001	10	99.198997	343.14600000000002	198.11500000000001	\N	106
29954	9657	118	134.45400000000001	1.4099999999999999	1.347	1.911	2.226	3.0076000000000001	1.9384999999999999	1.7786	1.5786	1.3786	0.99360000000000004	0.87419999999999998	0.75480000000000003	0.63539999999999996	0.5968	0.56020000000000003	0.53100000000000003	0.44640000000000002	0.063	0.0049999999	16	99.947998	306.04300000000001	176.69399999999999	\N	126
29955	9657	138	64.768000000000001	4.8320999999999996	0.5	2.7530000000000001	8.3569999999999993	9.4151000000000007	8.3244000000000007	7.5972999999999997	6.6882999999999999	6.0465999999999998	5.1618000000000004	4.2769000000000004	3.3904999999999998	2.5034000000000001	2.0598000000000001	1.5314000000000001	1.0980000000000001	0.61770000000000003	0.125	0.0099999998	16	99.508003	167.13900000000001	96.498000000000005	\N	146
27726	9082	43	15.628	1.8372999999999999	1.671	2.4209999999999998	2.9980000000000002	4.1185999999999998	3.2589999999999999	2.7368999999999999	2.0842000000000001	1.8286	1.4351	1.0416000000000001	0.87409999999999999	0.73329999999999995	0.66290000000000004	0.60050000000000003	0.55620000000000003	0.47870000000000001	0.125	0.0089999996	10	99.546997	38.515000000000001	22.236999999999998	\N	64
27727	9082	63	155.446	1.4778	1.325	1.9259999999999999	2.395	3.0975999999999999	2.1438999999999999	1.8977999999999999	1.7325999999999999	1.5674999999999999	1.2372000000000001	0.96709999999999996	0.85060000000000002	0.73399999999999999	0.67569999999999997	0.61899999999999999	0.57799999999999996	0.51659999999999995	0.125	0.0040000002	10	99.639999	171.68100000000001	99.120000000000005	\N	84
27728	9082	83	122.681	1.5129999999999999	1.1240000000000001	1.972	2.6379999999999999	3.1333000000000002	2.3610000000000002	1.9665999999999999	1.8270999999999999	1.6875	1.4084000000000001	1.1293	0.92779999999999996	0.79339999999999999	0.72609999999999997	0.65890000000000004	0.60740000000000005	0.53400000000000003	0.125	0.0049999999	10	99.892998	317.19400000000002	183.13200000000001	\N	104
27729	9082	103	35.481000000000002	1.0369999999999999	1.276	1.734	1.9970000000000001	1.8341000000000001	1.5771999999999999	1.4059999999999999	1.1919	0.99509999999999998	0.90010000000000001	0.80510000000000004	0.70999999999999996	0.61929999999999996	0.58540000000000003	0.5514	0.52429999999999999	0.45079999999999998	0.125	0.0049999999	6.2999999999999998	99.766998	53.75	31.033000000000001	\N	124
27730	9082	123	94.659000000000006	1.4084000000000001	1.395	1.879	2.0710000000000002	3.0402	2.0451000000000001	1.8576999999999999	1.6668000000000001	1.4759	1.0942000000000001	0.92149999999999999	0.81720000000000004	0.71289999999999998	0.66080000000000005	0.61280000000000001	0.57899999999999996	0.52849999999999997	0.125	0.0040000002	10	99.953003	45.680999999999997	26.373999999999999	\N	144
23985	7281	24	16.718	5.9009999999999998	1.0469999999999999	4.1550000000000002	6.8550000000000004	16.210999999999999	12.295299999999999	9.8452999999999999	7.7439	5.9705000000000004	3.9329999999999998	2.8923000000000001	1.9106000000000001	1.2837000000000001	0.98560000000000003	0.83360000000000001	0.71209999999999996	0.57379999999999998	0.063	0.0020000001	16	89.862	0	0	\N	69
23984	7281	36	17.218	1.7422	2.1080000000000001	2.3759999999999999	2.153	4.1910999999999996	3.0291999999999999	2.3188	1.8389	1.5874999999999999	1.0847	0.878	0.73129999999999995	0.61309999999999998	0.58579999999999999	0.55840000000000001	0.53649999999999998	0.50370000000000004	0.063	0.0020000001	10	98.649002	0	0	\N	81
23983	7281	48	36.594999999999999	2.3473999999999999	1.177	2.831	4.0979999999999999	5.7256999999999998	4.3075999999999999	3.7222	3.2075999999999998	2.6930000000000001	1.8529	1.4027000000000001	0.97550000000000003	0.74319999999999997	0.62870000000000004	0.57799999999999996	0.53749999999999998	0.45219999999999999	0.063	0.0060000001	10	98.654999	0	0	\N	93
23982	7281	60	27.710999999999999	1.8774999999999999	1.2310000000000001	2.46	3.4289999999999998	4.0644999999999998	3.3206000000000002	2.8513000000000002	2.2645	1.9054	1.5608	1.2162999999999999	0.93540000000000001	0.76170000000000004	0.67490000000000006	0.59930000000000005	0.54859999999999998	0.45519999999999999	0.063	0.003	10	99.035004	0	0	\N	105
23981	7281	72	14.843	4.8956999999999997	0.49099999999999999	4.7560000000000002	12.058	12.870799999999999	10.8226	9.4732000000000003	7.8167999999999997	6.2361000000000004	4.7183000000000002	3.2480000000000002	1.8633999999999999	0.88439999999999996	0.62180000000000002	0.54079999999999995	0.47849999999999998	0.39129999999999998	0.063	0.0040000002	16	99.167	0	0	\N	117
26285	8581	22	6.1459999999999999	1.0496000000000001	1.6659999999999999	1.9390000000000001	2.1000000000000001	1.9550000000000001	1.5328999999999999	1.2514000000000001	0.97660000000000002	0.89470000000000005	0.73089999999999999	0.61250000000000004	0.56710000000000005	0.52159999999999995	0.4975	0.44769999999999999	0.4078	0.34799999999999998	0.063	0.003	10	99.556	0	0	\N	72
26284	8581	32	5.4169999999999998	1.0253000000000001	1.236	1.7430000000000001	1.9099999999999999	1.7834000000000001	1.0700000000000001	0.92210000000000003	0.80789999999999995	0.69369999999999998	0.59740000000000004	0.55220000000000002	0.50690000000000002	0.44429999999999997	0.41139999999999999	0.37859999999999999	0.3523	0.31280000000000002	0.063	0.0080000004	10	99.109001	0	0	\N	82
26283	8581	45	5.7290000000000001	0.75449999999999995	1.0800000000000001	1.6040000000000001	1.875	0.98050000000000004	0.85289999999999999	0.76790000000000003	0.66149999999999998	0.61229999999999996	0.56210000000000004	0.51180000000000003	0.45929999999999999	0.40610000000000002	0.3795	0.35289999999999999	0.33160000000000001	0.29970000000000002	0.063	0.0070000002	6.2999999999999998	98.938004	0	0	\N	95
26282	8581	56	9.1669999999999998	1.3672	1.1180000000000001	1.8440000000000001	2.4529999999999998	2.4161000000000001	1.8689	1.7561	1.6151	1.474	1.1919	0.95840000000000003	0.82820000000000005	0.69799999999999995	0.63290000000000002	0.58630000000000004	0.54959999999999998	0.48599999999999999	0.063	0.0049999999	6.2999999999999998	98.68	0	0	\N	106
26281	8581	69	0.83299999999999996	5.5772000000000004	0.31900000000000001	3.7909999999999999	11.871	12.5733	10.517300000000001	9.3657000000000004	8.0922000000000001	6.8186999999999998	5.6859999999999999	4.915	4.1440000000000001	2.7706	2.0146999999999999	1.1409	0.7319	0.47899999999999998	0.063	0.026000001	10	82.489998	0	0	\N	119
23336	6743	23	28.878	0.94999999999999996	1.3149999999999999	1.8700000000000001	2.274	1.7736000000000001	1.4329000000000001	1.2057	0.98270000000000002	0.91969999999999996	0.79390000000000005	0.66810000000000003	0.58879999999999999	0.52969999999999995	0.50019999999999998	0.44990000000000002	0.40960000000000002	0.34910000000000002	0.063	0.0049999999	6.2999999999999998	99.607002	0	0	\N	63
23335	6743	35	15.366	1.3986000000000001	1.169	2.0649999999999999	2.7200000000000002	2.9653999999999998	1.9169	1.7666999999999999	1.5790999999999999	1.3914	1.0161	0.85860000000000003	0.71089999999999998	0.58960000000000001	0.54490000000000005	0.50019999999999998	0.4496	0.37359999999999999	0.063	0.011	10	99.315002	0	0	\N	75
23334	6743	47	19.096	0.89710000000000001	1.036	1.591	1.9390000000000001	1.2549999999999999	0.94620000000000004	0.89400000000000002	0.8286	0.76319999999999999	0.63249999999999995	0.58450000000000002	0.53820000000000001	0.4859	0.44590000000000002	0.40600000000000003	0.374	0.3261	0.063	0.015	10	99.529999	0	0	\N	87
23333	6743	59	31.744	2.4722	0.79100000000000004	2.7229999999999999	4.7350000000000003	5.4280999999999997	4.0612000000000004	3.6949000000000001	3.2862	2.8774000000000002	2.0598999999999998	1.6769000000000001	1.3282	0.97870000000000001	0.79749999999999999	0.62290000000000001	0.54790000000000005	0.435	0.063	0.0080000004	10	97.676003	0	0	\N	99
23332	6743	71	1.6879999999999999	4.7504999999999997	0.35899999999999999	4.1070000000000002	11.074999999999999	11.389799999999999	8.8772000000000002	7.6443000000000003	6.2340999999999998	5.718	4.6859000000000002	3.609	2.4430999999999998	1.2684	0.80569999999999997	0.5897	0.5262	0.42309999999999998	0.063	0.021	16	97.819	0	0	\N	111
23331	6742	28	11.715	3.0884999999999998	4.4329999999999998	3.343	2.0790000000000002	11.4	6.4528999999999996	3.0663	1.8462000000000001	1.6020000000000001	1.1135999999999999	0.91690000000000005	0.80859999999999999	0.70030000000000003	0.64610000000000001	0.60550000000000004	0.57750000000000001	0.53559999999999997	0.125	0.0020000001	16	97.720001	0	0	\N	68
23330	6742	41	6.5220000000000002	2.7469999999999999	0.91400000000000003	2.944	4.8869999999999996	6.0804	5.1588000000000003	4.5444000000000004	3.8727999999999998	3.4359000000000002	2.5619999999999998	1.8335999999999999	1.3673	0.9405	0.80030000000000001	0.66010000000000002	0.59530000000000005	0.52429999999999999	0.063	0.001	10	98.559998	0	0	\N	81
23329	6742	52	1.145	1.7555000000000001	1.712	2.6150000000000002	3.4809999999999999	4.3070000000000004	3.3367	2.7991999999999999	2.1273	1.8222	1.3835	0.97540000000000004	0.77980000000000005	0.61040000000000005	0.56859999999999999	0.52680000000000005	0.48799999999999999	0.39739999999999998	0.25	0.242	6.2999999999999998	96.907997	0	0	\N	92
23328	6742	65	38.149999999999999	3.4868000000000001	5.8540000000000001	4.5119999999999996	4.3360000000000003	11.011699999999999	7.6451000000000002	5.9402999999999997	4.6391	3.3508	1.4231	0.70030000000000003	0.56399999999999995	0.48580000000000001	0.44640000000000002	0.40699999999999997	0.3755	0.32819999999999999	0.063	0.001	16	96.986	0	0	\N	105
23327	6742	77	0.20899999999999999	1.0589999999999999	1.869	2.274	2.3149999999999999	2.6185	1.7859	1.5208999999999999	1.1896	0.94979999999999998	0.71489999999999998	0.57440000000000002	0.49109999999999998	0.43030000000000002	0.39989999999999998	0.36959999999999998	0.34520000000000001	0.30880000000000002	0.125	0.033	4	96.185997	0	0	\N	117
23326	6741	95	56.722000000000001	10.084199999999999	0.66600000000000004	6.0860000000000003	15.692	27.196400000000001	22.773900000000001	19.825500000000002	16.140000000000001	13.5609	8.4466999999999999	4.5837000000000003	2.2221000000000002	1.1194999999999999	0.87939999999999996	0.7198	0.6149	0.5383	0.063	0.0060000001	31.5	95.838997	0	0	\N	70
23325	6741	107	94.445999999999998	6.8155999999999999	0.77700000000000002	5.1749999999999998	11.164	19.863600000000002	14.8056	13.0227	10.7942	8.4268999999999998	5.0998999999999999	3.2456	1.8236000000000001	0.97929999999999995	0.76680000000000004	0.60619999999999996	0.55279999999999996	0.45679999999999998	0.063	0.0060000001	16	86.68	0	0	\N	82
23324	6741	118	108.015	7.1124999999999998	0.66800000000000004	4.2720000000000002	10.143000000000001	19.204599999999999	14.4558	12.6357	10.3606	8.4246999999999996	5.6479999999999997	4.1406000000000001	2.9493	1.8520000000000001	1.4426000000000001	1.0333000000000001	0.79210000000000003	0.55679999999999996	0.063	0.0049999999	16	87.393997	0	0	\N	93
23323	6741	129	104.191	6.9589999999999996	0.871	3.3300000000000001	6.7779999999999996	17.4282	13.4414	11.388400000000001	9.3384	7.8971	5.6905999999999999	4.3240999999999996	3.2412000000000001	2.2464	1.8273999999999999	1.4855	1.2119	0.83960000000000001	0.063	0.0060000001	16	88.985001	0	0	\N	104
23322	6741	142	53.578000000000003	11.1494	0.65400000000000003	2.9329999999999998	8.1590000000000007	25.372199999999999	21.695499999999999	19.244399999999999	16.180499999999999	14.688599999999999	11.9017	9.1501000000000001	6.4744000000000002	4.7803000000000004	3.9679000000000002	3.1648000000000001	2.5223	1.4587000000000001	0.063	0.0070000002	16	74.706001	0	0	\N	117
23321	6741	154	33.902999999999999	6.4282000000000004	0.624	3.536	9.1769999999999996	14.871499999999999	12.1974	10.4146	8.9966000000000008	7.7638999999999996	5.7413999999999996	4.3663999999999996	3.1505999999999998	1.9954000000000001	1.6292	1.2629999999999999	0.9758	0.62560000000000004	0.063	0.0080000004	16	92.531998	0	0	\N	129
23405	1991	22	18.164999999999999	1.3225	1.319	1.964	2.4089999999999998	2.5373999999999999	1.8232999999999999	1.6498999999999999	1.4332	1.2164999999999999	0.93600000000000005	0.80830000000000002	0.68049999999999999	0.58650000000000002	0.55059999999999998	0.51470000000000005	0.47260000000000002	0.3886	0.063	0.0020000001	10	99.179001	0	0	\N	62
23404	1991	33	11.967000000000001	2.3940999999999999	0.89300000000000002	3.024	5.0110000000000001	5.5875000000000004	4.4909999999999997	3.8769	3.4079999999999999	2.9390999999999998	2.0013000000000001	1.5718000000000001	1.143	0.79730000000000001	0.6452	0.55610000000000004	0.49109999999999998	0.39929999999999999	0.063	0.0020000001	10	98.899002	0	0	\N	73
13299	1991	37	2.972	1.3226	1.319	1.964	2.4089999999999998	2.5373999999999999	1.8232999999999999	1.6499999999999999	1.4333	1.2165999999999999	0.93610000000000004	0.80830000000000002	0.68049999999999999	0.58650000000000002	0.55059999999999998	0.51470000000000005	0.47260000000000002	0.3886	0.125	0.0020000001	10	99.178001	0	0	\N	77
23403	1991	45	13.646000000000001	0.97409999999999997	1.4930000000000001	1.9910000000000001	2.331	1.8859999999999999	1.5427	1.3138000000000001	1.0278	0.93259999999999998	0.78320000000000001	0.63390000000000002	0.57030000000000003	0.50890000000000002	0.46860000000000002	0.4244	0.38900000000000001	0.33600000000000002	0.063	0.0020000001	4	97.973999	0	0	\N	85
13300	1991	48	3.9929999999999999	2.3940999999999999	0.89300000000000002	3.024	5.0110000000000001	5.5875000000000004	4.4911000000000003	3.8769	3.4079999999999999	2.9390999999999998	2.0013999999999998	1.5718000000000001	1.143	0.79730000000000001	0.64529999999999998	0.55620000000000003	0.49109999999999998	0.39939999999999998	0.125	0.003	10	98.899002	0	0	\N	88
23402	1991	57	19.262	1.0222	1.296	1.726	1.9450000000000001	1.802	1.5637000000000001	1.4049	1.2063999999999999	1.0078	0.89880000000000004	0.79559999999999997	0.69240000000000002	0.60680000000000001	0.57750000000000001	0.54820000000000002	0.52480000000000004	0.46210000000000001	0.063	0.003	6.2999999999999998	99.816002	0	0	\N	97
13301	1991	60	2.847	0.97409999999999997	1.4930000000000001	1.9910000000000001	2.331	1.8859999999999999	1.5427	1.3139000000000001	1.0278	0.93259999999999998	0.7833	0.63390000000000002	0.57030000000000003	0.50890000000000002	0.46860000000000002	0.4244	0.38900000000000001	0.33600000000000002	0.125	0.0099999998	4	97.973999	0	0	\N	100
23401	1991	69	0.55800000000000005	5.4320000000000004	0.28899999999999998	4.899	14.198	13.1976	11.5162	10.395300000000001	8.9347999999999992	7.4511000000000003	5.5693999999999999	4.3757999999999999	3.0455999999999999	1.5286	0.79110000000000003	0.5575	0.47989999999999999	0.39229999999999998	0.063	0.013	10	78.588997	0	0	\N	109
13302	1991	72	2.6739999999999999	1.0222	1.296	1.726	1.9450000000000001	1.802	1.5637000000000001	1.4049	1.2063999999999999	1.0078	0.89880000000000004	0.79559999999999997	0.6925	0.6069	0.5776	0.54820000000000002	0.52480000000000004	0.46210000000000001	0.125	0.003	6.2999999999999998	99.816002	0	0	\N	112
13303	1991	84	0.55600000000000005	5.4325999999999999	0.28899999999999998	4.8979999999999997	14.193	13.198	11.5168	10.396000000000001	8.9358000000000004	7.4522000000000004	5.5700000000000003	4.3765999999999998	3.0467	1.5302	0.79200000000000004	0.55779999999999996	0.47999999999999998	0.39240000000000003	0.125	0.013	10	78.586998	0	0	\N	124
23385	1992	26	18.311	2.3071000000000002	1.6850000000000001	1.9970000000000001	1.847	5.1985999999999999	2.2239	1.8221000000000001	1.5588	1.2955000000000001	0.95660000000000001	0.85760000000000003	0.75860000000000005	0.65969999999999995	0.61680000000000001	0.58379999999999999	0.55740000000000001	0.51780000000000004	0.063	0.0020000001	16	97.594002	0	0	\N	66
13304	1992	31	3.3330000000000002	2.3071000000000002	1.6859999999999999	1.9970000000000001	1.847	5.1988000000000003	2.2240000000000002	1.8222	1.5588	1.2955000000000001	0.95660000000000001	0.85760000000000003	0.75870000000000004	0.65969999999999995	0.61680000000000001	0.58379999999999999	0.55740000000000001	0.51780000000000004	0.125	0.0020000001	16	97.594002	0	0	\N	71
23384	1992	40	16.814	4.4973999999999998	1.762	4.3799999999999999	6.5659999999999998	13.220499999999999	9.9598999999999993	7.8784999999999998	5.7774000000000001	4.4484000000000004	2.7732000000000001	1.7133	1.111	0.77290000000000003	0.63370000000000004	0.56920000000000004	0.51919999999999999	0.4224	0.063	0.001	16	95.112	0	0	\N	80
13305	1992	45	6.1459999999999999	4.4974999999999996	1.762	4.3799999999999999	6.5659999999999998	13.220499999999999	9.9600000000000009	7.8787000000000003	5.7774999999999999	4.4485000000000001	2.7732999999999999	1.7133	1.111	0.77300000000000002	0.63380000000000003	0.56920000000000004	0.51919999999999999	0.4224	0.125	0.001	16	95.112	0	0	\N	85
23383	1992	54	6.7300000000000004	3.3925000000000001	1.1919999999999999	3.7360000000000002	5.4610000000000003	9.3969000000000005	5.9960000000000004	4.8951000000000002	3.7852000000000001	3.1707999999999998	1.9761	1.4699	0.97260000000000002	0.61429999999999996	0.54069999999999996	0.4748	0.42959999999999998	0.36180000000000001	0.063	0.0020000001	16	97.086998	0	0	\N	94
13306	1992	59	2.9239999999999999	3.3925999999999998	1.1919999999999999	3.7360000000000002	5.4610000000000003	9.3970000000000002	5.9961000000000002	4.8952999999999998	3.7852999999999999	3.1709000000000001	1.9761	1.47	0.97260000000000002	0.61439999999999995	0.54069999999999996	0.4748	0.42959999999999998	0.36180000000000001	0.125	0.0020000001	16	97.086998	0	0	\N	99
23382	1992	68	16.844000000000001	6.6492000000000004	0.83399999999999996	2.5659999999999998	5.6420000000000003	14.4725	11.5128	9.7893000000000008	8.6601999999999997	7.5311000000000003	5.8665000000000003	4.9134000000000002	3.9624999999999999	3.0649000000000002	2.6160999999999999	2.1673	1.7479	1.0398000000000001	0.063	0.0020000001	16	93.097	0	0	\N	108
13307	1992	73	6.7359999999999998	6.6494	0.83399999999999996	2.5659999999999998	5.641	14.4726	11.513	9.7894000000000005	8.6602999999999994	7.5312999999999999	5.8666	4.9134000000000002	3.9626000000000001	3.0649999999999999	2.6162000000000001	2.1674000000000002	1.7481	1.04	0.125	0.003	16	93.097	0	0	\N	113
23381	1992	82	8.2850000000000001	3.8058000000000001	3.903	4.5030000000000001	4.6260000000000003	12.187200000000001	7.7674000000000003	5.7622	4.1776999999999997	3.0781000000000001	1.5344	0.87309999999999999	0.61439999999999995	0.504	0.46029999999999999	0.41739999999999999	0.3831	0.33169999999999999	0.063	0.0040000002	16	94.351997	0	0	\N	122
13308	1992	87	3.75	3.8058999999999998	3.903	4.5030000000000001	4.6260000000000003	12.1876	7.7678000000000003	5.7624000000000004	4.1779999999999999	3.0783	1.5346	0.87319999999999998	0.61439999999999995	0.504	0.46029999999999999	0.41739999999999999	0.3831	0.33169999999999999	0.125	0.024	16	94.351997	0	0	\N	127
23365	1993	21	20.399000000000001	4.9794999999999998	5.96	5.7539999999999996	5.7140000000000004	15.2662	12.6408	10.890599999999999	7.2065999999999999	4.6018999999999997	1.8975	0.89980000000000004	0.59440000000000004	0.49769999999999998	0.45629999999999998	0.41489999999999999	0.38169999999999998	0.33210000000000001	0.063	0.003	16	91.677002	0	0	\N	61
23364	1993	33	30.699999999999999	2.6909000000000001	1.974	3.3820000000000001	4.633	6.3288000000000002	4.7327000000000004	3.8431999999999999	3.1962000000000002	2.5491999999999999	1.6314	0.996	0.70389999999999997	0.55569999999999997	0.50590000000000002	0.45479999999999998	0.41370000000000001	0.35210000000000002	0.063	0.0020000001	16	98.305	0	0	\N	73
13309	1993	36	4.375	4.9795999999999996	5.9589999999999996	5.7539999999999996	5.7140000000000004	15.266299999999999	12.641	10.8909	7.2073999999999998	4.6022999999999996	1.8976	0.89990000000000003	0.59440000000000004	0.49769999999999998	0.45629999999999998	0.41489999999999999	0.38179999999999997	0.33210000000000001	0.125	0.003	16	91.677002	0	0	\N	76
23363	1993	45	31.295000000000002	2.657	2.3119999999999998	3.294	3.8340000000000001	7.7229000000000001	4.8072999999999997	3.6732999999999998	2.7483	1.9495	1.4200999999999999	0.9597	0.7641	0.59709999999999996	0.54479999999999995	0.49130000000000001	0.443	0.37040000000000001	0.063	0.001	16	98.956001	0	0	\N	85
13310	1993	48	4.2640000000000002	2.6909000000000001	1.974	3.3820000000000001	4.633	6.3289999999999997	4.7327000000000004	3.8433000000000002	3.1962999999999999	2.5491999999999999	1.6315	0.996	0.70389999999999997	0.55569999999999997	0.50590000000000002	0.45479999999999998	0.41370000000000001	0.35210000000000002	0.125	0.0020000001	16	98.305	0	0	\N	88
23362	1993	56	19.776	2.5150999999999999	1.2050000000000001	2.6139999999999999	3.7770000000000001	3.9603999999999999	3.0057	2.3693	1.9077999999999999	1.7358	1.3916999999999999	1.0476000000000001	0.83099999999999996	0.63490000000000002	0.55910000000000004	0.48759999999999998	0.44	0.36849999999999999	0.063	0.0020000001	16	95.612	0	0	\N	96
13311	1993	60	4.8609999999999998	2.657	2.3119999999999998	3.294	3.8340000000000001	7.7229999999999999	4.8074000000000003	3.6732999999999998	2.7484000000000002	1.9495	1.4201999999999999	0.9597	0.7641	0.59709999999999996	0.54479999999999995	0.4914	0.443	0.37040000000000001	0.125	0.001	16	98.956001	0	0	\N	100
23361	1993	68	1.9079999999999999	3.9746000000000001	0.82599999999999996	2.2749999999999999	4.3719999999999999	8.4901999999999997	6.5618999999999996	5.9116999999999997	5.3022	4.6927000000000003	3.7507000000000001	3.1735000000000002	2.5962000000000001	2.0190000000000001	1.7498	1.4819	1.2676000000000001	0.8579	0.063	0.0040000002	10	94.697998	0	0	\N	108
13312	1993	71	3.2850000000000001	2.5152000000000001	1.2050000000000001	2.6139999999999999	3.7759999999999998	3.9603999999999999	3.0057999999999998	2.3694000000000002	1.9077999999999999	1.7358	1.3916999999999999	1.0476000000000001	0.83099999999999996	0.63490000000000002	0.55910000000000004	0.48759999999999998	0.44	0.36849999999999999	0.125	0.0020000001	16	95.612	0	0	\N	111
13313	1993	83	1.9239999999999999	3.9748000000000001	0.82599999999999996	2.2749999999999999	4.3700000000000001	8.4903999999999993	6.5621	5.9118000000000004	5.3022999999999998	4.6928000000000001	3.7507999999999999	3.1736	2.5964	2.0190999999999999	1.7499	1.4821	1.2678	0.85840000000000005	0.125	0.0040000002	10	94.696999	0	0	\N	123
13016	1990	72	6.694	1.6063000000000001	1.349	1.8600000000000001	1.9790000000000001	3.0886	1.9041999999999999	1.7421	1.5396000000000001	1.337	0.9829	0.88119999999999998	0.77949999999999997	0.67769999999999997	0.62739999999999996	0.58450000000000002	0.55030000000000001	0.49669999999999997	0.125	0.016000001	10	97.431999	12.093	6.9820000000000002	\N	72
13017	1990	86	4.7569999999999997	1.9550000000000001	6.1219999999999999	3.6480000000000001	1.8540000000000001	6.1330999999999998	4.2176999999999998	3.1446999999999998	1.8762000000000001	0.92000000000000004	0.53820000000000001	0.4672	0.42299999999999999	0.37880000000000003	0.35670000000000002	0.33460000000000001	0.31690000000000002	0.2903	0.125	0.018999999	10	95.705002	7.7770000000000001	4.4900000000000002	\N	86
13018	1990	98	8.7219999999999995	0.77370000000000005	1.0629999999999999	1.431	1.6120000000000001	0.90700000000000003	0.61950000000000005	0.57509999999999994	0.51959999999999995	0.48880000000000001	0.45429999999999998	0.41980000000000001	0.38529999999999998	0.3508	0.33350000000000002	0.31630000000000003	0.30249999999999999	0.28179999999999999	0.125	0.011	10	98.553001	5.5119999999999996	3.1829999999999998	\N	98
13019	1990	111	5.444	1.1487000000000001	1.4990000000000001	1.6970000000000001	1.609	2.5720999999999998	0.86370000000000002	0.60109999999999997	0.50549999999999995	0.4839	0.44990000000000002	0.4158	0.38179999999999997	0.34770000000000001	0.33069999999999999	0.31369999999999998	0.30009999999999998	0.27960000000000002	0.125	0.032000002	10	97.786003	2.5590000000000002	1.478	\N	111
13020	1990	124	0.28499999999999998	6.5021000000000004	0.85199999999999998	5.6260000000000003	14.605	20.475999999999999	14.1126	10.220800000000001	8.9771999999999998	7.9058000000000002	5.4012000000000002	2.7168999999999999	1.3478000000000001	0.70709999999999995	0.5766	0.4965	0.44579999999999997	0.36980000000000002	0.125	0.048999999	16	85.940002	0.318	0.184	\N	124
10273	1888	15	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	15
10274	1888	35	0.61499999999999999	6.4271000000000003	0.77100000000000002	2.5710000000000002	4.8220000000000001	14.784700000000001	11.6555	9.8163999999999998	8.7043999999999997	7.7218	6.2324000000000002	5.1650999999999998	4.0978000000000003	3.0952000000000002	2.5972	2.0992000000000002	1.7639	1.2924	0.125	0.226	10	80.825996	0	0	\N	35
10275	1888	45	1.2010000000000001	1.7316	2.161	2.7930000000000001	3.5870000000000002	3.7606000000000002	2.8264999999999998	2.2037	1.8267	1.5921000000000001	1.1228	0.68830000000000002	0.55930000000000002	0.47720000000000001	0.43619999999999998	0.39510000000000001	0.36230000000000001	0.313	0.063	0.472	10	97.167999	0.70299999999999996	0.497	\N	45
10276	1888	70	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	70
10277	1888	95	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	95
34808	10853	35	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	63
34807	10853	50	3.4990000000000001	12.6608	0.60799999999999998	2.774	6.8680000000000003	26.667100000000001	23.767299999999999	21.834199999999999	19.4177	17.001200000000001	13.784800000000001	10.9907	8.5033999999999992	6.1787000000000001	4.9607999999999999	3.8096999999999999	3.0886999999999998	2.0072000000000001	0.125	0.039999999	16	67.928001	5.6399999999999997	3.2570000000000001	\N	78
34806	10853	65	125.53	10.3146	0.373	4.8860000000000001	17.888999999999999	25.599499999999999	21.537199999999999	18.829000000000001	15.706	13.916499999999999	10.337400000000001	7.2168000000000001	4.8010000000000002	2.9226000000000001	2.0608	1.3592	0.90229999999999999	0.57789999999999997	0.125	0.0060000001	31.5	98.714996	248.68799999999999	143.58000000000001	\N	93
34805	10853	80	216.27199999999999	9.5032999999999994	0.68300000000000005	4.3499999999999996	9.8030000000000008	26.330200000000001	17.399999999999999	14.372299999999999	11.7121	9.4797999999999991	6.5602	4.8404999999999996	3.218	1.823	1.4821	1.1411	0.91949999999999998	0.66920000000000002	0.25	0.0049999999	31.5	93.473	575.13999999999999	332.05700000000002	\N	108
34804	10853	95	4.383	10.467499999999999	0.29699999999999999	4.0650000000000004	18.523	24.5139	20.322199999999999	17.527799999999999	15.325699999999999	14.1272	11.7303	9.1804000000000006	6.2420999999999998	3.6958000000000002	2.4904000000000002	1.6720999999999999	1.2297	0.63329999999999997	0.125	0.016000001	16	77.813004	10.477	6.0490000000000004	\N	123
34725	10832	25	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	64
34724	10832	40	14.557	9.5233000000000008	0.89000000000000001	2.1640000000000001	3.5409999999999999	18.020800000000001	14.599	13.4473	12.0076	10.5679	8.7314000000000007	7.1510999999999996	5.7824	4.6607000000000003	4.0998000000000001	3.5531000000000001	3.1181999999999999	2.4659	0.125	0.043000001	31.5	97.567001	12.843	7.415	\N	79
34723	10832	55	107.70699999999999	2.4710000000000001	1.216	1.859	2.262	3.9533999999999998	3.4935999999999998	3.1871	2.8039999999999998	2.4207999999999998	1.9080999999999999	1.7042999999999999	1.5004	1.2966	1.1947000000000001	1.0928	1.0113000000000001	0.84340000000000004	0.125	0.003	16	99.114998	105.83799999999999	61.104999999999997	\N	94
34722	10832	70	79.329999999999998	2.5489999999999999	1.349	1.8560000000000001	2.0339999999999998	5.0327000000000002	3.7675999999999998	3.4285000000000001	3.0045999999999999	2.5807000000000002	1.9394	1.7471000000000001	1.5547	1.3624000000000001	1.2663	1.1700999999999999	1.0931999999999999	0.9536	0.125	0.0070000002	16	99.924004	214.48599999999999	123.833	\N	109
34721	10832	85	2.931	5.8978000000000002	0.67800000000000005	4.8010000000000002	11.656000000000001	16.2104	11.8482	9.6038999999999994	8.1791999999999998	6.7545999999999999	4.8438999999999997	2.9975999999999998	1.476	0.81410000000000005	0.64680000000000004	0.56869999999999998	0.5141	0.41560000000000002	0.125	0.024	16	89.862	1.3220000000000001	0.76300000000000001	\N	124
34726	10833	22	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	70
34727	10833	32	107.607	2.2826	1.774	2.2669999999999999	2.468	5.3188000000000004	3.4220000000000002	2.7063000000000001	1.9650000000000001	1.7987	1.466	1.1333	0.93330000000000002	0.82189999999999996	0.76619999999999999	0.71050000000000002	0.66600000000000004	0.59409999999999996	0.25	0.0089999996	16	99.044998	198.27600000000001	114.474	\N	80
34728	10833	52	120.379	1.5373000000000001	1.2509999999999999	1.7929999999999999	2.2410000000000001	2.8761999999999999	1.9459	1.8248	1.6733	1.5219	1.2190000000000001	0.97019999999999995	0.86240000000000006	0.75470000000000004	0.70079999999999998	0.64690000000000003	0.60519999999999996	0.54400000000000004	0.125	0.0020000001	16	99.820999	204.29900000000001	117.952	\N	100
34729	10833	62	79.435000000000002	1.3917999999999999	1.296	1.76	1.891	1.9675	1.7358	1.5812999999999999	1.3882000000000001	1.1951000000000001	0.95569999999999999	0.86609999999999998	0.77649999999999997	0.68689999999999996	0.6421	0.59670000000000001	0.56020000000000003	0.50539999999999996	0.125	0.0020000001	10	98.695999	69.543000000000006	40.151000000000003	\N	110
34730	10833	72	0.29199999999999998	5.9683000000000002	0.19500000000000001	5.3250000000000002	20.562999999999999	13.7554	12.4086	11.5107	10.388400000000001	9.3742000000000001	7.4602000000000004	5.2743000000000002	2.6194000000000002	0.88349999999999995	0.5907	0.48749999999999999	0.43759999999999999	0.36280000000000001	0.125	0.23899999	10	73.269997	0.54800000000000004	0.316	\N	120
29864	10075	32	10.925000000000001	1.5729	2.2559999999999998	2.2530000000000001	1.972	3.9245999999999999	2.6417000000000002	1.9296	1.577	1.2243999999999999	0.91120000000000001	0.78080000000000005	0.65049999999999997	0.58889999999999998	0.5645	0.54010000000000002	0.52059999999999995	0.46200000000000002	0.125	0.037999999	10	99.299004	17.431999999999999	10.064	\N	81
29863	10075	40	39.488999999999997	1.1588000000000001	1.554	2.0830000000000002	2.4279999999999999	2.3780999999999999	1.7585999999999999	1.5471999999999999	1.2829999999999999	1.0187999999999999	0.84150000000000003	0.67710000000000004	0.58679999999999999	0.5262	0.49340000000000001	0.44440000000000002	0.40529999999999999	0.34649999999999997	0.125	0.017999999	10	99.778	20.254999999999999	11.694000000000001	\N	89
29862	10075	48	27.861999999999998	1.0506	1.2609999999999999	1.837	2.2919999999999998	1.8542000000000001	1.6095999999999999	1.4464999999999999	1.2425999999999999	1.0387999999999999	0.89559999999999995	0.7802	0.66479999999999995	0.58320000000000005	0.54959999999999998	0.5161	0.47699999999999998	0.39069999999999999	0.125	0.0049999999	6.2999999999999998	99.500999	40.456000000000003	23.356999999999999	\N	97
29861	10075	56	20.562999999999999	0.73960000000000004	1.0089999999999999	1.3979999999999999	1.893	0.96650000000000003	0.91979999999999995	0.88870000000000005	0.8498	0.81079999999999997	0.73299999999999998	0.6552	0.59930000000000005	0.55389999999999995	0.53120000000000001	0.50860000000000005	0.47060000000000002	0.38719999999999999	0.25	0.13500001	10	99.796997	28.042000000000002	16.190000000000001	\N	105
29860	10075	64	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	113
29854	10073	29	0.016	1.9016	0.93500000000000005	2.6160000000000001	3.8969999999999998	4.6132999999999997	3.6533000000000002	3.0667	2.3332999999999999	1.9333	1.6889000000000001	1.4443999999999999	1.2	0.92600000000000005	0.72250000000000003	0.59099999999999997	0.53380000000000005	0.43330000000000002	0.5	13.636	4	86.363998	0.023	0.012999999999999999	\N	74
29853	10073	34	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	79
29852	10073	39	2.516	2.8269000000000002	1.6020000000000001	2.867	3.4670000000000001	7.3563000000000001	4.4996	3.5867	2.8374999999999999	2.0882000000000001	1.6314	1.2397	0.92689999999999995	0.73860000000000003	0.64439999999999997	0.58740000000000003	0.54720000000000002	0.47049999999999997	0.125	0.055	16	97.817001	8.5640000000000001	4.9450000000000003	\N	84
29851	10073	49	68.706000000000003	1.5236000000000001	1.1779999999999999	1.881	2.448	3.1353	1.9946999999999999	1.8714	1.7172000000000001	1.5630999999999999	1.2547999999999999	0.97709999999999997	0.84489999999999998	0.7127	0.64659999999999995	0.59799999999999998	0.56379999999999997	0.51249999999999996	0.125	0.0099999998	16	99.857002	121.66500000000001	70.242999999999995	\N	94
29850	10073	59	139.35300000000001	1.9017999999999999	1.0029999999999999	1.982	2.7370000000000001	3.5459000000000001	3.0960999999999999	2.7963	2.4215	2.0467	1.7867	1.5592999999999999	1.3318000000000001	1.1044	0.99070000000000003	0.87809999999999999	0.78790000000000004	0.65269999999999995	0.125	0.001	10	99.602997	185.56399999999999	107.13500000000001	\N	104
29849	10073	69	0.031	0.83030000000000004	1.381	1.9179999999999999	2.0430000000000001	1.75	1.3	1	0.90749999999999997	0.81499999999999995	0.63	0.57679999999999998	0.52359999999999995	0.45829999999999999	0.42080000000000001	0.38329999999999997	0.3533	0.30830000000000002	0.25	2.2219999	2	93.333	0.040000000000000001	0.023	\N	114
27476	8968	25	29.638999999999999	3.081	2.8610000000000002	2.802	2.641	8.4835999999999991	5.0633999999999997	3.7576000000000001	2.8189000000000002	1.9712000000000001	1.5198	1.0684	0.90720000000000001	0.79790000000000005	0.74329999999999996	0.68859999999999999	0.64490000000000003	0.57550000000000001	0.125	0.0049999999	16	96.843002	79.266000000000005	45.764000000000003	\N	72
27477	8968	37	25.045999999999999	1.7746	0.90400000000000003	2.6240000000000001	4.4539999999999997	3.6638000000000002	3.2347999999999999	2.9487999999999999	2.5912999999999999	2.2338	1.7170000000000001	1.2964	0.91600000000000004	0.63160000000000005	0.57550000000000001	0.52029999999999998	0.46970000000000001	0.38540000000000002	0.125	0.0060000001	10	99.571999	30.931000000000001	17.858000000000001	\N	84
27478	8968	49	28.809999999999999	1.4869000000000001	0.88800000000000001	1.6899999999999999	2.4390000000000001	2.6233	1.9407000000000001	1.8557999999999999	1.7496	1.6435	1.4312	1.2189000000000001	1.0065999999999999	0.86890000000000001	0.80130000000000001	0.73370000000000002	0.67959999999999998	0.58679999999999999	0.125	0.0049999999	10	99.766998	50.848999999999997	29.358000000000001	\N	96
27479	8968	61	6.5259999999999998	1.2690999999999999	1.2330000000000001	1.655	2.0070000000000001	1.9093	1.7537	1.6499999999999999	1.5204	1.3907	1.1315	0.95450000000000002	0.86209999999999998	0.76970000000000005	0.72350000000000003	0.67730000000000001	0.64039999999999997	0.56369999999999998	0.125	0.011	10	99.446999	11.986000000000001	6.9199999999999999	\N	108
27480	8968	73	0.023	0.57609999999999995	0.72799999999999998	2.149	3.4049999999999998	1.2	0.91710000000000003	0.82240000000000002	0.70399999999999996	0.61890000000000001	0.55940000000000001	0.5	0.40000000000000002	0.29999999999999999	0.25	0.22140000000000001	0.1986	0.1643	0.125	3.125	1	87.5	0.079000000000000001	0.045999999999999999	\N	120
27470	8966	26	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	62
27469	8966	43	2.4969999999999999	15.3444	0.754	2.0579999999999998	4.4210000000000003	27.881699999999999	25.710599999999999	24.263300000000001	22.4541	20.645	17.026599999999998	14.383900000000001	12.127599999999999	9.8489000000000004	8.5241000000000007	7.1992000000000003	6.0700000000000003	3.8511000000000002	0.125	0.028000001	16	57.162998	1.415	0.81699999999999995	\N	79
27468	8966	60	14.672000000000001	5.1246	1.708	3.548	5.1769999999999996	12.562200000000001	8.7190999999999992	7.1940999999999997	5.6696	4.4824000000000002	2.9420000000000002	1.8799999999999999	1.4669000000000001	1.0538000000000001	0.91049999999999998	0.78939999999999999	0.6925	0.56830000000000003	0.125	0.0089999996	31.5	97.898003	35.853000000000002	20.699999999999999	\N	96
27467	8966	77	46.433999999999997	3.1743999999999999	0.79400000000000004	1.6200000000000001	2.411	5.1185	3.9565999999999999	3.8134999999999999	3.6345999999999998	3.4558	3.0981000000000001	2.7403	2.3826000000000001	2.0249000000000001	1.8406	1.6555	1.5074000000000001	1.2851999999999999	0.125	0.0020000001	16	99.374001	34.122999999999998	19.701000000000001	\N	113
27466	8966	94	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	130
27465	8965	28	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	66
27464	8965	42	62.344999999999999	8.5465	0.40400000000000003	4.718	15.082000000000001	22.398599999999998	16.402000000000001	14.8665	13.2911	11.7158	8.5606000000000009	5.4698000000000002	2.9167999999999998	1.5263	1.1182000000000001	0.87619999999999998	0.7369	0.56759999999999999	0.25	0.041999999	31.5	99.107002	129.40000000000001	74.709000000000003	\N	80
27463	8965	56	357.53399999999999	2.6772999999999998	2.73	2.8300000000000001	2.859	6.9787999999999997	5.0510999999999999	4.0107999999999997	3.1709999999999998	2.3351999999999999	1.5913999999999999	1.0803	0.90410000000000001	0.79020000000000001	0.73329999999999995	0.6764	0.63090000000000002	0.55659999999999998	0.25	0.017999999	16	99.199997	583.59799999999996	336.94	\N	94
27462	8965	70	132.363	3.6162000000000001	1.278	2.8519999999999999	3.927	8.2637	5.5457000000000001	4.5129000000000001	3.7115999999999998	3.2332000000000001	2.2764000000000002	1.72	1.3262	0.96519999999999995	0.86399999999999999	0.76270000000000004	0.68169999999999997	0.57969999999999999	0.125	0.0049999999	31.5	99.411003	224.19999999999999	129.44200000000001	\N	108
27461	8965	84	5.0899999999999999	1.2202	1.0800000000000001	1.337	1.4890000000000001	1.5699000000000001	0.97950000000000004	0.94720000000000004	0.90680000000000005	0.86629999999999996	0.78549999999999998	0.70469999999999999	0.62749999999999995	0.59419999999999995	0.5776	0.56100000000000005	0.54769999999999996	0.52769999999999995	0.25	0.068000004	10	98.142998	5.5919999999999996	3.2280000000000002	\N	122
27460	8964	27	0.19	1.3734999999999999	1.198	1.7929999999999999	2.4020000000000001	2.7926000000000002	1.9497	1.8360000000000001	1.6938	1.5517000000000001	1.2674000000000001	0.99329999999999996	0.88049999999999995	0.76770000000000005	0.71140000000000003	0.65500000000000003	0.60650000000000004	0.52759999999999996	0.125	2.372	4	96.443001	0.65900000000000003	0.38100000000000001	\N	65
27459	8964	40	121.40300000000001	4.2820999999999998	2.3420000000000001	3.5910000000000002	3.5249999999999999	12.689399999999999	8.8867999999999991	6.8110999999999997	4.8125999999999998	3.5807000000000002	2.0869	1.6169	1.2101	0.92020000000000002	0.8377	0.75509999999999999	0.68910000000000005	0.59189999999999998	0.125	0.017999999	16	94.745003	238.64599999999999	137.78200000000001	\N	78
27458	8964	55	16.818999999999999	6.5075000000000003	1.25	4.3760000000000003	7.5620000000000003	19.989100000000001	14.2232	11.418900000000001	8.8771000000000004	6.9904000000000002	4.4669999999999996	2.9064000000000001	1.8070999999999999	1.2456	0.98329999999999995	0.84960000000000002	0.74260000000000004	0.5907	0.25	0.066	16	86.533997	30.050000000000001	17.349	\N	93
27457	8964	71	131.44399999999999	2.9375	1.079	2.0510000000000002	2.9540000000000002	5.4607000000000001	3.9721000000000002	3.7002000000000002	3.3605	3.0207000000000002	2.3411	1.8645	1.5925	1.3205	1.1845000000000001	1.0485	0.94399999999999995	0.79239999999999999	0.25	0.028000001	16	98.289001	430.827	248.738	\N	109
27456	8964	89	1.861	0.70899999999999996	1.0660000000000001	1.639	1.9550000000000001	1.2847999999999999	0.95889999999999997	0.89829999999999999	0.8226	0.74690000000000001	0.61829999999999996	0.56679999999999997	0.51539999999999997	0.45229999999999998	0.41830000000000001	0.38429999999999997	0.35709999999999997	0.31619999999999998	0.25	0.26100001	4	99.850998	2.6480000000000001	1.5289999999999999	\N	127
24551	7783	21	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	71
24552	7783	32	139.304	1.9247000000000001	2.1019999999999999	2.194	2.262	3.9954000000000001	3.0937999999999999	2.4927000000000001	1.9279999999999999	1.7188000000000001	1.3004	0.97260000000000002	0.87560000000000004	0.77859999999999996	0.72999999999999998	0.68149999999999999	0.64270000000000005	0.57479999999999998	0.125	0.001	16	99.681	441.96699999999998	255.16999999999999	\N	82
24553	7783	47	152.52699999999999	1.3732	1.2689999999999999	2.0539999999999998	2.5840000000000001	2.9857	1.9390000000000001	1.7743	1.5684	1.3625	0.98260000000000003	0.83779999999999999	0.69299999999999995	0.5857	0.54649999999999999	0.50729999999999997	0.45950000000000002	0.38030000000000003	0.125	0.0060000001	10	99.539001	142.84999999999999	101.01000000000001	\N	97
24554	7783	64	107.723	2.0775000000000001	0.871	2.3900000000000001	3.7839999999999998	3.8673000000000002	3.4011	3.0903	2.7018	2.3132000000000001	1.8223	1.5246	1.2269000000000001	0.93920000000000003	0.8115	0.68369999999999997	0.59530000000000005	0.48149999999999998	0.25	0.15099999	16	99.654999	220.79300000000001	127.47499999999999	\N	114
24555	7783	75	0.33300000000000002	4.4185999999999996	0.54600000000000004	3.8889999999999998	9.6289999999999996	10.084	8.8869000000000007	8.1268999999999991	7.1768000000000001	6.2337999999999996	4.5157999999999996	3.0920999999999998	1.8799999999999999	1.1214999999999999	0.87609999999999999	0.69359999999999999	0.58750000000000002	0.46899999999999997	0.25	0.40599999	10	89.858002	0.57999999999999996	0.33500000000000002	\N	125
24550	7782	23	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	73
24549	7782	37	13.16	8.9900000000000002	0.41499999999999998	3.5179999999999998	12.464	21.6097	15.911300000000001	14.8291	13.4764	12.123799999999999	9.4724000000000004	7.0180999999999996	4.6547000000000001	2.9731000000000001	2.2585000000000002	1.6829000000000001	1.2853000000000001	0.76000000000000001	0.25	0.052999999	16	84.328003	0.52500000000000002	0.30299999999999999	\N	87
24548	7782	52	166.876	1.8728	1.8109999999999999	2.2970000000000002	2.6480000000000001	4.3324999999999996	3.0625	2.3382000000000001	1.8855999999999999	1.7029000000000001	1.3374999999999999	0.99080000000000001	0.87090000000000001	0.751	0.69099999999999995	0.63100000000000001	0.5806	0.505	0.25	0.050000001	10	98.474998	241.61799999999999	139.49799999999999	\N	102
24547	7782	66	38.451000000000001	4.9591000000000003	0.84699999999999998	2.5329999999999999	3.7250000000000001	9.5443999999999996	3.8856000000000002	3.5385	3.1046	2.6705999999999999	1.9382999999999999	1.667	1.3956999999999999	1.1244000000000001	0.97999999999999998	0.73929999999999996	0.60550000000000004	0.52039999999999997	0.25	0.115	31.5	94.990997	60.457999999999998	34.905999999999999	\N	116
24546	7782	83	1.054	1.2750999999999999	1.49	1.972	2.0169999999999999	1.9806999999999999	1.3526	0.98829999999999996	0.89559999999999995	0.80289999999999995	0.62570000000000003	0.56179999999999997	0.498	0.43540000000000001	0.40410000000000001	0.37280000000000002	0.34770000000000001	0.31009999999999999	0.25	0.39500001	10	97.563004	3.0449999999999999	1.758	\N	133
24545	7781	26	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	76
24544	7781	41	100.419	4.4165000000000001	2.9620000000000002	4.2160000000000002	3.9649999999999999	13.3955	9.9300999999999995	7.8262	5.6353999999999997	4.0518000000000001	2.0379	1.3686	0.91559999999999997	0.71809999999999996	0.626	0.58860000000000001	0.55879999999999996	0.51390000000000002	0.125	0.0049999999	16	94.5	248.38800000000001	143.40700000000001	\N	91
24543	7781	55	92.582999999999998	2.9824000000000002	1.46	2.8370000000000002	3.3900000000000001	7.6078999999999999	5.1458000000000004	3.9862000000000002	3.4079000000000002	2.8296000000000001	1.8900999999999999	1.5014000000000001	1.1127	0.87870000000000004	0.79320000000000002	0.70779999999999998	0.63939999999999997	0.55759999999999998	0.125	0.0049999999	16	98.709999	253.03899999999999	146.09200000000001	\N	105
24542	7781	71	217.012	2.2944	1.2549999999999999	2.1120000000000001	2.4870000000000001	4.6050000000000004	3.4756	2.9716999999999998	2.3416999999999999	1.9455	1.7071000000000001	1.4688000000000001	1.2303999999999999	0.99490000000000001	0.91779999999999995	0.8407	0.77900000000000003	0.6865	0.125	0.0049999999	16	99.25	142.14599999999999	82.067999999999998	\N	121
24541	7781	86	1.288	7.7591000000000001	0.215	5.0890000000000004	18.504999999999999	17.4895	14.5245	13.329000000000001	11.8347	10.340299999999999	8.1972000000000005	6.1540999999999997	3.9906999999999999	1.859	0.97670000000000001	0.65629999999999999	0.56079999999999997	0.443	0.25	0.37799999	16	88.936996	2.742	1.583	\N	136
13011	1989	60	12.361000000000001	3.6358000000000001	1.8959999999999999	2.3780000000000001	2.3170000000000002	9.3681000000000001	5.4238	3.8500000000000001	3.1385999999999998	2.4272999999999998	1.8584000000000001	1.6560999999999999	1.4538	1.2515000000000001	1.1504000000000001	1.0491999999999999	0.95899999999999996	0.80200000000000005	0.125	0.0060000001	16	95.372002	15.669	9.0470000000000006	\N	60
13012	1989	75	20.021000000000001	2.7547000000000001	2.0230000000000001	2.835	3.4260000000000002	7.4439000000000002	3.9550000000000001	3.0665	1.9917	1.7827	1.3646	0.98080000000000001	0.8306	0.6804	0.6089	0.54479999999999995	0.49199999999999999	0.39829999999999999	0.125	0.0099999998	16	97.268997	14.574999999999999	8.4149999999999991	\N	75
13013	1989	91	10.75	4.9724000000000004	13.254	6.202	3.1949999999999998	14.261900000000001	13.218999999999999	12.5237	11.6547	10.785600000000001	0.98150000000000004	0.58550000000000002	0.48949999999999999	0.42870000000000003	0.39829999999999999	0.36799999999999999	0.34370000000000001	0.30719999999999997	0.125	0.0089999996	10	65.480003	8.3079999999999998	4.7960000000000003	\N	91
13014	1989	106	15.25	3.9260999999999999	1.0880000000000001	3.577	6.2869999999999999	10.952	7.0494000000000003	5.7263000000000002	4.7041000000000004	3.8395000000000001	2.8077999999999999	1.8895	1.3802000000000001	0.91759999999999997	0.75509999999999999	0.61229999999999996	0.55089999999999995	0.4466	0.125	0.003	16	96.900002	22.888999999999999	13.215	\N	106
13015	1989	122	1.472	1.8897999999999999	2.125	2.2530000000000001	1.95	3.6526000000000001	1.6754	1.1819999999999999	0.89170000000000005	0.73809999999999998	0.58289999999999997	0.51029999999999998	0.45529999999999998	0.40310000000000001	0.37709999999999999	0.35099999999999998	0.33019999999999999	0.2989	0.125	0.0049999999	16	97.013	0.70899999999999996	0.40899999999999997	\N	122
12897	1988	65	5.7569999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	4.931	2.847	\N	65
12898	1988	80	6.5830000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	4.5860000000000003	2.6480000000000001	\N	80
12899	1988	95	8.6809999999999992	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	13.497	7.7930000000000001	\N	95
12900	1988	109	15.847	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	15.856	9.1539999999999999	\N	109
12901	1988	125	0.32300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.45700000000000002	0.32300000000000001	\N	125
12892	1987	66	26.431000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5.6340000000000003	3.2530000000000001	\N	66
12893	1987	82	18.542000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	25.492999999999999	14.718	\N	82
12894	1987	97	3.8679999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	7.0330000000000004	4.0599999999999996	\N	97
12895	1987	112	3.2919999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	6.827	3.9420000000000002	\N	112
12896	1987	127	6.569	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	14.333	8.2750000000000004	\N	127
10764	1985	59	169.57499999999999	2.6164000000000001	1.1679999999999999	1.8029999999999999	2.3260000000000001	4.4945000000000004	3.7296999999999998	3.5003000000000002	3.2134999999999998	2.9266000000000001	2.3530000000000002	1.9133	1.6878	1.4623999999999999	1.3496999999999999	1.2369000000000001	1.1468	1.0115000000000001	0.5	0.40000001	10	98.101997	106.328	61.387999999999998	\N	59
10765	1985	74	63.444000000000003	4.6646000000000001	0.92400000000000004	2.2130000000000001	3.3980000000000001	9.4285999999999994	7.3959999999999999	6.2214999999999998	5.7079000000000004	5.1943000000000001	4.1669999999999998	3.4773000000000001	2.8530000000000002	2.2288000000000001	1.9368000000000001	1.7	1.5105999999999999	1.2263999999999999	0.5	0.121	16	97.936996	130.00700000000001	75.058999999999997	\N	74
10766	1985	88	29.41	9.3611000000000004	0.94399999999999995	2.0739999999999998	3.359	19.489100000000001	15.065899999999999	13.858599999999999	12.349399999999999	10.840299999999999	8.9430999999999994	7.4783999999999997	6.0993000000000004	5.0728	4.5594999999999999	4.0461999999999998	3.5028000000000001	2.6623000000000001	0.5	0.27500001	16	87.095001	87.814999999999998	50.700000000000003	\N	88
10767	1985	106	12.333	15.071400000000001	0.96199999999999997	1.8220000000000001	2.7040000000000002	27.185300000000002	24.596399999999999	22.8705	20.713200000000001	18.555800000000001	15.352600000000001	13.7645	12.176500000000001	10.5884	9.6738999999999997	8.4151000000000007	7.4080000000000004	5.6779000000000002	0.5	0.056000002	16	64.077003	25.530999999999999	14.74	\N	106
10768	1985	120	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	120
10759	1984	59	206.26499999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	266.20499999999998	153.69300000000001	\N	59
10760	1984	76	176.495	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	345.96600000000001	199.74299999999999	\N	76
10761	1984	108	46.517000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	115.065	66.433000000000007	\N	108
10762	1984	114	60.859999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	110.482	63.786999999999999	\N	114
10763	1984	124	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	124
10754	1983	70	0.021000000000000001	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	70
10755	1983	85	0.056000000000000001	0.75880000000000003	1.52	1.9530000000000001	1.948	1.6000000000000001	1.3600000000000001	1.2	1	0.85199999999999998	0.61699999999999999	0.56499999999999995	0.51300000000000001	0.45000000000000001	0.41670000000000001	0.38329999999999997	0.35670000000000002	0.31669999999999998	0.5	37.5	1	75	0	0	\N	85
10756	1983	100	0.042000000000000003	1.2607999999999999	0.77000000000000002	2.371	4	2.7999999999999998	2.0800000000000001	1.8999999999999999	1.75	1.6000000000000001	1.3	1	0.77800000000000002	0.47499999999999998	0.4375	0.40000000000000002	0.37	0.32500000000000001	0.5	33.333	2	83.333	0	0	\N	100
10757	1983	115	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	115
10758	1983	130	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	130
10749	1982	72	2.3610000000000002	1.2958000000000001	1.357	1.718	1.738	1.9253	1.6677999999999999	1.4962	1.2816000000000001	1.0670999999999999	0.92390000000000005	0.83360000000000001	0.74339999999999995	0.6532	0.61629999999999996	0.58799999999999997	0.56540000000000001	0.53149999999999997	0.5	4.4250002	10	99.114998	0	0	\N	72
10750	1982	87	4.4859999999999998	1.9468000000000001	1.0760000000000001	2.3540000000000001	3.1400000000000001	3.9510000000000001	3.1686000000000001	2.6471	1.9988999999999999	1.8586	1.5781000000000001	1.2975000000000001	1.0168999999999999	0.8105	0.70960000000000001	0.6179	0.57179999999999997	0.50260000000000005	0.5	9.7740002	10	98.346001	0	0	\N	87
10751	1982	96	1.7569999999999999	1.7135	1.05	2.5169999999999999	3.8540000000000001	3.5571000000000002	2.8342999999999998	2.3523999999999998	1.9309000000000001	1.7645	1.4316	1.0987	0.80630000000000002	0.59519999999999995	0.54679999999999995	0.498	0.44740000000000002	0.3715	0.25	0.39500001	10	98.024002	0	0	\N	96
10752	1982	107	10.599	1.7174	0.91600000000000004	1.3480000000000001	1.6459999999999999	2.5350999999999999	1.9574	1.9056999999999999	1.841	1.7763	1.647	1.5177	1.3883000000000001	1.2589999999999999	1.1942999999999999	1.1296999999999999	1.0780000000000001	1.0004	0.5	0.273	10	99.726997	14.474	10.234	\N	107
10753	1982	122	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	122
10744	1981	76	7.5	4.9109999999999996	0.68500000000000005	3.3500000000000001	7.3499999999999996	12.5517	9.2057000000000002	7.9767000000000001	6.7191999999999998	5.8101000000000003	4.3402000000000003	3.3197000000000001	2.4344000000000001	1.6584000000000001	1.323	0.99199999999999999	0.82020000000000004	0.59050000000000002	0.25	0.093000002	10	86.573997	0	0	\N	76
10745	1981	88	51.887999999999998	3.0524	1.792	3.323	4.008	9.0557999999999996	5.6881000000000004	4.2514000000000003	3.2643	2.4089	1.6883999999999999	1.2789999999999999	0.92900000000000005	0.70620000000000005	0.61280000000000001	0.55859999999999999	0.51519999999999999	0.42130000000000001	0.5	14.594	10	91.512001	95.620000000000005	55.206000000000003	\N	88
10746	1981	99	0.29199999999999998	3.2730000000000001	1.3	2.5750000000000002	4.1029999999999998	7.8867000000000003	6.4587000000000003	5.6559999999999997	4.6900000000000004	3.8799999999999999	3.04	2.2000000000000002	1.7538	1.4308000000000001	1.2692000000000001	1.1076999999999999	0.97409999999999997	0.74099999999999999	0.5	2.381	8	90.475998	0	0	\N	99
10747	1981	112	3.089	1.4356	1.3540000000000001	1.732	1.885	2.6240000000000001	1.8645	1.7293000000000001	1.5603	1.3914	1.0533999999999999	0.92510000000000003	0.83609999999999995	0.74709999999999999	0.7026	0.65810000000000002	0.62129999999999996	0.55889999999999995	0.5	4.3369999	10	99.235001	1.466	1.036	\N	112
10748	1981	124	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	124
10740	1980	80	3.391	6.5999999999999996	0.99399999999999999	3.9420000000000002	8.9969999999999999	17.915099999999999	14.2302	11.7736	9.0832999999999995	7.2302999999999997	5.0266000000000002	3.6200000000000001	2.7519999999999998	1.9065000000000001	1.5565	1.2064999999999999	0.91559999999999997	0.55869999999999997	0.25	0.154	20	93.394997	2.0840000000000001	1.474	\N	80
10741	1980	94	9.0630000000000006	7.8712	1.7070000000000001	4.8600000000000003	7.9009999999999998	24.0974	19.6647	16.780100000000001	13.174300000000001	9.5839999999999996	4.9897	3.0964999999999998	1.9121999999999999	1.4319999999999999	1.1919999999999999	0.96650000000000003	0.83250000000000002	0.63149999999999995	0.25	0.057999998	20	84.464996	0.029000000000000001	0.021000000000000001	\N	94
10742	1980	110	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	110
10743	1980	124	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	124
10735	1979	71	19.210999999999999	2.8372999999999999	1.224	1.931	2.6309999999999998	5.5770999999999997	4.2629000000000001	3.8281999999999998	3.5215000000000001	3.2147000000000001	2.6012	1.9950000000000001	1.7444	1.4937	1.3684000000000001	1.2431000000000001	1.1429	0.98870000000000002	0.5	0.1	10	98.5	57.353000000000002	33.113	\N	71
10736	1979	83	30.268999999999998	4.9252000000000002	0.78900000000000003	3.1459999999999999	5.6260000000000003	12.1648	8.9909999999999997	7.8592000000000004	6.6437999999999997	5.7755000000000001	4.3127000000000004	3.2172999999999998	2.2216999999999998	1.5659000000000001	1.2867	1.0075000000000001	0.90849999999999997	0.76649999999999996	0.5	0.98000002	20	99.109001	50.939	29.41	\N	83
10737	1979	98	140.822	2.4857	2.093	2.46	2.4449999999999998	6.0961999999999996	4.3494000000000002	3.5625	2.7812999999999999	2	1.6109	1.2218	0.95720000000000005	0.85780000000000001	0.80800000000000005	0.75829999999999997	0.71850000000000003	0.65880000000000005	0.5	1	10	96.800003	177.09800000000001	102.247	\N	98
10738	1979	112	0.66100000000000003	6.4688999999999997	0.27100000000000002	4.4379999999999997	13.276999999999999	15.300000000000001	12.48	10.6	9.3635999999999999	8.5091000000000001	6.7533000000000003	5.4055999999999997	4.2043999999999997	2.5817999999999999	1.75	0.98150000000000004	0.63370000000000004	0.50870000000000004	0.5	9.5740004	10	78.723	0.036999999999999998	0.025999999999999999	\N	112
10739	1979	128	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	128
10731	1978	75	13.086	4.0159000000000002	5.6379999999999999	4.9779999999999998	3.7210000000000001	14.4094	10.098699999999999	7.8430999999999997	4.726	2.5442999999999998	1.2931999999999999	0.85450000000000004	0.62909999999999999	0.54169999999999996	0.49769999999999998	0.4476	0.40760000000000002	0.34749999999999998	0.25	0.26100001	20	97.781998	5.71	3.2970000000000002	\N	75
10732	1978	90	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	90
10733	1978	105	14.375	2.2364999999999999	1.159	2.0880000000000001	2.6139999999999999	4.0534999999999997	3.2578999999999998	2.7547000000000001	2.1257999999999999	1.9083000000000001	1.6789000000000001	1.4495	1.2202	0.99299999999999999	0.90529999999999999	0.81759999999999999	0.74750000000000005	0.64229999999999998	0.25	0.1	10	97.199997	24.568999999999999	14.185	\N	105
10734	1978	119	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	119
10727	1977	75	12.385	1.3648	1.4370000000000001	1.8520000000000001	1.956	2.5070000000000001	1.8125	1.6338999999999999	1.4107000000000001	1.1875	0.9325	0.81620000000000004	0.69979999999999998	0.60740000000000005	0.57909999999999995	0.55089999999999995	0.52829999999999999	0.47689999999999999	0.25	0.2	10	98.900002	43.033000000000001	21.515999999999998	\N	75
10728	1977	80	4.5469999999999997	2.1673	2.097	3.1000000000000001	3.722	5.6464999999999996	4.1772999999999998	3.4163000000000001	2.5255000000000001	1.8902000000000001	1.3546	0.93049999999999999	0.72470000000000001	0.57940000000000003	0.53249999999999997	0.4819	0.43469999999999998	0.3639	0.25	0.34400001	10	97.595001	12.923999999999999	6.4619999999999997	\N	80
10729	1977	105	0.22900000000000001	3.6808999999999998	1.7390000000000001	2.7130000000000001	3.8980000000000001	7.8300000000000001	6.7080000000000002	5.8399999999999999	4.5750000000000002	3.7000000000000002	2.6000000000000001	1.875	1.6000000000000001	1.325	1.1875	1.05	0.91120000000000001	0.66700000000000004	0.5	9.0909996	10	90.908997	0	0	\N	105
10730	1977	120	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	120
10722	1976	74	8.2989999999999995	1.3648	1.4370000000000001	1.8520000000000001	1.956	2.5070000000000001	1.8125	1.6338999999999999	1.4107000000000001	1.1875	0.9325	0.81620000000000004	0.69979999999999998	0.60740000000000005	0.57909999999999995	0.55089999999999995	0.52829999999999999	0.47689999999999999	0.25	0.2	10	98.900002	13.109	7.5679999999999996	\N	74
10723	1976	85	10.068	1.8064	3.706	3.1619999999999999	2.25	5.4154	3.3938999999999999	2.1818	1.5111000000000001	0.9879	0.68459999999999999	0.5575	0.47960000000000003	0.42109999999999997	0.39190000000000003	0.36270000000000002	0.33939999999999998	0.30430000000000001	0.125	0.1	10	97.300003	32.241999999999997	16.120999999999999	\N	85
10724	1976	97	0.84699999999999998	4.1001000000000003	0.96899999999999997	3.2160000000000002	5.8499999999999996	10.0952	7.6890999999999998	6.1131000000000002	5.3655999999999997	4.6181000000000001	3.419	2.4285999999999999	1.7256	1.2419	1	0.85750000000000004	0.74350000000000005	0.58450000000000002	0.25	0.48100001	10	89.903999	0.13700000000000001	0.097000000000000003	\N	97
10725	1976	109	0.42399999999999999	7.2450000000000001	0.86899999999999999	2.8460000000000001	5.2699999999999996	16.517199999999999	14.4276	13.0345	11.293100000000001	9.6286000000000005	6.9314	5.4375	4.2759999999999998	3.1894999999999998	2.6579000000000002	2.1263000000000001	1.7815000000000001	1.3153999999999999	0.5	0.99000001	10	71.287003	0.02	0.014	\N	109
10726	1976	121	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	121
10717	1975	70	32.420000000000002	3.1621999999999999	2.5760000000000001	2.919	2.6680000000000001	8.7524999999999995	6.0183999999999997	4.5789	3.4178999999999999	2.5596999999999999	1.7119	1.2844	0.96399999999999997	0.85660000000000003	0.80289999999999995	0.74909999999999999	0.70609999999999995	0.64170000000000005	0.25	0.086999997	20	99.390999	46.326999999999998	23.163	\N	70
10718	1975	83	\N	3.2601	5.7009999999999996	4.258	3.6219999999999999	9.4856999999999996	7.7279999999999998	6.3680000000000003	4.9024999999999999	3.4933000000000001	1.3016000000000001	0.76019999999999999	0.59830000000000005	0.54179999999999995	0.51359999999999995	0.47099999999999997	0.42630000000000001	0.3594	0.25	0.2	10	91.800003	\N	\N	\N	83
10719	1975	99	2.347	6.2362000000000002	0.96699999999999997	1.9430000000000001	2.7719999999999998	12.7143	9.6222999999999992	8.9581	8.1279000000000003	7.3887999999999998	6.0500999999999996	5.0364000000000004	4.0227000000000004	3.4034	3.0983000000000001	2.7932000000000001	2.5491000000000001	2.1829000000000001	0.63	0.28	10	86.275002	4.3970000000000002	2.5390000000000001	\N	99
10720	1975	113	0.074999999999999997	8.4277999999999995	1.0149999999999999	2.1619999999999999	2.9969999999999999	17	15.199999999999999	14	12.5	11	7.5919999999999996	6.9800000000000004	6.3680000000000003	5.0732999999999997	4.3833000000000002	3.7332999999999998	3.2532999999999999	2.5333000000000001	2	5.5560002	10	66.667	0	0	\N	113
10721	1975	128	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	128
10713	1974	71	23.177	1.9071	1.3819999999999999	1.738	2.0720000000000001	3.3472	1.9890000000000001	1.8619000000000001	1.7030000000000001	1.5442	1.2264999999999999	0.97340000000000004	0.88070000000000004	0.78800000000000003	0.74160000000000004	0.69530000000000003	0.65820000000000001	0.59189999999999998	0.25	0.043000001	20	99.174004	52.337000000000003	26.169	\N	71
10714	1974	88	15.167	5.6906999999999996	0.83899999999999997	3.1190000000000002	6.5350000000000001	15.165699999999999	9.3350000000000009	8.2413000000000007	7.0323000000000002	5.9962	4.3836000000000004	3.2686000000000002	2.3090000000000002	1.6599999999999999	1.4093	1.1586000000000001	0.9597	0.67069999999999996	0.25	0.041000001	20	93.338997	40.366999999999997	20.184000000000001	\N	88
10715	1974	103	1.236	8.0458999999999996	1.071	2.907	4.5759999999999996	18.675000000000001	16.004999999999999	14.225	12	9.8363999999999994	6.9527999999999999	5.3197000000000001	3.9849999999999999	3.0950000000000002	2.6499999999999999	2.2050000000000001	1.8939999999999999	1.5193000000000001	0.5	0.28099999	20	92.977997	1.748	1.236	\N	103
10716	1974	124	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	124
10708	1973	80	3.9060000000000001	6.2603	1.341	6.0869999999999997	13.988	17.815200000000001	15.199999999999999	13.4565	11.277200000000001	8.9625000000000004	4.8707000000000003	2.1562000000000001	0.83660000000000001	0.55769999999999997	0.50339999999999996	0.45150000000000001	0.41020000000000001	0.34820000000000001	0.25	0.49900001	20	95.012001	5.141	3.6349999999999998	\N	80
10709	1973	90	86.269999999999996	3.8513000000000002	2.3900000000000001	3.7160000000000002	3.4500000000000002	11.757300000000001	8.3157999999999994	6.4843000000000002	4.4668999999999999	3.1456	1.8190999999999999	1.4475	1.0759000000000001	0.85089999999999999	0.7571	0.66339999999999999	0.60229999999999995	0.5272	0.25	0.043000001	20	98.565002	276.38900000000001	138.19499999999999	\N	90
10710	1973	100	1.5760000000000001	6.8308999999999997	0.73099999999999998	3.5649999999999999	7.9020000000000001	17.256399999999999	13.764099999999999	11.4359	9.4250000000000007	8.2899999999999991	6.3170000000000002	4.5155000000000003	3.0470999999999999	1.8774999999999999	1.5938000000000001	1.3100000000000001	1.083	0.7994	0.5	2.6429999	20	94.713997	2.008	1.159	\N	100
10711	1973	110	1.361	10.149800000000001	0.499	3.3500000000000001	8.0719999999999992	23.151900000000001	19.2073	17.7818	16	14.2182	10.654500000000001	8.1175999999999995	5.5843999999999996	3.4462000000000002	2.6922999999999999	1.9733000000000001	1.712	1.3200000000000001	0.5	0.50999999	20	86.223999	0.52900000000000003	0.30599999999999999	\N	110
10712	1973	120	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	120
23835	7143	43	13.003	2.9022999999999999	0.84799999999999998	2.1190000000000002	3.609	5.6096000000000004	4.7862999999999998	4.2374999999999998	3.8210999999999999	3.5472999999999999	2.9998999999999998	2.4523999999999999	1.9370000000000001	1.5741000000000001	1.3926000000000001	1.2111000000000001	1.0660000000000001	0.83130000000000004	0.063	0.0040000002	10	99.482002	0	0	\N	53
23834	7143	60	34.234999999999999	2.0390000000000001	1.6180000000000001	2.02	2.3490000000000002	3.9184999999999999	2.5756000000000001	1.9547000000000001	1.7959000000000001	1.6372	1.3196000000000001	1.0021	0.89200000000000002	0.78320000000000001	0.7288	0.6744	0.63090000000000002	0.56169999999999998	0.063	0.003	16	98.616997	0	0	\N	70
23833	7143	80	5.8330000000000002	3.7128000000000001	1.0960000000000001	4.0250000000000004	7.8319999999999999	9.8642000000000003	8.0165000000000006	6.7847	5.6414999999999997	4.6806000000000001	3.1414	1.9017999999999999	1.2073	0.78249999999999997	0.62880000000000003	0.5544	0.49469999999999997	0.40110000000000001	0.063	0.012	10	90.441002	0	0	\N	90
23832	7143	100	11.487	1.9184000000000001	1.329	2.7069999999999999	4.0919999999999996	4.4244000000000003	3.5785999999999998	3.1888000000000001	2.7016	2.2143000000000002	1.6261000000000001	1.1468	0.82950000000000002	0.61380000000000001	0.57089999999999996	0.52790000000000004	0.48849999999999999	0.39739999999999998	0.063	0.011	10	99.170998	0	0	\N	110
23831	7143	118	28.135999999999999	1.3674999999999999	2.0779999999999998	2.5089999999999999	2.681	3.5274000000000001	2.4228999999999998	1.8994	1.6040000000000001	1.3087	0.89329999999999998	0.66990000000000005	0.57340000000000002	0.50439999999999996	0.46239999999999998	0.41930000000000001	0.38490000000000002	0.3332	0.063	0.0099999998	6.2999999999999998	98.203003	0	0	\N	128
23830	7142	53	30.367000000000001	3.2934000000000001	0.83299999999999996	1.899	4.508	6.8777999999999997	3.8561999999999999	3.6642999999999999	3.4245000000000001	3.1846999999999999	2.7050000000000001	2.2252999999999998	1.8315999999999999	1.514	1.3552999999999999	1.1964999999999999	1.0693999999999999	0.59999999999999998	0.063	0.0020000001	16	97.970001	0	0	\N	53
23829	7142	74	29.100000000000001	2.4735	1.1279999999999999	2.4670000000000001	3.4769999999999999	5.5541	4.5065	3.9037000000000002	3.4657	3.0276999999999998	2.1516000000000002	1.72	1.3814	1.0427999999999999	0.92390000000000005	0.82199999999999995	0.74050000000000005	0.61890000000000001	0.063	0.001	6.2999999999999998	94.272003	0	0	\N	74
23828	7142	85	1.6399999999999999	4.3007	0.73699999999999999	4.1950000000000003	9.0660000000000007	9.4605999999999995	6.8545999999999996	5.8608000000000002	5.0545	4.2481	3.0312000000000001	1.9026000000000001	0.95489999999999997	0.54100000000000004	0.47199999999999998	0.42609999999999998	0.38940000000000002	0.33429999999999999	0.063	0.0099999998	16	91.959999	0	0	\N	85
23827	7142	115	20.616	2.4388999999999998	1.1220000000000001	3.4830000000000001	6.0119999999999996	5.8342000000000001	4.8052000000000001	4.1192000000000002	3.5626000000000002	3.0545	2.0383	1.3022	0.78249999999999997	0.5444	0.48159999999999997	0.43409999999999999	0.39610000000000001	0.33900000000000002	0.063	0.016000001	10	97.403	0	0	\N	115
23826	7142	134	3.782	2.5977999999999999	0.73099999999999998	3.5059999999999998	7.2039999999999997	6.0119999999999996	5.1090999999999998	4.5072000000000001	3.8553999999999999	3.4119000000000002	2.5247000000000002	1.7051000000000001	0.99060000000000004	0.61119999999999997	0.52229999999999999	0.45929999999999999	0.41570000000000001	0.35049999999999998	0.063	0.0040000002	10	98.683998	0	0	\N	134
23805	7121	62	22.231000000000002	1.8520000000000001	1.5109999999999999	2.5089999999999999	3.226	4.3118999999999996	3.4376000000000002	2.9708999999999999	2.3874	1.9314	1.5230999999999999	1.1148	0.88229999999999997	0.71850000000000003	0.63670000000000004	0.58520000000000005	0.54630000000000001	0.47210000000000002	0.063	0.0020000001	10	99.613998	0	0	\N	72
23804	7121	82	2.472	0.95020000000000004	1.5469999999999999	2.0329999999999999	2.1240000000000001	1.8142	1.4274	1.1696	0.95299999999999996	0.85389999999999999	0.65559999999999996	0.56440000000000001	0.49130000000000001	0.4304	0.40000000000000002	0.36959999999999998	0.34520000000000001	0.30869999999999997	0.063	0.0040000002	10	99.322998	0	0	\N	92
23803	7121	92	6.8150000000000004	2.7151000000000001	0.52100000000000002	2.9180000000000001	6.7089999999999996	5.6378000000000004	4.8624000000000001	4.3455000000000004	3.8559000000000001	3.5464000000000002	2.9272	2.3079999999999998	1.7478	1.246	0.99470000000000003	0.7258	0.57089999999999996	0.43630000000000002	0.063	0.0020000001	6.2999999999999998	95.124001	0	0	\N	102
23802	7121	103	10.611000000000001	0.90900000000000003	1.907	2.1589999999999998	2.0750000000000002	1.9019999999999999	1.53	1.282	0.98809999999999998	0.85619999999999996	0.61539999999999995	0.5131	0.45419999999999999	0.4017	0.37540000000000001	0.34920000000000001	0.32819999999999999	0.29659999999999997	0.063	0.003	6.2999999999999998	99.698997	0	0	\N	113
23801	7121	122	12.111000000000001	1.4456	1.6279999999999999	2.6539999999999999	3.177	3.5847000000000002	2.7673000000000001	2.2223999999999999	1.8299000000000001	1.5774999999999999	1.0725	0.81720000000000004	0.61819999999999997	0.52259999999999995	0.47570000000000001	0.42970000000000003	0.39290000000000003	0.33760000000000001	0.063	0.003	6.2999999999999998	99.021004	0	0	\N	132
23790	7101	53	18.954999999999998	1.6645000000000001	1.5529999999999999	2.1920000000000002	2.5950000000000002	3.6385000000000001	2.7985000000000002	2.2385000000000002	1.8864000000000001	1.714	1.3692	1.0244	0.87749999999999995	0.74570000000000003	0.67979999999999996	0.61890000000000001	0.58230000000000004	0.52749999999999997	0.125	0.003	10	99.782997	0	0	\N	53
23789	7101	64	23.585999999999999	1.0539000000000001	1.415	1.839	2.1960000000000002	1.8824000000000001	1.5854999999999999	1.3875999999999999	1.1403000000000001	0.97309999999999997	0.84899999999999998	0.72489999999999999	0.61729999999999996	0.56330000000000002	0.53639999999999999	0.50939999999999996	0.46889999999999998	0.3866	0.063	0.003	6.2999999999999998	99.194	0	0	\N	64
23788	7101	73	18.244	1.7798	1.766	2.71	3.423	4.0632000000000001	3.2456	2.7267999999999999	2.0781999999999998	1.7744	1.2614000000000001	0.9012	0.69979999999999998	0.57620000000000005	0.53500000000000003	0.4909	0.44190000000000002	0.36849999999999999	0.063	0.0020000001	10	98.356003	0	0	\N	73
23787	7101	93	15.329000000000001	2.5143	0.91900000000000004	3.427	6.8689999999999998	5.8475999999999999	5.1406000000000001	4.6692	4.0799000000000003	3.5514999999999999	2.5137	1.5649	0.88329999999999997	0.60099999999999998	0.54349999999999998	0.48549999999999999	0.43769999999999998	0.36599999999999999	0.063	0.0020000001	10	99.527	0	0	\N	93
23786	7101	113	21.983000000000001	2.3546999999999998	0.60899999999999999	2.6640000000000001	5.6150000000000002	4.9915000000000003	3.9910999999999999	3.7440000000000002	3.4350999999999998	3.1261000000000001	2.5083000000000002	1.9191	1.4628000000000001	1.0065999999999999	0.82499999999999996	0.64470000000000005	0.56240000000000001	0.44669999999999999	0.063	0.0020000001	6.2999999999999998	97.728996	0	0	\N	113
23770	7063	47	25.914999999999999	5.5338000000000003	1.042	2.0059999999999998	2.907	11.4032	8.8135999999999992	7.5332999999999997	6.2125000000000004	5.8308999999999997	5.0678000000000001	4.3047000000000004	3.6379000000000001	3.0350999999999999	2.7338	2.4323999999999999	2.1913	1.7432000000000001	0.063	0.0020000001	16	97.512001	0	0	\N	47
23769	7063	57	24.736999999999998	3.0783999999999998	1.0620000000000001	2.1309999999999998	3.274	5.9951999999999996	4.8753000000000002	4.1285999999999996	3.7382	3.4346000000000001	2.8273999999999999	2.2202000000000002	1.8056000000000001	1.5006999999999999	1.3482000000000001	1.1957	1.0737000000000001	0.86370000000000002	0.063	0.001	10	96.222	0	0	\N	57
23768	7063	87	22.117999999999999	4.0014000000000003	0.82399999999999995	3.2090000000000001	6.2690000000000001	9.3093000000000004	6.2767999999999997	5.6444000000000001	4.8539000000000003	4.0633999999999997	3.0964999999999998	2.1554000000000002	1.5740000000000001	1.0638000000000001	0.88119999999999998	0.72270000000000001	0.60960000000000003	0.49399999999999999	0.063	0.0070000002	16	95.935997	0	0	\N	87
23767	7063	97	21.753	1.8909	1.55	2.5009999999999999	3.2410000000000001	3.9559000000000002	2.8965999999999998	2.1903000000000001	1.8424	1.6414	1.2395	0.9304	0.75819999999999999	0.60599999999999998	0.55889999999999995	0.51190000000000002	0.4632	0.38250000000000001	0.063	0.0089999996	10	96.362999	0	0	\N	97
23766	7063	127	18.204000000000001	1.7016	1.413	2.6139999999999999	3.7839999999999998	3.8464999999999998	3.2176	2.7984	2.2743000000000002	1.8973	1.4663999999999999	1.0354000000000001	0.80169999999999997	0.6109	0.56430000000000002	0.51780000000000004	0.47089999999999999	0.38750000000000001	0.063	0.0080000004	6.2999999999999998	98.152	0	0	\N	127
23785	7082	52	26.173999999999999	1.2398	1.3859999999999999	1.8899999999999999	2.2269999999999999	2.4796999999999998	1.8188	1.6467000000000001	1.4316	1.2165999999999999	0.93940000000000001	0.8175	0.6956	0.60009999999999997	0.56769999999999998	0.5353	0.50939999999999996	0.42180000000000001	0.125	0.0020000001	6.2999999999999998	99.031998	0	0	\N	72
23784	7082	62	26.977	2.6461000000000001	1.0800000000000001	2.9750000000000001	4.6360000000000001	5.9555999999999996	5.0168999999999997	4.3910999999999998	3.7545999999999999	3.2637	2.282	1.6225000000000001	1.0929	0.81899999999999995	0.70920000000000005	0.61360000000000003	0.56669999999999998	0.49220000000000003	0.063	0.0020000001	10	97.514999	0	0	\N	82
23783	7082	80	28.045000000000002	2.1080999999999999	1.512	3.113	4.532	5.3505000000000003	4.0938999999999997	3.5712000000000002	2.9676	2.3639999999999999	1.6173	1.0692999999999999	0.77829999999999999	0.58120000000000005	0.52249999999999996	0.4662	0.42249999999999999	0.35680000000000001	0.063	0.0020000001	10	98.789001	0	0	\N	100
23782	7082	91	26.030999999999999	1.2453000000000001	1.8540000000000001	2.2160000000000002	2.1070000000000002	2.7576999999999998	1.6856	1.3632	0.98880000000000001	0.87539999999999996	0.64859999999999995	0.55869999999999997	0.48549999999999999	0.42630000000000001	0.3967	0.36699999999999999	0.34329999999999999	0.30780000000000002	0.063	0.0020000001	10	98.388	0	0	\N	111
23781	7082	122	11.461	1.4034	1.6259999999999999	2.6080000000000001	3.0670000000000002	3.4775	2.6913	2.1671	1.8098000000000001	1.5546	1.044	0.80920000000000003	0.6169	0.52459999999999996	0.47849999999999998	0.4325	0.3957	0.34039999999999998	0.063	0.003	6.2999999999999998	99.470001	0	0	\N	142
12992	2099	83	38.055999999999997	1.4634	1.3999999999999999	1.9399999999999999	2.2240000000000002	3.1299000000000001	1.954	1.7842	1.5720000000000001	1.3599000000000001	0.98040000000000005	0.85129999999999995	0.72219999999999995	0.61119999999999997	0.57830000000000004	0.5454	0.51910000000000001	0.44080000000000003	0.125	0.0020000001	10	98.581001	8.1609999999999996	4.7110000000000003	\N	83
12993	2099	93	7.0899999999999999	0.99080000000000001	1.472	1.845	2.1629999999999998	1.8320000000000001	1.4081999999999999	1.1256999999999999	0.95750000000000002	0.89159999999999995	0.75970000000000004	0.62919999999999998	0.57899999999999996	0.52880000000000005	0.50370000000000004	0.45550000000000002	0.4138	0.3513	0.125	0.003	6.2999999999999998	99.150002	8.3919999999999995	4.8449999999999998	\N	93
12994	2099	104	23.146000000000001	1.7195	1.8380000000000001	2.7080000000000002	3.0760000000000001	4.1523000000000003	3.0657999999999999	2.4016000000000002	1.8662000000000001	1.6069	1.0885	0.83509999999999995	0.63629999999999998	0.55149999999999999	0.51100000000000001	0.46089999999999998	0.41810000000000003	0.35389999999999999	0.125	0.0070000002	10	98.720001	24.314	14.038	\N	104
12995	2099	144	5.4240000000000004	1.4807999999999999	3.9289999999999998	2.9910000000000001	1.9470000000000001	3.9430999999999998	2.7639	1.9883999999999999	1.4758	0.97660000000000002	0.54730000000000001	0.46610000000000001	0.4199	0.37359999999999999	0.35049999999999998	0.32740000000000002	0.30890000000000001	0.28110000000000002	0.125	0.124	10	97.782997	14.782999999999999	8.5350000000000001	\N	144
12996	2099	153	1.167	0.96160000000000001	1.9550000000000001	2.097	1.8240000000000001	1.9357	1.3435999999999999	0.98080000000000001	0.79610000000000003	0.62409999999999999	0.50819999999999999	0.45829999999999999	0.41339999999999999	0.36849999999999999	0.34599999999999997	0.3236	0.30559999999999998	0.2787	0.125	0.48300001	6.2999999999999998	97.346001	1.2829999999999999	0.74099999999999999	\N	153
11015	2115	20	18.173999999999999	1.4678	1.5569999999999999	2.1259999999999999	2.4169999999999998	3.3538000000000001	2.4308000000000001	1.9512	1.748	1.5447	1.1382000000000001	0.91639999999999999	0.78969999999999996	0.66290000000000004	0.61060000000000003	0.57020000000000004	0.53800000000000003	0.47099999999999997	0.25	0.1	8	99.300003	38.442999999999998	22.195	\N	20
11016	2115	60	12.603999999999999	1.7855000000000001	1.325	2.512	3.5680000000000001	3.9350999999999998	3.2865000000000002	2.8540999999999999	2.3134999999999999	1.9179999999999999	1.5273000000000001	1.1367	0.88029999999999997	0.69630000000000003	0.61529999999999996	0.56289999999999996	0.52100000000000002	0.42809999999999998	0.25	0.1	8	98.800003	20.530000000000001	11.853	\N	60
11017	2115	100	60.615000000000002	1.5144	1.2809999999999999	1.867	2.258	3.1456	1.9965999999999999	1.8601000000000001	1.6894	1.5187999999999999	1.1775	0.94469999999999998	0.82940000000000003	0.71409999999999996	0.65649999999999997	0.6069	0.57269999999999999	0.52139999999999997	0.25	0.1	10	99.400002	83.075999999999993	47.963999999999999	\N	100
11018	2115	140	5.0330000000000004	1.4054	1.302	2.1419999999999999	2.9790000000000001	3.1227999999999998	2.3860000000000001	1.9709000000000001	1.8009999999999999	1.6311	1.2912999999999999	0.97609999999999997	0.80900000000000005	0.64190000000000003	0.59450000000000003	0.55320000000000003	0.52010000000000001	0.4335	0.25	0.14300001	8	99.857002	1.8879999999999999	1.0900000000000001	\N	140
11010	2114	11	10.25	1.3983000000000001	1.496	2.036	2.2559999999999998	3.1429	2.1905000000000001	1.8837999999999999	1.6762999999999999	1.4689000000000001	1.0539000000000001	0.87990000000000002	0.74180000000000001	0.6179	0.58599999999999997	0.55420000000000003	0.52869999999999995	0.46710000000000002	0.25	0.1	10	99.800003	9.6460000000000008	5.569	\N	11
11011	2114	51	26.465	3.6168999999999998	1.1739999999999999	3.0939999999999999	5.1589999999999998	8.9091000000000005	6.7065000000000001	5.6824000000000003	4.6176000000000004	3.8100000000000001	2.9049999999999998	2	1.5798000000000001	1.1597	0.96479999999999999	0.81789999999999996	0.70050000000000001	0.56310000000000004	0.25	0.1	10	93	22.468	12.972	\N	51
11012	2114	61	67.587999999999994	1.7905	1.5349999999999999	2.2410000000000001	2.681	3.6690999999999998	2.8058000000000001	2.2302	1.8815	1.7073	1.3589	1.0105	0.85870000000000002	0.71299999999999997	0.64019999999999999	0.59299999999999997	0.5585	0.50690000000000002	0.25	0.1	10	98.5	94.444999999999993	54.527999999999999	\N	61
11013	2114	91	25.742999999999999	1.6002000000000001	1.391	1.9770000000000001	2.266	3.3978000000000002	2.1074999999999999	1.8637999999999999	1.6693	1.4746999999999999	1.0855999999999999	0.90410000000000001	0.78120000000000001	0.6583	0.60909999999999997	0.57040000000000002	0.53949999999999998	0.47920000000000001	0.25	0.1	10	99.099998	28.413	16.404	\N	91
11014	2114	111	14.055999999999999	1.5497000000000001	1.1279999999999999	1.897	2.4889999999999999	3.1469	2.3077000000000001	1.9516	1.8171999999999999	1.6828000000000001	1.4139999999999999	1.1452	0.94230000000000003	0.81689999999999996	0.75419999999999998	0.6915	0.64129999999999998	0.56799999999999995	0.25	0.1	8	99.099998	7.923	4.5750000000000002	\N	111
11004	2113	19	73.066999999999993	2.0831	1.161	2.0470000000000002	2.5600000000000001	3.9218999999999999	2.9843999999999999	2.3593999999999999	1.9369000000000001	1.8201000000000001	1.5864	1.3528	1.1192	0.9254	0.84930000000000005	0.77310000000000001	0.71220000000000006	0.61960000000000004	0.5	3.0999999	10	98	60.332000000000001	34.832999999999998	\N	19
11005	2113	29	85.381	2.4384999999999999	1.7769999999999999	2.669	2.9500000000000002	6.9032	4.2130000000000001	3.3578000000000001	2.4403999999999999	1.9060999999999999	1.5450999999999999	1.1840999999999999	0.92889999999999995	0.78380000000000005	0.71130000000000004	0.63870000000000005	0.59160000000000001	0.52370000000000005	0.25	0.1	10	97.099998	129.47999999999999	74.754999999999995	\N	29
11006	2113	49	25.507000000000001	1.3467	1.3839999999999999	1.978	2.3759999999999999	2.8915999999999999	1.8915	1.7028000000000001	1.4670000000000001	1.2311000000000001	0.93689999999999996	0.81310000000000004	0.68940000000000001	0.5927	0.55669999999999997	0.52080000000000004	0.48359999999999997	0.39429999999999998	0.25	0.30000001	10	99.599998	33.768000000000001	19.495999999999999	\N	49
11007	2113	59	60.926000000000002	1.6198999999999999	1.4450000000000001	2.1120000000000001	2.6309999999999998	3.4087000000000001	2.3652000000000002	1.9291	1.7424999999999999	1.556	1.1828000000000001	0.93140000000000001	0.79679999999999995	0.6623	0.60760000000000003	0.56459999999999999	0.53010000000000002	0.4496	0.25	0.1	10	98.800003	93.278999999999996	53.853999999999999	\N	59
11008	2113	99	25.146000000000001	2.3912	0.98599999999999999	2.597	3.847	5.1500000000000004	3.8100000000000001	3.448	2.9954999999999998	2.5430000000000001	1.8507	1.4776	1.1045	0.83350000000000002	0.71789999999999998	0.61499999999999999	0.56499999999999995	0.48110000000000003	0.25	0.2	10	97.099998	24.719000000000001	14.272	\N	99
11009	2113	139	17.228999999999999	1.7742	1.6040000000000001	2.806	3.9670000000000001	3.9683999999999999	3.3368000000000002	2.9157999999999999	2.3895	1.9330000000000001	1.4175	0.93889999999999996	0.627	0.55269999999999997	0.51559999999999995	0.46789999999999998	0.42370000000000002	0.35730000000000001	0.25	0.30000001	10	99.099998	20.324000000000002	11.734	\N	139
10995	2112	34	38.933	1.3059000000000001	1.3029999999999999	1.776	1.8839999999999999	2	1.7818000000000001	1.6364000000000001	1.4544999999999999	1.2726999999999999	0.9758	0.87890000000000001	0.78210000000000002	0.68520000000000003	0.63680000000000003	0.59630000000000005	0.56499999999999995	0.51800000000000002	0.25	0.1	10	99.800003	53.933	31.138000000000002	\N	34
10996	2112	41	31.338999999999999	2.5202	1.6180000000000001	2.5910000000000002	3.0310000000000001	6.6863999999999999	3.8281000000000001	3.2031000000000001	2.4218999999999999	1.9135	1.5376000000000001	1.1617	0.91210000000000002	0.75800000000000001	0.68089999999999995	0.61219999999999997	0.57020000000000004	0.50729999999999997	0.25	0.1	10	94.900002	24.364000000000001	12.182	\N	41
10997	2112	52	31.59	1.7961	1.546	2.0960000000000001	2.383	3.6800000000000002	2.48	1.9419999999999999	1.7608999999999999	1.5797000000000001	1.2174	0.95179999999999998	0.83130000000000004	0.7107	0.65049999999999997	0.60040000000000004	0.56459999999999999	0.51080000000000003	0.25	0.1	10	98	20.701000000000001	11.951000000000001	\N	52
10998	2112	64	39.542999999999999	2.4855999999999998	2.2290000000000001	2.8279999999999998	3.25	7.6077000000000004	4.2091000000000003	3.3208000000000002	2.3774000000000002	1.8684000000000001	1.4298	0.99670000000000003	0.8337	0.67069999999999996	0.60740000000000005	0.56230000000000002	0.5262	0.43990000000000001	0.25	0.2	10	95.800003	144.517	64.629999999999995	\N	64
10999	2112	98	21.989999999999998	2.8298999999999999	1.046	2.9209999999999998	4.484	6.5297000000000001	5.1177999999999999	4.2579000000000002	3.6577000000000002	3.2071999999999998	2.3062999999999998	1.7130000000000001	1.2783	0.91410000000000002	0.79469999999999996	0.6754	0.59999999999999998	0.51429999999999998	0.25	0.1	10	97	34.799999999999997	17.399999999999999	\N	98
11000	2112	107	33.036000000000001	2.6343000000000001	1.0569999999999999	2.6019999999999999	3.6150000000000002	6.4821	4.0396999999999998	3.6061000000000001	3.101	2.5960000000000001	1.8575999999999999	1.5104	1.1632	0.88400000000000001	0.77449999999999997	0.66500000000000004	0.5968	0.51380000000000003	0.25	0.1	10	96.5	55.098999999999997	27.550000000000001	\N	107
11001	2112	125	22.193000000000001	1.3738999999999999	1.3380000000000001	1.9139999999999999	2.1869999999999998	2.9091	1.9333	1.7778	1.5832999999999999	1.3889	1	0.873	0.74609999999999999	0.62409999999999999	0.58960000000000001	0.55520000000000003	0.52759999999999996	0.45729999999999998	0.25	0.28600001	8	98.713997	27.946999999999999	13.974	\N	125
11002	2112	133	9.9309999999999992	0.8165	1.1240000000000001	1.627	1.899	1.5308999999999999	1.0123	0.94020000000000004	0.86260000000000003	0.78510000000000002	0.63	0.5867	0.54330000000000001	0.5	0.45789999999999997	0.41589999999999999	0.38219999999999998	0.33169999999999999	0.25	0.28600001	8	99.857002	13.425000000000001	7.7510000000000003	\N	133
11003	2112	142	14.002000000000001	1.3589	2.536	2.5350000000000001	2.1629999999999998	3.4862000000000002	2.3853	1.8332999999999999	1.3947000000000001	0.9859	0.70340000000000003	0.59089999999999998	0.53800000000000003	0.47849999999999998	0.44019999999999998	0.40179999999999999	0.37119999999999997	0.32519999999999999	0.25	0.2	10	99.400002	34.441000000000003	15.403	\N	142
10989	2111	36	9.1530000000000005	1.4685999999999999	1.5329999999999999	1.905	2.1760000000000002	2.7924000000000002	1.7727999999999999	1.5219	1.2082999999999999	0.98080000000000001	0.86609999999999998	0.75139999999999996	0.63680000000000003	0.57589999999999997	0.54720000000000002	0.51849999999999996	0.48830000000000001	0.39810000000000001	0.25	0.152	10	97.646004	10.488	6.0549999999999997	\N	36
10990	2111	57	34.838999999999999	2.3542000000000001	1.6830000000000001	2.7749999999999999	3.4950000000000001	5.7403000000000004	4.2084999999999999	3.6192000000000002	3.0209999999999999	2.4228000000000001	1.6737	1.1692	0.88570000000000004	0.71379999999999999	0.62890000000000001	0.58309999999999995	0.54649999999999999	0.47889999999999999	0.25	0.1	10	97.598	42.491999999999997	24.533000000000001	\N	57
10991	2111	77	78.896000000000001	2.8786999999999998	2.1190000000000002	3.1190000000000002	3.1749999999999998	8.7309000000000001	5.5236000000000001	3.7713999999999999	2.8795000000000002	1.9973000000000001	1.607	1.2168000000000001	0.92669999999999997	0.76160000000000005	0.67910000000000004	0.60919999999999996	0.56789999999999996	0.50609999999999999	0.25	0.1	10	93.492996	130.363	75.265000000000001	\N	77
10992	2111	97	40.817	2.6295000000000002	1.1020000000000001	2.3340000000000001	3.1720000000000002	5.7000000000000002	3.9135	3.5287999999999999	3.0480999999999998	2.5672999999999999	1.8829	1.5971	1.3113999999999999	1.0257000000000001	0.91180000000000005	0.80420000000000003	0.71819999999999995	0.59370000000000001	0.25	0.1	10	96.099998	53.939	31.141999999999999	\N	97
10993	2111	119	18.548999999999999	4.2851999999999997	1.1200000000000001	3.2280000000000002	5.2569999999999997	12.481199999999999	8.1999999999999993	6.2582000000000004	5.2126999999999999	4.1673	3.2332999999999998	2.3999999999999999	1.7636000000000001	1.3090999999999999	1.0818000000000001	0.90529999999999999	0.78690000000000004	0.61509999999999998	0.25	0.1	10	86.699997	7.282	4.2039999999999997	\N	119
10994	2111	138	20.228999999999999	1.6525000000000001	4.1680000000000001	3.2229999999999999	1.9359999999999999	5.2451999999999996	3.6665000000000001	2.6286	1.4148000000000001	0.86670000000000003	0.6079	0.55710000000000004	0.50639999999999996	0.44350000000000001	0.41110000000000002	0.37880000000000003	0.35289999999999999	0.31409999999999999	0.25	0.1	10	98.999001	19.073	11.012	\N	138
10982	2110	24	3.3439999999999999	0.747	1.091	1.3819999999999999	1.8360000000000001	0.99560000000000004	0.94430000000000003	0.91020000000000001	0.86750000000000005	0.82479999999999998	0.73929999999999996	0.65390000000000004	0.59960000000000002	0.5575	0.53639999999999999	0.51529999999999998	0.49419999999999997	0.40260000000000001	0.5	16.379	2	98.921997	0.309	0.219	\N	24
10983	2110	34	110.873	1.4160999999999999	1.3029999999999999	1.839	2.044	2.2928000000000002	1.8132999999999999	1.6637	1.4765999999999999	1.2895000000000001	0.97489999999999999	0.8639	0.75290000000000001	0.64190000000000003	0.60150000000000003	0.56520000000000004	0.53620000000000001	0.47699999999999998	0.5	11.011	10	98.698997	254.756	127.378	\N	34
10984	2110	64	38.465000000000003	2.4777	1.0369999999999999	2.4950000000000001	3.5649999999999999	5.1897000000000002	3.7044000000000001	3.3102999999999998	2.8176999999999999	2.3250999999999999	1.7825	1.4578	1.1331	0.87670000000000003	0.77210000000000001	0.66759999999999997	0.59509999999999996	0.5	0.25	0.1	10	95.699997	51.128	36.152999999999999	\N	64
10985	2110	93	47.326000000000001	2.2035999999999998	1.167	2.4390000000000001	3.2160000000000002	4.6938000000000004	3.5596000000000001	3.1389	2.6132	2.0874000000000001	1.6895	1.3508	1.0122	0.83030000000000004	0.74229999999999996	0.65429999999999999	0.59819999999999995	0.52539999999999998	0.25	0.1	10	97.797997	259.40100000000001	129.69999999999999	\N	93
10986	2110	103	5.4390000000000001	1.6146	1.5820000000000001	2.3690000000000002	3.1499999999999999	3.5648	2.8815	2.4258999999999999	1.948	1.7416	1.3289	0.96719999999999995	0.80579999999999996	0.64439999999999997	0.59350000000000003	0.54910000000000003	0.51359999999999995	0.4219	0.25	0.163	10	99.836998	6.1310000000000002	4.335	\N	103
10987	2110	133	5.109	1.3337000000000001	1.899	2.2690000000000001	2.4569999999999999	3.2667000000000002	1.9875	1.7153	1.375	1.0347	0.8226	0.63570000000000004	0.56830000000000003	0.50460000000000005	0.46329999999999999	0.42049999999999998	0.38619999999999999	0.33479999999999999	0.25	0.102	10	99.592003	11.359	5.6799999999999997	\N	133
10988	2110	143	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	143
10975	2109	17	1.734	0.77880000000000005	0.999	1.5509999999999999	2.109	1.3	0.97360000000000002	0.93269999999999997	0.88149999999999995	0.83040000000000003	0.72809999999999997	0.62790000000000001	0.57540000000000002	0.52300000000000002	0.49399999999999999	0.44440000000000002	0.4047	0.34520000000000001	0.25	0.40700001	6.2999999999999998	99.593002	0.081000000000000003	0.057000000000000002	\N	17
10976	2109	46	0.31900000000000001	0.82550000000000001	1.6479999999999999	2.0190000000000001	1.9990000000000001	1.8275999999999999	1.3516999999999999	1.0345	0.89059999999999995	0.77070000000000005	0.59830000000000005	0.52170000000000005	0.46129999999999999	0.4073	0.38030000000000003	0.3533	0.33169999999999999	0.29930000000000001	0.25	0.87	4	99.782997	0	0	\N	46
10977	2109	57	6.9580000000000002	1.3209	1.2470000000000001	1.974	2.5019999999999998	2.7652000000000001	1.9154	1.7628999999999999	1.5721000000000001	1.3814	1	0.86899999999999999	0.73799999999999999	0.61499999999999999	0.57220000000000004	0.52949999999999997	0.49149999999999999	0.3997	0.25	0.22499999	10	99.849998	27.684000000000001	13.842000000000001	\N	57
10978	2109	87	5.0830000000000002	1.1194	1.27	1.8899999999999999	2.3490000000000002	1.9602999999999999	1.7153	1.552	1.3478000000000001	1.1435999999999999	0.9234	0.80530000000000002	0.68720000000000003	0.59230000000000005	0.55579999999999996	0.51919999999999999	0.48010000000000003	0.3931	0.25	0.13699999	8	99.862999	7.7329999999999997	4.4649999999999999	\N	87
10979	2109	97	0.049000000000000002	1.3048999999999999	2.4929999999999999	2.6400000000000001	2.3039999999999998	3.3332999999999999	2.3999999999999999	1.8571	1.3571	0.96299999999999997	0.70399999999999996	0.57579999999999998	0.5	0.43519999999999998	0.40279999999999999	0.37040000000000001	0.34439999999999998	0.30559999999999998	0.25	1.429	6.2999999999999998	94.286003	0	0	\N	97
10980	2109	128	1.181	0.74750000000000005	1.095	1.6439999999999999	1.9139999999999999	1.3783000000000001	0.94450000000000001	0.86570000000000003	0.76719999999999999	0.66859999999999997	0.59389999999999998	0.54900000000000004	0.50409999999999999	0.44069999999999998	0.40810000000000002	0.3755	0.34939999999999999	0.31030000000000002	0.25	0.76499999	4	99.235001	0.83499999999999996	0.48199999999999998	\N	128
10981	2109	136	0.13200000000000001	0.64090000000000003	1.03	1.4259999999999999	1.6419999999999999	1.25	0.61419999999999997	0.57889999999999997	0.53480000000000005	0.49619999999999997	0.4602	0.42420000000000002	0.38829999999999998	0.3523	0.33429999999999999	0.31630000000000003	0.3019	0.28029999999999999	0.25	1.579	2	93.157997	0	0	\N	136
10968	2108	20	4.9429999999999996	1.0165	1.2070000000000001	1.5660000000000001	1.7330000000000001	1.6964999999999999	1.2929999999999999	1.0241	0.96109999999999995	0.91930000000000001	0.83560000000000001	0.75190000000000001	0.66810000000000003	0.60129999999999995	0.57499999999999996	0.54869999999999997	0.52759999999999996	0.48220000000000002	0.25	0.105	8	99.262001	4.383	3.0990000000000002	\N	20
10969	2108	46	6.069	2.1810999999999998	1.0449999999999999	2.4820000000000002	3.23	4.9511000000000003	3.8664999999999998	3.4988999999999999	3.0394999999999999	2.5800000000000001	1.8716999999999999	1.5239	1.1760999999999999	0.9022	0.80310000000000004	0.70399999999999996	0.62790000000000001	0.5796	0.5	0.115	10	99.771004	0	0	\N	46
10970	2108	58	8.2010000000000005	1.9047000000000001	0.56299999999999994	2.5209999999999999	5.2450000000000001	3.6494	3.3885999999999998	3.2147999999999999	2.9975000000000001	2.7801	2.3454999999999999	1.7917000000000001	0.95030000000000003	0.72489999999999999	0.62219999999999998	0.57269999999999999	0.53310000000000002	0.44719999999999999	0.25	0.059	8	99.589996	3.2410000000000001	1.871	\N	58
10971	2108	92	10.629	2.5752000000000002	1.2150000000000001	2.649	3.4870000000000001	5.8116000000000003	4.2625999999999999	3.6846999999999999	3.1560999999999999	2.6274999999999999	1.8438000000000001	1.4596	1.0753999999999999	0.85360000000000003	0.76259999999999994	0.67159999999999997	0.60750000000000004	0.52880000000000005	0.5	7.8080001	10	96.295998	10.73	7.5869999999999997	\N	92
10972	2108	105	32.396999999999998	2.9687000000000001	0.96099999999999997	2.9039999999999999	4.71	6.2515000000000001	5.1185	4.3631000000000002	3.7399	3.3172999999999999	2.4721000000000002	1.7978000000000001	1.3398000000000001	0.93579999999999997	0.8115	0.68710000000000004	0.60680000000000001	0.52490000000000003	0.25	0.043000001	20	99.477997	91.903000000000006	53.060000000000002	\N	105
10973	2108	125	13.198	1.5760000000000001	1.8899999999999999	2.3220000000000001	2.4319999999999999	3.7202999999999999	2.7837999999999998	2.1594000000000002	1.8022	1.5537000000000001	1.0567	0.87209999999999999	0.72770000000000001	0.60870000000000002	0.57569999999999999	0.54279999999999995	0.51639999999999997	0.4345	0.25	0.1	10	99.599998	26.870000000000001	13.435	\N	125
10974	2108	136	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	136
10963	2107	32	5.0419999999999998	1.4770000000000001	1.3180000000000001	1.9399999999999999	2.3319999999999999	3.0817000000000001	1.9686999999999999	1.8121	1.6164000000000001	1.4206000000000001	1.0290999999999999	0.88380000000000003	0.75829999999999997	0.63270000000000004	0.59289999999999998	0.55410000000000004	0.52300000000000002	0.44140000000000001	0.25	0.103	10	99.172997	13.500999999999999	6.75	\N	32
10964	2107	57	38.811999999999998	2.9218000000000002	1.3660000000000001	2.907	3.6099999999999999	7.5308000000000002	4.8848000000000003	3.8367	3.2456	2.6543999999999999	1.8265	1.4377	1.0489999999999999	0.82450000000000001	0.72399999999999998	0.62609999999999999	0.57799999999999996	0.50590000000000002	0.25	0.1	10	93.093002	203.26599999999999	90.903000000000006	\N	57
10965	2107	82	9.7330000000000005	1.0152000000000001	1.3200000000000001	1.766	2.141	1.8119000000000001	1.4350000000000001	1.1836	0.97760000000000002	0.92349999999999999	0.81540000000000001	0.70740000000000003	0.61450000000000005	0.55989999999999995	0.53259999999999996	0.50539999999999996	0.46010000000000001	0.38080000000000003	0.25	0.1	8	99.699997	29.364999999999998	16.954000000000001	\N	82
10966	2107	119	22.510000000000002	1.7914000000000001	1.2849999999999999	2.4289999999999998	3.5169999999999999	3.6640000000000001	2.9670000000000001	2.5023	1.9757	1.796	1.4367000000000001	1.0772999999999999	0.84399999999999997	0.64529999999999998	0.58930000000000005	0.54120000000000001	0.50270000000000004	0.40849999999999997	0.25	0.1	10	98.498001	51.725000000000001	29.863	\N	119
10967	2107	144	10.448	1.1517999999999999	2.129	2.2629999999999999	1.9770000000000001	3.0712999999999999	1.9433	1.5552999999999999	1.0704	0.89610000000000001	0.65290000000000004	0.58840000000000003	0.54249999999999998	0.49399999999999999	0.4531	0.41210000000000002	0.37940000000000002	0.33019999999999999	0.25	0.2	8	99.800003	23.417999999999999	13.52	\N	144
10955	2106	43	36.997999999999998	0.96560000000000001	1.2390000000000001	1.625	1.732	1.6919999999999999	1.4180999999999999	1.2354000000000001	1.0071000000000001	0.95789999999999997	0.87090000000000001	0.78400000000000003	0.69699999999999995	0.6169	0.58840000000000003	0.55989999999999995	0.53700000000000003	0.50280000000000002	0.5	9.5120001	8	99.75	67.013000000000005	38.689999999999998	\N	43
10956	2106	51	23.548999999999999	1.1298999999999999	1.302	1.7190000000000001	1.9139999999999999	1.8401000000000001	1.5573999999999999	1.3689	1.1333	0.9798	0.88700000000000001	0.79410000000000003	0.70120000000000005	0.61529999999999996	0.58379999999999999	0.55230000000000001	0.52700000000000002	0.46350000000000002	0.5	11.712	10	99.599998	29.437000000000001	16.995999999999999	\N	51
10957	2106	72	0.79200000000000004	1.0385	1.214	1.7549999999999999	1.9730000000000001	1.6664000000000001	1.0462	0.92879999999999996	0.82869999999999999	0.72850000000000004	0.59989999999999999	0.54079999999999995	0.48170000000000002	0.4224	0.39279999999999998	0.36320000000000002	0.33950000000000002	0.30399999999999999	0.25	0.88	10	98.240997	0	0	\N	72
10958	2106	83	9.5939999999999994	1.3435999999999999	1.3899999999999999	1.97	2.375	2.9379	1.9277	1.7493000000000001	1.5263	1.3032999999999999	0.95889999999999997	0.83020000000000005	0.70150000000000001	0.59830000000000005	0.56269999999999998	0.52710000000000001	0.49690000000000001	0.4037	0.25	0.107	10	99.785004	13.244	9.3650000000000002	\N	83
10959	2106	114	67.194999999999993	1.6021000000000001	1.288	2.222	2.9209999999999998	3.4436	2.7170999999999998	2.2326999999999999	1.8988	1.7344999999999999	1.4058999999999999	1.0772999999999999	0.87919999999999998	0.72119999999999995	0.64229999999999998	0.58909999999999996	0.55030000000000001	0.48120000000000002	0.5	10.811	10	99.800003	113.842	65.727000000000004	\N	114
10960	2106	135	22.722000000000001	1.5722	1.5629999999999999	2.2429999999999999	2.8010000000000002	3.5754000000000001	2.5928	1.9850000000000001	1.7884	1.5916999999999999	1.1983999999999999	0.92459999999999998	0.77249999999999996	0.62509999999999999	0.58589999999999998	0.54679999999999995	0.51549999999999996	0.4279	0.25	0.1	10	99.599998	33.476999999999997	19.327999999999999	\N	135
10961	2106	155	29.786999999999999	1.4040999999999999	2.6419999999999999	2.3570000000000002	2.1949999999999998	3.5979999999999999	2.3871000000000002	1.8190999999999999	1.3848	0.9889	0.7944	0.62309999999999999	0.57879999999999998	0.53449999999999998	0.51229999999999998	0.47489999999999999	0.42970000000000003	0.3619	0.25	0.1	10	99.399002	85.253	49.220999999999997	\N	155
10962	2106	161	1.7709999999999999	2.1042999999999998	3.5	3.262	3.5459999999999998	5.5252999999999997	3.8447	3.2471000000000001	2.5	1.8765000000000001	1.1294	0.63	0.54079999999999995	0.4612	0.42559999999999998	0.38990000000000002	0.36130000000000001	0.31850000000000001	0.25	0.39399999	10	96.457001	1.605	0.92600000000000005	\N	161
10399	2000	27	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	27
10400	2000	37	0.042000000000000003	1.105	0.95599999999999996	2.056	3.0670000000000002	1.9523999999999999	1.7809999999999999	1.6667000000000001	1.5238	1.381	1.0952	0.88619999999999999	0.71540000000000004	0.57430000000000003	0.51859999999999995	0.46429999999999999	0.4214	0.35709999999999997	0.5	23.333	2	91.667	0.083000000000000004	0.048000000000000001	\N	37
10401	2000	57	1.1930000000000001	1.7487999999999999	0.80800000000000005	1.929	3.0059999999999998	3.2787999999999999	2.5472999999999999	2.0596000000000001	1.9189000000000001	1.829	1.6491	1.4693000000000001	1.2895000000000001	1.1095999999999999	1.0197000000000001	0.84430000000000005	0.68469999999999998	0.54859999999999998	0.25	0.134	10	99.565002	1.6930000000000001	0.84599999999999997	\N	57
10402	2000	67	0.92700000000000005	2.7221000000000002	1.0209999999999999	2.544	3.6619999999999999	5.9897999999999998	4.2632000000000003	3.6646000000000001	3.1212	2.5777999999999999	1.8911	1.6587000000000001	1.4262999999999999	1.194	1.0778000000000001	0.9002	0.65890000000000004	0.51639999999999997	0.25	0.093000002	10	96.375	1.885	0.94299999999999995	\N	67
10403	2000	96	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	96
10395	1999	27	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	27
10396	1999	47	3.7639999999999998	5.6962000000000002	1.0509999999999999	2.871	4.8529999999999998	14.422700000000001	11.0763	9.4536999999999995	8.1341000000000001	6.9408000000000003	5.1528999999999998	3.7642000000000002	2.8845999999999998	2.0049000000000001	1.7674000000000001	1.5322	1.3440000000000001	1.0617000000000001	0.5	2.033	10	82.07	12.823	7.4029999999999996	\N	47
10397	1999	67	0.049000000000000002	0.85960000000000003	1.518	2.0710000000000002	2.6909999999999998	1.72	1.552	1.4399999999999999	1.3	1.1599999999999999	0.86129999999999995	0.60829999999999995	0.53249999999999997	0.46000000000000002	0.42499999999999999	0.39000000000000001	0.36199999999999999	0.32000000000000001	0.5	35.714001	1	64.286003	0.16800000000000001	0.097000000000000003	\N	67
10398	1999	82	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	82
10390	1998	22	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	22
10391	1998	32	0.049000000000000002	1.7547999999999999	1.1020000000000001	1.6559999999999999	2.331	3.2222	2.7555999999999998	2.4443999999999999	2.0556000000000001	1.9268000000000001	1.7561	1.5853999999999999	1.4146000000000001	1.2439	1.1585000000000001	1.0731999999999999	1.0048999999999999	0.75329999999999997	0.5	2.8570001	2	74.286003	0.16800000000000001	0.097000000000000003	\N	32
10392	1998	51	0.86099999999999999	3.9782000000000002	1.952	3.206	4.2199999999999998	10.538500000000001	8.0914000000000001	7.0225	5.5094000000000003	3.8940999999999999	2.4470999999999998	1.8068	1.5273000000000001	1.2477	1.1080000000000001	0.95289999999999997	0.78739999999999999	0.57989999999999997	0.5	6.5040002	10	89.431	2.0009999999999999	1.155	\N	51
10393	1998	62	7.3440000000000003	1.6956	0.60099999999999998	1.9359999999999999	3.0830000000000002	3.0829	2.1211000000000002	1.9428000000000001	1.8546	1.7664	1.5899000000000001	1.4135	1.2371000000000001	1.0607	0.79769999999999996	0.59909999999999997	0.56579999999999997	0.51570000000000005	0.5	8.1110001	10	99.109001	39.097999999999999	19.548999999999999	\N	62
10394	1998	92	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	92
10384	1997	25	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	25
10385	1997	33	0.042000000000000003	1.2957000000000001	0.89300000000000002	1.8879999999999999	2.8719999999999999	2.5	1.9333	1.8332999999999999	1.7082999999999999	1.5832999999999999	1.3332999999999999	1.0832999999999999	0.88619999999999999	0.71540000000000004	0.63	0.58120000000000005	0.54220000000000002	0.46429999999999999	0.5	11.667	2	86.667	0	0	\N	33
10386	1997	53	1.1040000000000001	6.6418999999999997	1.149	3.3540000000000001	6.2069999999999999	16.460000000000001	14.336	12.92	11.15	9.5039999999999996	6.3399999999999999	3.9866000000000001	2.8027000000000002	1.8643000000000001	1.6536	1.4429000000000001	1.2743	1.0214000000000001	0.25	0.113	10	71.750999	3.0539999999999998	1.7629999999999999	\N	53
10387	1997	73	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	73
10388	1997	93	0.089999999999999997	4.6833999999999998	2.7879999999999998	3.2810000000000001	4.2830000000000004	14.347799999999999	10.9565	9.25	5.6100000000000003	3.7930999999999999	2.8965999999999998	2	1.7111000000000001	1.4221999999999999	1.2778	1.1333	1.0178	0.67620000000000002	0.5	6.9229999	10	82.307999	0	0	\N	93
10389	1997	113	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	113
10378	1996	25	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	25
10379	1996	35	0.049000000000000002	0.93310000000000004	1.508	2.0510000000000002	2.4359999999999999	1.8667	1.5867	1.3999999999999999	1.1667000000000001	0.97529999999999994	0.80269999999999997	0.63	0.56000000000000005	0.48859999999999998	0.44890000000000002	0.40910000000000002	0.37730000000000002	0.32950000000000002	0.5	31.429001	2	92.857002	0.16800000000000001	0.097000000000000003	\N	35
10380	1996	55	0.11799999999999999	0.89700000000000002	1.4690000000000001	1.99	2.4119999999999999	1.7749999999999999	1.52	1.3500000000000001	1.1375	0.96999999999999997	0.80000000000000004	0.63	0.56689999999999996	0.50370000000000004	0.4617	0.41839999999999999	0.38369999999999999	0.33160000000000001	0.25	0.588	2	95.293999	0.40899999999999997	0.23599999999999999	\N	55
10381	1996	65	0.075999999999999998	1.0086999999999999	1.397	2.1659999999999999	2.8690000000000002	1.9375	1.7313000000000001	1.5938000000000001	1.4218999999999999	1.25	0.93059999999999998	0.67630000000000001	0.55689999999999995	0.47299999999999998	0.43580000000000002	0.39860000000000001	0.36890000000000001	0.32429999999999998	0.5	33.636002	2	91.818001	0.26500000000000001	0.153	\N	65
10382	1996	95	0.23599999999999999	0.81540000000000001	1.8959999999999999	2.113	1.96	1.8269	1.4461999999999999	1.1922999999999999	0.92710000000000004	0.74209999999999998	0.5746	0.49690000000000001	0.44600000000000001	0.39510000000000001	0.36959999999999998	0.34410000000000002	0.32379999999999998	0.29320000000000002	0.25	1.515	2	92.726997	0.81799999999999995	0.47199999999999998	\N	95
10383	1996	105	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	105
10371	1995	35	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	35
10372	1995	45	0.22900000000000001	3.2288000000000001	1.046	2.5019999999999998	4.0990000000000002	7.0933000000000002	5.0343	4.1254999999999997	3.6882000000000001	3.3376000000000001	2.6366000000000001	1.9666999999999999	1.6044	1.2422	1.0610999999999999	0.91120000000000001	0.80400000000000005	0.64319999999999999	0.63	9.5089998	10	94.171997	0	0	\N	45
10373	1995	59	0.035000000000000003	0.65429999999999999	1.0509999999999999	1.593	1.893	1.0600000000000001	0.91520000000000001	0.85199999999999998	0.77300000000000002	0.69389999999999996	0.60399999999999998	0.56040000000000001	0.51670000000000005	0.45739999999999997	0.42280000000000001	0.38819999999999999	0.36059999999999998	0.31909999999999999	0.5	36.169998	1	89.362	0.12	0.069000000000000006	\N	59
10374	1995	75	0.072999999999999995	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0.10299999999999999	0.072999999999999995	\N	75
10375	1995	85	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	85
10376	1995	89	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	89
10377	1995	99	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	99
10361	1994	25	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	25
10362	1994	36	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	36
10363	1994	39	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	39
10364	1994	46	0.215	4.2624000000000004	0.81000000000000005	2.1800000000000002	3.7000000000000002	7.7248000000000001	6.2561	5.8117000000000001	5.2561999999999998	4.7005999999999997	3.7810999999999999	3.1886999999999999	2.5962000000000001	2.0038	1.7578	1.5125	1.3162	1.0219	0.25	0.31799999	10	91.083	0.35399999999999998	0.20499999999999999	\N	46
10365	1994	50	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	50
10366	1994	56	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	56
10367	1994	60	0.028000000000000001	0.62619999999999998	1.073	1.6120000000000001	1.889	1	0.88900000000000001	0.81499999999999995	0.72250000000000003	0.63	0.58120000000000005	0.53249999999999997	0.48080000000000001	0.42309999999999998	0.39419999999999999	0.3654	0.34229999999999999	0.30769999999999997	0.5	43.333	1	90	0.024	0.014	\N	60
10368	1994	70	0.014	0.70269999999999999	1.278	1.7949999999999999	1.958	1.45	1.1200000000000001	0.96299999999999997	0.86129999999999995	0.75949999999999995	0.60919999999999996	0.55200000000000005	0.49440000000000001	0.43330000000000002	0.40279999999999999	0.37219999999999998	0.3478	0.31109999999999999	0.5	40.909	1	81.818001	0.048000000000000001	0.028000000000000001	\N	70
10369	1994	86	0.049000000000000002	0.91720000000000002	1.196	1.8799999999999999	2.399	1.7388999999999999	1.5156000000000001	1.3667	1.1806000000000001	0.99809999999999999	0.86760000000000004	0.73709999999999998	0.61799999999999999	0.55100000000000005	0.51749999999999996	0.4733	0.42870000000000003	0.36170000000000002	0.5	22.388	2	97.014999	0.064000000000000001	0.036999999999999998	\N	86
10370	1994	100	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	100
34799	10852	60	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	26
34800	10852	80	3.5179999999999998	2.5047999999999999	1.3069999999999999	1.9199999999999999	2.4460000000000002	5.2051999999999996	3.9986000000000002	3.6884999999999999	3.3008999999999999	2.9133	2.1381000000000001	1.8218000000000001	1.605	1.3880999999999999	1.2797000000000001	1.1713	1.0846	0.87390000000000001	0.5	2.5109999	6.2999999999999998	95.433998	12.186999999999999	7.0359999999999996	\N	46
34801	10852	100	1.647	6.7385999999999999	4.5110000000000001	5.4199999999999999	4.1200000000000001	24.186199999999999	19.797999999999998	16.872499999999999	8.1902000000000008	4.2271000000000001	2.2210000000000001	1.7197	1.4011	1.0825	0.93110000000000004	0.78820000000000001	0.67379999999999995	0.53910000000000002	0.25	0.127	16	78.806999	2.8109999999999999	1.623	\N	66
34802	10852	110	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	76
34803	10852	120	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	86
34794	10851	61	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	23
34795	10851	71	0.125	3.0266000000000002	0.86599999999999999	2.0529999999999999	3.2690000000000001	5.6345000000000001	5.1177000000000001	4.7732000000000001	4.3426	3.9357000000000002	3.3071000000000002	2.6785999999999999	2.0499999999999998	1.6884999999999999	1.5192000000000001	1.3500000000000001	1.2145999999999999	1.0115000000000001	0.5	1.705	6.2999999999999998	97.726997	0.433	0.25	\N	33
34796	10851	91	0.53800000000000003	3.1568000000000001	1.0629999999999999	2.1110000000000002	3.2160000000000002	5.9215999999999998	5.1660000000000004	4.6623000000000001	4.0326000000000004	3.6884999999999999	3.0314999999999999	2.3744999999999998	1.8723000000000001	1.5753999999999999	1.4269000000000001	1.2785	1.1597	0.94269999999999998	0.25	0.13	10	96.632004	0.94099999999999995	0.54300000000000004	\N	53
34797	10851	111	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	73
34798	10851	121	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	83
34716	10831	64	45.643999999999998	2.52	0.98699999999999999	2.141	3.3300000000000001	5.1063000000000001	3.9119999999999999	3.6440999999999999	3.3092999999999999	2.9744999999999999	2.3048000000000002	1.8398000000000001	1.5457000000000001	1.2516	1.1045	0.96109999999999995	0.85350000000000004	0.69220000000000004	0.25	0.035999998	16	99.905998	103.261	59.618000000000002	\N	22
34717	10831	74	0.080000000000000002	1.111	1.0569999999999999	2.2229999999999999	3.0630000000000002	2.3714	1.8632	1.7161	1.5323	1.3484	0.99080000000000001	0.81499999999999995	0.63929999999999998	0.50239999999999996	0.45700000000000002	0.41249999999999998	0.37690000000000001	0.32340000000000002	0.25	1.7539999	2	87.719002	0.27700000000000002	0.16	\N	32
34718	10831	94	0.161	2.1934	0.71199999999999997	2.294	4.6130000000000004	3.9729000000000001	3.6461000000000001	3.4281999999999999	3.1558999999999999	2.8835000000000002	2.3388	1.8833	1.5747	1.266	1.1116999999999999	0.92110000000000003	0.69269999999999998	0.50700000000000001	0.25	1.08	4	90.497002	0.55800000000000005	0.32200000000000001	\N	52
34719	10831	104	0.044999999999999998	1.4241999999999999	1.347	2.2759999999999998	3.2130000000000001	3.2999999999999998	2.52	2	1.8193999999999999	1.6389	1.2778	0.95379999999999998	0.75329999999999997	0.60050000000000003	0.56200000000000006	0.52359999999999995	0.4864	0.3977	0.5	16.923	4	95.385002	0.11600000000000001	0.067000000000000004	\N	62
34720	10831	114	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	72
29839	10072	71	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	24
29840	10072	81	10.531000000000001	1.7855000000000001	1.5109999999999999	2.2050000000000001	2.6339999999999999	3.5985999999999998	2.7707000000000002	2.2187000000000001	1.8825000000000001	1.7103999999999999	1.3663000000000001	1.0222	0.86839999999999995	0.72770000000000001	0.6573	0.60389999999999999	0.56979999999999997	0.51870000000000005	0.25	0.072999999	16	99.498001	21.986000000000001	12.693	\N	34
29841	10072	91	0.14299999999999999	0.62239999999999995	0.995	1.5469999999999999	1.875	0.94130000000000003	0.84330000000000005	0.77800000000000002	0.69640000000000002	0.62629999999999997	0.58630000000000004	0.54630000000000001	0.50629999999999997	0.44450000000000001	0.41149999999999998	0.37859999999999999	0.35220000000000001	0.31269999999999998	0.25	0.493	2	99.014999	0.496	0.28599999999999998	\N	44
29842	10072	111	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	64
29843	10072	121	0.11	0.48709999999999998	0.89300000000000002	1.391	1.756	0.66210000000000002	0.60799999999999998	0.59099999999999997	0.56969999999999998	0.54849999999999999	0.50600000000000001	0.46250000000000002	0.41889999999999999	0.37530000000000002	0.35349999999999998	0.33169999999999999	0.31419999999999998	0.28810000000000002	0.25	1.274	1	98.725998	0.38	0.219	\N	74
29834	10071	65	43.652000000000001	2.4893000000000001	1.1779999999999999	2.1190000000000002	2.6659999999999999	5.1062000000000003	3.6897000000000002	3.2928999999999999	2.7968000000000002	2.3008000000000002	1.8374999999999999	1.6043000000000001	1.371	1.1377999999999999	1.0212000000000001	0.90980000000000005	0.82150000000000001	0.68920000000000003	0.125	0.0099999998	16	99.413002	51.101999999999997	29.504000000000001	\N	25
29835	10071	75	0.63300000000000001	3.274	0.96499999999999997	2.4729999999999999	4.7610000000000001	7.3978000000000002	5.7666000000000004	5.0629999999999997	4.1836000000000002	3.7313000000000001	3.0522	2.3731	1.8352999999999999	1.4699	1.2870999999999999	1.1044	0.94259999999999999	0.64100000000000001	0.25	0.11	10	97.032997	1.583	0.91400000000000003	\N	35
29836	10071	85	3.028	1.7526999999999999	1.6040000000000001	2.258	2.6840000000000002	3.8033999999999999	2.8294999999999999	2.1802999999999999	1.8615999999999999	1.6838	1.3280000000000001	0.98919999999999997	0.85140000000000005	0.71360000000000001	0.64470000000000005	0.5927	0.55479999999999996	0.49480000000000002	0.25	0.023	10	98.989998	8.1530000000000005	4.7069999999999999	\N	45
29837	10071	95	0.309	2.8003999999999998	1.046	2.3010000000000002	3.5470000000000002	6.0484	4.1294000000000004	3.7037	3.2917000000000001	2.8795999999999999	2.0556000000000001	1.7544	1.4911000000000001	1.2278	1.0962000000000001	0.94450000000000001	0.77980000000000005	0.57940000000000003	0.25	0.22499999	10	94.831001	0.217	0.125	\N	55
29838	10071	105	0.036999999999999998	0.8024	1.0800000000000001	1.5760000000000001	1.887	1.3600000000000001	0.96509999999999996	0.91010000000000002	0.84140000000000004	0.77270000000000005	0.63529999999999998	0.58940000000000003	0.54710000000000003	0.50490000000000002	0.4667	0.42330000000000001	0.38869999999999999	0.3367	0.5	28.846001	4	98.077003	0.034000000000000002	0.019	\N	65
29829	9655	69	5.9800000000000004	5.8331999999999997	1.198	2.3839999999999999	3.391	13.274100000000001	9.7838999999999992	8.6263000000000005	7.1792999999999996	6.0472000000000001	4.7587000000000002	3.7498999999999998	3.1417000000000002	2.5333999999999999	2.2292999999999998	1.9346000000000001	1.7221	1.4033	0.125	0.023	16	94.374001	10.722	6.1900000000000004	\N	39
29830	9655	84	5.2869999999999999	14.266299999999999	0.251	3.6280000000000001	11.541	28.0001	25.900099999999998	24.5001	22.7502	21.0002	17.500299999999999	14.2385	11.1554	6.1500000000000004	3.8372999999999999	2.7662	1.9681	1.5163	0.25	0.039000001	16	55.713001	12.239000000000001	7.0659999999999998	\N	54
29831	9655	99	2.3330000000000002	4.9875999999999996	3.0920000000000001	2.8050000000000002	2.0649999999999999	19.191800000000001	8.5508000000000006	3.9992999999999999	3.3740999999999999	2.7488999999999999	1.9237	1.7334000000000001	1.5430999999999999	1.3528	1.2577	1.1625000000000001	1.0864	0.93169999999999997	0.25	0.059999999	16	87.406998	3.1960000000000002	1.845	\N	69
29832	9655	114	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	84
29833	9655	129	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	99
27417	8944	66	47.798000000000002	1.3473999999999999	1.1000000000000001	1.794	2.4329999999999998	2.3243999999999998	1.8835	1.7797000000000001	1.6498999999999999	1.5201	1.2605	1.0009999999999999	0.877	0.75349999999999995	0.69179999999999997	0.63009999999999999	0.58530000000000004	0.51800000000000002	0.125	0.003	10	99.691002	97.823999999999998	56.478999999999999	\N	31
27418	8944	87	0.056000000000000001	0.9355	1.2909999999999999	1.9510000000000001	2.4340000000000002	1.8	1.5600000000000001	1.3999999999999999	1.2	1	0.85199999999999998	0.70399999999999996	0.59750000000000003	0.53249999999999997	0.5	0.45000000000000001	0.40999999999999998	0.34999999999999998	0.5	25	2	95	0.122	0.070000000000000007	\N	52
27419	8944	97	21.844999999999999	0.98129999999999995	1.2809999999999999	1.768	2.206	1.7914000000000001	1.5649	1.4139999999999999	1.2253000000000001	1.0366	0.89649999999999996	0.78190000000000004	0.6673	0.58789999999999998	0.55669999999999997	0.52549999999999997	0.50049999999999994	0.40639999999999998	0.25	0.109	4	99.564003	72.429000000000002	41.817	\N	62
27420	8944	107	0.028000000000000001	0.5736	1.119	1.6140000000000001	1.8759999999999999	0.95679999999999998	0.81989999999999996	0.72870000000000001	0.62590000000000001	0.59589999999999999	0.53580000000000005	0.4803	0.43159999999999998	0.38290000000000002	0.35859999999999997	0.3342	0.31469999999999998	0.28549999999999998	0.25	2.7030001	1	91.891998	0.016	0.0089999999999999993	\N	72
27421	8944	117	0.27400000000000002	0.5081	0.92700000000000005	1.4410000000000001	1.8	0.79649999999999999	0.6633	0.61829999999999996	0.59489999999999998	0.57150000000000001	0.52470000000000006	0.47799999999999998	0.43130000000000002	0.38469999999999999	0.3614	0.33810000000000001	0.31940000000000002	0.29149999999999998	0.125	0.278	1	99.167	0.63400000000000001	0.36599999999999999	\N	82
27416	8943	58	0.36699999999999999	5.7763	0.97199999999999998	2.262	3.7000000000000002	12.394299999999999	10.2309	9.3238000000000003	8.3175000000000008	7.3110999999999997	5.7313000000000001	4.5885999999999996	3.6637	2.9702999999999999	2.6236000000000002	2.2768999999999999	1.9995000000000001	1.5488	0.125	0.15800001	10	83.360001	1.2729999999999999	0.73499999999999999	\N	23
27415	8943	71	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	36
27414	8943	88	0.52500000000000002	1.8804000000000001	1.1910000000000001	1.653	1.9850000000000001	3.4382000000000001	2.9483999999999999	2.6217999999999999	2.2136	1.9611000000000001	1.7978000000000001	1.6345000000000001	1.4713000000000001	1.3080000000000001	1.2263999999999999	1.1447000000000001	1.0793999999999999	0.90569999999999995	0.125	0.111	4	96.882004	0.91100000000000003	0.52600000000000002	\N	53
27413	8943	103	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	68
27412	8943	118	5.3399999999999999	5.0541999999999998	5.5049999999999999	4.7210000000000001	3.3530000000000002	15.7403	12.7242	10.7134	6.4111000000000002	3.4923999999999999	1.7524	1.1488	0.88480000000000003	0.7319	0.65539999999999998	0.60319999999999996	0.57099999999999995	0.52270000000000005	0.125	0.013	16	90.516998	18.497	10.679	\N	83
27411	8942	63	1.9570000000000001	21.0366	1.3999999999999999	2.5750000000000002	3.6360000000000001	50.364100000000001	42.782499999999999	37.728099999999998	31.428599999999999	26.4071	16.3643	14.0433	12.013	9.9785000000000004	8.7188999999999997	7.4592999999999998	6.4516	4.5003000000000002	0.125	0.035999998	31.5	75.070999	3.0640000000000001	1.7689999999999999	\N	27
27410	8942	73	513.721	3.3792	1.679	3.391	4.8700000000000001	9.1323000000000008	6.8567999999999998	5.8201000000000001	4.8723999999999998	3.9472	2.6173999999999999	1.5605	0.9506	0.79449999999999998	0.71650000000000003	0.63849999999999996	0.59619999999999995	0.53739999999999999	0.125	0.003	16	99.710999	522.92899999999997	301.91300000000001	\N	37
27409	8942	83	31.308	5.4081999999999999	1.0920000000000001	2.7570000000000001	4.2549999999999999	13.019600000000001	9.6280999999999999	8.3971	6.8583999999999996	5.7827999999999999	4.1592000000000002	3.3420000000000001	2.6124000000000001	1.9245000000000001	1.6894	1.4542999999999999	1.2662	0.97760000000000002	0.125	0.0040000002	16	94.728996	24.712	14.268000000000001	\N	47
27408	8942	98	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	62
27407	8942	113	0.055	1.2815000000000001	1.397	2.1960000000000002	3.097	2.9556	2.3289	1.9666999999999999	1.7707999999999999	1.575	1.1833	0.8972	0.70399999999999996	0.58809999999999996	0.55420000000000003	0.5202	0.4829	0.3821	0.25	2.128	2	80.850998	0.14999999999999999	0.085999999999999993	\N	77
27406	8942	123	0.019	0.51180000000000003	0.96899999999999997	1.5580000000000001	1.9610000000000001	0.85199999999999998	0.7077	0.62570000000000003	0.59750000000000003	0.56930000000000003	0.51300000000000001	0.46150000000000002	0.41149999999999998	0.36149999999999999	0.33650000000000002	0.3115	0.29149999999999998	0.26150000000000001	0.125	3.846	1	96.153999	0.051999999999999998	0.029999999999999999	\N	87
27405	8941	67	12.951000000000001	2.1198000000000001	2.0009999999999999	2.3079999999999998	2.0750000000000002	4.8571	2.9319000000000002	1.9901	1.7490000000000001	1.5079	1.0257000000000001	0.89810000000000001	0.79049999999999998	0.68289999999999995	0.62929999999999997	0.58550000000000002	0.55049999999999999	0.49419999999999997	0.125	0.011	16	98.862999	24.344000000000001	14.055	\N	32
27404	8941	77	57.634999999999998	1.5580000000000001	1.6519999999999999	2.0649999999999999	2.3650000000000002	3.4129999999999998	2.5657000000000001	2.0007999999999999	1.8142	1.6282000000000001	1.2563	0.96689999999999998	0.86029999999999995	0.75380000000000003	0.70050000000000001	0.6472	0.60189999999999999	0.53110000000000002	0.25	0.064999998	10	99.785004	54.816000000000003	31.648	\N	42
27403	8941	87	123.173	1.2011000000000001	1.274	1.758	1.8979999999999999	1.9417	1.7252000000000001	1.5808	1.4004000000000001	1.2199	0.96330000000000005	0.86929999999999996	0.77529999999999999	0.68130000000000002	0.63429999999999997	0.59179999999999999	0.55810000000000004	0.50760000000000005	0.125	0.003	16	99.883003	134.96899999999999	77.924999999999997	\N	52
27402	8941	108	0.74199999999999999	6.0896999999999997	11.428000000000001	6.343	3.2330000000000001	23.054099999999998	17.986499999999999	14.447100000000001	9.6036000000000001	3.8111000000000002	1.2021999999999999	0.83879999999999999	0.64319999999999999	0.5665	0.53249999999999997	0.49719999999999998	0.44700000000000001	0.37180000000000002	0.25	0.28099999	16	81.648003	1.9930000000000001	1.151	\N	73
27401	8941	118	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	83
24531	7763	70	35.838999999999999	2.1478999999999999	2.395	2.8690000000000002	3.3969999999999998	5.7392000000000003	4.1063000000000001	3.4925000000000002	2.7894999999999999	2.0863999999999998	1.3758999999999999	0.92479999999999996	0.75190000000000001	0.60729999999999995	0.56869999999999998	0.5302	0.49869999999999998	0.40500000000000003	0.25	0.078000002	10	98.278999	15.345000000000001	8.859	\N	35
24532	7763	80	50.451000000000001	1.7337	1.532	2.3650000000000002	2.9660000000000002	3.7541000000000002	3.0916000000000001	2.6497999999999999	2.0977000000000001	1.8389	1.4474	1.0559000000000001	0.87029999999999996	0.71909999999999996	0.64349999999999996	0.59079999999999999	0.55249999999999999	0.48799999999999999	0.25	0.097000003	16	99.917	55.399999999999999	31.984999999999999	\N	45
24533	7763	92	11.175000000000001	1.3545	1.306	2.1240000000000001	2.6080000000000001	2.7837000000000001	1.8593	1.6677999999999999	1.4285000000000001	1.1892	0.91180000000000005	0.76600000000000001	0.62460000000000004	0.5444	0.50429999999999997	0.4536	0.41199999999999998	0.34970000000000001	0.25	0.412	10	98.727997	17.728000000000002	10.234999999999999	\N	57
24534	7763	110	0.63900000000000001	6.1578999999999997	7.6529999999999996	5.8639999999999999	5.3869999999999996	20.506900000000002	15.0444	13.0327	10.5182	7.8841000000000001	1.9561999999999999	0.9274	0.71150000000000002	0.57669999999999999	0.53390000000000004	0.48709999999999998	0.4375	0.36320000000000002	0.25	0.86799997	16	85.900002	1.4319999999999999	0.82699999999999996	\N	75
24535	7763	120	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	85
24525	7761	62	1.905	8.6153999999999993	1.036	2.2090000000000001	4.9429999999999996	15.6881	14.3355	13.4337	12.3066	11.179399999999999	8.8300000000000001	6.3761999999999999	5.5083000000000002	4.6912000000000003	4.2827000000000002	3.7048999999999999	2.9386999999999999	1.7865	0.5	0.072999999	16	91.384003	6.194	3.5760000000000001	\N	32
24524	7761	72	16.361999999999998	4.0171000000000001	0.71599999999999997	3.4390000000000001	6.3860000000000001	9.8707999999999991	7.7606999999999999	6.3539000000000003	5.524	4.7233999999999998	3.5276999999999998	2.6659999999999999	1.8455999999999999	1.1656	0.92369999999999997	0.77510000000000001	0.65610000000000002	0.5524	0.25	0.023	16	99.290001	4.9189999999999996	2.8399999999999999	\N	42
24523	7761	91	37.313000000000002	2.694	1.52	3.0779999999999998	4.173	7.2245999999999997	4.9570999999999996	3.9199999999999999	3.3452999999999999	2.7707000000000002	1.8282	1.3065	0.90229999999999999	0.66539999999999999	0.60009999999999997	0.55740000000000001	0.52329999999999999	0.43809999999999999	0.125	0.0049999999	10	94.097	58.719000000000001	33.902000000000001	\N	61
24522	7761	111	0.096000000000000002	4.8097000000000003	2.0289999999999999	4.4080000000000004	9.8539999999999992	12.908899999999999	11.0542	9.8735999999999997	8.8013999999999992	7.7290999999999999	4.9660000000000002	1.7605	1.0284	0.80210000000000004	0.69920000000000004	0.61229999999999996	0.56889999999999996	0.504	0.25	0.43099999	10	80.589996	0.33300000000000002	0.192	\N	81
24521	7761	121	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	91
23970	7262	66	12.356	2.3736000000000002	0.996	2.9079999999999999	4.6600000000000001	5.5685000000000002	4.415	3.8321999999999998	3.3763999999999998	2.9207000000000001	2.0091999999999999	1.5213000000000001	1.0378000000000001	0.72260000000000002	0.61099999999999999	0.5615	0.52200000000000002	0.43109999999999998	0.063	0.003	10	98.802002	0	0	\N	31
23969	7262	76	17.928000000000001	6.6166999999999998	0.29099999999999998	4.5819999999999999	16.611999999999998	14.335100000000001	13.3361	12.6701	11.8377	11.0052	8.6260999999999992	5.3963000000000001	3.1065	1.6706000000000001	1.2499	0.87719999999999998	0.63529999999999998	0.51929999999999998	0.063	0.001	10	63.963001	0	0	\N	41
23968	7262	86	16.286000000000001	3.5788000000000002	1.9319999999999999	4.3860000000000001	5.4489999999999998	11.2835	8.5599000000000007	6.8029000000000002	5.2622	3.9403000000000001	2.0205000000000002	1.4041999999999999	0.90369999999999995	0.62170000000000003	0.55810000000000004	0.49459999999999998	0.44500000000000001	0.37080000000000002	0.063	0.003	10	87.278999	0	0	\N	51
23967	7262	106	0.23499999999999999	1.6244000000000001	3.2000000000000002	2.9510000000000001	2.1920000000000002	5.8482000000000003	3.0545	1.8400000000000001	1.2050000000000001	0.91879999999999995	0.67910000000000004	0.57869999999999999	0.51419999999999999	0.44669999999999999	0.41239999999999999	0.37819999999999998	0.35089999999999999	0.30980000000000002	0.063	0.063000001	6.2999999999999998	90.865997	0	0	\N	71
23966	7262	116	0.11899999999999999	0.4118	0.93100000000000005	1.3100000000000001	1.5609999999999999	0.4985	0.48080000000000001	0.46899999999999997	0.45429999999999998	0.43959999999999999	0.41010000000000002	0.38059999999999999	0.35110000000000002	0.3216	0.30690000000000001	0.29220000000000002	0.28039999999999998	0.26269999999999999	0.063	0.063000001	2	99.366997	0	0	\N	81
23600	6924	69	15.997999999999999	1.2264999999999999	1.3069999999999999	1.833	2.1240000000000001	2.0604	1.7638	1.6013999999999999	1.3984000000000001	1.1953	0.94579999999999997	0.84140000000000004	0.73709999999999998	0.63270000000000004	0.59360000000000002	0.55530000000000002	0.52470000000000006	0.44529999999999997	0.063	0.003	6.2999999999999998	98.968002	0	0	\N	34
23599	6924	79	5.3650000000000002	1.0359	1.3160000000000001	1.7390000000000001	2.1379999999999999	1.7627999999999999	1.4903999999999999	1.3088	1.0818000000000001	0.96519999999999995	0.85619999999999996	0.74719999999999998	0.63819999999999999	0.57720000000000005	0.54869999999999997	0.5202	0.4929	0.40050000000000002	0.063	0.016000001	10	99.406998	0	0	\N	44
23598	6924	95	5.1929999999999996	0.93720000000000003	1.3100000000000001	1.7909999999999999	1.9059999999999999	1.8052999999999999	1.1326000000000001	0.93269999999999997	0.81320000000000003	0.69369999999999998	0.59719999999999995	0.55259999999999998	0.50790000000000002	0.4456	0.41260000000000002	0.3795	0.35310000000000002	0.31340000000000001	0.063	0.021	6.2999999999999998	98.524002	0	0	\N	60
23597	6924	109	0.019	0.8256	1.9399999999999999	2.1190000000000002	1.8720000000000001	2.375	1.3999999999999999	0.90749999999999997	0.62749999999999995	0.59499999999999997	0.53000000000000003	0.4743	0.42649999999999999	0.37869999999999998	0.3548	0.33090000000000003	0.31180000000000002	0.28310000000000002	0.063	0.308	2	87.692001	0	0	\N	74
23596	6924	119	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	84
23595	6923	62	4.2789999999999999	3.2031999999999998	1.2789999999999999	2.6240000000000001	4.1879999999999997	7.5888	5.6234000000000002	4.9032999999999998	4.0030999999999999	3.5402999999999998	2.6179000000000001	1.8955	1.5791999999999999	1.2628999999999999	1.1047	0.9456	0.81699999999999995	0.62509999999999999	0.063	0.0020000001	10	94.195	0	0	\N	27
23594	6923	72	15.343	2.0600000000000001	1.2090000000000001	2.323	2.968	4.3532999999999999	3.3588	2.8519000000000001	2.2181000000000002	1.9035	1.6093999999999999	1.3151999999999999	1.0209999999999999	0.8488	0.76739999999999997	0.68600000000000005	0.62250000000000005	0.54220000000000002	0.063	0.0020000001	10	97.873001	0	0	\N	37
23593	6923	81	11.332000000000001	2.331	2.04	2.5950000000000002	2.8559999999999999	5.8894000000000002	3.6017000000000001	2.8906000000000001	2.0017999999999998	1.7857000000000001	1.3562000000000001	0.9718	0.80659999999999998	0.64149999999999996	0.59930000000000005	0.56359999999999999	0.53500000000000003	0.47489999999999999	0.063	0.0020000001	10	93.125	0	0	\N	46
23592	6923	101	0.128	8.4318000000000008	0.34999999999999998	2.5449999999999999	8.2789999999999999	14.727600000000001	13.9641	13.4552	12.819000000000001	12.1828	10.910299999999999	9.2805999999999997	6.7522000000000002	4.7850000000000001	3.859	2.9127999999999998	2.1558999999999999	1.3179000000000001	0.063	0.054000001	10	52.846001	0	0	\N	66
23591	6923	112	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	77
23590	6922	63	0.29499999999999998	16.965900000000001	1.123	1.593	2.351	28.190100000000001	26.2042	24.880199999999999	23.225300000000001	21.5703	18.260400000000001	15.515499999999999	13.9876	12.4596	11.6957	10.931699999999999	10.320499999999999	7.766	0.25	0.024	16	53.171001	0	0	\N	28
23589	6922	74	28.123999999999999	4.1252000000000004	0.65100000000000002	2.5790000000000002	5.7770000000000001	8.5045999999999999	6.1302000000000003	5.6577999999999999	5.0673000000000004	4.4767999999999999	3.6065	2.9466999999999999	2.2867999999999999	1.6877	1.4115	1.1353	0.92190000000000005	0.62429999999999997	0.063	0.001	16	97.091003	0	0	\N	39
23588	6922	85	49.372999999999998	3.5939999999999999	0.97599999999999998	3.0009999999999999	5.2539999999999996	8.625	5.9478999999999997	5.2252999999999998	4.3220000000000001	3.7237	2.8651	2.0064000000000002	1.5435000000000001	1.0834999999999999	0.9113	0.77210000000000001	0.66059999999999997	0.54530000000000001	0.125	0.0040000002	16	97.942001	0	0	\N	50
23587	6922	114	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	79
23586	6922	125	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	90
23585	6921	23	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	23
23584	6921	41	27.774000000000001	13.57	0.90800000000000003	2.0190000000000001	3.0739999999999998	26.329499999999999	23.2271	21.158899999999999	18.573599999999999	15.9956	14.0344	12.0732	10.112	8.2767999999999997	7.3630000000000004	6.4493	5.6986999999999997	4.5651999999999999	0.5	0.0070000002	16	70.022003	0	0	\N	41
23583	6921	63	25.260999999999999	5.2133000000000003	1.262	2.786	3.8420000000000001	13.4102	9.4224999999999994	7.3998999999999997	5.8032000000000004	4.9237000000000002	3.6815000000000002	3.0108000000000001	2.3401999999999998	1.7952999999999999	1.5876999999999999	1.3801000000000001	1.214	0.95820000000000005	0.125	0.0020000001	16	93.689003	0	0	\N	63
23582	6921	83	4.1289999999999996	13.8422	0.58299999999999996	4.101	11.436	30.276399999999999	27.383900000000001	25.4556	23.045200000000001	20.634799999999998	15.726100000000001	8.7454000000000001	3.8740000000000001	2.6417000000000002	2.0255000000000001	1.7975000000000001	1.6286	1.3752	0.125	0.0020000001	31.5	92.538002	0	0	\N	83
23581	6921	102	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	102
23565	6901	67	4.9379999999999997	1.4404999999999999	1.3260000000000001	1.929	2.2799999999999998	3.1061000000000001	2.0139999999999998	1.8487	1.6558999999999999	1.4632000000000001	1.0775999999999999	0.90669999999999995	0.78990000000000005	0.67310000000000003	0.61880000000000002	0.57569999999999999	0.5413	0.47260000000000002	0.063	0.003	10	99.360001	0	0	\N	32
23564	6901	87	7.0389999999999997	1.22	1.4970000000000001	1.8879999999999999	2.1419999999999999	1.9165000000000001	1.4239999999999999	1.0955999999999999	0.94569999999999999	0.87480000000000002	0.73319999999999996	0.61650000000000005	0.56699999999999995	0.51739999999999997	0.48570000000000002	0.43790000000000001	0.39960000000000001	0.3422	0.063	0.0040000002	10	97.669998	0	0	\N	52
23563	6901	97	0.058000000000000003	4.1390000000000002	15.156000000000001	6.2279999999999998	2.2370000000000001	13.885	12.616	11.77	10.7125	3.7000000000000002	0.65469999999999995	0.52029999999999998	0.45540000000000003	0.4012	0.374	0.34689999999999999	0.32519999999999999	0.29270000000000002	0.125	0.071000002	10	71.630997	0	0	\N	62
23562	6901	107	0.087999999999999995	0.56140000000000001	1.054	1.5600000000000001	1.8520000000000001	0.90910000000000002	0.78700000000000003	0.7056	0.62319999999999998	0.59670000000000001	0.54359999999999997	0.49120000000000003	0.44180000000000003	0.39240000000000003	0.36770000000000003	0.34300000000000003	0.32319999999999999	0.29360000000000003	0.063	0.079000004	1	94.466003	0	0	\N	72
23561	6901	117	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	82
23555	6883	68	19.364999999999998	1.5510999999999999	1.1819999999999999	1.825	2.3500000000000001	3.0823999999999998	2.1421999999999999	1.9139999999999999	1.7749999999999999	1.6358999999999999	1.3577999999999999	1.0798000000000001	0.91830000000000001	0.80369999999999997	0.74639999999999995	0.68910000000000005	0.64329999999999998	0.57769999999999999	0.125	0.0020000001	10	99.524002	0	0	\N	33
23554	6883	72	22.486999999999998	1.4529000000000001	1.472	2.032	2.2559999999999998	3.2515000000000001	2.2239	1.8922000000000001	1.6919999999999999	1.4918	1.0914999999999999	0.90180000000000005	0.77459999999999996	0.64729999999999999	0.60360000000000003	0.56740000000000002	0.53839999999999999	0.48370000000000002	0.063	0.0020000001	10	99.818001	0	0	\N	37
23553	6883	81	23.515999999999998	1.5510999999999999	1.7470000000000001	2.1819999999999999	2.2090000000000001	3.5139	2.4933999999999998	1.9469000000000001	1.7053	1.4638	0.99480000000000002	0.86439999999999995	0.73399999999999999	0.61660000000000004	0.58330000000000004	0.55010000000000003	0.52349999999999997	0.45040000000000002	0.063	0.0020000001	10	99.164001	0	0	\N	46
23552	6883	110	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	75
23551	6883	120	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	85
23545	6881	63	5	3.9121000000000001	1.012	2.0630000000000002	2.8420000000000001	8.0082000000000004	6.0029000000000003	5.3954000000000004	4.6360999999999999	3.9567000000000001	3.4241000000000001	2.8914	2.3586999999999998	1.8884000000000001	1.7175	1.5466	1.4098999999999999	1.2049000000000001	0.063	0.0020000001	16	98.746002	0	0	\N	28
23544	6881	75	17.763999999999999	5.1067	1.7589999999999999	2.8889999999999998	3.7010000000000001	13.502800000000001	9.4917999999999996	7.7130000000000001	5.9459999999999997	4.9748999999999999	3.4937999999999998	2.4773000000000001	1.8439000000000001	1.5496000000000001	1.4024000000000001	1.2552000000000001	1.1375	0.94410000000000005	0.063	0.001	16	93.462997	0	0	\N	40
23543	6881	85	33.084000000000003	6.5766	3.0539999999999998	4.6100000000000003	5.8449999999999998	21.4011	15.5854	13.0411	9.8636999999999997	6.7492999999999999	3.496	1.9343999999999999	1.5313000000000001	1.1282000000000001	0.95509999999999995	0.83189999999999997	0.73329999999999995	0.59809999999999997	0.063	0.0020000001	16	84.652	0	0	\N	50
23542	6881	115	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	80
23541	6881	125	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	90
23525	6861	61	5.2590000000000003	3.4108000000000001	1.5660000000000001	2.6739999999999999	3.4550000000000001	8.843	6.2313000000000001	5.3518999999999997	4.2526999999999999	3.6027999999999998	2.5712000000000002	1.8623000000000001	1.5538000000000001	1.2453000000000001	1.0911	0.95650000000000002	0.87160000000000004	0.74419999999999997	0.125	0.0020000001	10	92.587997	0	0	\N	26
23524	6861	71	14.327	2.3595000000000002	1.395	2.415	2.9020000000000001	5.8160999999999996	3.9517000000000002	3.4550999999999998	2.8344999999999998	2.2139000000000002	1.7217	1.3855	1.0492999999999999	0.87790000000000001	0.80640000000000001	0.7349	0.67769999999999997	0.59319999999999995	0.063	0.0049999999	10	98.044998	0	0	\N	36
23523	6861	80	15.025	1.0548999999999999	1.2969999999999999	1.6639999999999999	1.728	1.8067	1.5125	1.3164	1.0711999999999999	0.96960000000000002	0.88390000000000002	0.79830000000000001	0.71260000000000001	0.62790000000000001	0.5988	0.56979999999999997	0.54649999999999999	0.51160000000000005	0.063	0.0060000001	6.2999999999999998	99.480003	0	0	\N	45
23522	6861	109	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	74
23521	6861	120	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	85
27386	8926	42	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	28
27387	8926	52	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	38
27388	8926	62	0.34899999999999998	0.76980000000000004	1.1990000000000001	1.7709999999999999	2.0209999999999999	1.5249999999999999	1.0811999999999999	0.94999999999999996	0.86380000000000001	0.77769999999999995	0.62090000000000001	0.55740000000000001	0.49409999999999998	0.43180000000000002	0.4007	0.36959999999999998	0.34470000000000001	0.30730000000000002	0.125	0.199	4	99.205002	0.78900000000000003	0.45600000000000002	\N	48
27389	8926	72	1.1399999999999999	1.847	1.075	2.302	3.101	3.7439	3.1857000000000002	2.8136000000000001	2.3483999999999998	1.9608000000000001	1.6479999999999999	1.3351999999999999	1.0225	0.83509999999999995	0.74629999999999996	0.65749999999999997	0.60140000000000005	0.53139999999999998	0.125	0.061000001	6.2999999999999998	97.015999	3.9500000000000002	2.2810000000000001	\N	58
27390	8926	92	0.039	1.1097999999999999	1.119	2.0750000000000002	3.0449999999999999	2.1333000000000002	1.8259000000000001	1.6940999999999999	1.5294000000000001	1.3647	1.0353000000000001	0.83179999999999998	0.64349999999999996	0.56240000000000001	0.52600000000000002	0.47999999999999998	0.42399999999999999	0.34000000000000002	0.125	1.786	2	89.286003	0.13500000000000001	0.078	\N	78
27381	8925	49	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	32
27382	8925	59	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	42
27383	8925	79	0.29899999999999999	0.67720000000000002	1.024	1.5209999999999999	1.8660000000000001	0.9728	0.90100000000000002	0.85309999999999997	0.79330000000000001	0.73340000000000005	0.62470000000000003	0.58560000000000001	0.54649999999999999	0.50739999999999996	0.47170000000000001	0.42609999999999998	0.3896	0.33479999999999999	0.125	0.234	2	98.829002	0.11899999999999999	0.069000000000000006	\N	62
27384	8925	89	0.106	0.67769999999999997	1.022	1.6120000000000001	1.9690000000000001	1.0570999999999999	0.92300000000000004	0.86680000000000001	0.79649999999999999	0.72619999999999996	0.61480000000000001	0.56659999999999999	0.51839999999999997	0.45569999999999999	0.41980000000000001	0.38400000000000001	0.3553	0.31230000000000002	0.25	1.316	2	98.683998	0.36599999999999999	0.21099999999999999	\N	72
27385	8925	99	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	82
27380	8924	43	0.76700000000000002	27.262599999999999	0.17299999999999999	3.9449999999999998	15.904	56.893799999999999	53.229999999999997	50.787500000000001	47.734400000000001	44.6813	38.575000000000003	32.468800000000002	9.5559999999999992	6.6409000000000002	5.3566000000000003	4.125	3.4207999999999998	2.4256000000000002	0.125	0.090999998	31.5	48.412998	2.6560000000000001	1.5329999999999999	\N	32
27379	8924	63	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	52
27378	8924	73	7.3419999999999996	2.6394000000000002	0.94399999999999995	2.0739999999999998	3.6760000000000002	4.5993000000000004	3.7576000000000001	3.5167000000000002	3.2155	2.9142999999999999	2.3119999999999998	1.8651	1.5851999999999999	1.3052999999999999	1.1653	1.0254000000000001	0.87360000000000004	0.629	0.125	0.0089999996	16	98.624001	25.431999999999999	14.683	\N	62
27377	8924	83	119.17100000000001	3.9943	1.266	2.891	4.4829999999999997	9.7377000000000002	6.7925000000000004	5.6208	4.4874000000000001	3.7614999999999998	2.9245999999999999	2.0876999999999999	1.6548	1.2693000000000001	1.0765	0.9194	0.81259999999999999	0.65229999999999999	0.125	0.0020000001	16	96.619003	120.32599999999999	69.469999999999999	\N	72
27376	8924	103	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	92
27375	8923	41	0.156	4.2628000000000004	0.90500000000000003	2.2890000000000001	3.9009999999999998	8.5914000000000001	7.7462	7.1828000000000003	6.4785000000000004	5.7824999999999998	4.3960999999999997	3.5571000000000002	2.9371	2.3170999999999999	2.0070999999999999	1.7135	1.4789000000000001	1.127	0.25	0.461	6.2999999999999998	73.733002	0.307	0.17699999999999999	\N	31
27374	8923	61	2.4169999999999998	7.4222000000000001	1.0940000000000001	3.2490000000000001	5.7809999999999997	18.897200000000002	14.522399999999999	12.9254	10.9293	9.1354000000000006	6.0773000000000001	4.2744999999999997	3.1907000000000001	2.2359	1.8631	1.5925	1.3759999999999999	1.0512999999999999	0.125	0.057	16	87.700996	6.431	3.7130000000000001	\N	51
27373	8923	71	8.7360000000000007	2.6625999999999999	0.99299999999999999	2.6749999999999998	3.762	5.9081000000000001	4.1577000000000002	3.6678000000000002	3.1876000000000002	2.7073999999999998	1.9083000000000001	1.5602	1.212	0.89629999999999999	0.76359999999999995	0.63090000000000002	0.58120000000000005	0.50719999999999998	0.125	0.0080000004	16	98.790001	28.048999999999999	16.193999999999999	\N	61
27372	8923	86	0.55900000000000005	6.3949999999999996	0.89000000000000001	2.9289999999999998	5.1399999999999997	14.075200000000001	12.920299999999999	12.150399999999999	11.188000000000001	10.2256	6.0327999999999999	4.6764999999999999	3.5005999999999999	2.5043000000000002	2.0062000000000002	1.7269000000000001	1.5057	1.1738	0.125	0.125	10	68.828003	1.738	1.0029999999999999	\N	76
27371	8923	101	0.014	0.2203	1.075	1.4470000000000001	1.625	0.375	0.29999999999999999	0.25	0.2417	0.23330000000000001	0.2167	0.20000000000000001	0.18329999999999999	0.16669999999999999	0.1583	0.14999999999999999	0.14330000000000001	0.1333	0.125	5	0.25	80	0.012	0.0070000000000000001	\N	91
27370	8922	48	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	34
27369	8922	58	0.063	1.3017000000000001	0.97299999999999998	1.7889999999999999	2.5179999999999998	2.3635999999999999	1.9080999999999999	1.8108	1.6892	1.5676000000000001	1.3243	1.0810999999999999	0.91120000000000001	0.77800000000000002	0.71140000000000003	0.64480000000000004	0.59619999999999995	0.52600000000000002	0.5	7.7779999	2	87.778	0.217	0.125	\N	44
27368	8922	67	0.40400000000000003	0.91359999999999997	1.514	1.9570000000000001	2.1549999999999998	1.7853000000000001	1.4447000000000001	1.2176	0.97899999999999998	0.88900000000000001	0.70899999999999996	0.59999999999999998	0.54669999999999996	0.4899	0.44969999999999999	0.40939999999999999	0.37730000000000002	0.32900000000000001	0.25	0.17299999	4	98.099998	0.78400000000000003	0.45200000000000001	\N	53
27367	8922	78	25.154	1.2506999999999999	1.343	1.7929999999999999	1.9299999999999999	2.1993999999999998	1.756	1.5724	1.3429	1.1134999999999999	0.9335	0.84530000000000005	0.75700000000000001	0.66869999999999996	0.62460000000000004	0.58109999999999995	0.54630000000000001	0.48380000000000001	0.25	0.077	10	99.674004	47.253999999999998	27.282	\N	64
27366	8922	98	0.34699999999999998	14.664	0.51300000000000001	2.6520000000000001	7.2450000000000001	28.245699999999999	26.293099999999999	24.991299999999999	23.3642	21.736999999999998	18.482700000000001	13.8437	8.9742999999999995	7.1974999999999998	6.3091999999999997	4.8080999999999996	3.7387999999999999	2.5510000000000002	0.5	0.206	16	52.370998	1.2030000000000001	0.69399999999999995	\N	84
27365	8922	108	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	94
24481	7721	47	0.55400000000000005	5.8673000000000002	3.0129999999999999	4.8840000000000003	5.1699999999999999	20.703399999999998	14.267799999999999	10.052199999999999	7.5332999999999997	4.9966999999999997	2.6128	1.6829000000000001	1.1901999999999999	0.87429999999999997	0.77190000000000003	0.66949999999999998	0.59799999999999998	0.50539999999999996	0.125	0.248	16	85.643997	0.73399999999999999	0.42399999999999999	\N	27
24482	7721	57	1.7969999999999999	1.4823	1.073	2.081	3.024	3.1427	2.3895	1.9741	1.8298000000000001	1.6855	1.3969	1.1083000000000001	0.90290000000000004	0.74760000000000004	0.66990000000000005	0.60040000000000004	0.55169999999999997	0.46189999999999998	0.25	0.23199999	6.2999999999999998	99.226997	5.8970000000000002	3.4049999999999998	\N	37
24483	7721	67	2.4990000000000001	1.0946	1.2829999999999999	1.804	2.121	1.8920999999999999	1.2345999999999999	0.97460000000000002	0.90639999999999998	0.83809999999999996	0.7016	0.60399999999999998	0.5494	0.4924	0.45200000000000001	0.41160000000000002	0.37930000000000003	0.33079999999999998	0.5	30.940001	10	98.887001	4.7869999999999999	2.7639999999999998	\N	47
24484	7721	97	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	77
24485	7721	107	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	87
34400	7702	86	54.353000000000002	2.2597	1.4710000000000001	2.2759999999999998	2.6960000000000002	4.8033000000000001	3.2913999999999999	2.6676000000000002	1.9774	1.8204	1.5063	1.1922999999999999	0.94930000000000003	0.81840000000000002	0.753	0.68759999999999999	0.63529999999999998	0.55869999999999997	0.25	0.059999999	16	99.073997	123.706	71.421000000000006	\N	64
34401	7702	65	2.492	1.0669	1.4319999999999999	1.9079999999999999	2.0710000000000002	1.8517999999999999	1.3483000000000001	1.0125999999999999	0.91969999999999996	0.83699999999999997	0.67149999999999999	0.59030000000000005	0.53739999999999999	0.47749999999999998	0.43919999999999998	0.40089999999999998	0.37019999999999997	0.32429999999999998	0.25	0.30700001	10	99.163002	8.6340000000000003	4.9850000000000003	\N	85
23965	7261	48	0.13500000000000001	0.89580000000000004	1.258	1.835	2.2450000000000001	1.72	1.276	0.99650000000000005	0.93189999999999995	0.86739999999999995	0.73819999999999997	0.62	0.55830000000000002	0.4955	0.45379999999999998	0.41220000000000001	0.37880000000000003	0.32879999999999998	0.063	0.054000001	4	98.108002	0	0	\N	28
23964	7261	55	0.152	2.8086000000000002	0.997	3.0169999999999999	5.2930000000000001	6.2179000000000002	5.5114000000000001	5.0404999999999998	4.4518000000000004	3.8683999999999998	2.7368000000000001	1.8294999999999999	1.3409	0.92710000000000004	0.80659999999999998	0.68610000000000004	0.60540000000000005	0.5171	0.063	0.046999998	6.2999999999999998	90.697998	0	0	\N	35
23963	7261	65	0.098000000000000004	0.72299999999999998	1.3400000000000001	1.768	1.901	1.5265	1.0306	0.90569999999999995	0.77569999999999995	0.64570000000000005	0.56869999999999998	0.50349999999999995	0.45179999999999998	0.40089999999999998	0.3755	0.34999999999999998	0.3296	0.29909999999999998	0.125	0.071000002	2	95.730003	0	0	\N	45
23962	7261	85	0.94399999999999995	0.73719999999999997	1.0960000000000001	1.5600000000000001	1.8480000000000001	1.2890999999999999	0.96109999999999995	0.90449999999999997	0.8337	0.76300000000000001	0.62760000000000005	0.58840000000000003	0.54920000000000002	0.50990000000000002	0.4773	0.43149999999999999	0.39479999999999998	0.3397	0.063	0.0070000002	4	99.740997	0	0	\N	65
23961	7261	105	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	85
23640	6964	46	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	26
23639	6964	56	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	36
23638	6964	66	1.042	1.2649999999999999	1.3959999999999999	2.1949999999999998	2.7570000000000001	2.8523000000000001	1.9273	1.7507999999999999	1.5302	1.3096000000000001	0.94089999999999996	0.74299999999999999	0.59899999999999998	0.52690000000000003	0.48759999999999998	0.43890000000000001	0.39989999999999998	0.34129999999999999	0.063	0.0070000002	6.2999999999999998	98.197998	0	0	\N	46
23637	6964	94	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	74
23636	6964	105	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	85
23635	6963	50	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	30
23634	6963	70	0.93200000000000005	1.278	1.1639999999999999	1.873	2.508	2.2778999999999998	1.8456999999999999	1.7203999999999999	1.5637000000000001	1.4071	1.0938000000000001	0.91349999999999998	0.78990000000000005	0.66639999999999999	0.61070000000000002	0.56369999999999998	0.52610000000000001	0.43609999999999999	0.063	0.037	6.2999999999999998	99.181999	0	0	\N	50
23633	6963	80	16.864000000000001	2.0966	1.099	2.2120000000000002	2.8780000000000001	3.8782000000000001	3.1271	2.6263000000000001	2.0004	1.8697999999999999	1.6093	1.3488	1.0883	0.88429999999999997	0.79679999999999995	0.70920000000000005	0.63919999999999999	0.55910000000000004	0.063	0.0049999999	10	96.466003	0	0	\N	60
23632	6963	96	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	76
23631	6963	110	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	90
23630	6962	33	0.83399999999999996	2.8197000000000001	0.83499999999999996	1.6299999999999999	2.331	4.5113000000000003	3.8538999999999999	3.7050000000000001	3.5190000000000001	3.3329	2.9607999999999999	2.5886999999999998	2.2166000000000001	1.8738999999999999	1.7230000000000001	1.5721000000000001	1.4514	1.2704	0.063	0.0080000004	6.2999999999999998	97.251999	0	0	\N	13
23629	6962	53	17.893999999999998	4.3274999999999997	0.92200000000000004	2.0739999999999998	3.177	9.0330999999999992	6.5793999999999997	5.9134000000000002	5.3304999999999998	4.7477	3.8159999999999998	3.3029000000000002	2.7898000000000001	2.2766999999999999	2.0200999999999998	1.748	1.5291999999999999	1.2011000000000001	0.063	0.001	16	99.070999	0	0	\N	33
23628	6962	73	24.248999999999999	9.5158000000000005	0.93300000000000005	5.3220000000000001	10.641	26.655899999999999	21.1297	17.445599999999999	14.110200000000001	11.3559	6.2366000000000001	4.1092000000000004	2.4234	1.4401999999999999	1.0646	0.87080000000000002	0.74590000000000001	0.58609999999999995	0.063	0.0040000002	31.5	95.259003	0	0	\N	53
23627	6962	93	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	73
23626	6962	113	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	93
23625	6961	36	2.4209999999999998	14.039400000000001	0.48099999999999998	2.6659999999999999	7.6479999999999997	27.227699999999999	24.664300000000001	22.955300000000001	20.819199999999999	18.683	15.2804	13.3462	11.411899999999999	8.8295999999999992	6.6627999999999998	4.7065000000000001	3.4704000000000002	1.9979	0.063	0.003	16	63.720001	0	0	\N	16
23624	6961	55	6.6189999999999998	8.6950000000000003	1.1180000000000001	2.3769999999999998	3.7370000000000001	20.0198	15.099299999999999	13.657400000000001	11.854900000000001	10.0525	7.8460000000000001	6.0073999999999996	5.0079000000000002	4.0084	3.5308999999999999	3.0537999999999998	2.6720999999999999	2.0996000000000001	0.063	0.001	16	86.499001	0	0	\N	35
23623	6961	74	44.341999999999999	9.4944000000000006	0.80100000000000005	3.593	8.9079999999999995	24.092099999999999	19.647400000000001	16.684200000000001	14.5694	12.8147	9.3231000000000002	6.1089000000000002	4.4619999999999997	3.0514000000000001	2.3921000000000001	1.8393999999999999	1.5222	1.0465	0.125	0.0020000001	16	79.075996	0	0	\N	54
23622	6961	95	4.0629999999999997	15.987	0.433	2.4369999999999998	6.3390000000000004	28.538699999999999	26.761900000000001	25.577400000000001	24.096800000000002	22.616099999999999	19.654800000000002	16.6935	12.952400000000001	9.0417000000000005	7.1852999999999998	5.5904999999999996	4.5053999999999998	3.1004	0.063	0.0020000001	16	47.658001	0	0	\N	75
23621	6961	115	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	95
23615	6943	51	1.7809999999999999	1.0779000000000001	1.534	2.0819999999999999	2.3359999999999999	1.9529000000000001	1.5531999999999999	1.2867	0.98799999999999999	0.90200000000000002	0.73009999999999997	0.60209999999999997	0.53549999999999998	0.46450000000000002	0.42659999999999998	0.3886	0.35820000000000002	0.31259999999999999	0.063	0.0049999999	10	99.279999	0	0	\N	51
23614	6943	62	13.202999999999999	1.0265	1.2909999999999999	1.8979999999999999	2.347	1.8543000000000001	1.5840000000000001	1.4037999999999999	1.1786000000000001	0.9869	0.86070000000000002	0.73440000000000005	0.61919999999999997	0.55659999999999998	0.5252	0.48820000000000002	0.43959999999999999	0.36680000000000001	0.063	0.003	6.2999999999999998	99.234001	0	0	\N	62
23613	6943	71	1.085	0.5716	0.93400000000000005	1.5	1.8580000000000001	0.88439999999999996	0.76039999999999996	0.67769999999999997	0.61980000000000002	0.60070000000000001	0.56269999999999998	0.52470000000000006	0.4793	0.42049999999999998	0.39100000000000001	0.36159999999999998	0.33810000000000001	0.30280000000000001	0.063	0.0070000002	2	99.644997	0	0	\N	71
23612	6943	81	1.369	4.2820999999999998	2.181	3.8420000000000001	5.1020000000000003	12.547800000000001	10.4765	8.7659000000000002	6.4104000000000001	5.0275999999999996	3.0007999999999999	1.8465	1.4466000000000001	1.0467	0.91339999999999999	0.80030000000000001	0.70989999999999998	0.58809999999999996	0.063	0.0049999999	10	82.620003	0	0	\N	81
23611	6943	91	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	91
23610	6942	42	0.14199999999999999	0.82099999999999995	1.3180000000000001	1.9530000000000001	2.3460000000000001	1.6724000000000001	1.3494999999999999	1.1342000000000001	0.96050000000000002	0.88170000000000004	0.72399999999999998	0.6018	0.53180000000000005	0.45900000000000002	0.4214	0.38379999999999997	0.35370000000000001	0.30859999999999999	0.063	0.048999999	2	96.087997	0	0	\N	42
23609	6942	53	0.126	0.53939999999999999	1.1180000000000001	1.589	1.8100000000000001	0.91249999999999998	0.7339	0.62580000000000002	0.5847	0.54359999999999997	0.47989999999999999	0.43690000000000001	0.39389999999999997	0.35099999999999998	0.32950000000000002	0.308	0.2908	0.26500000000000001	0.063	0.056000002	2	99.153	0	0	\N	53
23608	6942	63	6.7030000000000003	1.2023999999999999	1.268	1.986	2.5209999999999999	2.4796999999999998	1.8573999999999999	1.7022999999999999	1.5084	1.3145	0.97309999999999997	0.83050000000000002	0.68789999999999996	0.58679999999999999	0.55049999999999999	0.5141	0.47089999999999999	0.38590000000000002	0.063	0.003	6.2999999999999998	99.675003	0	0	\N	63
23607	6942	74	2.2480000000000002	1.2399	1.4550000000000001	1.974	2.3290000000000002	2.4293999999999998	1.7705	1.5612999999999999	1.2998000000000001	1.0384	0.87660000000000005	0.74350000000000005	0.62129999999999996	0.56200000000000006	0.53239999999999998	0.50280000000000002	0.45419999999999999	0.37640000000000001	0.063	0.0040000002	10	99.225998	0	0	\N	74
23606	6942	86	0.58199999999999996	7.6166999999999998	0.96899999999999997	4.3150000000000004	9.2699999999999996	22.205500000000001	16.628799999999998	14.105600000000001	11.255599999999999	8.9941999999999993	5.8124000000000002	3.9154	2.6720999999999999	1.7163999999999999	1.4077999999999999	1.0992999999999999	0.8931	0.627	0.063	0.012	16	83.322998	0	0	\N	86
23605	6941	40	5.6470000000000002	12.139900000000001	0.69999999999999996	2.577	5.3259999999999996	25.9772	22.663499999999999	20.4544	17.693000000000001	15.5162	13.015499999999999	10.514799999999999	7.9204999999999997	5.6818	4.8708999999999998	4.0599999999999996	3.4134000000000002	2.444	0.063	0.0060000001	16	71.934998	0	0	\N	25
23604	6941	50	8.8100000000000005	10.7056	0.72699999999999998	2.944	6.3410000000000002	24.9239	20.978300000000001	18.347899999999999	15.571099999999999	14.071300000000001	11.0715	8.3568999999999996	5.9551999999999996	4.1905000000000001	3.5207999999999999	2.9097	2.4207999999999998	1.746	0.063	0.0049999999	16	76.43	0	0	\N	35
23603	6941	70	21.827000000000002	7.8014999999999999	0.97899999999999998	4.141	11.16	21.02	15.623100000000001	14.3772	12.819800000000001	11.2624	6.9557000000000002	3.8136999999999999	2.3258000000000001	1.6091	1.3588	1.1085	0.91100000000000003	0.62329999999999997	0.063	0.0060000001	16	85.209999	0	0	\N	55
23602	6941	100	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	85
23601	6941	110	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	95
13041	2033	24	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	24
13042	2033	43	2.028	0.53600000000000003	1	1.4139999999999999	1.657	0.83160000000000001	0.61360000000000003	0.5857	0.55089999999999995	0.51600000000000001	0.47120000000000001	0.43390000000000001	0.39650000000000002	0.35909999999999997	0.34039999999999998	0.32169999999999999	0.30680000000000002	0.28439999999999999	0.125	0.018999999	4	99.870003	1.248	0.72099999999999997	\N	43
10554	1902	37	7.6210000000000004	0.91690000000000005	1.2549999999999999	1.629	2.036	1.6357999999999999	1.2588999999999999	1.0075000000000001	0.94930000000000003	0.89739999999999998	0.79359999999999997	0.68979999999999997	0.60909999999999997	0.55989999999999995	0.5353	0.51070000000000004	0.47439999999999999	0.38969999999999999	0.25	0.1	8	99.800003	15.217000000000001	7.609	\N	37
10555	1902	42	7.8179999999999996	0.91720000000000002	1.464	1.855	1.915	1.8101	1.1366000000000001	0.92810000000000004	0.79879999999999995	0.66959999999999997	0.57330000000000003	0.50639999999999996	0.45350000000000001	0.40210000000000001	0.37640000000000001	0.35070000000000001	0.33019999999999999	0.29930000000000001	0.25	0.40000001	8	99.299004	16.748999999999999	8.375	\N	42
10556	1902	58	2.1200000000000001	0.47739999999999999	1.0029999999999999	1.3879999999999999	1.6080000000000001	0.63	0.58209999999999995	0.55020000000000002	0.51019999999999999	0.48730000000000001	0.45300000000000001	0.41870000000000002	0.38440000000000002	0.35020000000000001	0.33300000000000002	0.31590000000000001	0.30220000000000002	0.28160000000000002	0.25	0.76899999	4	99.872002	7.4089999999999998	3.7040000000000002	\N	58
10557	1902	68	1.0700000000000001	0.55349999999999999	1.107	1.538	1.7390000000000001	0.90590000000000004	0.73360000000000003	0.62739999999999996	0.59370000000000001	0.56010000000000004	0.4955	0.45340000000000003	0.4113	0.36919999999999997	0.34820000000000001	0.3271	0.31030000000000002	0.28499999999999998	0.25	1.681	2	99.160004	1.843	0.92200000000000004	\N	68
10558	1902	78	1.0620000000000001	0.66549999999999998	0.95899999999999996	1.5720000000000001	2.0609999999999999	0.97699999999999998	0.9143	0.87250000000000005	0.82030000000000003	0.76800000000000002	0.66349999999999998	0.59409999999999996	0.54110000000000003	0.48220000000000002	0.44209999999999999	0.40210000000000001	0.37	0.32200000000000001	0.25	1.012	2	99.855003	2.778	1.2430000000000001	\N	78
10559	1902	88	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	88
10564	1904	32	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	32
10565	1904	41	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	41
10566	1904	52	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	52
10567	1904	82	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	82
10568	1904	92	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	92
10550	1901	35	0.017000000000000001	0.72460000000000002	1.149	1.726	2.0750000000000002	1.4286000000000001	1.0857000000000001	0.96299999999999997	0.88900000000000001	0.81499999999999995	0.66700000000000004	0.5867	0.52890000000000004	0.46429999999999999	0.42859999999999998	0.39290000000000003	0.36430000000000001	0.32140000000000002	0.5	35	1	82.5	0	0	\N	35
10551	1901	55	0.075999999999999998	0.56330000000000002	1.0529999999999999	1.4930000000000001	1.734	0.91059999999999997	0.70889999999999997	0.62060000000000004	0.59230000000000005	0.56399999999999995	0.50729999999999997	0.46289999999999998	0.42030000000000001	0.37769999999999998	0.35639999999999999	0.3352	0.31809999999999999	0.29260000000000003	0.5	58.716	2	99.083	0	0	\N	55
10552	1901	71	0.069000000000000006	0.62929999999999997	1.0620000000000001	1.617	1.919	0.98240000000000005	0.87670000000000003	0.80620000000000003	0.71809999999999996	0.63	0.57799999999999996	0.52600000000000002	0.47160000000000002	0.4148	0.38640000000000002	0.35799999999999998	0.3352	0.30109999999999998	0.25	1	2	99	0	0	\N	71
10553	1901	95	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	95
10546	1900	33	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	33
10547	1900	53	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	53
10548	1900	73	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	73
10549	1900	93	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	93
10540	1899	31	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	31
10541	1899	41	1.7330000000000001	2.984	1.625	3.1589999999999998	4.2190000000000003	7.5324999999999998	5.6497999999999999	4.7957000000000001	3.8565999999999998	3.2934000000000001	2.1671999999999998	1.4031	0.92500000000000004	0.74850000000000005	0.66020000000000001	0.60119999999999996	0.56620000000000004	0.51359999999999995	0.5	8.4429998	10	94.904999	9.7780000000000005	4.3730000000000002	\N	41
10542	1899	52	0.047	1.4194	1.601	2.8260000000000001	4.1109999999999998	3.4285999999999999	2.9142999999999999	2.5714000000000001	2.1429	1.8234999999999999	1.2941	0.81499999999999995	0.57579999999999998	0.48149999999999998	0.43980000000000002	0.39810000000000001	0.36480000000000001	0.31480000000000002	0.25	2.2219999	4	96.667	0	0	\N	52
10543	1899	66	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	66
10544	1899	81	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	81
10545	1899	91	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	91
10536	1898	47	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	47
10537	1898	57	0.16700000000000001	1.8868	1.343	2.4569999999999999	3.323	6.6399999999999997	3.0667	2	1.8462000000000001	1.6922999999999999	1.3846000000000001	1.0769	0.82920000000000005	0.62	0.57999999999999996	0.54000000000000004	0.50800000000000001	0.41670000000000001	0.5	15	6.2999999999999998	87.5	0	0	\N	57
10538	1898	72	0.25700000000000001	1.5008999999999999	0.72499999999999998	2.2250000000000001	3.7909999999999999	3.1373000000000002	2.4763999999999999	2.0358000000000001	1.8908	1.7741	1.5405	1.3069999999999999	1.0733999999999999	0.73999999999999999	0.60540000000000005	0.54690000000000005	0.50009999999999999	0.40639999999999998	0.5	15.989	4	97.832001	0	0	\N	72
10539	1898	87	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	87
10530	1897	32	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	32
10531	1897	37	0.60399999999999998	7.1726000000000001	0.91400000000000003	3.024	5.3440000000000003	16.685700000000001	14.697100000000001	13.3714	11.7143	10.0571	7.0366999999999997	5.0823999999999998	3.6726999999999999	2.6181999999999999	2.0909	1.8	1.6067	1.3167	0.5	0.86199999	10	69.828003	0	0	\N	37
10532	1897	47	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	47
10533	1897	57	3.9900000000000002	7.1338999999999997	0.81899999999999995	2.8599999999999999	5.2489999999999997	16.596299999999999	13.7835	11.908300000000001	9.7979000000000003	8.7105999999999995	6.7557	5.3269000000000002	4.0354000000000001	2.9752999999999998	2.4485000000000001	1.9505999999999999	1.6852	1.2869999999999999	0.5	2.74	20	97.260002	4.375	3.0939999999999999	\N	57
10534	1897	87	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	87
10535	1897	96	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	96
10525	1896	38	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	38
10526	1896	53	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	53
10527	1896	68	0.028000000000000001	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	68
10528	1896	83	82.155000000000001	10.952299999999999	0.85999999999999999	2.2909999999999999	4.173	22.351700000000001	18.914000000000001	17.647400000000001	16.064	14.480700000000001	11.314	8.9019999999999992	7.0773999999999999	5.5374999999999996	4.8596000000000004	4.1816000000000004	3.6040999999999999	2.7113	0.25	0.043000001	20	87.429001	372.16399999999999	186.08199999999999	\N	83
10529	1896	98	93.680000000000007	4.1234000000000002	0.89400000000000002	2.1579999999999999	3.3300000000000001	8.2413000000000007	6.3285	5.8219000000000003	5.2099000000000002	4.5979000000000001	3.6960999999999999	3.1021000000000001	2.508	1.9399	1.7323999999999999	1.5248999999999999	1.3589	1.1099000000000001	0.25	0.043000001	10	93.518997	419.74299999999999	209.87200000000001	\N	98
10329	1895	27	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	27
10330	1895	37	0.099000000000000005	14.0153	0.93000000000000005	1.3100000000000001	1.9830000000000001	18.882400000000001	18.2118	17.764700000000001	17.2059	16.647099999999998	15.529400000000001	14.411799999999999	13.2941	12.176500000000001	11.617599999999999	11.0588	10.611800000000001	7.8300000000000001	2	0.52600002	10	10.526	0.59399999999999997	0.29699999999999999	\N	37
10331	1895	57	0.30199999999999999	9.5333000000000006	0.87	1.9750000000000001	3.6600000000000001	17.478300000000001	15.965199999999999	14.9565	13.6957	12.434799999999999	9.9556000000000004	8.6667000000000005	7.524	6.5380000000000003	5.8071000000000002	4.8543000000000003	4.0919999999999996	2.7200000000000002	0.63	1.724	10	60.345001	1.73	0.86499999999999999	\N	57
10332	1895	67	7.3630000000000004	14.110900000000001	0.77100000000000002	1.5880000000000001	2.9609999999999999	22.977900000000002	19.591200000000001	18.938600000000001	18.122800000000002	17.307099999999998	15.675599999999999	14.044	12.4125	10.781000000000001	9.9504000000000001	8.7867999999999995	7.7647000000000004	5.2933000000000003	0.25	0.071000002	20	86.505997	42.737000000000002	21.367999999999999	\N	67
10333	1895	87	367.73399999999998	4.5849000000000002	0.96199999999999997	2.6309999999999998	4.3970000000000002	9.9845000000000006	7.7058	6.5214999999999996	5.6737000000000002	4.9372999999999996	3.7294	2.9853999999999998	2.2414000000000001	1.7113	1.4977	1.284	1.1131	0.84830000000000005	0.25	0.043000001	20	98.390999	931.02499999999998	465.51299999999998	\N	87
10334	1895	97	0.93799999999999994	0.53890000000000005	1.0529999999999999	1.4850000000000001	1.7390000000000001	0.97360000000000002	0.59530000000000005	0.49740000000000001	0.47960000000000003	0.46179999999999999	0.42630000000000001	0.39079999999999998	0.3553	0.31969999999999998	0.30199999999999999	0.28420000000000001	0.27000000000000002	0.2452	0.125	0.741	2	97.037003	0.85099999999999998	0.49099999999999999	\N	97
10321	1894	29	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	29
10322	1894	36	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	36
10323	1894	46	0.042000000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	46
10324	1894	56	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	56
10325	1894	67	0.083000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	67
10326	1894	77	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	77
10327	1894	88	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	88
10328	1894	97	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	97
10301	1892	20	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	20
10302	1892	26	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	26
10303	1892	31	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	31
10304	1892	34	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	34
10305	1892	36	0.104	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0.191	0.11	\N	36
10306	1892	40	3.8399999999999999	0.82269999999999999	1.089	1.6619999999999999	1.9670000000000001	1.4966999999999999	0.99060000000000004	0.92769999999999997	0.84919999999999995	0.77059999999999995	0.62439999999999996	0.57130000000000003	0.5181	0.45469999999999999	0.4204	0.3861	0.35859999999999997	0.31740000000000002	0.25	0.18099999	8	99.819	12.377000000000001	7.1459999999999999	\N	40
10307	1892	45	0.042000000000000003	0.66810000000000003	1.5229999999999999	1.8180000000000001	1.8029999999999999	1.4556	1.0622	0.88900000000000001	0.70709999999999995	0.6079	0.53120000000000001	0.47349999999999998	0.42880000000000001	0.3841	0.36170000000000002	0.33939999999999998	0.32150000000000001	0.29470000000000002	0.5	55.931999	2	98.305	0.14399999999999999	0.083000000000000004	\N	45
10308	1892	50	0.049000000000000002	0.83589999999999998	1.4550000000000001	2.0950000000000002	2.4609999999999999	1.74	1.464	1.28	1.05	0.92320000000000002	0.7268	0.57940000000000003	0.48699999999999999	0.42309999999999998	0.39119999999999999	0.35930000000000001	0.3337	0.2954	0.25	2.8989999	2	95.652	0.086999999999999994	0.050000000000000003	\N	50
10309	1892	66	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	66
10310	1892	76	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	76
10311	1892	80	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	80
10312	1892	90	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	90
10295	1891	29	0.021000000000000001	1.7690999999999999	2.0409999999999999	2.3759999999999999	2.8450000000000002	3.9428999999999998	3.3942999999999999	3.0286	2.5714000000000001	2.1143000000000001	1.5333000000000001	1	0.88160000000000005	0.76319999999999999	0.70399999999999996	0.64480000000000004	0.60140000000000005	0.53900000000000003	0.5	6.25	4	90.625	0.071999999999999995	0.042000000000000003	\N	29
10296	1891	35	0.028000000000000001	1.2312000000000001	1.5649999999999999	2.2429999999999999	2.5979999999999999	2.9714	2.1829000000000001	1.8667	1.6111	1.3555999999999999	0.94820000000000004	0.77800000000000002	0.62129999999999996	0.55489999999999995	0.52170000000000005	0.47999999999999998	0.434	0.36499999999999999	0.5	21.739	4	97.825996	0.096000000000000002	0.056000000000000001	\N	35
10297	1891	45	2.4380000000000002	0.77969999999999995	0.95199999999999996	1.518	2.1099999999999999	1.3754999999999999	0.99480000000000002	0.95679999999999998	0.9093	0.8619	0.76690000000000003	0.67200000000000004	0.59930000000000005	0.54420000000000002	0.51670000000000005	0.47760000000000002	0.43190000000000001	0.36349999999999999	0.25	0.057	4	99.972	5.173	2.9860000000000002	\N	45
10298	1891	55	0.11799999999999999	2.1284000000000001	1.897	3.4039999999999999	5.2629999999999999	5.4260000000000002	4.46	3.875	3.3281000000000001	2.7812000000000001	1.75	0.95130000000000003	0.62350000000000005	0.50980000000000003	0.46379999999999999	0.41999999999999998	0.38500000000000001	0.33250000000000002	0.25	0.57099998	8	95.429001	0.33900000000000002	0.19600000000000001	\N	55
10299	1891	81	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	81
10300	1891	91	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	91
10288	1890	26	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	26
10289	1890	38	0.16	1.4253	1.79	2.4300000000000002	2.7440000000000002	3.4449999999999998	2.782	2.3399999999999999	1.8937999999999999	1.6174999999999999	1.0649999999999999	0.85570000000000002	0.69220000000000004	0.58550000000000002	0.54959999999999998	0.51370000000000005	0.47099999999999997	0.3881	0.5	18.1	4	95.023003	0.064000000000000001	0.036999999999999998	\N	38
10290	1890	51	7.7380000000000004	6.4976000000000003	1.0069999999999999	4.7160000000000002	8.9860000000000007	17.115500000000001	12.9168	10.117699999999999	8.4814000000000007	6.9684999999999997	4.6215999999999999	2.7288000000000001	1.5016	0.88980000000000004	0.75360000000000005	0.62490000000000001	0.58069999999999999	0.51429999999999998	0.125	0.0049999999	31.5	94.122002	56.781999999999996	25.393999999999998	\N	51
10291	1890	66	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	66
10292	1890	78	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	78
10293	1890	86	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	86
10294	1890	93	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	93
10278	1889	8	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	8
10279	1889	17	0.97899999999999998	16.7638	0.98199999999999998	1.552	2.5470000000000002	27.4693	25.050799999999999	23.438500000000001	21.423100000000002	19.745699999999999	18.014800000000001	16.283999999999999	14.553100000000001	12.8222	11.956799999999999	11.0914	10.398999999999999	7.0735000000000001	0.63	0.071000002	20	71.469002	0	0	\N	17
10280	1889	21	0.60699999999999998	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	21
10281	1889	31	0.32200000000000001	13.042299999999999	0.80900000000000005	1.484	2.121	18.680800000000001	17.889199999999999	17.361499999999999	16.701899999999998	16.042300000000001	14.723100000000001	13.4038	12.0846	10.7654	10.1058	9.0399999999999991	8.1252999999999993	6.9402999999999997	2	0.292	10	24.198	0	0	\N	31
10282	1889	41	15.444000000000001	10.2949	1.0489999999999999	1.8799999999999999	2.4889999999999999	18.4834	16.815899999999999	15.7043	14.3147	12.9251	10.146000000000001	8.7309999999999999	7.4813999999999998	6.3395000000000001	5.7735000000000003	5.2077999999999998	4.7553000000000001	4.0765000000000002	0.5	0.0089999996	20	95.457001	36.104999999999997	20.844999999999999	\N	41
10283	1889	50	28.016999999999999	10.337199999999999	1.264	2.8130000000000002	4.1379999999999999	26.020499999999998	18.093299999999999	15.7103	12.7316	9.8794000000000004	7.3318000000000003	5.7214999999999998	4.4489000000000001	3.4582000000000002	3.0396000000000001	2.621	2.2862	1.7718	0.125	0.0020000001	40	92.547997	66.587000000000003	38.444000000000003	\N	50
10284	1889	51	0.60699999999999998	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	51
10285	1889	58	170.56200000000001	8.0367999999999995	1.236	2.8359999999999999	4.1130000000000004	19.422799999999999	15.8947	13.5426	10.602499999999999	8.6786999999999992	6.4004000000000003	5.0408999999999997	3.8336999999999999	3.0583999999999998	2.6707000000000001	2.2831000000000001	1.9757	1.5563	0.125	0.0020000001	31.5	98.803001	165.55099999999999	117.063	\N	58
10286	1889	63	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	63
10287	1889	77	14.254	3.2694000000000001	1.004	2.9199999999999999	4.4480000000000004	7.0696000000000003	5.3604000000000003	4.4531999999999998	3.7448000000000001	3.3197999999999999	2.4697	1.8322000000000001	1.4571000000000001	1.0820000000000001	0.91100000000000003	0.753	0.62870000000000004	0.55530000000000002	0.125	0.037	20	98.397003	30.619	17.678000000000001	\N	77
24030	7302	41	22.169	0.81420000000000003	1.046	1.3240000000000001	1.49	0.99390000000000001	0.94999999999999996	0.92069999999999996	0.88419999999999999	0.84760000000000002	0.77449999999999997	0.70130000000000003	0.62909999999999999	0.59260000000000002	0.57440000000000002	0.55610000000000004	0.54149999999999998	0.51959999999999995	0.063	0.003	6.2999999999999998	99.771004	0	0	\N	71
24029	7302	52	27.532	1.7186999999999999	1.292	2.2930000000000001	2.9060000000000001	3.7376999999999998	2.9599000000000002	2.4413	1.9480999999999999	1.7857000000000001	1.4607000000000001	1.1357999999999999	0.90700000000000003	0.74729999999999996	0.66749999999999998	0.60329999999999995	0.56299999999999994	0.50260000000000005	0.063	0.003	6.2999999999999998	97.156998	0	0	\N	82
24028	7302	62	63.054000000000002	1.2316	1.6559999999999999	1.853	2.0150000000000001	3.0566	1.478	0.99109999999999998	0.92569999999999997	0.86029999999999995	0.72940000000000005	0.61970000000000003	0.57679999999999998	0.53380000000000005	0.51239999999999997	0.47589999999999999	0.43030000000000002	0.36199999999999999	0.063	0.003	6.2999999999999998	96.582001	0	0	\N	92
24027	7302	82	64.579999999999998	0.68920000000000003	0.97099999999999997	1.4119999999999999	1.6879999999999999	0.76849999999999996	0.61009999999999998	0.58589999999999998	0.55569999999999997	0.52549999999999997	0.47749999999999998	0.4385	0.39960000000000001	0.36070000000000002	0.3412	0.32179999999999997	0.30620000000000003	0.28289999999999998	0.063	0.0070000002	6.2999999999999998	98.099998	0	0	\N	112
24026	7302	102	1.357	3.8064	0.28599999999999998	4.867	16.959	8.8720999999999997	8.1952999999999996	7.7442000000000002	7.1802000000000001	6.6162000000000001	5.2199999999999998	3.1511999999999998	0.49880000000000002	0.43519999999999998	0.40329999999999999	0.3715	0.34599999999999997	0.30780000000000002	0.063	0.0049999999	6.2999999999999998	67.195999	0	0	\N	132
24005	7284	29	13.981999999999999	2.0848	1.1739999999999999	2.1659999999999999	2.7080000000000002	4.1898999999999997	3.5424000000000002	3.1981000000000002	2.7677	2.3372999999999999	1.8146	1.5097	1.2049000000000001	0.95350000000000001	0.88270000000000004	0.81179999999999997	0.75509999999999999	0.67010000000000003	0.063	0.003	10	99.549004	0	0	\N	69
24004	7284	39	32.003999999999998	1.3126	1.5289999999999999	1.8979999999999999	1.887	2.9134000000000002	1.917	1.7333000000000001	1.5036	1.2739	0.94730000000000003	0.81679999999999997	0.68620000000000003	0.60160000000000002	0.57669999999999999	0.55179999999999996	0.53190000000000004	0.502	0.063	0.0020000001	6.2999999999999998	98.727997	0	0	\N	79
24003	7284	49	19.59	0.80720000000000003	1.085	1.5109999999999999	1.7749999999999999	1.0506	0.89629999999999999	0.82399999999999995	0.73360000000000003	0.64329999999999998	0.60089999999999999	0.56940000000000002	0.53800000000000003	0.50649999999999995	0.47360000000000002	0.42859999999999998	0.3926	0.33850000000000002	0.063	0.003	6.2999999999999998	99.287003	0	0	\N	89
24002	7284	79	13.185	3.0152999999999999	7.6849999999999996	4.6150000000000002	2.839	10.767300000000001	7.2423999999999999	5.702	4.4819000000000004	3.0762999999999998	0.86760000000000004	0.56610000000000005	0.47810000000000002	0.42059999999999997	0.39190000000000003	0.36309999999999998	0.34010000000000001	0.30559999999999998	0.063	0.0020000001	10	88.533997	0	0	\N	119
24001	7284	89	0.035999999999999997	0.95450000000000002	1.881	1.9870000000000001	1.7170000000000001	3.1800000000000002	1.1439999999999999	0.79769999999999996	0.58450000000000002	0.49630000000000002	0.45810000000000001	0.41980000000000001	0.38159999999999999	0.34329999999999999	0.32419999999999999	0.30509999999999998	0.2898	0.26679999999999998	0.063	0.207	4	91.700996	0	0	\N	129
25909	8442	44	5.2080000000000002	0.90680000000000005	1.224	1.5309999999999999	1.944	1.5819000000000001	1.1733	0.98580000000000001	0.93689999999999996	0.88800000000000001	0.7903	0.6925	0.61309999999999998	0.56610000000000005	0.54259999999999997	0.51910000000000001	0.50029999999999997	0.40649999999999997	0.063	0.0040000002	6.2999999999999998	99.436996	0	0	\N	74
25908	8442	54	5.1040000000000001	1.2347999999999999	1.304	1.655	1.7869999999999999	1.9302999999999999	1.7524	1.6336999999999999	1.4854000000000001	1.3371	1.0405	0.92700000000000005	0.84250000000000003	0.75800000000000001	0.71579999999999999	0.67349999999999999	0.63970000000000005	0.58209999999999995	0.063	0.0040000002	6.2999999999999998	99.632004	0	0	\N	84
25907	8442	68	7.0830000000000002	1.7942	1.964	2.2330000000000001	2.431	4.2991000000000001	3.0901999999999998	2.3614000000000002	1.8876999999999999	1.7016	1.3294999999999999	0.98760000000000003	0.87980000000000003	0.77200000000000002	0.71809999999999996	0.66410000000000002	0.61990000000000001	0.54679999999999995	0.063	0.015	10	99.293999	0	0	\N	98
25906	8442	94	5.1040000000000001	0.755	0.93500000000000005	1.4079999999999999	1.73	0.9274	0.62570000000000003	0.60519999999999996	0.57950000000000002	0.55379999999999996	0.50249999999999995	0.4597	0.41739999999999999	0.37509999999999999	0.35389999999999999	0.3327	0.31580000000000003	0.29039999999999999	0.063	0.0080000004	6.2999999999999998	99.299004	0	0	\N	124
23745	7041	46	36.101999999999997	2.4007000000000001	0.80900000000000005	2.5190000000000001	4.2610000000000001	5.1417999999999999	4.0955000000000004	3.7589000000000001	3.4098000000000002	3.0607000000000002	2.3624000000000001	1.8076000000000001	1.4077	1.0077	0.87660000000000005	0.74819999999999998	0.64549999999999996	0.55449999999999999	0.063	0.001	10	99.574997	0	0	\N	66
23744	7041	62	5.5389999999999997	2.6398000000000001	1.5229999999999999	2.6000000000000001	3.052	5.9938000000000002	4.6482999999999999	3.8687	3.2766000000000002	2.6846000000000001	1.8365	1.4489000000000001	1.0611999999999999	0.88270000000000004	0.81299999999999994	0.74339999999999995	0.68759999999999999	0.6018	0.063	0.0020000001	10	95.093002	0	0	\N	82
23743	7041	78	6.6870000000000003	1.8977999999999999	2.1429999999999998	2.798	3.3530000000000002	4.8337000000000003	3.5608	3.0524	2.4169999999999998	1.8915999999999999	1.2608999999999999	0.86950000000000005	0.64690000000000003	0.56940000000000002	0.53659999999999997	0.50380000000000003	0.45500000000000002	0.376	0.063	0.0049999999	10	98.834	0	0	\N	98
23742	7041	93	1.4490000000000001	1.0112000000000001	1.232	1.663	1.8080000000000001	2.2523	0.8851	0.62809999999999999	0.60309999999999997	0.57809999999999995	0.5282	0.47960000000000003	0.43269999999999997	0.38590000000000002	0.3624	0.33900000000000002	0.32019999999999998	0.29210000000000003	0.063	0.0099999998	10	98.697998	0	0	\N	113
23741	7041	108	0.189	0.97719999999999996	0.95999999999999996	1.226	1.468	1.5894999999999999	0.98070000000000002	0.96140000000000003	0.93730000000000002	0.91320000000000001	0.86499999999999999	0.81669999999999998	0.76849999999999996	0.72030000000000005	0.69610000000000005	0.67200000000000004	0.65269999999999995	0.58930000000000005	0.063	0.071999997	2	91.398003	0	0	\N	128
23725	7021	41	22.149999999999999	3.5337999999999998	1.133	2.234	3.2149999999999999	7.7972000000000001	5.8048999999999999	5.1872999999999996	4.4154	3.8386999999999998	3.1400000000000001	2.4413	1.8887	1.5864	1.4353	1.2842	1.1633	0.97670000000000001	0.125	0.001	10	94.109001	0	0	\N	61
23724	7021	51	54.539999999999999	3.0156000000000001	1.45	2.2240000000000002	2.399	7.0846	4.2283999999999997	3.5390999999999999	2.8692000000000002	2.1993	1.8063	1.5788	1.3512	1.1236999999999999	1.0099	0.92259999999999998	0.85470000000000002	0.75280000000000002	0.063	0.001	16	97.986	0	0	\N	71
23723	7021	61	20.641999999999999	2.6762999999999999	1.4970000000000001	2.6160000000000001	3.2570000000000001	6.2725	4.2344999999999997	3.5589	2.8925000000000001	2.2261000000000002	1.6927000000000001	1.3226	0.98070000000000002	0.83030000000000004	0.755	0.67979999999999996	0.61860000000000004	0.51970000000000005	0.063	0.0020000001	16	98.569	0	0	\N	81
23722	7021	71	25.239999999999998	2.5689000000000002	2.5640000000000001	3.0590000000000002	2.7130000000000001	6.9843000000000002	4.1372	3.1711	2.0421999999999998	1.6758	1.0023	0.84460000000000002	0.68869999999999998	0.5776	0.53549999999999998	0.49049999999999999	0.44209999999999999	0.36940000000000001	0.063	0.001	16	97.705002	0	0	\N	91
23721	7021	102	2.1000000000000001	4.1931000000000003	4.7480000000000002	5.2519999999999998	11.981999999999999	12.4826	10.3721	9.0724	7.4960000000000004	6.0487000000000002	3.9338000000000002	0.90629999999999999	0.58599999999999997	0.48730000000000001	0.44750000000000001	0.4078	0.376	0.32829999999999998	0.063	0.003	10	82.942001	0	0	\N	122
23945	7241	32	24.469000000000001	7.3939000000000004	0.997	2.0800000000000001	3.1909999999999998	14.3004	12.1464	10.7103	9.5069999999999997	8.6912000000000003	7.0594999999999999	5.8505000000000003	5.0095000000000001	4.1684999999999999	3.7023000000000001	3.2056	2.8081999999999998	2.2122000000000002	0.125	0.0020000001	16	94.734001	0	0	\N	57
23944	7241	62	104.41800000000001	4.2645	1.4330000000000001	2.9399999999999999	4.4059999999999997	10.1793	7.4108999999999998	6.0419999999999998	5.1843000000000004	4.3265000000000002	3.1522999999999999	2.1053000000000002	1.6661999999999999	1.2950999999999999	1.1094999999999999	0.9516	0.85709999999999997	0.71540000000000004	0.063	0.0040000002	16	95.955002	0	0	\N	87
23943	7241	80	103.98	3.5825999999999998	1.371	3.2370000000000001	4.5869999999999997	8.8477999999999994	5.7053000000000003	4.7896999999999998	3.8170000000000002	3.2267000000000001	2.0461	1.5053000000000001	0.99619999999999997	0.78959999999999997	0.68630000000000002	0.59909999999999997	0.54459999999999997	0.44600000000000001	0.063	0.0040000002	16	95.205002	0	0	\N	105
23942	7241	102	17.978999999999999	5.7911999999999999	0.26100000000000001	4.4710000000000001	13.349	13.605399999999999	9.8536999999999999	8.8908000000000005	7.6871999999999998	6.4836	5.3468	4.3148	3.1795	1.9977	0.97770000000000001	0.58830000000000005	0.49280000000000002	0.40050000000000002	0.063	0.0049999999	16	93.581001	0	0	\N	127
23941	7241	121	6.8719999999999999	1.0077	2.7559999999999998	2.3039999999999998	1.6120000000000001	3.1495000000000002	1.5410999999999999	0.58579999999999999	0.48559999999999998	0.46910000000000002	0.436	0.40289999999999998	0.36969999999999997	0.33660000000000001	0.3201	0.30349999999999999	0.2903	0.27039999999999997	0.063	0.017999999	6.2999999999999998	97.922997	0	0	\N	146
23705	7003	42	13.397	2.286	1.48	2.4700000000000002	2.8799999999999999	5.4466000000000001	4.2205000000000004	3.6177000000000001	2.9634	2.3090000000000002	1.7421	1.4045000000000001	1.0669	0.88770000000000004	0.81759999999999999	0.74760000000000004	0.6915	0.60489999999999999	0.063	0.0020000001	10	98.879997	0	0	\N	82
23704	7003	61	12.856999999999999	1.7924	2.3159999999999998	2.5750000000000002	2.6579999999999999	4.3042999999999996	3.1728999999999998	2.5335999999999999	1.9045000000000001	1.6173	1.0427999999999999	0.80969999999999998	0.62309999999999999	0.56840000000000002	0.54110000000000003	0.51370000000000005	0.47849999999999998	0.39219999999999999	0.063	0.0020000001	10	97.639999	0	0	\N	101
23703	7003	72	15.055	1.5734999999999999	2.371	2.544	2.633	3.9077000000000002	3.1099000000000001	2.5781000000000001	1.9598	1.6515	1.0347999999999999	0.79400000000000004	0.61719999999999997	0.5655	0.53969999999999996	0.51380000000000003	0.48070000000000002	0.3931	0.063	0.0020000001	6.2999999999999998	98.170998	0	0	\N	112
23702	7003	81	16.538	0.88829999999999998	1.3120000000000001	1.645	1.696	2.0569000000000002	0.84250000000000003	0.62749999999999995	0.58940000000000003	0.5514	0.48699999999999999	0.4471	0.40710000000000002	0.36709999999999998	0.34710000000000002	0.32719999999999999	0.31119999999999998	0.28720000000000001	0.063	0.0020000001	6.2999999999999998	98.825996	0	0	\N	121
23701	7003	102	0.214	2.8395999999999999	7.0990000000000002	4.351	5.3079999999999998	8.4259000000000004	6.2122000000000002	5.5629999999999997	4.7514000000000003	3.9163999999999999	1.5727	0.53590000000000004	0.45579999999999998	0.4027	0.37609999999999999	0.34949999999999998	0.32819999999999999	0.29630000000000001	0.063	0.032000002	10	94.042	0	0	\N	142
23687	7002	42	26.388000000000002	3.8273999999999999	1.111	2.2879999999999998	3.286	9.0737000000000005	6.2687999999999997	5.6447000000000003	4.8644999999999996	4.0843999999999996	3.3189000000000002	2.5988000000000002	1.9474	1.6349	1.4786999999999999	1.3224	1.1974	1.0099	0.063	0.0040000002	10	91.936996	0	0	\N	72
23686	7002	52	1.95	3.1619000000000002	1.29	2.3100000000000001	3.4710000000000001	6.5175999999999998	5.4930000000000003	4.9107000000000003	4.1828000000000003	3.6993999999999998	2.8963999999999999	2.0933999999999999	1.7386999999999999	1.4430000000000001	1.2950999999999999	1.1473	1.0289999999999999	0.83450000000000002	0.063	0.014	10	97.302002	0	0	\N	82
23685	7002	62	17.350999999999999	3.0790999999999999	1.429	2.6720000000000002	3.1509999999999998	7.3234000000000004	5.2415000000000003	4.2548000000000004	3.5667	3.0206	1.978	1.6414	1.3048	0.98319999999999996	0.89429999999999998	0.8054	0.73419999999999996	0.62770000000000004	0.063	0.0020000001	16	98.518997	0	0	\N	92
23684	7002	72	18.698	3.3974000000000002	1.3480000000000001	2.7210000000000001	3.2440000000000002	7.7769000000000004	4.9642999999999997	3.8936999999999999	3.2765	2.6594000000000002	1.8638999999999999	1.5716000000000001	1.2794000000000001	0.9899	0.87590000000000001	0.76190000000000002	0.67059999999999997	0.57450000000000001	0.063	0.0040000002	16	95.403	0	0	\N	102
23683	7002	102	4.3780000000000001	6.8091999999999997	0.20899999999999999	4.8109999999999999	16.957999999999998	14.4253	12.396000000000001	11.043200000000001	9.6706000000000003	8.8109000000000002	7.0915999999999997	5.6333000000000002	4.3975999999999997	2.9350000000000001	2.1499000000000001	0.77949999999999997	0.53549999999999998	0.41820000000000002	0.063	0.0020000001	16	94.655998	0	0	\N	132
23682	7001	96	12.676	0.70130000000000003	1.048	1.54	1.8109999999999999	0.95750000000000002	0.77439999999999998	0.65229999999999999	0.60980000000000001	0.58609999999999995	0.53869999999999996	0.49109999999999998	0.44269999999999998	0.39429999999999998	0.37009999999999998	0.34589999999999999	0.32650000000000001	0.29749999999999999	0.125	0.003	6.2999999999999998	99.551003	0	0	\N	126
23681	7001	106	0.29999999999999999	3.4830000000000001	0.63500000000000001	4.1159999999999997	8.7989999999999995	8.6392000000000007	7.8226000000000004	7.2782999999999998	6.5979000000000001	5.1996000000000002	3.3384999999999998	2.3845999999999998	1.3683000000000001	0.75070000000000003	0.60029999999999994	0.51970000000000005	0.46179999999999999	0.37940000000000002	0.125	0.023	6.2999999999999998	72.810997	0	0	\N	136
13007	2089	72	2.778	0.99039999999999995	1.107	1.4359999999999999	1.5740000000000001	1.6106	1.2172000000000001	0.99570000000000003	0.96399999999999997	0.93240000000000001	0.86919999999999997	0.80600000000000005	0.74270000000000003	0.67949999999999999	0.64790000000000003	0.61609999999999998	0.59060000000000001	0.55230000000000001	0.125	0.0080000004	6.2999999999999998	99.667999	4.3220000000000001	2.4950000000000001	\N	72
13008	2089	81	13.048999999999999	1.3948	1.296	1.8	2.0430000000000001	2.8003999999999998	1.9047000000000001	1.7722	1.6067	1.4411	1.1099000000000001	0.9294	0.8236	0.71789999999999998	0.66500000000000004	0.61750000000000005	0.5877	0.54320000000000002	0.125	0.0049999999	6.2999999999999998	98.861	7.1559999999999997	4.1310000000000002	\N	81
13009	2089	90	12.938000000000001	0.95709999999999995	1.254	1.5920000000000001	1.6719999999999999	1.6938	1.373	1.1592	0.98280000000000001	0.94030000000000002	0.85519999999999996	0.77010000000000001	0.68500000000000005	0.61219999999999997	0.58699999999999997	0.56179999999999997	0.54169999999999996	0.51149999999999995	0.125	0.003	4	99.057999	35.429000000000002	20.454999999999998	\N	90
13010	2089	122	18.263999999999999	0.45629999999999998	0.95099999999999996	1.371	1.6419999999999999	0.60719999999999996	0.57699999999999996	0.55679999999999996	0.53159999999999996	0.50639999999999996	0.46810000000000002	0.43149999999999999	0.39489999999999997	0.35830000000000001	0.34000000000000002	0.3216	0.307	0.28499999999999998	0.125	0.093000002	4	99.944	11.428000000000001	6.5979999999999999	\N	122
13002	2088	86	1.1899999999999999	2.8730000000000002	1.093	1.944	2.665	5.6487999999999996	4.6586999999999996	3.9996	3.7151000000000001	3.4306000000000001	2.8616999999999999	2.2928000000000002	1.871	1.6052999999999999	1.4724999999999999	1.3395999999999999	1.2333000000000001	1.0739000000000001	0.125	0.057	6.2999999999999998	93.946999	3.0129999999999999	1.74	\N	86
13003	2088	96	1.569	2.2921	1.526	3.1699999999999999	4.3559999999999999	5.8369	3.9409999999999998	3.3065000000000002	2.5133000000000001	1.9195	1.4630000000000001	1.0065999999999999	0.78139999999999998	0.55769999999999997	0.4768	0.42980000000000002	0.39219999999999999	0.33589999999999998	0.125	0.048	10	94.775002	2.1560000000000001	1.2450000000000001	\N	96
13004	2088	106	3.4239999999999999	0.66539999999999999	1.2230000000000001	1.661	1.8779999999999999	1.0075000000000001	0.88980000000000004	0.81559999999999999	0.72299999999999998	0.63029999999999997	0.55230000000000001	0.4844	0.43680000000000002	0.38919999999999999	0.3654	0.3417	0.3226	0.29409999999999997	0.125	0.025	4	99.210999	2.23	1.2869999999999999	\N	106
13005	2088	117	3.5830000000000002	0.82669999999999999	1.034	1.587	1.8959999999999999	0.95479999999999998	0.85150000000000003	0.78269999999999995	0.69669999999999999	0.62460000000000004	0.57620000000000005	0.52780000000000005	0.47560000000000002	0.41839999999999999	0.38969999999999999	0.36109999999999998	0.3382	0.3039	0.125	0.024	10	98.794998	1.631	0.94199999999999995	\N	117
13006	2088	147	0.26400000000000001	0.58489999999999998	0.93999999999999995	1.3260000000000001	1.579	0.59950000000000003	0.50849999999999995	0.48920000000000002	0.47360000000000002	0.45800000000000002	0.42670000000000002	0.39539999999999997	0.36409999999999998	0.33279999999999998	0.31719999999999998	0.30159999999999998	0.28910000000000002	0.27029999999999998	0.125	0.086000003	6.2999999999999998	99.714996	0.12	0.069000000000000006	\N	147
12997	2087	82	12.013999999999999	4.4339000000000004	1.27	2.1179999999999999	2.6419999999999999	9.0393000000000008	6.1246999999999998	5.3945999999999996	4.4820000000000002	3.8487	3.2073	2.5659000000000001	1.9702999999999999	1.7181999999999999	1.5921000000000001	1.4661	1.3652	1.2139	0.125	0.0060000001	16	94.250999	24.545000000000002	14.170999999999999	\N	82
12998	2087	92	20.646000000000001	4.0799000000000003	2.0139999999999998	3.2210000000000001	3.4060000000000001	10.4329	7.2325999999999997	5.8018999999999998	4.6086	3.6204000000000001	2.0712000000000002	1.5823	1.1444000000000001	0.90200000000000002	0.82889999999999997	0.75580000000000003	0.69730000000000003	0.60809999999999997	0.125	0.0049999999	16	94.152	27.001999999999999	15.589	\N	92
12999	2087	112	22.875	2.7416	6.8540000000000001	4.2619999999999996	2.2280000000000002	10.419700000000001	6.1498999999999997	4.1120999999999999	2.0085999999999999	1.2265999999999999	0.67830000000000001	0.55120000000000002	0.4753	0.41839999999999999	0.38990000000000002	0.3614	0.33860000000000001	0.3044	0.125	0.013	16	98.649002	7.8810000000000002	4.5499999999999998	\N	112
13000	2087	122	17.082999999999998	1.0922000000000001	1.655	2.0070000000000001	1.976	2.6383000000000001	1.2324999999999999	0.9224	0.76939999999999997	0.62639999999999996	0.54469999999999996	0.47720000000000001	0.42680000000000001	0.37640000000000001	0.35120000000000001	0.32600000000000001	0.30590000000000001	0.27560000000000001	0.125	0.0089999996	6.2999999999999998	96.086998	18.699000000000002	10.795999999999999	\N	122
13001	2087	152	5.6870000000000003	0.3831	0.94299999999999995	1.2769999999999999	1.4910000000000001	0.48270000000000002	0.46679999999999999	0.45619999999999999	0.44290000000000002	0.42959999999999998	0.40310000000000001	0.37659999999999999	0.34999999999999998	0.32350000000000001	0.31019999999999998	0.29699999999999999	0.2863	0.27039999999999997	0.125	0.054000001	2	99.892998	5.3140000000000001	3.0680000000000001	\N	152
12925	2086	63	0.45100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	1.0880000000000001	0.628	\N	63
12926	2086	72	2.7010000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	4.9690000000000003	2.8690000000000002	\N	72
12927	2086	92	11.993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5.6040000000000001	3.2360000000000002	\N	92
12928	2086	102	10.146000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	1.5069999999999999	0.87	\N	102
12929	2086	131	0.98599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.48699999999999999	0.28100000000000003	\N	131
12930	2086	142	8.2149999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	3.2589999999999999	1.8819999999999999	\N	142
12919	2085	66	5.5019999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	3.972	2.2930000000000001	\N	66
12920	2085	76	4.2809999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	6.6639999999999997	3.847	\N	76
12921	2085	96	22.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	24.465	14.125	\N	96
12922	2085	106	35.162999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	11.349	6.5519999999999996	\N	106
12923	2085	136	18.100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5.4960000000000004	3.173	\N	136
10699	1972	54	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	54
10700	1972	68	32.566000000000003	5.2568999999999999	1.675	3.1400000000000001	4.3659999999999997	15.1227	9.8261000000000003	8.1917000000000009	6.4264000000000001	5.1736000000000004	3.4607999999999999	2.4177	1.7995000000000001	1.4650000000000001	1.2977000000000001	1.1304000000000001	0.99660000000000004	0.79259999999999997	0.25	0.039999999	20	95.306999	117.241	52.432000000000002	\N	68
10701	1972	82	2.4540000000000002	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	82
10702	1972	89	26.971	7.6013000000000002	0.51400000000000001	3.2269999999999999	13.384	16.776700000000002	14.6069	13.160399999999999	11.3522	9.7642000000000007	7.9097999999999997	6.3139000000000003	5.0271999999999997	3.6667000000000001	2.8332999999999999	2	1.4026000000000001	0.59099999999999997	0.25	0.043000001	20	98.913002	7.7359999999999998	5.4710000000000001	\N	89
10703	1972	103	1.8260000000000001	10.0985	0.93000000000000005	1.8240000000000001	2.5790000000000002	17.651800000000001	16.242899999999999	15.303599999999999	14.1295	12.955399999999999	10.607100000000001	9.2353000000000005	8.2039000000000009	6.7630999999999997	6.0430999999999999	5.3996000000000004	4.8848000000000003	4.1125999999999996	2	1.141	10	57.414001	3.5099999999999998	2.0259999999999998	\N	103
10704	1972	108	1.4099999999999999	12.8072	0.84999999999999998	2.1030000000000002	3.7850000000000001	25.1905	21.404900000000001	19.5	18.090299999999999	16.680599999999998	13.8611	11.041700000000001	9.1172000000000004	7.5644	6.4859	5.5568999999999997	4.8385999999999996	3.6625000000000001	1	0.493	20	81.773003	0	0	\N	108
10705	1972	122	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	122
10706	1972	128	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	128
10707	1972	142	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	142
10693	1971	68	0.70099999999999996	1.2054	1.278	1.78	2.169	1.8999999999999999	1.6113999999999999	1.419	1.1786000000000001	0.98799999999999999	0.89459999999999995	0.80110000000000003	0.7077	0.61699999999999999	0.57840000000000003	0.53979999999999995	0.50890000000000002	0.41249999999999998	0.25	0.99000001	8	99.010002	0	0	\N	68
10694	1971	80	20.271000000000001	1.6157999999999999	2.7280000000000002	2.484	2.3130000000000002	3.8235000000000001	2.6471	1.9420999999999999	1.5288999999999999	1.1156999999999999	0.83599999999999997	0.64529999999999998	0.58550000000000002	0.53720000000000001	0.51300000000000001	0.47410000000000002	0.42909999999999998	0.36149999999999999	0.25	0.1	10	97.900002	34.271000000000001	19.786000000000001	\N	80
10695	1971	91	53.438000000000002	3.5943999999999998	4.6820000000000004	4.452	4.0990000000000002	11.150399999999999	8.7791999999999994	7.5526	5.2672999999999996	3.3134000000000001	1.5172000000000001	0.91139999999999999	0.68979999999999997	0.57279999999999998	0.53369999999999995	0.49149999999999999	0.443	0.37009999999999998	0.25	0.1	10	88.699997	24.800999999999998	14.319000000000001	\N	91
10696	1971	102	25.581	1.5611999999999999	1.216	1.659	2.0819999999999999	2	1.8519000000000001	1.7531000000000001	1.6295999999999999	1.5062	1.2593000000000001	1.0123	0.9073	0.80959999999999999	0.76080000000000003	0.71199999999999997	0.67300000000000004	0.60489999999999999	0.25	0.1	10	98.900002	48.398000000000003	27.943000000000001	\N	102
10697	1971	113	0.153	7.8899999999999997	0.58299999999999996	2.9169999999999998	6.9640000000000004	16.857099999999999	14.971399999999999	13.7143	12.142899999999999	10.571400000000001	7.6600000000000001	6.7249999999999996	5.6100000000000003	4.3449999999999998	3.5	2.3999999999999999	1.76	1.1000000000000001	0.63	4.5450001	10	68.181999	0	0	\N	113
10698	1971	124	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	124
10688	1970	65	155.12	3.4331999999999998	1.0649999999999999	1.9379999999999999	2.8860000000000001	6.2720000000000002	4.2382999999999997	3.8138000000000001	3.5312999999999999	3.2488999999999999	2.6840000000000002	2.1192000000000002	1.7843	1.5108999999999999	1.3743000000000001	1.2376	1.1282000000000001	0.93000000000000005	0.25	0.086999997	20	98.652	246.07900000000001	142.07400000000001	\N	65
10689	1970	80	25.876999999999999	7.3487999999999998	0.45500000000000002	4.056	10.664	17.621400000000001	14.852	13.005699999999999	10.697900000000001	9.3209999999999997	7.3019999999999996	5.4257	3.7921999999999998	2.0861999999999998	1.5843	1.1217999999999999	0.90259999999999996	0.68469999999999998	0.25	0.082999997	20	95.153	8.8019999999999996	6.2240000000000002	\N	80
10690	1970	95	48.003	10.3621	0.40000000000000002	3.3450000000000002	11.715999999999999	21.885999999999999	18.7605	17.532699999999998	15.997999999999999	14.4633	11.3939	8.8694000000000006	6.6256000000000004	4.3673999999999999	3.3071999999999999	2.2761999999999998	1.6763999999999999	0.97250000000000003	0.25	0.043000001	20	88.038002	106.60599999999999	53.302999999999997	\N	95
10691	1970	110	70.769000000000005	12.301500000000001	0.54800000000000004	2.4319999999999999	8.0310000000000006	24.5425	20.367999999999999	19.099299999999999	17.8019	16.5045	13.909700000000001	11.3149	9.0667000000000009	7.0144000000000002	5.8327999999999998	4.5617000000000001	3.4438	1.7319	0.25	0.043000001	20	83.471001	133.095	66.548000000000002	\N	110
10692	1970	125	0.17199999999999999	1.3843000000000001	0.94299999999999995	1.7689999999999999	2.5510000000000002	2.6530999999999998	1.9570000000000001	1.8608	1.7404999999999999	1.6203000000000001	1.3796999999999999	1.1392	0.94420000000000004	0.8115	0.74519999999999997	0.67889999999999995	0.62549999999999994	0.54090000000000005	0.5	7.105	4	98.683998	0	0	\N	125
10684	1969	67	2.0680000000000001	4.2103999999999999	1.73	3.3370000000000002	4.6539999999999999	12.08	8.5155999999999992	6.8799999999999999	5.5843999999999996	4.5724	3.0983999999999998	1.9398	1.4626999999999999	0.995	0.91269999999999996	0.83040000000000003	0.76449999999999996	0.66579999999999995	0.5	2.02	10	87.374001	2.3940000000000001	1.6930000000000001	\N	67
10685	1969	91	0.025999999999999999	1.2011000000000001	1.2869999999999999	1.9390000000000001	2.5	2.5714000000000001	1.9286000000000001	1.7857000000000001	1.6071	1.4286000000000001	1.0713999999999999	0.87670000000000003	0.72250000000000003	0.60399999999999998	0.57150000000000001	0.53900000000000003	0.51300000000000001	0.42859999999999998	0.5	14	2	86	0	0	\N	91
10686	1969	106	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	106
10687	1969	121	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	121
10678	1968	70	2.9689999999999999	3.9041999999999999	1.448	3.6099999999999999	5.399	9.75	8.0399999999999991	7.0157999999999996	5.7249999999999996	4.4139999999999997	2.9091	1.8509	1.3509	0.93089999999999995	0.81499999999999995	0.69910000000000005	0.61680000000000001	0.53879999999999995	0.25	0.175	10	90.876999	0	0	\N	70
10679	1968	81	17.323	3.8894000000000002	9.8510000000000009	4.6920000000000002	2.7469999999999999	13.1347	9.2334999999999994	7.6994999999999996	5.9366000000000003	4.1006	0.97650000000000003	0.627	0.57889999999999997	0.53090000000000004	0.50680000000000003	0.46189999999999998	0.4194	0.35549999999999998	0.25	0.086999997	20	98.869003	66.125	33.063000000000002	\N	81
10680	1968	91	0.89900000000000002	2.0790000000000002	1.022	2.0449999999999999	2.843	3.8182	3.3818000000000001	3.0909	2.7273000000000001	2.3635999999999999	1.8788	1.6364000000000001	1.3938999999999999	1.1515	1.0303	0.90749999999999997	0.80879999999999996	0.66080000000000005	0.5	4.375	8	98.75	0.53700000000000003	0.31	\N	91
10681	1968	101	35.652000000000001	4.9988999999999999	1.2230000000000001	2.4409999999999998	3.1419999999999999	12.305199999999999	8.3238000000000003	6.7533000000000003	5.6828000000000003	4.8742999999999999	3.7115	3.0832999999999999	2.4552	1.9009	1.7210000000000001	1.5411999999999999	1.3972	1.1814	0.25	0.043000001	20	97.128998	192.88900000000001	96.444000000000003	\N	101
10682	1968	113	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	113
10683	1968	133	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	133
10673	1967	66	0.17399999999999999	1.1559999999999999	1.319	2.165	2.681	2.6667000000000001	1.9273	1.7455000000000001	1.5182	1.2908999999999999	0.9405	0.77539999999999998	0.62050000000000005	0.54120000000000001	0.50160000000000005	0.4516	0.4113	0.3508	0.5	24.799999	4	98.800003	0	0	\N	66
10674	1967	83	25.495999999999999	4.6547000000000001	0.624	4.5019999999999998	11.677	12.627700000000001	9.2445000000000004	8.1562000000000001	7.0227000000000004	6.0232999999999999	4.4210000000000003	2.5992000000000002	0.95050000000000001	0.59840000000000004	0.55200000000000005	0.50560000000000005	0.45610000000000001	0.37859999999999999	0.25	0.043000001	20	99.042999	71.614999999999995	41.347000000000001	\N	83
10675	1967	91	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	91
10676	1967	113	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	113
10677	1967	125	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	125
10668	1966	64	1.0780000000000001	7.6021000000000001	0.66100000000000003	2.5070000000000001	5.5830000000000002	16.122	13.7951	12.2439	10.3049	9.4417000000000009	8.1166999999999998	6.7675000000000001	5.3799999999999999	3.976	3.3399999999999999	2.7040000000000002	2.1951999999999998	1.4538	0.5	1.887	10	74.213997	0.11	0.078	\N	64
10669	1966	81	326.20100000000002	4.5388999999999999	6.4729999999999999	4.3760000000000003	3.6509999999999998	14.620100000000001	10.980499999999999	9.1232000000000006	7.2392000000000003	5.3262	1.9009	0.98619999999999997	0.8569	0.72770000000000001	0.66300000000000003	0.60850000000000004	0.57340000000000002	0.52059999999999995	0.25	0.043000001	20	98.869003	1073.088	536.54399999999998	\N	81
10670	1966	97	42.850999999999999	10.952400000000001	1.0169999999999999	2.121	3.3849999999999998	22.057700000000001	18.708200000000001	17.355899999999998	15.6654	13.975	10.594099999999999	8.7449999999999992	7.3094000000000001	5.9713000000000003	5.3232999999999997	4.6753	4.1569000000000003	3.1295999999999999	0.5	0.043000001	20	87.820999	125.548	72.484999999999999	\N	97
10671	1966	112	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	112
10672	1966	123	1.153	10.398199999999999	1.1279999999999999	1.6379999999999999	2.0009999999999999	17.558800000000002	16.094100000000001	15.117599999999999	13.8971	12.676500000000001	10.235300000000001	9.25	8.4199999999999999	7.5021000000000004	6.9981999999999998	6.4943	5.9957000000000003	5.1146000000000003	4	2.4100001	10	59.035999	0	0	\N	123
10662	1965	67	128.49000000000001	3.5276999999999998	1.6850000000000001	2.2719999999999998	2.6160000000000001	8.6793999999999993	5.4438000000000004	4.0336999999999996	3.5785	3.1488	2.2892999999999999	1.8455999999999999	1.613	1.3803000000000001	1.2639	1.1476	1.0545	0.875	0.5	0.47799999	20	99.174004	50.143999999999998	35.457000000000001	\N	67
10663	1965	72	40.969000000000001	4.101	1.72	2.5110000000000001	3.2879999999999998	9.4547000000000008	6.5552000000000001	5.4301000000000004	4.1771000000000003	3.6417000000000002	2.8073000000000001	1.9908999999999999	1.7112000000000001	1.4315	1.2917000000000001	1.1517999999999999	1.04	0.8538	0.5	0.87	20	97.128998	34.930999999999997	20.167000000000002	\N	72
10664	1965	89	30.353999999999999	7.431	1.2450000000000001	2.1200000000000001	2.5630000000000002	16.388200000000001	12.9975	10.7371	9.0908999999999995	7.9112	6.3410000000000002	5.4936999999999996	4.6658999999999997	3.8639999999999999	3.5165999999999999	3.1692	2.8912	2.4742999999999999	1	0.043000001	20	96.390999	39.249000000000002	22.66	\N	89
10665	1965	102	1.097	11.0585	1.0760000000000001	2.0899999999999999	3.306	21.796900000000001	18.7273	17.5	15.9659	14.431800000000001	11.3636	8.6364000000000001	7	5.7845000000000004	5.2491000000000003	4.7138	4.2854999999999999	3.4375	2	1.4809999	20	88.148003	0	0	\N	102
10666	1965	116	1.2010000000000001	13.6585	0.63500000000000001	1.893	3.4790000000000001	24.317699999999999	20.008299999999998	19.2087	18.216699999999999	17.224799999999998	15.2408	13.2569	11.2729	9.1564999999999994	7.9732000000000003	6.4253	5.5811000000000002	4.3814000000000002	1	0.057999998	20	83.987999	0	0	\N	116
10667	1965	131	0.075999999999999998	6.1965000000000003	2.0230000000000001	3.0510000000000002	2.9609999999999999	16.333300000000001	14.1333	12.666700000000001	10.833299999999999	7.3624999999999998	3.8856999999999999	3.2570999999999999	2.6286	2	1.8281000000000001	1.6563000000000001	1.5186999999999999	1.3125	1	0.90899998	10	72.726997	0	0	\N	131
10657	1964	72	0.59699999999999998	5.9221000000000004	0.92200000000000004	3.0579999999999998	5.3490000000000002	15.0694	12.111000000000001	10.1387	8.2872000000000003	7.1970000000000001	5.5467000000000004	4.125	2.9119000000000002	1.8985000000000001	1.6831	1.4677	1.2954000000000001	1.0368999999999999	0.5	1.758	10	79.719002	0	0	\N	72
10658	1964	81	0.099000000000000005	1.6752	1.046	2.8300000000000001	4.4359999999999999	3.7231000000000001	3.1568999999999998	2.7795000000000001	2.3077000000000001	1.9273	1.5091000000000001	1.0909	0.68659999999999999	0.52729999999999999	0.47549999999999998	0.4304	0.39429999999999998	0.3402	0.5	27.716999	6.2999999999999998	96.195999	0	0	\N	81
10659	1964	98	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	98
10660	1964	110	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	110
10661	1964	127	0.96399999999999997	9.8816000000000006	0.89400000000000002	1.881	3.0830000000000002	17.610399999999998	16.176600000000001	15.220800000000001	14.026	12.831200000000001	10.441599999999999	9.0908999999999995	7.9728000000000003	6.7215999999999996	6.0346000000000002	5.2207999999999997	4.5697000000000001	3.3866999999999998	0.5	0.54299998	10	58.152	0	0	\N	127
34824	10857	39	28.666	6.5114000000000001	1.2330000000000001	2.8860000000000001	4.3899999999999997	15.488799999999999	12.1393	9.9562000000000008	8.6532999999999998	7.3503999999999996	5.2794999999999996	3.7881999999999998	2.9462000000000002	2.1042999999999998	1.8402000000000001	1.6276999999999999	1.4577	1.2028000000000001	0.25	0.016000001	16	90.916	77.888999999999996	44.969000000000001	\N	65
34825	10857	59	298.94499999999999	3.9756	1.0649999999999999	2.4009999999999998	3.6600000000000001	8.7730999999999995	6.5628000000000002	5.7765000000000004	4.9801000000000002	4.1837	3.3656000000000001	2.6486000000000001	1.9670000000000001	1.6218999999999999	1.4494	1.2768999999999999	1.1388	0.91959999999999997	0.25	0.016000001	16	98.265999	393.23500000000001	227.03399999999999	\N	85
34826	10857	79	440.65300000000002	4.1007999999999996	1.26	3.2959999999999998	5.3369999999999997	9.9143000000000008	7.5773000000000001	6.1688000000000001	5.2590000000000003	4.3491999999999997	3.1274000000000002	2.0476999999999999	1.4498	0.95909999999999995	0.86570000000000003	0.7722	0.69750000000000001	0.58599999999999997	0.25	0.057999998	16	96.586998	908.399	524.46400000000006	\N	105
34827	10857	89	131.75899999999999	4.7988999999999997	0.46899999999999997	3.8500000000000001	8.9359999999999999	11.200900000000001	8.8331999999999997	7.7400000000000002	6.3735999999999997	5.7005999999999997	4.4336000000000002	3.3506	2.3633000000000002	1.3339000000000001	0.92259999999999998	0.71109999999999995	0.59589999999999999	0.49609999999999999	0.125	0.0020000001	16	96.915001	208.57300000000001	120.42	\N	115
34828	10857	99	52.853999999999999	7.3281000000000001	0.35899999999999999	3.827	14.128	15.234500000000001	13.162699999999999	11.7814	10.0548	9.1082999999999998	7.2664999999999997	5.7400000000000002	4.5614999999999997	3.2791000000000001	2.5905999999999998	1.821	0.89859999999999995	0.51429999999999998	0.125	0.0040000002	16	92.217003	18.93	10.929	\N	125
34819	10856	35	188.82599999999999	5.4010999999999996	0.94399999999999995	2.069	3.218	9.952	8.7874999999999996	8.0111000000000008	7.0407000000000002	6.1923000000000004	5.2820999999999998	4.3719000000000001	3.6152000000000002	2.9645000000000001	2.6392000000000002	2.3138999999999998	2.0535999999999999	1.6414	0.125	0.0089999996	16	98.754997	605.13699999999994	349.37599999999998	\N	61
34820	10856	55	176.51400000000001	6.5232000000000001	1.0620000000000001	3.347	6.5110000000000001	15.2439	12.869	11.2858	9.5300999999999991	8.1888000000000005	5.6443000000000003	3.7307999999999999	2.6867999999999999	1.8329	1.5886	1.3444	1.149	0.86680000000000001	0.125	0.0070000002	16	91.910004	207.43199999999999	119.761	\N	81
34821	10856	75	225.06700000000001	5.6205999999999996	0.70799999999999996	3.004	6.383	13.0304	9.6586999999999996	8.6262000000000008	7.3353999999999999	6.1806999999999999	4.9740000000000002	3.8228	2.9041999999999999	1.9897	1.6615	1.3331999999999999	1.0706	0.77929999999999999	0.125	0.0049999999	16	94.584	375.65600000000001	216.88499999999999	\N	101
34822	10856	95	49.372999999999998	6.5938999999999997	0.32900000000000001	4.1050000000000004	11.564	14.484500000000001	11.997400000000001	10.339399999999999	9.1959999999999997	8.2347000000000001	6.3118999999999996	5.0948000000000002	3.875	2.5882999999999998	1.9233	1.0264	0.71179999999999999	0.54579999999999995	0.125	0.0089999996	16	93.655998	46.607999999999997	26.908999999999999	\N	121
34823	10856	115	34.094999999999999	6.2527999999999997	0.184	5.0919999999999996	18.407	13.818099999999999	11.786	10.4312	9.3912999999999993	8.5745000000000005	6.9410999999999996	5.3993000000000002	3.8822999999999999	1.6936	0.61199999999999999	0.50990000000000002	0.4546	0.37709999999999999	0.125	0.014	16	96.442001	11.833	6.8319999999999999	\N	141
34736	10835	39	30.076000000000001	2.9426000000000001	1.546	2.7080000000000002	3.1459999999999999	7.4520999999999997	5.6258999999999997	4.7489999999999997	3.8226	3.2625999999999999	2.1423999999999999	1.6711	1.2943	0.96850000000000003	0.89659999999999995	0.82469999999999999	0.76719999999999999	0.68089999999999995	0.125	0.0049999999	10	96.469002	70.774000000000001	40.860999999999997	\N	65
34737	10835	49	9.4440000000000008	2.3330000000000002	1.8959999999999999	2.7480000000000002	3.028	6.3840000000000003	4.3887	3.4817999999999998	2.5617000000000001	1.9254	1.5426	1.1597999999999999	0.9163	0.77249999999999996	0.7006	0.629	0.58120000000000005	0.50949999999999995	0.125	0.015	10	97.541	19.768000000000001	11.413	\N	75
34738	10835	79	78.656999999999996	1.8447	2.1629999999999998	2.5449999999999999	2.722	4.3643999999999998	3.4605999999999999	3.0108000000000001	2.4485999999999999	1.9371	1.3152999999999999	0.92449999999999999	0.77139999999999997	0.625	0.59260000000000002	0.56020000000000003	0.5343	0.48309999999999997	0.125	0.0049999999	10	99.290001	50.026000000000003	28.882999999999999	\N	105
34739	10835	89	66.320999999999998	1.9713000000000001	3.0990000000000002	2.7999999999999998	2.4239999999999999	5.3646000000000003	3.8565999999999998	3.2997000000000001	2.6036000000000001	1.9274	0.97130000000000005	0.78239999999999998	0.62009999999999998	0.56889999999999996	0.54330000000000001	0.51770000000000005	0.4919	0.40060000000000001	0.125	0.003	10	98.568001	173.96799999999999	100.44	\N	115
34740	10835	99	59.412999999999997	1.673	3.8820000000000001	3.1360000000000001	1.9650000000000001	4.9690000000000003	3.5253000000000001	2.8115000000000001	1.9187000000000001	1.0210999999999999	0.62329999999999997	0.57040000000000002	0.51749999999999996	0.45419999999999999	0.41999999999999998	0.38579999999999998	0.3584	0.31730000000000003	0.125	0.0080000004	10	98.813004	57.244999999999997	33.049999999999997	\N	125
23980	7264	24	130.964	2.2414000000000001	1.0760000000000001	2.4140000000000001	3.1819999999999999	5.0354999999999999	3.7361	3.3632	2.8969999999999998	2.4308999999999998	1.8223	1.4918	1.1613	0.90390000000000004	0.81010000000000004	0.71619999999999995	0.64119999999999999	0.57269999999999999	0.25	0.028000001	10	99.171997	0	0	\N	74
23979	7264	38	108.31100000000001	2.0085000000000002	2.871	2.8599999999999999	2.5019999999999998	5.8531000000000004	3.3039999999999998	2.1023000000000001	1.6203000000000001	1.2129000000000001	0.86480000000000001	0.68179999999999996	0.58620000000000005	0.52500000000000002	0.49120000000000003	0.44269999999999998	0.40389999999999998	0.34570000000000001	0.125	0.015	10	94.539001	0	0	\N	88
23978	7264	48	137.38200000000001	1.4942	1.9450000000000001	2.0800000000000001	1.964	3.4586999999999999	1.7352000000000001	1.3142	0.96160000000000001	0.86619999999999997	0.67559999999999998	0.59840000000000004	0.55679999999999996	0.51519999999999999	0.48720000000000002	0.43940000000000001	0.4012	0.34389999999999998	0.063	0.017999999	10	96.697998	0	0	\N	98
23977	7264	59	141.64400000000001	1.1014999999999999	1.4470000000000001	1.806	2.0209999999999999	1.9160999999999999	1.6894	1.5383	1.3494999999999999	1.1606000000000001	0.91879999999999995	0.77769999999999995	0.63649999999999995	0.58460000000000001	0.56079999999999997	0.53710000000000002	0.51800000000000002	0.45450000000000002	0.125	0.024	6.2999999999999998	99.426003	0	0	\N	109
23976	7264	71	0.081000000000000003	6.5491999999999999	0.25600000000000001	5.2409999999999997	23.190000000000001	14.4659	13.545500000000001	12.931800000000001	12.1648	11.3977	9.2599999999999998	5.1089000000000002	2.5	1.1875	0.8216	0.5867	0.49309999999999998	0.39929999999999999	0.25	0.44400001	10	60.889	0	0	\N	121
23975	7263	27	1.9299999999999999	0.79390000000000005	1.012	1.5489999999999999	1.8480000000000001	0.96650000000000003	0.83999999999999997	0.75560000000000005	0.6502	0.61470000000000002	0.57679999999999998	0.53900000000000003	0.50119999999999998	0.43869999999999998	0.40710000000000002	0.37540000000000001	0.35010000000000002	0.31219999999999998	0.063	0.0040000002	6.2999999999999998	97.971001	0	0	\N	77
23974	7263	37	116.233	1.0025999999999999	1.647	2.0609999999999999	1.9970000000000001	2.0771000000000002	1.4838	1.1258999999999999	0.92400000000000004	0.81820000000000004	0.62319999999999998	0.56100000000000005	0.49890000000000001	0.43669999999999998	0.40550000000000003	0.37440000000000001	0.34949999999999998	0.31209999999999999	0.063	0.003	6.2999999999999998	99.185997	0	0	\N	87
23973	7263	47	64.061000000000007	0.77459999999999996	1.0489999999999999	1.615	2.028	1.387	0.98129999999999995	0.9284	0.86219999999999997	0.79590000000000005	0.66349999999999998	0.59299999999999997	0.54359999999999997	0.49020000000000002	0.44950000000000001	0.40870000000000001	0.37609999999999999	0.32719999999999999	0.063	0.0070000002	6.2999999999999998	99.818001	0	0	\N	97
23972	7263	57	9.8089999999999993	0.85009999999999997	1.123	1.6759999999999999	2.1669999999999998	1.5806	1.2822	1.0832999999999999	0.96740000000000004	0.91830000000000001	0.82010000000000005	0.72189999999999999	0.62609999999999999	0.56510000000000005	0.53449999999999998	0.504	0.45650000000000002	0.3785	0.063	0.0040000002	4	99.924004	0	0	\N	107
23971	7263	67	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	117
23495	6823	24	4.0549999999999997	2.9874000000000001	1.087	2.4740000000000002	4.2789999999999999	6.1308999999999996	5.0701999999999998	4.3632	3.7810999999999999	3.4094000000000002	2.6661999999999999	1.9655	1.6327	1.2999000000000001	1.1335	0.96599999999999997	0.82809999999999995	0.62309999999999999	0.063	0.0099999998	10	96.133003	0	0	\N	64
23494	6823	33	1.9079999999999999	0.79010000000000002	1.238	1.7	1.881	1.5723	0.94889999999999997	0.84430000000000005	0.71340000000000003	0.61939999999999995	0.56059999999999999	0.50180000000000002	0.45069999999999999	0.39979999999999999	0.37430000000000002	0.34889999999999999	0.32850000000000001	0.29799999999999999	0.063	0.024	4	97.707001	0	0	\N	73
23493	6823	46	10.880000000000001	0.97950000000000004	1.4590000000000001	1.734	2.0209999999999999	1.8199000000000001	1.5224	1.3240000000000001	1.0760000000000001	0.95960000000000001	0.84319999999999995	0.7268	0.62190000000000001	0.57369999999999999	0.54949999999999999	0.52539999999999998	0.50609999999999999	0.4173	0.063	0.016000001	4	99.054001	0	0	\N	86
23492	6823	57	10.442	1.0724	1.282	1.7090000000000001	1.792	1.8553999999999999	1.6482000000000001	1.51	1.3372999999999999	1.1646000000000001	0.94910000000000005	0.8518	0.75460000000000005	0.6573	0.61719999999999997	0.58799999999999997	0.56459999999999999	0.52949999999999997	0.063	0.0080000004	4	99.556	0	0	\N	97
23491	6823	69	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	109
23490	6822	22	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	62
23489	6822	35	13.785	2.1404000000000001	1.8600000000000001	2.3700000000000001	2.5840000000000001	5.0438000000000001	3.2141000000000002	2.3849	1.8866000000000001	1.7060999999999999	1.3452	0.99419999999999997	0.86050000000000004	0.72689999999999999	0.66010000000000002	0.60640000000000005	0.57210000000000005	0.52059999999999995	0.063	0.0020000001	10	94.913002	0	0	\N	75
23488	6822	49	31.088999999999999	1.3363	1.383	2.012	2.4660000000000002	3.0335000000000001	1.9728000000000001	1.7969999999999999	1.5771999999999999	1.3574999999999999	0.9738	0.83350000000000002	0.69330000000000003	0.5917	0.55689999999999995	0.52210000000000001	0.48720000000000002	0.39479999999999998	0.063	0.0099999998	6.2999999999999998	98.517998	0	0	\N	89
23487	6822	63	9.1780000000000008	1.6271	0.95299999999999996	1.835	2.5430000000000001	3.2334999999999998	2.2090999999999998	1.9350000000000001	1.8180000000000001	1.7010000000000001	1.4669000000000001	1.2327999999999999	0.99919999999999998	0.85609999999999997	0.78459999999999996	0.71299999999999997	0.65580000000000005	0.57689999999999997	0.063	0.013	6.2999999999999998	97.732002	0	0	\N	103
23486	6822	77	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	117
23470	6802	60	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	60
23469	6802	81	64.262	7.6219999999999999	1.0229999999999999	2.246	3.4780000000000002	15.136699999999999	12.9762	11.5359	9.8588000000000005	8.8978000000000002	6.9757999999999996	5.7122000000000002	4.8056000000000001	3.8948999999999998	3.4226000000000001	2.9504000000000001	2.5724999999999998	2.0057999999999998	0.125	0.003	16	92.398003	0	0	\N	81
23468	6802	105	32.911999999999999	20.0533	0.65000000000000002	1.8169999999999999	4.4710000000000001	30.723600000000001	29.094000000000001	28.0077	26.649699999999999	25.291799999999999	22.575900000000001	19.860099999999999	17.144200000000001	14.058199999999999	12.3804	10.7026	8.8168000000000006	5.0499000000000001	0.125	0.003	31.5	92.859001	0	0	\N	105
23467	6802	128	28.744	5.9226000000000001	0.495	4.3940000000000001	10.491	14.5983	11.613	9.7743000000000002	8.2857000000000003	6.7972000000000001	5.1258999999999997	3.7547999999999999	2.5365000000000002	1.5043	1.0613999999999999	0.76390000000000002	0.60140000000000005	0.48859999999999998	0.063	0.0040000002	16	92.817001	0	0	\N	128
23466	6802	151	0.071999999999999995	3.4258000000000002	0.96599999999999997	3.2490000000000001	7.0439999999999996	8.2651000000000003	7.2241999999999997	6.5301999999999998	5.5572999999999997	4.5461999999999998	3.2667000000000002	2.2618999999999998	1.7214	1.3446	1.1561999999999999	0.94450000000000001	0.68430000000000002	0.4637	0.063	0.094999999	6.2999999999999998	78.672997	0	0	\N	151
23465	6801	22	14.273	3.0175000000000001	1.1850000000000001	2.8839999999999999	3.9129999999999998	6.2080000000000002	4.8369	3.9674999999999998	3.4857999999999998	3.0041000000000002	2.0407000000000002	1.5407	1.0610999999999999	0.81920000000000004	0.71550000000000002	0.62129999999999996	0.58140000000000003	0.52159999999999995	0.063	0.0020000001	16	97.438004	0	0	\N	62
23464	6801	32	18.422999999999998	1.1215999999999999	1.8620000000000001	2.1680000000000001	2.1899999999999999	2.6936	1.7765	1.4804999999999999	1.1105	0.92779999999999996	0.72189999999999999	0.60040000000000004	0.54690000000000005	0.49020000000000002	0.4501	0.40989999999999999	0.37780000000000002	0.32969999999999999	0.063	0.003	6.2999999999999998	98.853996	0	0	\N	72
23463	6801	43	18.872	1.0185	1.673	2.0499999999999998	2.1419999999999999	2.2071999999999998	1.5913999999999999	1.2761	0.97340000000000004	0.88470000000000004	0.70709999999999995	0.60029999999999994	0.54779999999999995	0.49270000000000003	0.45200000000000001	0.41139999999999999	0.37890000000000001	0.3301	0.063	0.003	6.2999999999999998	99.488998	0	0	\N	83
23462	6801	56	4.9630000000000001	0.64000000000000001	1.054	1.5920000000000001	1.879	0.97050000000000003	0.85699999999999998	0.78129999999999999	0.68669999999999998	0.62039999999999995	0.57240000000000002	0.52439999999999998	0.47249999999999998	0.41649999999999998	0.3886	0.36059999999999998	0.33829999999999999	0.30470000000000003	0.063	0.0040000002	4	99.522003	0	0	\N	96
23461	6801	68	1.514	2.2578	4.8040000000000003	3.8889999999999998	3.0449999999999999	6.835	5.2377000000000002	4.3455000000000004	3.2267000000000001	2.1061999999999999	0.93259999999999998	0.61450000000000005	0.51080000000000003	0.44009999999999999	0.40660000000000002	0.37309999999999999	0.34639999999999999	0.30620000000000003	0.063	0.023	10	97.318001	0	0	\N	108
23445	6781	27	0.091999999999999998	6.3376000000000001	0.623	2.4929999999999999	5.2480000000000002	13.0214	11.234299999999999	10.042899999999999	9.3249999999999993	8.6300000000000008	7.2400000000000002	5.7085999999999997	3.9409999999999998	3.0295000000000001	2.5737999999999999	2.1179999999999999	1.8071999999999999	1.3794999999999999	0.063	0.071999997	10	79.856003	0	0	\N	67
23444	6781	44	31.317	9.9979999999999993	0.80700000000000005	2.0169999999999999	3.5600000000000001	19.6736	15.381600000000001	14.5267	13.4581	12.3895	10.2523	8.4888999999999992	6.7755999999999998	5.4596999999999998	4.8780999999999999	4.2965999999999998	3.782	2.8801000000000001	0.125	0.001	16	86.893997	0	0	\N	84
23443	6781	62	36.523000000000003	5.2725	2.3519999999999999	5.218	8.0739999999999998	15.9206	12.060700000000001	9.5876000000000001	6.9996999999999998	5.3074000000000003	2.9889000000000001	1.5073000000000001	0.80969999999999998	0.58260000000000001	0.53820000000000001	0.49149999999999999	0.443	0.37019999999999997	0.063	0.0020000001	16	90.123001	0	0	\N	102
23442	6781	78	27.706	6.3902999999999999	2.6899999999999999	4.6580000000000004	5.8609999999999998	20.815300000000001	15.0634	12.554399999999999	9.3903999999999996	6.1871999999999998	3.3782000000000001	1.9718	1.5236000000000001	1.0752999999999999	0.91759999999999997	0.79349999999999998	0.69430000000000003	0.57640000000000002	0.063	0.0020000001	16	85.492996	0	0	\N	118
23441	6781	96	8.1270000000000007	2.3654999999999999	4.7110000000000003	3.5	2.1120000000000001	6.9443999999999999	4.0660999999999996	2.8746	1.7008000000000001	0.98960000000000004	0.63070000000000004	0.5353	0.46510000000000001	0.40960000000000002	0.38190000000000002	0.35410000000000003	0.33189999999999997	0.29859999999999998	0.063	0.0080000004	16	97.528	0	0	\N	136
23425	6761	27	36.893000000000001	3.512	3.5739999999999998	3.5510000000000002	3.5859999999999999	10.6845	6.4474	5.1163999999999996	3.6833	2.5785999999999998	1.5097	0.96050000000000002	0.79069999999999996	0.62560000000000004	0.58479999999999999	0.54400000000000004	0.51139999999999997	0.42099999999999999	0.125	0.001	16	95.609001	0	0	\N	67
23424	6761	36	33.848999999999997	2.4087999999999998	2.423	2.9889999999999999	3.4860000000000002	6.5190000000000001	4.4800000000000004	3.5775999999999999	2.7326999999999999	1.9639	1.4200999999999999	0.96279999999999999	0.79910000000000003	0.63549999999999995	0.58609999999999995	0.53900000000000003	0.50129999999999997	0.40739999999999998	0.125	0.0020000001	10	94.933998	0	0	\N	76
23423	6761	46	29.457000000000001	2.0728	1.5229999999999999	2.3570000000000002	2.8159999999999998	4.6140999999999996	3.2662	2.6229	1.9621999999999999	1.7943	1.4584999999999999	1.1227	0.91210000000000002	0.77359999999999995	0.70440000000000003	0.63519999999999999	0.58779999999999999	0.51790000000000003	0.063	0.0020000001	10	96.498001	0	0	\N	86
23422	6761	60	21.065999999999999	3.2671999999999999	1.2609999999999999	2.3410000000000002	2.8980000000000001	8.1183999999999994	3.4510999999999998	2.7837000000000001	1.9918	1.8559000000000001	1.5841000000000001	1.3123	1.0405	0.8599	0.77759999999999996	0.69520000000000004	0.62949999999999995	0.54659999999999997	0.063	0.0080000004	16	93.786003	0	0	\N	100
23421	6761	72	0.39700000000000002	15.9452	0.081000000000000003	5.3109999999999999	33.116	28.7956	27.172899999999998	26.091100000000001	24.738900000000001	23.386700000000001	20.682200000000002	17.977799999999998	14.279999999999999	8.6781000000000006	6.6836000000000002	3.0491999999999999	0.96340000000000003	0.62450000000000006	0.125	0.02	16	42.687	0	0	\N	112
13026	1959	77	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	77
13027	1959	92	2.5489999999999999	0.50990000000000002	0.91400000000000003	1.389	1.724	0.62849999999999995	0.60160000000000002	0.5837	0.56130000000000002	0.53890000000000005	0.49459999999999998	0.45300000000000001	0.41149999999999998	0.37	0.34920000000000001	0.32850000000000001	0.31190000000000001	0.28689999999999999	0.125	0.0070000002	4	99.597	0.88300000000000001	0.51000000000000001	\N	92
13028	1959	107	5.8470000000000004	0.43359999999999999	0.93400000000000005	1.3	1.5409999999999999	0.56530000000000002	0.49690000000000001	0.4849	0.46999999999999997	0.4551	0.42520000000000002	0.39539999999999997	0.36549999999999999	0.3357	0.32079999999999997	0.30580000000000002	0.29389999999999999	0.27600000000000002	0.125	0.0049999999	4	99.961998	1.6759999999999999	0.96699999999999997	\N	107
13029	1959	123	5.1319999999999997	0.5121	0.996	1.3580000000000001	1.5660000000000001	0.65529999999999999	0.54630000000000001	0.49730000000000002	0.48159999999999997	0.46589999999999998	0.4345	0.40310000000000001	0.37159999999999999	0.3402	0.32450000000000001	0.30880000000000002	0.29630000000000001	0.27739999999999998	0.125	0.0099999998	4	99.709	1.8979999999999999	1.0960000000000001	\N	123
13030	1959	137	0.20799999999999999	0.43809999999999999	0.92700000000000005	1.3180000000000001	1.5800000000000001	0.55400000000000005	0.48849999999999999	0.4763	0.46100000000000002	0.44579999999999997	0.4153	0.38479999999999998	0.3543	0.32379999999999998	0.3085	0.29330000000000001	0.28110000000000002	0.26279999999999998	0.125	0.204	2	99.490997	0.29499999999999998	0.20799999999999999	\N	137
13021	1958	83	0.32300000000000001	2.6434000000000002	1.585	2.903	3.5680000000000001	7.0391000000000004	5.5853999999999999	4.7695999999999996	3.8210999999999999	3.0920000000000001	1.9053	1.5282	1.151	0.89890000000000003	0.81459999999999999	0.73029999999999995	0.66290000000000004	0.53400000000000003	0.125	0.029999999	6.2999999999999998	87.503998	0.45700000000000002	0.32300000000000001	\N	83
13022	1958	97	16.423999999999999	4.7542	1.526	2.601	3.3290000000000002	11.9392	8.2140000000000004	6.2811000000000003	5.4896000000000003	4.6980000000000004	3.4824000000000002	2.5567000000000002	1.8880999999999999	1.6074999999999999	1.4671000000000001	1.3268	1.2145999999999999	1.0462	0.125	0.0040000002	16	94.982002	28.523	16.468	\N	97
13023	1958	119	9.8330000000000002	1.3964000000000001	1.1319999999999999	1.5640000000000001	1.764	1.2079	0.7742	0.62629999999999997	0.59770000000000001	0.56910000000000005	0.51180000000000003	0.46529999999999999	0.42149999999999999	0.37769999999999998	0.35580000000000001	0.33389999999999997	0.31640000000000001	0.29010000000000002	0.125	0.02	16	97.200996	3.7749999999999999	2.1789999999999998	\N	119
13024	1958	136	3.3610000000000002	1.849	5.1929999999999996	3.4119999999999999	1.8520000000000001	6.5170000000000003	3.641	1.5586	0.83740000000000003	0.621	0.52849999999999997	0.46829999999999999	0.42259999999999998	0.37680000000000002	0.35399999999999998	0.33110000000000001	0.31280000000000002	0.28539999999999999	0.125	0.037999999	10	94.738998	2.9140000000000001	1.6830000000000001	\N	136
13025	1958	154	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	154
12887	1957	73	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	73
12888	1957	85	3.944	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	3.593	2.0739999999999998	\N	85
12889	1957	100	21.167000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	13.238	7.6429999999999998	\N	100
12890	1957	117	1.4930000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	117
12891	1957	131	0.45100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	131
12882	1956	71	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	71
12883	1956	86	13.055999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	21.117999999999999	12.193	\N	86
12884	1956	101	15.954000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	12.326000000000001	7.1159999999999997	\N	101
12885	1956	115	13.117000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	22.026	12.717000000000001	\N	115
12886	1956	131	13.323	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	38.902000000000001	22.460000000000001	\N	131
10652	1954	75	0.014	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	75
10653	1954	93	6.9320000000000004	13.7403	0.85399999999999998	2.0489999999999999	3.4590000000000001	26.538799999999998	23.562100000000001	21.5776	19.097000000000001	16.616399999999999	14.337400000000001	12.4389	10.5405	8.5564999999999998	7.5475000000000003	6.5385999999999997	5.6112000000000002	4.1444999999999999	1	0.36199999	16	68.758003	4.9569999999999999	3.5049999999999999	\N	93
10654	1954	113	419.846	6.5446	1.0489999999999999	3.1600000000000001	5.7800000000000002	14.813700000000001	12.8431	11.529400000000001	9.9099000000000004	8.5968	6.0374999999999996	3.9674999999999998	2.7581000000000002	1.8498000000000001	1.6484000000000001	1.4471000000000001	1.2861	1.0445	0.5	0.23899999	16	93.612	938.75400000000002	541.99000000000001	\N	113
10655	1954	133	2.6880000000000002	12.488099999999999	0.47799999999999998	3.5190000000000001	10.099	27.182099999999998	24.5914	22.8643	20.705400000000001	18.546399999999998	14.2857	10.107100000000001	7.1879999999999997	4.8886000000000003	3.8649	2.8108	1.9854000000000001	1.4146000000000001	0.5	3.5899999	16	64.102997	2.5830000000000002	1.4910000000000001	\N	133
10656	1954	153	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	153
10647	1953	85	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	85
10648	1953	100	3.2029999999999998	14.647500000000001	0.98899999999999999	1.7929999999999999	2.4780000000000002	26.626300000000001	23.702100000000002	21.752600000000001	19.3157	16.878900000000002	14.7805	13.2927	11.8049	10.3171	9.3651999999999997	8.2588000000000008	7.3737000000000004	5.9645999999999999	2	0.98400003	16	68.196999	0.92100000000000004	0.65100000000000002	\N	100
10649	1953	114	137.28100000000001	8.2331000000000003	1.2769999999999999	3.3100000000000001	5.4050000000000002	22.485800000000001	17.077200000000001	14.608499999999999	12.1282	9.7803000000000004	6.6859999999999999	4.5664999999999996	3.3767999999999998	2.5041000000000002	2.0676999999999999	1.7734000000000001	1.5588	1.2370000000000001	0.25	0.034000002	16	82.805	74.051000000000002	42.753	\N	114
10650	1953	128	18.792000000000002	8.3709000000000007	0.35799999999999998	3.6680000000000001	16.901	18.5593	14.914300000000001	13.8346	12.484999999999999	11.135300000000001	8.8231999999999999	6.7922000000000002	4.7515000000000001	2.9441999999999999	2.1093000000000002	1.5357000000000001	1.1083000000000001	0.52210000000000001	0.25	0.056000002	16	88.022003	13.189	7.6150000000000002	\N	128
10651	1953	144	15.278	1.2287999999999999	1.3839999999999999	1.768	1.907	1.9575	1.6457999999999999	1.4379	1.1780999999999999	0.98480000000000001	0.88800000000000001	0.7913	0.69450000000000001	0.61009999999999998	0.58020000000000005	0.55030000000000001	0.52649999999999997	0.4657	0.25	0.126	10	99.119003	5.7770000000000001	3.335	\N	144
10798	2058	58	0.028000000000000001	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	58
10799	2058	68	32.368000000000002	2.3081999999999998	1.294	1.698	1.7929999999999999	3.7926000000000002	3.3469000000000002	3.0497999999999998	2.6783999999999999	2.3071000000000002	1.9013	1.7332000000000001	1.5649999999999999	1.3968	1.3127	1.2285999999999999	1.1613	1.0604	0.63	0.1	10	98.398003	43.387	25.048999999999999	\N	68
10800	2058	72	1.347	2.9914999999999998	0.76100000000000001	2.2869999999999999	4.0990000000000002	5.7752999999999997	4.9429999999999996	4.3880999999999997	3.8767999999999998	3.5971000000000002	3.0377000000000001	2.4782999999999999	1.9391	1.5196000000000001	1.3098000000000001	1.1000000000000001	0.94499999999999995	0.74099999999999999	0.5	2.5910001	10	98.445999	0	0	\N	72
10801	2058	78	13.375	3.0756999999999999	0.90900000000000003	2.4039999999999999	4.1210000000000004	6.1288	5.0922000000000001	4.4012000000000002	3.8279999999999998	3.5068000000000001	2.8643000000000001	2.2219000000000002	1.7551000000000001	1.3809	1.1938	1.0066999999999999	0.88139999999999996	0.69499999999999995	0.25	0.1	10	96.997002	17.463000000000001	10.083	\N	78
10802	2058	82	0.53600000000000003	0.95179999999999998	1.2549999999999999	1.6870000000000001	2.0600000000000001	1.7737000000000001	1.4483999999999999	1.2316	0.99339999999999995	0.94799999999999995	0.85729999999999995	0.76649999999999996	0.67579999999999996	0.59840000000000004	0.5665	0.53469999999999995	0.50919999999999999	0.41610000000000003	0.25	0.97100002	2	94.175003	0.75900000000000001	0.53600000000000003	\N	82
10803	2058	88	43.337000000000003	3.2418999999999998	1.73	2.472	2.5350000000000001	8.0467999999999993	5.7291999999999996	4.6848000000000001	3.7301000000000002	3.1625000000000001	2.0272999999999999	1.7622	1.5185	1.2748999999999999	1.153	1.0311999999999999	0.93759999999999999	0.79979999999999996	0.5	0.50099999	10	94.595001	74.753	43.158999999999999	\N	88
10804	2058	92	1.403	1.8365	1.077	1.9099999999999999	2.4169999999999998	3.3900000000000001	2.7839999999999998	2.3799999999999999	1.9719	1.8584000000000001	1.6315	1.4045000000000001	1.1775	0.96809999999999996	0.89480000000000004	0.82150000000000001	0.76290000000000002	0.67500000000000004	0.5	1.98	10	99.010002	0	0	\N	92
10805	2058	102	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	102
10806	2058	118	45.662999999999997	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	71.094999999999999	41.046999999999997	\N	118
10807	2058	128	0.97199999999999998	2.5243000000000002	1.153	2.8889999999999998	4.3970000000000002	5.7268999999999997	4.5781000000000001	3.9161999999999999	3.4893000000000001	3.0623999999999998	2.2084999999999999	1.4757	0.93000000000000005	0.70730000000000004	0.61819999999999997	0.57950000000000002	0.54859999999999998	0.50219999999999998	0.25	0.40000001	10	97.697998	0	0	\N	128
10808	2058	132	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	132
10809	2058	142	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	142
10786	2057	58	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	58
10787	2057	65	3.1509999999999998	3.7877999999999998	0.88300000000000001	1.883	2.8500000000000001	6.4922000000000004	5.7834000000000003	5.3952	4.9099000000000004	4.4245999999999999	3.7366000000000001	3.2683	2.7999999999999998	2.3317000000000001	2.0975999999999999	1.8444	1.6311	1.3110999999999999	0.5	0.52100003	10	97.917	2.6440000000000001	1.8700000000000001	\N	65
10788	2057	72	0.028000000000000001	1.6068	0.90300000000000002	2.294	3.3079999999999998	3.3399999999999999	2.944	2.6800000000000002	2.3500000000000001	2.02	1.6799999999999999	1.3500000000000001	1.02	0.77059999999999995	0.64849999999999997	0.59360000000000002	0.55930000000000002	0.50780000000000003	0.5	9.0909996	2	69.696999	0	0	\N	72
10789	2057	75	1.7150000000000001	1.9750000000000001	1.0740000000000001	1.7889999999999999	2.2080000000000002	3.7681	2.4927999999999999	1.9652000000000001	1.8617999999999999	1.7584	1.5516000000000001	1.3447	1.1378999999999999	0.95750000000000002	0.89380000000000004	0.83009999999999995	0.77910000000000001	0.7026	0.5	0.801	10	98.398003	1.008	0.71299999999999997	\N	75
10790	2057	79	0.13900000000000001	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	79
10791	2057	85	32.030999999999999	2.2772000000000001	1.1859999999999999	2.0680000000000001	2.5150000000000001	4.3201999999999998	3.4348999999999998	3.0074999999999998	2.4733000000000001	1.9867999999999999	1.7561	1.5254000000000001	1.2947	1.0640000000000001	0.96099999999999997	0.87339999999999995	0.80330000000000001	0.69820000000000004	0.5	1.702	10	97.898003	37.579999999999998	21.696999999999999	\N	85
10792	2057	89	42.451999999999998	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	116.51900000000001	67.272000000000006	\N	89
10793	2057	99	7.7709999999999999	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	10.99	7.7709999999999999	\N	99
10794	2057	115	13.118	3.0084	0.629	2.6219999999999999	5.0359999999999996	5.8552999999999997	5.0198	4.4627999999999997	3.9003000000000001	3.6030000000000002	3.0083000000000002	2.4137	1.819	1.2243999999999999	0.96760000000000002	0.83560000000000001	0.72999999999999998	0.59740000000000004	0.25	0.2	10	97.097	20.044	11.573	\N	115
10795	2057	125	7.0970000000000004	3.1133000000000002	4.0650000000000004	4.2539999999999996	7.8230000000000004	8.3902000000000001	6.6680999999999999	5.8331	4.9569000000000001	4.0807000000000002	2.5242	0.77759999999999996	0.56540000000000001	0.47549999999999998	0.43730000000000002	0.39910000000000001	0.36849999999999999	0.32269999999999999	0.25	0.49000001	10	94.808998	8.1590000000000007	4.7110000000000003	\N	125
10796	2057	129	0.035000000000000003	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	129
10797	2057	140	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	140
10778	2056	60	0.95799999999999996	4.3640999999999996	1.2589999999999999	2.2240000000000002	2.7109999999999999	11.4125	7.0324999999999998	5.8612000000000002	4.6458000000000004	3.8761999999999999	3.3477000000000001	2.8191999999999999	2.2907999999999999	1.8594999999999999	1.7034	1.5472999999999999	1.4224000000000001	1.2350000000000001	0.5	0.146	10	88.355003	0	0	\N	60
10779	2056	66	6.3799999999999999	2.5386000000000002	1.0600000000000001	2.1379999999999999	3.2309999999999999	5.2904999999999998	3.9845999999999999	3.6907999999999999	3.3235000000000001	2.9563000000000001	2.2216999999999998	1.8103	1.5386	1.2668999999999999	1.131	0.99450000000000005	0.87180000000000002	0.68769999999999998	0.25	0.037	10	98.880997	3.351	2.3700000000000001	\N	66
10780	2056	74	57.904000000000003	2.8220000000000001	1.3440000000000001	2.5230000000000001	3.0699999999999998	6.5297000000000001	4.9957000000000003	4.0281000000000002	3.5192000000000001	3.0270000000000001	2.0426000000000002	1.7076	1.4020999999999999	1.0965	0.96340000000000003	0.86399999999999999	0.78449999999999998	0.66520000000000001	0.25	0.02	10	97.197998	49.110999999999997	28.353999999999999	\N	74
10781	2056	84	23.302	3.7235	1.194	2.214	2.9969999999999999	8.1355000000000004	5.8795000000000002	5.0732999999999997	4.0655999999999999	3.7025000000000001	3.0661999999999998	2.4298999999999999	1.9047000000000001	1.6109	1.464	1.3170999999999999	1.1995	1.0232000000000001	0.5	0.2	10	92.892998	31.599	22.344000000000001	\N	84
10782	2056	92	17.228999999999999	1.7407999999999999	1.2050000000000001	1.8939999999999999	2.319	3.4474	2.5249999999999999	1.9850000000000001	1.8566	1.7281	1.4713000000000001	1.2143999999999999	0.98089999999999999	0.86539999999999995	0.80759999999999998	0.74980000000000002	0.7036	0.63429999999999997	0.25	0.02	10	99.198997	57.771000000000001	33.353999999999999	\N	92
10783	2056	108	8.6039999999999992	1.3210999999999999	1.4119999999999999	1.8460000000000001	1.8879999999999999	3.6368	1.2204999999999999	0.92649999999999999	0.81100000000000005	0.69540000000000002	0.59930000000000005	0.55640000000000001	0.51359999999999995	0.45350000000000001	0.4194	0.38540000000000002	0.35820000000000002	0.31740000000000002	0.25	0.1	10	98.598999	9.109	5.2590000000000003	\N	108
10784	2056	119	11.785	2.3405	6.2450000000000001	3.7879999999999998	2.0169999999999999	7.3719000000000001	5.6224999999999996	4.5776000000000003	2.9676	1.0827	0.68259999999999998	0.59389999999999998	0.55089999999999995	0.50790000000000002	0.47189999999999999	0.4274	0.39179999999999998	0.33850000000000002	0.25	0.050000001	10	96.498001	8.0649999999999995	4.6559999999999997	\N	119
10785	2056	134	0.051999999999999998	3.1661999999999999	0.30099999999999999	3.5910000000000002	9.7330000000000005	6.1849999999999996	5.6383000000000001	5.2737999999999996	4.8182999999999998	4.3627000000000002	3.5724	2.8620999999999999	2.1516999999999999	0.74099999999999999	0.56089999999999995	0.48409999999999997	0.43730000000000002	0.36699999999999999	0.5	21.358999	8	91.262001	0	0	\N	134
10769	2055	62	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	62
10770	2055	68	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	68
10771	2055	74	35.415999999999997	4.8341000000000003	1.119	2.367	3.246	11.6259	7.492	6.1851000000000003	5.2948000000000004	4.4046000000000003	3.5602	2.9910999999999999	2.4220000000000002	1.8966000000000001	1.6967000000000001	1.4967999999999999	1.3368	1.0969	0.25	0.0089999996	20	96.737999	48.759999999999998	34.478999999999999	\N	74
10772	2055	90	32.722999999999999	3.8734000000000002	1.079	2.25	3.3490000000000002	7.7514000000000003	5.4970999999999997	4.6372999999999998	3.8759000000000001	3.5709	2.9611000000000001	2.3512	1.8626	1.5387999999999999	1.3769	1.2150000000000001	1.0854999999999999	0.88419999999999999	0.25	0.0089999996	20	97.869003	50.152000000000001	28.954999999999998	\N	90
10773	2055	99	0.36499999999999999	4.3517999999999999	2.0750000000000002	4.0970000000000004	5.0529999999999999	14.175000000000001	10.68	7.3879999999999999	5.3944000000000001	3.8216999999999999	2.6566999999999998	1.8093999999999999	1.3725000000000001	0.96540000000000004	0.8478	0.73019999999999996	0.63619999999999999	0.52569999999999995	0.5	8.5839996	10	82.833	0.51600000000000001	0.36499999999999999	\N	99
10774	2055	110	136.09899999999999	5.2077999999999998	0.53800000000000003	4.0570000000000004	9.016	13.959199999999999	9.9642999999999997	8.8625000000000007	7.5545	6.3624999999999998	4.7714999999999996	3.3485	2.0672000000000001	1.0270999999999999	0.85129999999999995	0.69430000000000003	0.60529999999999995	0.5292	0.125	0.0040000002	20	98.956001	113.19199999999999	65.352000000000004	\N	110
10775	2055	127	19.228999999999999	5.8715999999999999	0.33500000000000002	4.7770000000000001	13.856	15.4086	11.7271	9.6946999999999992	8.4069000000000003	7.4344999999999999	5.8082000000000003	4.2409999999999997	2.5628000000000002	0.8599	0.6139	0.55830000000000002	0.51380000000000003	0.41920000000000002	0.125	0.0040000002	20	97.483002	12.522	8.8539999999999992	\N	127
10776	2055	134	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	134
10777	2055	141	15.688000000000001	0.44690000000000002	0.96499999999999997	1.345	1.581	0.58299999999999996	0.54620000000000002	0.52170000000000005	0.49519999999999997	0.4788	0.4461	0.4133	0.3805	0.34770000000000001	0.33129999999999998	0.315	0.3019	0.28220000000000001	0.25	0.18000001	8	99.739998	29.556000000000001	17.064	\N	141
34844	10861	39	27.280000000000001	6.1692999999999998	0.93000000000000005	1.6379999999999999	2.3109999999999999	9.5449999999999999	8.8559000000000001	8.3964999999999996	7.8223000000000003	7.2481	6.1970000000000001	5.6067	5.0164	4.4260000000000002	4.1307999999999998	3.7130000000000001	3.3005	2.6818	0.125	0.0040000002	16	98.878998	37.149000000000001	21.448	\N	47
34845	10861	59	3.593	3.2637999999999998	0.91400000000000003	1.865	2.6640000000000001	5.9782999999999999	4.7812000000000001	3.9963000000000002	3.7770000000000001	3.5577000000000001	3.1190000000000002	2.6804000000000001	2.2418	1.8480000000000001	1.6787000000000001	1.5094000000000001	1.3740000000000001	1.1708000000000001	0.25	0.032000002	10	97.021004	2.8879999999999999	1.6679999999999999	\N	67
34846	10861	79	78.353999999999999	3.3367	1.107	2.5539999999999998	4.1799999999999997	7.1101999999999999	5.2363	4.3402000000000003	3.7423999999999999	3.3723000000000001	2.6322999999999999	1.9491000000000001	1.5998000000000001	1.2504999999999999	1.0758000000000001	0.91830000000000001	0.80279999999999996	0.62970000000000004	0.125	0.0060000001	16	97.874001	7.9249999999999998	4.5759999999999996	\N	87
34847	10861	99	224.58199999999999	2.2957000000000001	1.6659999999999999	3.0539999999999998	4.452	5.5929000000000002	3.9687999999999999	3.5110999999999999	2.9390999999999998	2.367	1.5983000000000001	1.0067999999999999	0.70099999999999996	0.56330000000000002	0.51970000000000005	0.46970000000000001	0.4254	0.35899999999999999	0.125	0.0060000001	16	99.255997	197.58000000000001	114.07299999999999	\N	107
34848	10861	119	121.94	2.7330999999999999	0.626	3.2829999999999999	6.8620000000000001	5.9650999999999996	4.8619000000000003	4.1262999999999996	3.6808000000000001	3.3109000000000002	2.5709	1.8724000000000001	1.3141	0.78349999999999997	0.59509999999999996	0.50309999999999999	0.45119999999999999	0.37459999999999999	0.125	0.0060000001	16	99.637001	56.490000000000002	32.613999999999997	\N	127
34839	10860	51	646.99699999999996	3.4420000000000002	0.95299999999999996	2.3679999999999999	3.8460000000000001	7.1864999999999997	5.7236000000000002	5.1557000000000004	4.4458000000000002	3.8702999999999999	3.1730999999999998	2.4759000000000002	1.8855999999999999	1.5250999999999999	1.3448	1.1646000000000001	1.0204	0.82499999999999996	0.125	0.001	16	99.461998	1200.721	693.23699999999997	\N	59
34840	10860	71	89.227999999999994	3.226	1.0169999999999999	2.4390000000000001	4.0599999999999996	7.0373000000000001	5.5298999999999996	4.8257000000000003	3.9786000000000001	3.6324000000000001	2.9401999999999999	2.2479	1.7737000000000001	1.4211	1.2446999999999999	1.0684	0.92949999999999999	0.72409999999999997	0.125	0.0040000002	16	99.799004	89.992999999999995	51.957999999999998	\N	79
34841	10860	91	90.849000000000004	2.8258999999999999	0.95399999999999996	2.4820000000000002	4.4269999999999996	5.8438999999999997	4.9158999999999997	4.2972999999999999	3.7837999999999998	3.4325999999999999	2.7301000000000002	2.0276999999999998	1.6448	1.2749999999999999	1.0901000000000001	0.92110000000000003	0.79800000000000004	0.61660000000000004	0.125	0.0049999999	10	98.389	213.88300000000001	123.485	\N	99
34842	10860	111	61.859000000000002	3.0145	0.68999999999999995	3.0739999999999998	6.468	6.1269999999999998	5.2034000000000002	4.5876000000000001	3.9114	3.5367000000000002	2.7873999999999999	2.0381	1.5412999999999999	1.0580000000000001	0.84799999999999998	0.64800000000000002	0.55079999999999996	0.43099999999999999	0.125	0.022	16	99.094002	35.646999999999998	20.581	\N	119
34843	10860	131	22.440000000000001	0.68559999999999999	1.038	1.5760000000000001	1.8660000000000001	0.96230000000000004	0.83989999999999998	0.75829999999999997	0.65629999999999999	0.61329999999999996	0.56830000000000003	0.5232	0.4728	0.41670000000000001	0.38869999999999999	0.36059999999999998	0.3382	0.30449999999999999	0.125	0.0099999998	6.2999999999999998	99.597	17.146999999999998	9.9000000000000004	\N	139
34741	10836	47	21.893999999999998	3.3031999999999999	0.71899999999999997	2.488	4.8579999999999997	6.3735999999999997	5.5099999999999998	4.9698000000000002	4.2946	3.8285	3.2200000000000002	2.6114999999999999	2.0030999999999999	1.5270999999999999	1.2894000000000001	1.0518000000000001	0.88990000000000002	0.66279999999999994	0.125	0.0060000001	16	99.574997	52.020000000000003	30.033999999999999	\N	73
34742	10836	57	61.402999999999999	1.7566999999999999	1.905	2.2360000000000002	2.3969999999999998	3.8178000000000001	3.0179	2.4845999999999999	1.9440999999999999	1.7393000000000001	1.3295999999999999	0.97789999999999999	0.86470000000000002	0.75149999999999995	0.69489999999999996	0.63839999999999997	0.60350000000000004	0.55479999999999996	0.125	0.003	10	99.324997	71.251999999999995	41.137999999999998	\N	83
34743	10836	87	11.510999999999999	1.0894999999999999	1.5820000000000001	2.0539999999999998	2.3500000000000001	2.1764000000000001	1.6574	1.4037999999999999	1.0868	0.94489999999999996	0.79320000000000002	0.64149999999999996	0.57430000000000003	0.5141	0.47549999999999998	0.42959999999999998	0.39279999999999998	0.33760000000000001	0.125	0.012	6.2999999999999998	99.035004	12.028	6.9450000000000003	\N	113
34744	10836	97	110.881	1.9673	1.5629999999999999	2.7890000000000001	4.0199999999999996	4.7605000000000004	3.6576	3.2214	2.6762000000000001	2.1309	1.5548999999999999	1.0490999999999999	0.80049999999999999	0.60899999999999999	0.56310000000000004	0.51719999999999999	0.47039999999999998	0.38679999999999998	0.125	0.0080000004	16	99.935997	47.392000000000003	27.361999999999998	\N	123
34745	10836	117	91.489000000000004	1.9500999999999999	1.129	2.6019999999999999	3.988	4.2145000000000001	3.5442	3.1978	2.7648000000000001	2.3317999999999999	1.7261	1.2821	0.91920000000000002	0.69779999999999998	0.61109999999999998	0.56240000000000001	0.52339999999999998	0.43280000000000002	0.125	0.0020000001	10	99.598	143.065	82.597999999999999	\N	143
29919	10093	59	26.957000000000001	1.9786999999999999	1.248	2.3660000000000001	3.1349999999999998	3.9007000000000001	3.3319999999999999	2.9529000000000001	2.4790000000000001	2.0051000000000001	1.6314	1.2608999999999999	0.95479999999999998	0.80179999999999996	0.72540000000000004	0.64890000000000003	0.59540000000000004	0.52039999999999997	0.125	0.0080000004	16	99.766998	57.654000000000003	33.286999999999999	\N	84
29920	10093	79	64.373000000000005	1.1742999999999999	1.946	2.04	2.1030000000000002	2.7654999999999998	1.758	1.4303999999999999	1.0208999999999999	0.92010000000000003	0.75170000000000003	0.61780000000000002	0.57389999999999997	0.53010000000000002	0.5081	0.46589999999999998	0.42249999999999999	0.3574	0.125	0.0070000002	10	99.783997	32.799999999999997	18.937000000000001	\N	104
29921	10093	99	26.888000000000002	1.1819	2.1389999999999998	2.3079999999999998	1.9490000000000001	3.1560999999999999	1.8219000000000001	1.3886000000000001	0.95309999999999995	0.78669999999999995	0.59870000000000001	0.53959999999999997	0.48089999999999999	0.42299999999999999	0.39400000000000002	0.36509999999999998	0.34189999999999998	0.30709999999999998	0.125	0.0080000004	10	99.808998	19.170000000000002	11.068	\N	124
29922	10093	109	16.533000000000001	0.93899999999999995	1.9450000000000001	2.0609999999999999	1.835	1.9812000000000001	1.3669	0.98509999999999998	0.80579999999999996	0.62919999999999998	0.54079999999999995	0.47570000000000001	0.4304	0.38519999999999999	0.36259999999999998	0.34000000000000002	0.32190000000000002	0.29470000000000002	0.25	0.109	10	99.773003	20.385000000000002	11.769	\N	134
29923	10093	119	16.681000000000001	0.5454	1.0329999999999999	1.413	1.6160000000000001	0.81020000000000003	0.60860000000000003	0.57299999999999995	0.52839999999999998	0.49359999999999998	0.4587	0.42370000000000002	0.38879999999999998	0.3538	0.33629999999999999	0.31890000000000002	0.3049	0.28389999999999999	0.125	0.0040000002	6.2999999999999998	99.920998	24.936	14.397	\N	144
29914	9658	48	63.256	3.1314000000000002	0.93200000000000005	2.1299999999999999	3.3159999999999998	5.8672000000000004	4.9988000000000001	4.4198000000000004	3.8784999999999998	3.5891999999999999	3.0105	2.4319000000000002	1.9141999999999999	1.5759000000000001	1.4067000000000001	1.2376	1.1022000000000001	0.90780000000000005	0.25	0.0070000002	16	99.628998	127.901	73.843999999999994	\N	64
29915	9658	68	111.98399999999999	2.0899999999999999	1.1830000000000001	2.2989999999999999	2.9670000000000001	4.4009	3.4857999999999998	3.0617999999999999	2.5318999999999998	2.0019	1.6973	1.3939999999999999	1.0908	0.88639999999999997	0.8054	0.72430000000000005	0.65949999999999998	0.57210000000000005	0.125	0.0020000001	16	99.894997	227.90299999999999	131.58000000000001	\N	84
29916	9658	88	115.72799999999999	4.2614999999999998	0.438	2.5569999999999999	8.0519999999999996	8.2729999999999997	6.7751000000000001	6.1500000000000004	5.7923	5.4345999999999997	4.7191999999999998	4.0037000000000003	3.1937000000000002	2.3832	1.9717	1.452	1.0362	0.58609999999999995	0.125	0.0089999996	16	99.741997	115.673	66.784000000000006	\N	104
29917	9658	108	219.364	2.6442000000000001	0.70799999999999996	2.762	5.2699999999999996	5.5824999999999996	4.6897000000000002	4.0945999999999998	3.7054999999999998	3.3681000000000001	2.6932	2.0184000000000002	1.5599000000000001	1.1074999999999999	0.90969999999999995	0.73770000000000002	0.6149	0.5111	0.125	0.011	16	99.969002	88.191000000000003	50.917000000000002	\N	124
29918	9658	128	43.805999999999997	0.90500000000000003	1.544	1.98	1.9670000000000001	1.8481000000000001	1.4032	1.1067	0.92390000000000005	0.81699999999999995	0.62339999999999995	0.57040000000000002	0.51739999999999997	0.45400000000000001	0.41970000000000002	0.38550000000000001	0.35809999999999997	0.317	0.125	0.025	16	99.977997	9.5909999999999993	5.5369999999999999	\N	144
37345	11352	81	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	71
37344	11352	96	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	86
37352	11353	77	0.065000000000000002	1.2948999999999999	1.119	1.8149999999999999	2.3849999999999998	2.2000000000000002	1.8565	1.7471000000000001	1.6103000000000001	1.4735	1.2	0.96699999999999997	0.84409999999999996	0.72119999999999995	0.65969999999999995	0.60399999999999998	0.56369999999999998	0.50319999999999998	0.5	9.677	4	96.774002	0.19500000000000001	0.112	\N	77
37353	11353	88	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	88
37362	11371	73	0.097000000000000003	1.3667	1.0509999999999999	2.0920000000000001	3.141	3.1699999999999999	1.9674	1.8343	1.6678999999999999	1.5014000000000001	1.1686000000000001	0.91759999999999997	0.75080000000000002	0.60209999999999997	0.55159999999999998	0.50119999999999998	0.44969999999999999	0.372	0.25	0.57200003	4	93.561996	0.29099999999999998	0.16800000000000001	\N	73
37348	11352	36	0.63600000000000001	8.5482999999999993	0.81100000000000005	2.7970000000000002	5.4500000000000002	20.9392	15.4293	13.703900000000001	11.5472	9.7406000000000006	7.9047000000000001	6.1260000000000003	4.7445000000000004	3.4958	2.9491000000000001	2.4024000000000001	1.9722	1.4504999999999999	0.5	0.65700001	16	85.322998	2.2040000000000002	1.272	\N	26
37347	11352	51	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	41
37346	11352	66	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	56
37363	11371	84	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	84
37365	11372	104	0.66100000000000003	1.0541	1.3600000000000001	1.8560000000000001	2.2429999999999999	1.8197000000000001	1.5225	1.3244	1.0768	0.95640000000000003	0.82989999999999997	0.70340000000000003	0.60670000000000002	0.55100000000000005	0.5232	0.49009999999999998	0.44209999999999999	0.37	0.5	20.827	6.2999999999999998	98.092003	0.39300000000000002	0.27800000000000002	\N	74
37349	11353	44	0.035999999999999997	1.5865	1.2569999999999999	2.9420000000000002	4.4400000000000004	3.98	3.218	2.71	2.0750000000000002	1.8132999999999999	1.3899999999999999	0.97529999999999994	0.66210000000000002	0.51139999999999997	0.45960000000000001	0.4108	0.37169999999999997	0.31309999999999999	0.125	1.772	4	90.156998	0.11	0.064000000000000001	\N	44
37350	11353	55	0.051999999999999998	0.91110000000000002	1.7549999999999999	2.1949999999999998	2.1349999999999998	1.8947000000000001	1.5954999999999999	1.3959999999999999	1.1467000000000001	0.93669999999999998	0.62980000000000003	0.54879999999999995	0.47599999999999998	0.41560000000000002	0.38550000000000001	0.3553	0.33119999999999999	0.29499999999999998	0.125	1.2029999	4	98.796997	0.040000000000000001	0.023	\N	55
37351	11353	66	27.436	1.7002999999999999	1.625	2.2029999999999998	2.5760000000000001	3.7734000000000001	2.7414999999999998	2.0535999999999999	1.8310999999999999	1.651	1.2908999999999999	0.97609999999999997	0.85189999999999999	0.72770000000000001	0.66559999999999997	0.60729999999999995	0.56479999999999997	0.501	0.125	0.015	10	99.218002	42.631	24.613	\N	66
37364	11372	114	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	84
37370	11373	102	0.25600000000000001	1.7881	1.052	2.1080000000000001	3.266	3.8666999999999998	2.2311000000000001	1.9078999999999999	1.7619	1.6158999999999999	1.3238000000000001	1.0317000000000001	0.80430000000000001	0.61350000000000005	0.57369999999999999	0.53380000000000005	0.50190000000000001	0.40539999999999998	0.125	0.27200001	16	99.457001	0.32100000000000001	0.185	\N	72
37359	11371	40	0.82699999999999996	2.5234000000000001	0.85099999999999998	3.085	5.1390000000000002	6.1772	4.5895000000000001	3.8391000000000002	3.3851	2.931	2.0230000000000001	1.6124000000000001	1.2148000000000001	0.8276	0.64029999999999998	0.54820000000000002	0.48209999999999997	0.39369999999999999	0.125	0.083999999	10	98.481003	2.2549999999999999	1.302	\N	40
37360	11371	51	4.266	1.1242000000000001	1.3089999999999999	1.7789999999999999	2.1760000000000002	1.8329	1.5518000000000001	1.3643000000000001	1.1301000000000001	0.97619999999999996	0.86939999999999995	0.76259999999999994	0.65569999999999995	0.58289999999999997	0.55189999999999995	0.52090000000000003	0.49049999999999999	0.39950000000000002	0.125	0.033	10	98.921997	14.372	8.2970000000000006	\N	51
37361	11371	62	0.16200000000000001	0.80210000000000004	1.048	1.6140000000000001	1.925	1.0024999999999999	0.90080000000000005	0.83440000000000003	0.75149999999999995	0.66859999999999997	0.59319999999999995	0.54530000000000001	0.4965	0.43369999999999997	0.40229999999999999	0.37090000000000001	0.3458	0.30809999999999998	0.125	0.34999999	6.2999999999999998	97.813004	0.247	0.14199999999999999	\N	62
37369	11373	115	0.037999999999999999	1.2899	0.67800000000000005	1.931	3.6000000000000001	1.9822	1.8604000000000001	1.7793000000000001	1.6778	1.5763	1.3733	1.1704000000000001	0.96379999999999999	0.73850000000000005	0.62739999999999996	0.55620000000000003	0.49890000000000001	0.38140000000000002	0.125	1.642	4	98.175003	0.13300000000000001	0.076999999999999999	\N	85
37377	11374	59	0.045999999999999999	0.73140000000000005	1.0109999999999999	1.5700000000000001	2.1179999999999999	1.2314000000000001	0.96109999999999995	0.91610000000000003	0.8599	0.80369999999999997	0.69130000000000003	0.60909999999999997	0.56299999999999994	0.51690000000000003	0.48580000000000001	0.43269999999999997	0.3901	0.32629999999999998	0.125	1.411	2	98.432999	0.159	0.091999999999999998	\N	73
37368	11372	69	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	39
37367	11372	84	48.271999999999998	5.4249000000000001	1.0640000000000001	2.4929999999999999	3.7109999999999999	12.303699999999999	9.1971000000000007	8.032	6.5755999999999997	5.7850999999999999	4.5151000000000003	3.5762	2.8632	2.1501999999999999	1.8733	1.6544000000000001	1.4793000000000001	1.2165999999999999	0.125	0.0040000002	16	95.204002	134.411	77.602000000000004	\N	54
37366	11372	94	41.395000000000003	5.2267999999999999	0.78300000000000003	2.6749999999999998	5.5030000000000001	11.146699999999999	8.9970999999999997	8.0808999999999997	6.9356	6.0423	4.8841999999999999	3.7999999999999998	2.9544000000000001	2.1086999999999998	1.7830999999999999	1.4910000000000001	1.2574000000000001	0.88749999999999996	0.125	0.0040000002	16	96.862999	79.039000000000001	45.633000000000003	\N	64
37378	11374	72	0.14999999999999999	0.67279999999999995	1.0249999999999999	1.466	1.8999999999999999	0.95720000000000005	0.89929999999999999	0.86080000000000001	0.8125	0.76429999999999998	0.66779999999999995	0.60589999999999999	0.56620000000000004	0.52639999999999998	0.50660000000000005	0.46279999999999999	0.41830000000000001	0.35149999999999998	0.125	0.421	2	99.579002	0.40000000000000002	0.23100000000000001	\N	86
37380	11375	104	0.32800000000000001	0.80059999999999998	1.0409999999999999	1.4359999999999999	1.9710000000000001	1.3979999999999999	0.99809999999999999	0.96079999999999999	0.91420000000000001	0.86750000000000005	0.7742	0.68089999999999995	0.60850000000000004	0.56120000000000003	0.53749999999999998	0.51390000000000002	0.48380000000000001	0.39269999999999999	0.125	0.19	4	99.809998	1.1379999999999999	0.65700000000000003	\N	74
37373	11373	63	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	33
37372	11373	76	0.072999999999999995	2.0987	1.27	1.6779999999999999	1.7869999999999999	3.714	3.3024	3.028	2.6850000000000001	2.3420000000000001	1.9154	1.7466999999999999	1.5780000000000001	1.4093	1.325	1.2406999999999999	1.1732	1.0720000000000001	0.25	0.875	4	94.168999	0.253	0.14599999999999999	\N	46
37371	11373	89	0.83099999999999996	4.2835999999999999	1.101	3.1669999999999998	5.952	10.113099999999999	8.6808999999999994	7.7724000000000002	6.6368	5.6586999999999996	3.8851	2.6116999999999999	1.7954000000000001	1.4016	1.2048000000000001	1.0079	0.86539999999999995	0.65280000000000005	0.125	0.083999999	10	89.807999	2.8799999999999999	1.663	\N	59
37379	11375	114	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	84
37387	11376	50	46.762	6.0285000000000002	0.434	4.6699999999999999	12.394	14.274800000000001	11.435600000000001	9.7531999999999996	8.4760000000000009	7.1989000000000001	5.2727000000000004	3.7153999999999998	2.2719	1.1133999999999999	0.72260000000000002	0.57940000000000003	0.52429999999999999	0.4254	0.125	0.0080000004	31.5	98.975998	160.18799999999999	92.483999999999995	\N	91
37374	11374	20	0.16300000000000001	2.0545	1.04	2.0150000000000001	2.8620000000000001	3.7633999999999999	3.2364999999999999	2.8853	2.4462000000000002	2.0072000000000001	1.7883	1.5748	1.3613	1.1477999999999999	1.0410999999999999	0.91169999999999995	0.79690000000000005	0.62490000000000001	0.125	0.34400001	6.2999999999999998	95.273003	0.54500000000000004	0.315	\N	34
37375	11374	33	1.04	0.77880000000000005	1.081	1.488	1.9870000000000001	1.2816000000000001	0.97330000000000005	0.93279999999999996	0.8821	0.83140000000000003	0.72999999999999998	0.62939999999999996	0.58479999999999999	0.54020000000000001	0.51790000000000003	0.48809999999999998	0.43980000000000002	0.3674	0.125	0.067000002	6.2999999999999998	99.865997	2.73	1.5760000000000001	\N	47
37376	11374	46	0.075999999999999998	1.395	0.72399999999999998	1.917	3.339	2.6867000000000001	1.9509000000000001	1.8620000000000001	1.7509999999999999	1.6399999999999999	1.4179999999999999	1.1959	0.97509999999999997	0.76319999999999999	0.6573	0.58230000000000004	0.53080000000000005	0.42459999999999998	0.125	0.82700002	4	97.242996	0.26200000000000001	0.151	\N	60
37388	11376	60	16.827999999999999	3.1107999999999998	1.6299999999999999	2.2919999999999998	2.3940000000000001	7.5986000000000002	5.0077999999999996	3.9127000000000001	3.3492000000000002	2.7856000000000001	1.9328000000000001	1.7111000000000001	1.4894000000000001	1.2677	1.1568000000000001	1.046	0.95320000000000005	0.80720000000000003	0.125	0.0080000004	16	99.063004	29.029	16.760000000000002	\N	101
37393	11377	31	32.731999999999999	4.3250000000000002	1.8899999999999999	3.6080000000000001	4.3819999999999997	12.3584	8.6943999999999999	6.7953000000000001	5.1094999999999997	3.8250999999999999	2.4923999999999999	1.7525999999999999	1.3603000000000001	0.98170000000000002	0.86960000000000004	0.75749999999999995	0.66790000000000005	0.56879999999999997	0.125	0.0020000001	16	95.017998	67.418999999999997	38.923999999999999	\N	72
37383	11375	74	0.059999999999999998	1.0052000000000001	1.349	1.831	2.2970000000000002	1.8364	1.6017999999999999	1.4455	1.25	1.0545	0.88590000000000002	0.75329999999999997	0.62609999999999999	0.57020000000000004	0.5423	0.51429999999999998	0.47789999999999999	0.38569999999999999	0.25	1.163	4	98.836998	0.20899999999999999	0.121	\N	44
37382	11375	84	1.8080000000000001	1.1001000000000001	1.179	1.7929999999999999	2.2120000000000002	1.8665	1.6826000000000001	1.5600000000000001	1.4067000000000001	1.2534000000000001	0.97989999999999999	0.86429999999999996	0.74870000000000003	0.6331	0.59330000000000005	0.55459999999999998	0.52359999999999995	0.44290000000000002	0.125	0.037999999	6.2999999999999998	99.500999	4.4450000000000003	2.5659999999999998	\N	54
37381	11375	94	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	64
37392	11377	41	14.894	4.5331000000000001	3.2349999999999999	4.1870000000000003	4.3799999999999999	13.463100000000001	9.2786000000000008	7.3773999999999997	5.5232000000000001	4.1021000000000001	1.9285000000000001	1.2322	0.88109999999999999	0.70269999999999999	0.62060000000000004	0.56989999999999996	0.52939999999999998	0.44030000000000002	0.125	0.0049999999	31.5	99.519997	9.1720000000000006	5.2960000000000003	\N	82
37391	11377	51	134.65299999999999	2.1294	1.8009999999999999	2.456	2.8780000000000001	5.0015999999999998	3.7098	3.2568000000000001	2.6905000000000001	2.1242000000000001	1.5881000000000001	1.1254999999999999	0.90980000000000005	0.78590000000000004	0.72399999999999998	0.66210000000000002	0.61509999999999998	0.55189999999999995	0.125	0.025	16	99.827003	111.973	64.647999999999996	\N	92
37384	11376	20	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	61
37385	11376	30	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	71
37386	11376	40	0.28799999999999998	6.0305	0.58499999999999996	2.9950000000000001	6.8789999999999996	13.270300000000001	11.6325	10.540699999999999	9.4359999999999999	8.5020000000000007	6.6338999999999997	5.0781000000000001	3.6069	2.1793	1.7932999999999999	1.5173000000000001	1.2965	0.96440000000000003	0.125	0.242	10	78.018997	0.82199999999999995	0.47499999999999998	\N	81
37390	11377	61	196.88200000000001	1.5498000000000001	0.96399999999999997	1.9690000000000001	2.669	3.0255000000000001	2.1688000000000001	1.9246000000000001	1.7907999999999999	1.657	1.3894	1.1217999999999999	0.89070000000000005	0.69010000000000005	0.61709999999999998	0.58489999999999998	0.55910000000000004	0.52049999999999996	0.125	0.0049999999	31.5	99.972	135.64400000000001	78.313999999999993	\N	102
37389	11377	71	0.075999999999999998	1.0961000000000001	0.90600000000000003	1.929	3.1440000000000001	1.8945000000000001	1.7545999999999999	1.6613	1.5447	1.4280999999999999	1.1949000000000001	0.9556	0.68530000000000002	0.57850000000000001	0.54610000000000003	0.51370000000000005	0.4713	0.38	0.125	0.73000002	2	94.526001	0.26500000000000001	0.153	\N	112
10947	2105	41	1.083	0.6925	1.0680000000000001	1.601	1.861	1.2	0.86609999999999998	0.75329999999999997	0.62739999999999996	0.60660000000000003	0.56499999999999995	0.52339999999999998	0.47499999999999998	0.41789999999999999	0.38929999999999998	0.36070000000000002	0.33789999999999998	0.30359999999999998	0.25	0.625	2	95	0	0	\N	41
10948	2105	47	7.9370000000000003	1.5263	1.3879999999999999	1.966	2.359	3.1766999999999999	2.2254999999999998	1.9117999999999999	1.7407999999999999	1.5698000000000001	1.2278	0.9607	0.84299999999999997	0.72529999999999994	0.66649999999999998	0.61250000000000004	0.57569999999999999	0.52039999999999997	0.25	0.07	10	99.399002	5.9359999999999999	3.427	\N	47
10949	2105	71	42.731999999999999	1.7532000000000001	1.726	2.2589999999999999	2.5030000000000001	3.7711999999999999	2.6185	1.9649000000000001	1.7399	1.5148999999999999	1.0649	0.88239999999999996	0.745	0.61780000000000002	0.58050000000000002	0.54320000000000002	0.51329999999999998	0.4254	0.25	0.1	10	98.098	66.025000000000006	38.119999999999997	\N	71
10950	2105	83	58.765000000000001	1.2632000000000001	1.3340000000000001	1.8520000000000001	2.1619999999999999	2.1499999999999999	1.778	1.6162000000000001	1.4139999999999999	1.2117	0.94550000000000001	0.83099999999999996	0.71660000000000001	0.61350000000000005	0.57950000000000002	0.54549999999999998	0.51829999999999998	0.43730000000000002	0.25	0.1	10	99.800003	56.737000000000002	32.756999999999998	\N	83
10951	2105	118	12.680999999999999	2.8921000000000001	0.79700000000000004	2.512	4.7009999999999996	5.8559999999999999	4.6966999999999999	3.9752999999999998	3.6619000000000002	3.3485	2.7218	2.0950000000000002	1.6552	1.2487999999999999	1.0456000000000001	0.87419999999999998	0.74439999999999995	0.57899999999999996	0.25	0.07	10	97.399002	17.366	10.026	\N	118
10952	2105	126	72.510000000000005	1.5710999999999999	1.278	1.946	2.4830000000000001	3.2690999999999999	2.1983999999999999	1.9119999999999999	1.7597	1.6073	1.3027	0.99919999999999998	0.87029999999999996	0.74150000000000005	0.67710000000000004	0.61750000000000005	0.58040000000000003	0.52470000000000006	0.25	0.029999999	10	99.599998	237.983	137.40000000000001	\N	126
10953	2105	155	22.951000000000001	1.6275999999999999	1.399	2.0049999999999999	2.4630000000000001	3.3342000000000001	2.3347000000000002	1.9352	1.7724	1.6095999999999999	1.284	0.98440000000000005	0.86240000000000006	0.74029999999999996	0.67930000000000001	0.62050000000000005	0.58079999999999998	0.52129999999999999	0.25	0.050000001	10	99.199997	11.755000000000001	6.7869999999999999	\N	155
10954	2105	160	0.016	0.60780000000000001	1.046	1.579	1.859	0.97529999999999994	0.84950000000000003	0.76570000000000005	0.66080000000000005	0.61439999999999995	0.57020000000000004	0.52600000000000002	0.47670000000000001	0.41999999999999998	0.39169999999999999	0.36330000000000001	0.3407	0.30669999999999997	0.5	44.118	1	91.176003	0	0	\N	160
10938	2104	48	19.827999999999999	1.7675000000000001	1.454	1.8500000000000001	1.9279999999999999	3.0975999999999999	1.8134999999999999	1.6115999999999999	1.3592	1.1068	0.91759999999999997	0.81320000000000003	0.7087	0.61499999999999999	0.5847	0.55430000000000001	0.53000000000000003	0.47599999999999998	0.25	0.050000001	10	95.998001	27.791	19.651	\N	48
10939	2104	59	0.30599999999999999	1.7201	1.456	2.3210000000000002	3.1400000000000001	3.7280000000000002	2.6768000000000001	1.9950000000000001	1.8125	1.6299999999999999	1.2649999999999999	0.9556	0.79349999999999998	0.63149999999999995	0.58340000000000003	0.53600000000000003	0.49669999999999997	0.40289999999999998	0.25	0.228	8	95.433998	0	0	\N	59
10940	2104	72	88.614999999999995	2.6878000000000002	1.915	2.476	2.7509999999999999	5.9396000000000004	3.4184999999999999	2.6943000000000001	1.9552	1.7629999999999999	1.3785000000000001	0.99780000000000002	0.85819999999999996	0.71850000000000003	0.64859999999999995	0.59540000000000004	0.55769999999999997	0.50119999999999998	0.125	0.0040000002	20	98.217003	127.515	73.620999999999995	\N	72
10941	2104	83	26.026	3.6419000000000001	1.0209999999999999	2.302	3.637	7.8518999999999997	5.7257999999999996	5.0345000000000004	4.1702000000000004	3.7427999999999999	3.1023000000000001	2.4617	1.9041999999999999	1.5609	1.3892	1.2176	1.0802	0.85299999999999998	0.5	0.041999999	10	93.399002	71.353999999999999	41.195999999999998	\N	83
10942	2104	88	0.28499999999999998	1.2676000000000001	1.0329999999999999	2.0379999999999998	3.169	2.7233000000000001	1.9809000000000001	1.8569	1.7019	1.5468999999999999	1.2369000000000001	0.95609999999999995	0.76970000000000005	0.60809999999999997	0.5645	0.52080000000000004	0.47670000000000001	0.39040000000000002	0.25	0.248	4	99.503998	0	0	\N	88
10943	2104	111	15.493	2.2847	1.4810000000000001	2.6379999999999999	3.6349999999999998	5.0864000000000003	3.5251000000000001	2.9958	2.3340999999999998	1.9007000000000001	1.4994000000000001	1.0982000000000001	0.85229999999999995	0.65669999999999995	0.59450000000000003	0.54569999999999996	0.50660000000000005	0.41249999999999998	0.125	0.0099999998	10	95.396004	51.868000000000002	29.946000000000002	\N	111
10944	2104	123	0.56899999999999995	1.3353999999999999	1.151	1.9930000000000001	2.9100000000000001	2.8933	2.0053000000000001	1.8667	1.6984999999999999	1.5303	1.1939	0.93789999999999996	0.79120000000000001	0.64449999999999996	0.59140000000000004	0.54330000000000001	0.50490000000000002	0.4103	0.25	0.18000001	6.2999999999999998	99.278999	0	0	\N	123
10945	2104	141	7.8819999999999997	3.8975	2.7440000000000002	3.677	4.3099999999999996	10.064299999999999	7.2572000000000001	5.8559999999999999	4.5244999999999997	3.5619999999999998	2.1166999999999998	1.1915	0.83499999999999996	0.62809999999999999	0.59550000000000003	0.56289999999999996	0.53680000000000005	0.49120000000000003	0.125	0.0089999996	20	97.356003	0	0	\N	141
10946	2104	153	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	153
29908	10091	24	50.673000000000002	1.2102999999999999	1.2929999999999999	1.74	1.855	1.9643999999999999	1.7541	1.6140000000000001	1.4388000000000001	1.2636000000000001	0.97750000000000004	0.88670000000000004	0.79590000000000005	0.70509999999999995	0.65959999999999996	0.61480000000000001	0.57969999999999999	0.52700000000000002	0.125	0.003	10	99.955002	73.075000000000003	42.189999999999998	\N	65
29907	10091	37	17.956	0.9375	0.94699999999999995	1.337	1.587	1.2717000000000001	0.97570000000000001	0.94920000000000004	0.91600000000000004	0.88280000000000003	0.8165	0.75019999999999998	0.68379999999999996	0.62009999999999998	0.59370000000000001	0.56730000000000003	0.54620000000000002	0.51449999999999996	0.125	0.0080000004	10	99.799004	17.696000000000002	10.217000000000001	\N	78
29906	10091	50	67.921999999999997	0.84819999999999995	1.1439999999999999	1.355	1.528	1.0941000000000001	0.95369999999999999	0.91890000000000005	0.87539999999999996	0.83199999999999996	0.745	0.65810000000000002	0.60570000000000002	0.56989999999999996	0.55189999999999995	0.53400000000000003	0.51970000000000005	0.48770000000000002	0.125	0.0020000001	10	99.980003	28.826000000000001	16.643000000000001	\N	91
29905	10091	63	7.843	1.0476000000000001	1.8200000000000001	2.0960000000000001	1.881	2.8580000000000001	1.4998	0.94930000000000003	0.76659999999999995	0.62409999999999999	0.57730000000000004	0.53059999999999996	0.47999999999999998	0.42230000000000001	0.39340000000000003	0.36459999999999998	0.34150000000000003	0.30690000000000001	0.125	0.017999999	10	99.716003	11.395	6.5789999999999997	\N	104
29904	10091	76	2.4940000000000002	5.7839	0.14099999999999999	4.6479999999999997	18.260000000000002	11.2994	9.5348000000000006	9.0648	8.4773999999999994	7.8899999999999997	6.7152000000000003	5.4635999999999996	4.1702000000000004	2.2879	0.82040000000000002	0.49030000000000001	0.44130000000000003	0.36780000000000002	0.25	0.38999999	16	97.379997	3.8929999999999998	2.2480000000000002	\N	117
29899	10090	42	75.207999999999998	1.4581	1.4470000000000001	1.738	1.7430000000000001	2.8075000000000001	1.8821000000000001	1.7193000000000001	1.5158	1.3123	0.98109999999999997	0.90000000000000002	0.81879999999999997	0.73770000000000002	0.69710000000000005	0.65649999999999997	0.62270000000000003	0.56299999999999994	0.25	0.016000001	10	99.228996	140.292	80.998000000000005	\N	60
29900	10090	52	16.995999999999999	2.5423	2.419	2.988	3.1099999999999999	7.0209000000000001	5.1337999999999999	4.0732999999999997	3.2496999999999998	2.4554999999999998	1.6273	1.1049	0.88470000000000004	0.74039999999999995	0.66830000000000001	0.60970000000000002	0.57520000000000004	0.52329999999999999	0.125	0.016000001	10	96.619003	22.841000000000001	13.186999999999999	\N	70
29901	10090	72	95.471000000000004	2.5859999999999999	3.2679999999999998	3.1429999999999998	2.9849999999999999	7.1116000000000001	5.3616999999999999	4.4626999999999999	3.5004	2.6509999999999998	1.5149999999999999	0.94379999999999997	0.78080000000000005	0.62560000000000004	0.59609999999999996	0.5665	0.54290000000000005	0.50749999999999995	0.25	0.027000001	16	99.636002	76.968000000000004	44.436999999999998	\N	90
29902	10090	92	161.89500000000001	1.6674	3.7120000000000002	2.621	1.7070000000000001	5.1101999999999999	2.9885999999999999	1.7791999999999999	0.97240000000000004	0.84299999999999997	0.62429999999999997	0.59189999999999998	0.5595	0.5272	0.51100000000000001	0.48149999999999998	0.43509999999999999	0.36559999999999998	0.25	0.025	16	99.685997	81.033000000000001	46.783999999999999	\N	110
29903	10090	102	5.2089999999999996	2.0733000000000001	4.282	3.246	1.9139999999999999	6.0212000000000003	3.6457999999999999	2.0922000000000001	0.95930000000000004	0.74119999999999997	0.59279999999999999	0.54279999999999995	0.49130000000000001	0.43080000000000002	0.40050000000000002	0.37030000000000002	0.34599999999999997	0.30969999999999998	0.25	0.133	16	97.838997	10.779	6.2229999999999999	\N	120
29894	9647	44	272.14699999999999	3.0108999999999999	3.7949999999999999	2.9359999999999999	2.3420000000000001	9.0246999999999993	5.5190000000000001	3.8519000000000001	2.7816999999999998	1.9238	1.3585	0.96509999999999996	0.86960000000000004	0.77410000000000001	0.72629999999999995	0.67859999999999998	0.64039999999999997	0.58009999999999995	0.125	0.0020000001	16	97.807999	831.03200000000004	479.79599999999999	\N	74
29895	9647	59	593.28099999999995	4.4701000000000004	1.9590000000000001	3.3370000000000002	4.1760000000000002	12.363200000000001	8.7498000000000005	6.9775	5.3640999999999996	4.0159000000000002	2.8050999999999999	1.873	1.4883	1.1036999999999999	0.95630000000000004	0.86140000000000005	0.78549999999999998	0.67169999999999996	0.125	0.003	16	94.890999	332.36700000000002	191.892	\N	89
29896	9647	74	46.027000000000001	3.2970999999999999	1.8080000000000001	3.109	3.5489999999999999	8.4011999999999993	5.9387999999999996	4.9843000000000002	3.8748	3.1594000000000002	1.9077	1.4207000000000001	0.97919999999999996	0.82599999999999996	0.74939999999999996	0.67290000000000005	0.61460000000000004	0.53749999999999998	0.125	0.0070000002	16	97.276001	4.2750000000000004	2.468	\N	104
29897	9647	84	19.837	6.5716999999999999	0.41499999999999998	4.5090000000000003	10.425000000000001	15.8497	12.929600000000001	10.982799999999999	9.2017000000000007	7.8627000000000002	5.7568000000000001	4.4524999999999997	2.7867999999999999	1.4359	0.97919999999999996	0.78849999999999998	0.63590000000000002	0.55220000000000002	0.125	0.0040000002	16	90.308998	62.253999999999998	35.942999999999998	\N	114
29898	9647	94	251.68100000000001	3.7896000000000001	1.056	3.661	6.0789999999999997	9.5032999999999994	7.2558999999999996	6.0415000000000001	5.1487999999999996	4.2561	3.0407999999999999	1.9287000000000001	0.97489999999999999	0.66369999999999996	0.60309999999999997	0.56879999999999997	0.54139999999999999	0.50019999999999998	0.25	0.121	16	97.505997	414.86700000000002	239.524	\N	124
27551	8995	40	14.178000000000001	1.9265000000000001	1.405	2.3679999999999999	2.9750000000000001	4.2122000000000002	3.2991000000000001	2.7856000000000001	2.1438000000000001	1.8660000000000001	1.5205	1.1751	0.92889999999999995	0.78490000000000004	0.71279999999999999	0.64080000000000004	0.58819999999999995	0.5111	0.125	0.0099999998	10	99.154999	12.055999999999999	6.9610000000000003	\N	59
27552	8995	60	34.469000000000001	1.9162999999999999	1.24	2.1600000000000001	2.7440000000000002	3.9582999999999999	3.2136999999999998	2.7172000000000001	2.0966999999999998	1.8843000000000001	1.6103000000000001	1.3363	1.0622	0.88929999999999998	0.81769999999999998	0.74609999999999999	0.68879999999999997	0.58689999999999998	0.125	0.0040000002	10	99.572998	77.527000000000001	44.759999999999998	\N	79
27553	8995	80	108.521	1.637	1.417	2.1749999999999998	2.6850000000000001	3.496	2.7652000000000001	2.278	1.9086000000000001	1.7403999999999999	1.4040999999999999	1.0678000000000001	0.89270000000000005	0.75829999999999997	0.69110000000000005	0.62539999999999996	0.58440000000000003	0.52290000000000003	0.125	0.003	10	99.614998	144.20599999999999	83.257000000000005	\N	99
27554	8995	90	38.783999999999999	0.83860000000000001	0.94799999999999995	1.425	1.7589999999999999	0.94899999999999995	0.76229999999999998	0.63790000000000002	0.61719999999999997	0.60360000000000003	0.5766	0.54949999999999999	0.52239999999999998	0.4864	0.44679999999999997	0.40710000000000002	0.37540000000000001	0.32779999999999998	0.125	0.0040000002	10	99.903	28.831	16.646000000000001	\N	109
27555	8995	100	1.1459999999999999	7.1631	0.13600000000000001	4.9610000000000003	21.379999999999999	14.2432	13.1891	12.4863	11.607900000000001	10.7295	8.9731000000000005	7.2168999999999999	5.3727999999999998	3.3199999999999998	2.1570999999999998	0.6704	0.53590000000000004	0.41970000000000002	0.125	0.061000001	10	65.848	0.26300000000000001	0.152	\N	119
27961	9201	40	11.483000000000001	1.6813	1.673	2.3439999999999999	2.9260000000000002	3.7136	2.8753000000000002	2.3165	1.8846000000000001	1.6735	1.2515000000000001	0.94840000000000002	0.82079999999999997	0.69320000000000004	0.62939999999999996	0.5706	0.52349999999999997	0.42780000000000001	0.125	0.024	10	99.431	16.466999999999999	9.5069999999999997	\N	80
27962	9201	60	11.679	1.0569	1.2430000000000001	1.5740000000000001	1.6699999999999999	1.7716000000000001	1.4444999999999999	1.2264999999999999	0.99419999999999997	0.96009999999999995	0.89180000000000004	0.82350000000000001	0.75509999999999999	0.68679999999999997	0.65269999999999995	0.61619999999999997	0.58340000000000003	0.53410000000000002	0.125	0.017999999	6.2999999999999998	99.487999	15.138999999999999	8.7400000000000002	\N	100
27963	9201	80	53.409999999999997	1.3783000000000001	1.6519999999999999	2.0459999999999998	1.9390000000000001	3.1461999999999999	2.2924000000000002	1.9038999999999999	1.657	1.4100999999999999	0.98140000000000005	0.87170000000000003	0.76200000000000001	0.65229999999999999	0.60960000000000003	0.57509999999999994	0.54749999999999999	0.50609999999999999	0.125	0.003	10	99.931	19.09	11.021000000000001	\N	120
27964	9201	90	41.539000000000001	0.90080000000000005	1.121	1.4930000000000001	1.7230000000000001	1.4646999999999999	0.89339999999999997	0.79310000000000003	0.66779999999999995	0.62029999999999996	0.5927	0.56499999999999995	0.5373	0.50960000000000005	0.48549999999999999	0.43830000000000002	0.40060000000000001	0.34389999999999998	0.125	0.003	10	99.910004	27.917999999999999	16.119	\N	130
27965	9201	100	0.58699999999999997	6.3411	0.217	4.4299999999999997	16.009	13.388400000000001	11.8215	10.7768	9.6631999999999998	8.8316999999999997	7.1687000000000003	5.7286000000000001	4.5323000000000002	3.2086000000000001	2.4956999999999998	1.5154000000000001	0.60229999999999995	0.44779999999999998	0.125	0.121	10	77.025002	0.66300000000000003	0.38300000000000001	\N	140
27545	8993	36	20.077000000000002	4.7054999999999998	1.05	2.3220000000000001	3.2949999999999999	9.7573000000000008	8.2871000000000006	7.3068999999999997	6.1867000000000001	5.5507	4.2786999999999997	3.4821	2.8189000000000002	2.1556999999999999	1.8946000000000001	1.6959	1.5368999999999999	1.2984	0.125	0.0070000002	16	99.343002	48.020000000000003	27.725000000000001	\N	56
27544	8993	56	26.029	4.7443	0.90600000000000003	2.9169999999999998	5.0090000000000003	10.2052	8.2997999999999994	7.1268000000000002	5.9592000000000001	5.1776999999999997	3.8003	2.9903	2.1802000000000001	1.6315999999999999	1.3946000000000001	1.1577	0.97570000000000001	0.75870000000000004	0.125	0.0049999999	16	95.716003	43.984999999999999	25.395	\N	76
27543	8993	76	112.434	3.8323999999999998	0.84599999999999997	3.3149999999999999	6.149	9.0818999999999992	7.1993999999999998	6.1406000000000001	5.4374000000000002	4.7343000000000002	3.4702000000000002	2.3616000000000001	1.4785999999999999	0.92620000000000002	0.82940000000000003	0.73260000000000003	0.65510000000000002	0.56430000000000002	0.125	0.003	16	98.642998	247.422	142.84899999999999	\N	96
27542	8993	96	20.678999999999998	3.1541999999999999	2.0430000000000001	3.4470000000000001	5.6879999999999997	8.7737999999999996	5.9561000000000002	5.2380000000000004	4.3404999999999996	3.6019000000000001	2.3189000000000002	1.2089000000000001	0.78820000000000001	0.60129999999999995	0.56559999999999999	0.52980000000000005	0.50119999999999998	0.40770000000000001	0.125	0.0070000002	16	99.317001	24.420000000000002	14.099	\N	116
27541	8993	116	1.181	0.38329999999999997	0.94399999999999995	1.272	1.4810000000000001	0.47699999999999998	0.46139999999999998	0.4511	0.43809999999999999	0.42520000000000002	0.3992	0.37330000000000002	0.34739999999999999	0.32150000000000001	0.3085	0.29559999999999997	0.28520000000000001	0.2697	0.125	0.059	4	99.822998	2.0209999999999999	1.167	\N	136
27905	9141	30	143.03899999999999	4.9523000000000001	0.91200000000000003	2.2210000000000001	3.4929999999999999	9.5420999999999996	8.1719000000000008	7.2584999999999997	6.2220000000000004	5.7359	4.7637	3.8525	3.1648000000000001	2.4771999999999998	2.1334	1.8509	1.6559999999999999	1.3635999999999999	0.25	0.003	16	98.383003	275.34100000000001	158.96799999999999	\N	70
27904	9141	39	241.84100000000001	5.3268000000000004	0.72599999999999998	2.9670000000000001	5.8710000000000004	12.0471	9.4865999999999993	8.6378000000000004	7.5766999999999998	6.5156999999999998	5.0682	3.7523	2.6314000000000002	1.7806999999999999	1.5297000000000001	1.2786	1.0778000000000001	0.86319999999999997	0.25	0.041999999	16	96.914001	479.35700000000003	276.75700000000001	\N	79
27903	9141	59	402.17700000000002	3.7658999999999998	1.3819999999999999	3.0830000000000002	4.5919999999999996	9.1374999999999993	6.6806000000000001	5.7319000000000004	4.8068	3.9283999999999999	2.8087	1.8433999999999999	1.2795000000000001	0.92130000000000001	0.84330000000000005	0.76529999999999998	0.70289999999999997	0.61160000000000003	0.25	0.075999998	16	97.136002	240.869	139.066	\N	99
27902	9141	69	95.543999999999997	4.1227999999999998	3.0790000000000002	3.5920000000000001	4.234	10.448499999999999	7.7306999999999997	6.1772999999999998	5.0864000000000003	3.9965999999999999	2.3332000000000002	1.2264999999999999	0.89800000000000002	0.76490000000000002	0.69840000000000002	0.63180000000000003	0.59909999999999997	0.55100000000000005	0.125	0.0040000002	31.5	98.764999	116.899	67.491	\N	109
27901	9141	99	42.920000000000002	2.8721000000000001	8.1400000000000006	4.1029999999999998	1.7869999999999999	9.1700999999999997	6.8784000000000001	5.5637999999999996	4.0829000000000004	2.2262	0.62280000000000002	0.58760000000000001	0.5524	0.5171	0.49869999999999998	0.4486	0.40860000000000002	0.34849999999999998	0.125	0.003	16	98.790001	24.477	14.132	\N	139
27535	8991	39	99.602999999999994	3.7989999999999999	1.0780000000000001	2.8279999999999998	4.4000000000000004	8.8995999999999995	6.9695	5.9641000000000002	5.0888	4.2135999999999996	3.2395999999999998	2.3736000000000002	1.7626999999999999	1.3453999999999999	1.1367	0.96120000000000005	0.87119999999999997	0.73629999999999995	0.125	0.0040000002	16	98.926003	281.291	162.404	\N	59
27534	8991	59	419.22500000000002	4.4077999999999999	1.6899999999999999	3.1920000000000002	4.5759999999999996	11.3706	8.4201999999999995	6.8897000000000004	5.5571000000000002	4.4831000000000003	3.1396000000000002	2.0295000000000001	1.6304000000000001	1.2506999999999999	1.0608	0.9204	0.8266	0.68600000000000005	0.125	0.0049999999	31.5	99.882004	113.759	65.679000000000002	\N	79
27533	8991	80	95.227999999999994	2.3428	2.5099999999999998	2.774	2.9089999999999998	5.9485000000000001	3.9237000000000002	3.2846000000000002	2.4857999999999998	1.8731	1.2252000000000001	0.89270000000000005	0.72819999999999996	0.60309999999999997	0.56979999999999997	0.53639999999999999	0.50970000000000004	0.42120000000000002	0.125	0.021	16	99.125999	288.62299999999999	166.637	\N	100
27532	8991	99	106.96299999999999	2.7189000000000001	1.448	3.879	7.7000000000000002	6.7606999999999999	5.4606000000000003	4.7930000000000001	3.9750000000000001	3.4716999999999998	2.4653	1.1698999999999999	0.55959999999999999	0.46229999999999999	0.42680000000000001	0.39129999999999998	0.36280000000000001	0.32019999999999998	0.25	0.127	16	99.529999	146.744	84.722999999999999	\N	119
27531	8991	110	32.238	0.41120000000000001	0.93700000000000006	1.2929999999999999	1.526	0.54149999999999998	0.49540000000000001	0.48370000000000002	0.46910000000000002	0.45440000000000003	0.42509999999999998	0.39579999999999999	0.36649999999999999	0.3372	0.32250000000000001	0.30780000000000002	0.29609999999999997	0.27850000000000003	0.25	0.26300001	6.2999999999999998	99.931	34.103999999999999	19.690000000000001	\N	130
24621	7861	47	147.56399999999999	1.6738999999999999	1.907	2.1880000000000002	2.113	3.7810000000000001	2.7936999999999999	2.1355	1.8086	1.5793999999999999	1.121	0.92459999999999998	0.82230000000000003	0.71989999999999998	0.66869999999999996	0.61919999999999997	0.5837	0.53049999999999997	0.125	0.003	16	99.976997	238.821	137.88300000000001	\N	67
24622	7861	57	55.359999999999999	1.5843	1.429	1.744	1.921	3.1650999999999998	1.9516	1.8087	1.6299999999999999	1.4513	1.0939000000000001	0.93620000000000003	0.84950000000000003	0.76290000000000002	0.71960000000000002	0.67630000000000001	0.64170000000000005	0.56940000000000002	0.125	0.003	10	98.934998	26.128	15.085000000000001	\N	77
24623	7861	66	12.016999999999999	2.3031000000000001	1.2669999999999999	2.7330000000000001	3.6579999999999999	5.7304000000000004	4.1468999999999996	3.6015999999999999	3.0232000000000001	2.4447000000000001	1.7515000000000001	1.3479000000000001	0.97240000000000004	0.77259999999999995	0.67269999999999996	0.5988	0.55530000000000002	0.4788	0.25	0.082999997	10	98.643997	16.978000000000002	9.8019999999999996	\N	86
24624	7861	87	179.82900000000001	1.6184000000000001	3.5259999999999998	2.798	2.1419999999999999	4.2416999999999998	3.1543999999999999	2.5223	1.8250999999999999	1.3090999999999999	0.73980000000000001	0.60040000000000004	0.55840000000000001	0.51629999999999998	0.48930000000000001	0.44130000000000003	0.40289999999999998	0.3453	0.125	0.001	16	99.968002	129.07900000000001	74.524000000000001	\N	107
24625	7861	107	8.9779999999999998	4.0808999999999997	0.81799999999999995	5.0730000000000004	13.56	10.5389	8.8280999999999992	7.9161000000000001	6.7762000000000002	5.819	4.1670999999999996	1.9236	0.48609999999999998	0.42649999999999999	0.3967	0.3669	0.34310000000000002	0.30730000000000002	0.25	0.38699999	16	98.716003	16.960000000000001	9.7919999999999998	\N	127
24610	7842	38	75.224999999999994	2.1650999999999998	1.1890000000000001	1.8700000000000001	2.1920000000000002	3.7654000000000001	2.7484000000000002	2.0705	1.8989	1.7887	1.5681	1.3475999999999999	1.1271	0.95030000000000003	0.89159999999999995	0.83289999999999997	0.78590000000000004	0.71550000000000002	0.25	0.018999999	16	98.968002	119.121	68.775000000000006	\N	58
24609	7842	50	5.4610000000000003	2.2075	3.0630000000000002	2.8479999999999999	2.1589999999999998	6.0339999999999998	4.4183000000000003	3.5488	2.6267999999999998	1.8756999999999999	1.0993999999999999	0.88649999999999995	0.75639999999999996	0.62829999999999997	0.59850000000000003	0.56869999999999998	0.54490000000000005	0.5091	0.25	0.013	10	97.364998	6.4569999999999999	3.7280000000000002	\N	70
24608	7842	69	44.988999999999997	2.4672999999999998	3.3439999999999999	3.0960000000000001	2.4169999999999998	8.4414999999999996	4.7964000000000002	3.2176	1.9273	1.5884	0.98219999999999996	0.84709999999999996	0.71209999999999996	0.60170000000000001	0.5655	0.52929999999999999	0.50039999999999996	0.40629999999999999	0.125	0.0049999999	10	92.337997	46.774999999999999	27.006	\N	89
24607	7842	89	178.94499999999999	3.5062000000000002	1.3380000000000001	4.3440000000000003	8.0579999999999998	9.7269000000000005	7.8775000000000004	6.6444999999999999	5.4625000000000004	4.3837999999999999	2.8548	1.5679000000000001	0.78169999999999995	0.56289999999999996	0.51200000000000001	0.4597	0.41749999999999998	0.3543	0.125	0.0049999999	10	90.886002	49.598999999999997	28.635999999999999	\N	109
24606	7842	109	10.551	0.44080000000000003	0.95299999999999996	1.3169999999999999	1.5469999999999999	0.56879999999999997	0.51700000000000002	0.49380000000000002	0.47849999999999998	0.4632	0.43259999999999998	0.40200000000000002	0.37140000000000001	0.34079999999999999	0.32550000000000001	0.31019999999999998	0.29799999999999999	0.27960000000000002	0.125	0.016000001	6.2999999999999998	99.816002	19.277000000000001	11.129	\N	129
24604	7841	40	134.196	4.7271999999999998	1.0860000000000001	2.573	3.7480000000000002	10.671099999999999	8.3750999999999998	7.0968	5.9240000000000004	5.1741999999999999	3.8435999999999999	3.1230000000000002	2.4024000000000001	1.8238000000000001	1.6242000000000001	1.4247000000000001	1.2649999999999999	1.0255000000000001	0.25	0.0080000004	16	97.269997	285.66500000000002	164.929	\N	65
24605	7841	50	430.75200000000001	3.3980999999999999	1.492	2.601	3.1760000000000002	8.0701000000000001	5.6569000000000003	4.7373000000000003	3.8170999999999999	3.3069000000000002	2.2866	1.7803	1.4748000000000001	1.1694	1.0165999999999999	0.91369999999999996	0.83609999999999995	0.71989999999999998	0.25	0.02	16	97.871002	341.69499999999999	197.27799999999999	\N	75
24603	7841	60	308.30599999999998	2.5053000000000001	1.5509999999999999	2.3260000000000001	2.6560000000000001	5.8114999999999997	3.6379999999999999	2.9781	2.1533000000000002	1.8741000000000001	1.5649	1.2556	0.97789999999999999	0.85050000000000003	0.78690000000000004	0.72319999999999995	0.67220000000000002	0.58930000000000005	0.25	0.022	16	98.767998	427.41699999999997	246.77000000000001	\N	85
24602	7841	70	127.373	2.5104000000000002	2.3730000000000002	2.8119999999999998	3.137	6.2439	4.1833999999999998	3.4430000000000001	2.6394000000000002	1.9457	1.4141999999999999	0.96550000000000002	0.80940000000000001	0.6532	0.60160000000000002	0.56120000000000003	0.52890000000000004	0.45090000000000002	0.25	0.093000002	16	98.541	160.93600000000001	92.915999999999997	\N	95
24601	7841	110	71.388000000000005	0.63149999999999995	0.94199999999999995	1.278	1.4930000000000001	0.49419999999999997	0.47789999999999999	0.46700000000000003	0.45340000000000003	0.43980000000000002	0.41249999999999998	0.38529999999999998	0.35809999999999997	0.33079999999999998	0.31719999999999998	0.30359999999999998	0.29270000000000002	0.27639999999999998	0.25	0.32499999	10	98.685997	146.83000000000001	84.772000000000006	\N	135
25905	8441	45	11.978999999999999	1.1066	1.292	1.661	1.728	1.845	1.6197999999999999	1.4697	1.2821	1.0944	0.93920000000000003	0.8579	0.77659999999999996	0.69530000000000003	0.65459999999999996	0.61580000000000001	0.58689999999999998	0.54359999999999997	0.25	0.017999999	6.2999999999999998	99.650002	0	0	\N	75
25904	8441	55	14.478999999999999	2.0145	0.98599999999999999	2.286	3.181	3.9567000000000001	3.4666999999999999	3.1400000000000001	2.7315999999999998	2.3231999999999999	1.8221000000000001	1.5276000000000001	1.2331000000000001	0.95640000000000003	0.8518	0.74719999999999998	0.66349999999999998	0.57279999999999998	0.063	0.0070000002	10	99.667999	0	0	\N	85
25903	8441	65	13.542	5.2369000000000003	5.1150000000000002	5.4210000000000003	12.177	14.293200000000001	12.4107	11.1557	9.5291999999999994	7.7408999999999999	4.3365999999999998	1.0123	0.61129999999999995	0.54569999999999996	0.51290000000000002	0.46650000000000003	0.42230000000000001	0.35610000000000003	0.063	0.0080000004	16	95.440002	0	0	\N	95
25902	8441	85	8.9580000000000002	0.70420000000000005	0.96299999999999997	1.3919999999999999	1.6639999999999999	0.62960000000000005	0.59609999999999996	0.57379999999999998	0.54590000000000005	0.51800000000000002	0.47439999999999999	0.4365	0.39860000000000001	0.36080000000000001	0.34179999999999999	0.32290000000000002	0.30780000000000002	0.28499999999999998	0.063	0.023	10	99.206001	0	0	\N	115
25901	8441	105	1.1419999999999999	1.333	3.2519999999999998	2.6509999999999998	1.754	5.0132000000000003	2.0565000000000002	0.98429999999999995	0.67769999999999997	0.55100000000000005	0.47060000000000002	0.43009999999999998	0.3896	0.34920000000000001	0.32900000000000001	0.30869999999999997	0.29249999999999998	0.26829999999999998	0.063	0.183	6.2999999999999998	93.783997	0	0	\N	135
27725	9081	56	14.016999999999999	1.9479	1.073	2.1829999999999998	3.0209999999999999	3.6959	3.1482000000000001	2.7831000000000001	2.3267000000000002	1.9597	1.6759999999999999	1.3924000000000001	1.1088	0.89629999999999999	0.81220000000000003	0.72809999999999997	0.66080000000000005	0.55489999999999995	0.25	0.039999999	16	99.386002	15.185	8.7669999999999995	\N	80
27724	9081	77	91.248999999999995	0.84760000000000002	1.1859999999999999	1.544	2.1669999999999998	1.5304	1.1671	0.9879	0.93889999999999996	0.89000000000000001	0.79210000000000003	0.69420000000000004	0.61339999999999995	0.56520000000000004	0.54100000000000004	0.51690000000000003	0.48980000000000001	0.3654	0.125	0.018999999	10	99.902	106.827	61.677	\N	101
27723	9081	98	15.446999999999999	0.81430000000000002	1.0429999999999999	1.468	1.9870000000000001	1.3835999999999999	0.98529999999999995	0.94669999999999999	0.89849999999999997	0.85029999999999994	0.75380000000000003	0.65739999999999998	0.59660000000000002	0.55000000000000004	0.52659999999999996	0.50329999999999997	0.45729999999999998	0.37930000000000003	0.125	0.0049999999	6.2999999999999998	99.829002	31.109000000000002	17.960999999999999	\N	122
27722	9081	119	2.8530000000000002	0.66679999999999995	1.044	1.468	1.8009999999999999	0.95579999999999998	0.89139999999999997	0.84850000000000003	0.79479999999999995	0.74119999999999997	0.63390000000000002	0.59450000000000003	0.55759999999999998	0.52080000000000004	0.50239999999999996	0.4551	0.4138	0.35189999999999999	0.125	0.024	4	99.853996	9.5009999999999994	5.4850000000000003	\N	143
27721	9081	140	0.20999999999999999	1.1268	0.753	2.0099999999999998	4.5739999999999998	1.9029	1.7697000000000001	1.6809000000000001	1.5699000000000001	1.4588000000000001	1.2367999999999999	1.0146999999999999	0.83950000000000002	0.66759999999999997	0.59189999999999998	0.5242	0.43809999999999999	0.27039999999999997	0.125	5.6290002	4	99.668999	0.72599999999999998	0.41899999999999998	\N	164
27711	9067	40	290.06700000000001	2.5451999999999999	0.81799999999999995	2.347	3.8839999999999999	5.2351999999999999	3.9106999999999998	3.6783999999999999	3.3881000000000001	3.0977999999999999	2.5171000000000001	1.8426	0.95730000000000004	0.85419999999999996	0.80269999999999997	0.75119999999999998	0.70989999999999998	0.64810000000000001	0.125	0.0040000002	16	99.606003	288.66699999999997	166.66200000000001	\N	41
27710	9067	50	93.852999999999994	1.4711000000000001	1.2709999999999999	1.722	2.0510000000000002	2.1995	1.8460000000000001	1.7290000000000001	1.5829	1.4367000000000001	1.1443000000000001	0.95120000000000005	0.85489999999999999	0.75860000000000005	0.71040000000000003	0.66220000000000001	0.62290000000000001	0.55779999999999996	0.125	0.0040000002	16	99.665001	195.84899999999999	113.074	\N	51
27709	9067	80	279.72800000000001	1.8708	2.6549999999999998	2.3959999999999999	2.4609999999999999	3.9060000000000001	3.1231	2.6012	1.9821	1.7543	1.2985	0.80000000000000004	0.61050000000000004	0.58279999999999998	0.56899999999999995	0.55520000000000003	0.54410000000000003	0.52759999999999996	0.25	0.0020000001	16	99.528999	452.55500000000001	261.28300000000002	\N	81
27708	9067	110	81.781000000000006	2.5354999999999999	0.98399999999999999	2.25	3.3090000000000002	5.1928999999999998	3.8311999999999999	3.5339999999999998	3.1625000000000001	2.7909999999999999	2.048	1.7164999999999999	1.4133	1.1102000000000001	0.96799999999999997	0.85050000000000003	0.75660000000000005	0.61890000000000001	0.125	0.0020000001	16	99.807999	73.450000000000003	42.405999999999999	\N	111
27707	9067	139	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	140
27706	9066	33	146.47499999999999	2.2305999999999999	1.0649999999999999	2.262	3.0819999999999999	4.6289999999999996	3.7208000000000001	3.4178999999999999	3.0392000000000001	2.6604999999999999	1.954	1.5939000000000001	1.2339	0.94540000000000002	0.86760000000000004	0.78969999999999996	0.72740000000000005	0.63400000000000001	0.25	0.052999999	10	99.424004	231.703	133.774	\N	46
27705	9066	43	14.419	1.3012999999999999	1.369	2.0859999999999999	2.496	2.8180000000000001	1.8863000000000001	1.6820999999999999	1.4268000000000001	1.1715	0.9093	0.77259999999999995	0.63600000000000001	0.56000000000000005	0.52339999999999998	0.4793	0.43330000000000002	0.36430000000000001	0.25	0.057999998	10	99.265999	25.984999999999999	15.003	\N	56
27704	9066	83	82.469999999999999	1.7873000000000001	1.329	2.2869999999999999	2.9060000000000001	3.7254	3.0326	2.5707	1.9981	1.8285	1.4893000000000001	1.1500999999999999	0.91779999999999995	0.77029999999999998	0.6966	0.62460000000000004	0.57979999999999998	0.51249999999999996	0.25	0.161	10	99.192001	204.858	118.27500000000001	\N	96
27703	9066	93	251.041	1.9926999999999999	1.1259999999999999	2.1920000000000002	2.8900000000000001	3.8963999999999999	3.2871000000000001	2.8809	2.3731	1.9635	1.6883999999999999	1.4133	1.1382000000000001	0.91720000000000002	0.83399999999999996	0.75090000000000001	0.68430000000000002	0.58430000000000004	0.25	0.037	10	99.000999	178.37700000000001	102.986	\N	106
27702	9066	133	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	146
27693	9063	40	26.263999999999999	1.8273999999999999	1.266	2.032	2.4500000000000002	3.6230000000000002	2.9228000000000001	2.4559000000000002	1.9698	1.8315999999999999	1.5550999999999999	1.2786999999999999	1.0023	0.87890000000000001	0.81789999999999996	0.75680000000000003	0.70799999999999996	0.63480000000000003	0.125	0.0049999999	10	99.047997	20.469000000000001	11.818	\N	51
27692	9063	50	270.22899999999998	2.3365	1.1719999999999999	2.2679999999999998	2.9169999999999998	4.9160000000000004	3.7054999999999998	3.3147000000000002	2.8262	2.3378000000000001	1.8057000000000001	1.5086999999999999	1.2118	0.95240000000000002	0.86939999999999995	0.78649999999999998	0.72009999999999996	0.61899999999999999	0.125	0.0060000001	16	99.490997	118.172	68.227000000000004	\N	61
27691	9063	80	281.36599999999999	2.0038999999999998	1.1379999999999999	2.2690000000000001	3.0630000000000002	3.8982000000000001	3.3344999999999998	2.9586999999999999	2.4889999999999999	2.0192000000000001	1.6919999999999999	1.3774999999999999	1.0629999999999999	0.87180000000000002	0.79169999999999996	0.71150000000000002	0.64739999999999998	0.55230000000000001	0.125	0.003	16	99.716003	315.76600000000002	182.30799999999999	\N	91
27690	9063	110	161.13399999999999	2.2153	1.139	2.2229999999999999	2.891	4.5839999999999996	3.5973999999999999	3.2145999999999999	2.7361	2.2576999999999998	1.7958000000000001	1.5164	1.2369000000000001	0.97340000000000004	0.88580000000000003	0.79820000000000002	0.72819999999999996	0.62119999999999997	0.125	0.0060000001	16	99.874001	252.11099999999999	145.55699999999999	\N	121
27689	9063	140	2.0310000000000001	5.7698	0.86699999999999999	2.1499999999999999	4.524	11.2453	9.1150000000000002	8.3109000000000002	7.3057999999999996	6.3007	5.4272	4.5541	3.7336999999999998	3.0047000000000001	2.6402999999999999	2.2757999999999998	1.9722	1.1996	0.125	0.034000002	16	96.099998	6.8959999999999999	3.9809999999999999	\N	151
24791	8023	46	60.137999999999998	2.5186999999999999	0.97899999999999998	2.4710000000000001	3.75	5.4340999999999999	4.1041999999999996	3.7181999999999999	3.3191000000000002	2.9199000000000002	2.1215999999999999	1.6782999999999999	1.2988	0.95669999999999999	0.85509999999999997	0.75349999999999995	0.67210000000000003	0.56569999999999998	0.25	0.022	16	99.674004	102.553	59.209000000000003	\N	56
24792	8023	69	173.03999999999999	2.2561	0.91400000000000003	2.4359999999999999	3.706	4.7435	3.7618999999999998	3.4588999999999999	3.0800999999999998	2.7014	1.9735	1.6156999999999999	1.2579	0.93910000000000005	0.83020000000000005	0.72119999999999995	0.63400000000000001	0.53239999999999998	0.125	0.0080000004	16	99.873001	143.90899999999999	83.085999999999999	\N	79
24793	8023	95	239.148	1.5277000000000001	1.4570000000000001	2.1960000000000002	2.8700000000000001	3.3498999999999999	2.4639000000000002	1.9672000000000001	1.7763	1.5853999999999999	1.2036	0.92959999999999998	0.77869999999999995	0.62880000000000003	0.5867	0.54459999999999997	0.51090000000000002	0.4194	0.125	0.017000001	16	99.914001	99.004999999999995	57.161000000000001	\N	105
24794	8023	120	33.061	1.1309	1.369	1.7609999999999999	1.9450000000000001	1.9254	1.6220000000000001	1.4197	1.1668000000000001	0.98329999999999995	0.8851	0.78700000000000003	0.68879999999999997	0.60609999999999997	0.57640000000000002	0.54659999999999997	0.52280000000000004	0.4551	0.25	0.090000004	10	99.757004	48.090000000000003	27.765000000000001	\N	130
24795	8023	146	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	156
24790	8022	50	140.374	1.1108	1.431	2.0249999999999999	2.3929999999999998	2.1436000000000002	1.7041999999999999	1.4878	1.2172000000000001	0.98609999999999998	0.8448	0.70350000000000001	0.59989999999999999	0.53710000000000002	0.50570000000000004	0.45729999999999998	0.41560000000000002	0.35289999999999999	0.25	0.138	6.2999999999999998	98.982002	63.475999999999999	36.648000000000003	\N	55
24789	8022	64	134.761	1.3452	1.2190000000000001	1.859	2.2570000000000001	2.6614	1.9071	1.7784	1.6175999999999999	1.4568000000000001	1.1351	0.92910000000000004	0.80689999999999995	0.68469999999999998	0.62570000000000003	0.58479999999999999	0.55200000000000005	0.50290000000000001	0.25	0.013	10	99.787003	220.21600000000001	127.142	\N	69
24788	8022	84	109.968	1.5355000000000001	1.5149999999999999	2.5249999999999999	3.1110000000000002	3.6234000000000002	2.6682000000000001	2.0314000000000001	1.7827	1.5564	1.1037999999999999	0.85840000000000005	0.67459999999999998	0.55910000000000004	0.51239999999999997	0.46089999999999998	0.41849999999999998	0.3548	0.25	0.125	10	99.473999	95.569999999999993	55.177999999999997	\N	89
24787	8022	104	119.61499999999999	1.0210999999999999	1.2470000000000001	1.7509999999999999	2.1030000000000002	1.8136000000000001	1.5838000000000001	1.4305000000000001	1.2390000000000001	1.0475000000000001	0.91120000000000001	0.80979999999999996	0.70850000000000002	0.61419999999999997	0.57940000000000003	0.54449999999999998	0.51659999999999995	0.43340000000000001	0.25	0.017000001	6.2999999999999998	99.816002	102.155	58.978999999999999	\N	109
24786	8022	134	0.95099999999999996	1.3718999999999999	1.8879999999999999	2.1139999999999999	1.879	3.8780999999999999	1.6501999999999999	0.97670000000000001	0.86099999999999999	0.74539999999999995	0.60940000000000005	0.56820000000000004	0.52700000000000002	0.47410000000000002	0.43669999999999998	0.3992	0.36930000000000002	0.32429999999999998	0.25	0.072999999	10	98.32	2.0030000000000001	1.157	\N	139
27688	9062	44	17.611999999999998	2.2075	1.234	2.2069999999999999	2.7000000000000002	4.6802000000000001	3.5851999999999999	3.1534	2.6135999999999999	2.0739000000000001	1.7407999999999999	1.4625999999999999	1.1842999999999999	0.94869999999999999	0.87270000000000003	0.79679999999999995	0.73599999999999999	0.64480000000000004	0.5	2.5420001	10	98.021004	57.987000000000002	33.478999999999999	\N	44
27687	9062	70	87.727000000000004	1.2688999999999999	1.2849999999999999	1.786	1.9990000000000001	1.9460999999999999	1.7133	1.5580000000000001	1.3640000000000001	1.1699999999999999	0.9446	0.84589999999999999	0.74729999999999996	0.64859999999999995	0.60599999999999998	0.56759999999999999	0.53680000000000005	0.47260000000000002	0.25	0.16	10	99.139	115.908	66.920000000000002	\N	70
27686	9062	95	120.124	2.0682	1.2190000000000001	2.234	2.8879999999999999	4.2972999999999999	3.2559	2.6928999999999998	1.9979	1.8623000000000001	1.591	1.3197000000000001	1.0484	0.87139999999999995	0.79310000000000003	0.7147	0.65210000000000001	0.55079999999999996	0.25	0.1	10	97.527	38.286000000000001	22.103999999999999	\N	95
27685	9062	120	229.33099999999999	2.4178999999999999	1.2	2.1869999999999998	2.7389999999999999	4.5449000000000002	3.4275000000000002	2.9565999999999999	2.3679999999999999	1.9512	1.6909000000000001	1.4306000000000001	1.1702999999999999	0.94389999999999996	0.86270000000000002	0.78149999999999997	0.71650000000000003	0.61739999999999995	0.25	0.023	16	98.602997	373.24900000000002	215.495	\N	120
24785	8021	44	17.611999999999998	2.2075	1.234	2.2069999999999999	2.7000000000000002	4.6802000000000001	3.5851999999999999	3.1534	2.6135999999999999	2.0739000000000001	1.7407999999999999	1.4625999999999999	1.1842999999999999	0.94869999999999999	0.87270000000000003	0.79679999999999995	0.73599999999999999	0.64480000000000004	0.5	2.5420001	10	98.021004	57.987000000000002	33.478999999999999	\N	54
24784	8021	70	87.727000000000004	1.2688999999999999	1.2849999999999999	1.786	1.9990000000000001	1.9460999999999999	1.7133	1.5580000000000001	1.3640000000000001	1.1699999999999999	0.9446	0.84589999999999999	0.74729999999999996	0.64859999999999995	0.60599999999999998	0.56759999999999999	0.53680000000000005	0.47260000000000002	0.25	0.16	10	99.139	115.908	66.920000000000002	\N	80
24783	8021	95	120.124	2.0682	1.2190000000000001	2.234	2.8879999999999999	4.2972999999999999	3.2559	2.6928999999999998	1.9979	1.8623000000000001	1.591	1.3197000000000001	1.0484	0.87139999999999995	0.79310000000000003	0.7147	0.65210000000000001	0.55079999999999996	0.25	0.1	10	97.527	38.286000000000001	22.103999999999999	\N	105
24782	8021	120	229.33099999999999	2.4178999999999999	1.2	2.1869999999999998	2.7389999999999999	4.5449000000000002	3.4275000000000002	2.9565999999999999	2.3679999999999999	1.9512	1.6909000000000001	1.4306000000000001	1.1702999999999999	0.94389999999999996	0.86270000000000002	0.78149999999999997	0.71650000000000003	0.61739999999999995	0.25	0.023	16	98.602997	373.24900000000002	215.495	\N	130
24781	8021	145	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	155
24070	7311	64	74.867999999999995	1.639	1.0660000000000001	2.1909999999999998	2.9489999999999998	3.5055000000000001	2.8368000000000002	2.391	1.958	1.8170999999999999	1.5355000000000001	1.2538	0.98309999999999997	0.81220000000000003	0.7268	0.64129999999999998	0.59089999999999998	0.52059999999999995	0.125	0.015	6.2999999999999998	99.611	0	0	\N	64
24069	7311	72	149.58199999999999	1.4498	1.4710000000000001	2.04	2.302	3.2742	2.3031999999999999	1.9199999999999999	1.7321	1.5441	1.1680999999999999	0.93059999999999998	0.80500000000000005	0.6794	0.62190000000000001	0.5837	0.55320000000000003	0.50749999999999995	0.063	0.027000001	6.2999999999999998	99.125	0	0	\N	72
24068	7311	99	101.121	1.2203999999999999	1.375	1.794	1.8959999999999999	2.1042999999999998	1.7230000000000001	1.5285	1.2854000000000001	1.0423	0.91359999999999997	0.81899999999999995	0.72440000000000004	0.62990000000000002	0.59609999999999996	0.56240000000000001	0.53539999999999999	0.48199999999999998	0.063	0.035999998	6.2999999999999998	98.721001	0	0	\N	99
24067	7311	119	44.060000000000002	2.1408999999999998	1.3440000000000001	2.5489999999999999	3.2080000000000002	4.9455999999999998	3.8227000000000002	3.3595000000000002	2.7806000000000002	2.2016	1.6806000000000001	1.2938000000000001	0.96060000000000001	0.7964	0.71430000000000005	0.63219999999999998	0.58840000000000003	0.52380000000000004	0.25	0.068999998	10	97.922997	0	0	\N	119
24066	7311	140	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	140
24185	7421	59	101.63	1.1714	1.339	1.7509999999999999	1.8069999999999999	1.9377	1.7003999999999999	1.5422	1.3444	1.1467000000000001	0.93779999999999997	0.83889999999999998	0.74009999999999998	0.64119999999999999	0.60729999999999995	0.57789999999999997	0.5544	0.51910000000000001	0.063	0.003	6.2999999999999998	98.849998	0	0	\N	59
24184	7421	80	63.496000000000002	1.8119000000000001	1.6060000000000001	2.456	2.9900000000000002	4.1942000000000004	3.2681	2.7321	2.0621	1.8244	1.4373	1.0502	0.85229999999999995	0.68269999999999997	0.61470000000000002	0.57420000000000004	0.54179999999999995	0.48070000000000002	0.063	0.0020000001	6.2999999999999998	95.833	0	0	\N	80
24183	7421	100	22.321999999999999	1.0103	1.3400000000000001	1.802	2.1909999999999998	1.8466	1.5674999999999999	1.3814	1.1488	0.97950000000000004	0.86539999999999995	0.75139999999999996	0.63739999999999997	0.57509999999999994	0.54579999999999995	0.51639999999999997	0.48249999999999998	0.39500000000000002	0.063	0.003	4	98.476997	0	0	\N	100
24182	7421	120	60.677999999999997	1.7934000000000001	1.5720000000000001	2.2789999999999999	2.6520000000000001	4.1806000000000001	3.0926	2.4297	1.9194	1.752	1.4172	1.0823	0.90080000000000005	0.76929999999999998	0.7036	0.63780000000000003	0.59540000000000004	0.5343	0.063	0.0020000001	6.2999999999999998	96.165001	0	0	\N	120
24181	7421	140	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	140
24061	7309	45	64.421000000000006	1.9545999999999999	1.24	2.3029999999999999	2.9020000000000001	4.2808000000000002	3.4064000000000001	2.9342000000000001	2.3437999999999999	1.9365000000000001	1.6324000000000001	1.3284	1.0243	0.85809999999999997	0.78100000000000003	0.70389999999999997	0.64219999999999999	0.5625	0.063	0.003	10	99.459	0	0	\N	45
24060	7309	65	5.8280000000000003	1.5933999999999999	1.5489999999999999	2.5190000000000001	3.4169999999999998	3.7006000000000001	2.9708999999999999	2.4843999999999999	1.9567000000000001	1.7437	1.3177000000000001	0.94779999999999998	0.74219999999999997	0.59370000000000001	0.55359999999999998	0.51359999999999995	0.46829999999999999	0.38569999999999999	0.063	0.0040000002	6.2999999999999998	98.237	0	0	\N	65
24059	7309	86	77.682000000000002	1.5147999999999999	1.407	2.0739999999999998	2.452	3.1890000000000001	2.3222	1.9371	1.7594000000000001	1.5817000000000001	1.2262999999999999	0.94420000000000004	0.79049999999999998	0.63690000000000002	0.5998	0.5665	0.54000000000000004	0.50009999999999999	0.063	0.003	10	98.835999	0	0	\N	86
24058	7309	106	162.197	1.8123	1.27	2.3399999999999999	2.927	3.8248000000000002	3.0777999999999999	2.5798000000000001	1.9886999999999999	1.8243	1.4956	1.1668000000000001	0.91290000000000004	0.73609999999999998	0.64770000000000005	0.59599999999999997	0.56200000000000006	0.51090000000000002	0.063	0.003	10	99.046997	0	0	\N	106
24057	7309	128	96.677999999999997	1.3471	1.5700000000000001	2.1739999999999999	2.5619999999999998	2.9268000000000001	1.9006000000000001	1.6975	1.4437	1.1898	0.88360000000000005	0.69779999999999998	0.58899999999999997	0.52439999999999998	0.48820000000000002	0.44040000000000001	0.4022	0.34489999999999998	0.063	0.003	10	98.935997	0	0	\N	128
24056	7309	147	0.031	0.93810000000000004	0.86799999999999999	2.2599999999999998	3.911	1.8	1.6599999999999999	1.5667	1.45	1.3332999999999999	1.1000000000000001	0.78859999999999997	0.5	0.42709999999999998	0.3906	0.35420000000000001	0.32500000000000001	0.28129999999999999	0.063	0.28600001	2	98.570999	0	0	\N	147
24055	7308	46	66.792000000000002	1.1315	1.3540000000000001	1.9279999999999999	2.3170000000000002	1.9753000000000001	1.6704000000000001	1.4672000000000001	1.2131000000000001	0.99009999999999998	0.86739999999999995	0.74480000000000002	0.62590000000000001	0.56289999999999996	0.53129999999999999	0.49959999999999999	0.44950000000000001	0.37430000000000002	0.063	0.003	10	99.547997	0	0	\N	56
24054	7308	67	63.356000000000002	1.4237	1.641	2.2010000000000001	2.6059999999999999	3.3195999999999999	2.4380999999999999	1.9549000000000001	1.7337	1.5124	1.0699000000000001	0.86470000000000002	0.70409999999999995	0.5948	0.56210000000000004	0.52949999999999997	0.50339999999999996	0.41060000000000002	0.063	0.0040000002	6.2999999999999998	98.601997	0	0	\N	77
24053	7308	86	130.78800000000001	0.83450000000000002	1.169	1.7070000000000001	1.9419999999999999	1.5849	1.0499000000000001	0.93930000000000002	0.85109999999999997	0.76280000000000003	0.6179	0.56899999999999995	0.52010000000000001	0.45860000000000001	0.42349999999999999	0.38840000000000002	0.3604	0.31830000000000003	0.063	0.0049999999	6.2999999999999998	99.449997	0	0	\N	96
24052	7308	105	2.149	1.4162999999999999	0.91900000000000004	2.2519999999999998	3.6360000000000001	3.1202000000000001	2.2404999999999999	1.9298	1.7811999999999999	1.6326000000000001	1.3352999999999999	1.038	0.82499999999999996	0.62619999999999998	0.5585	0.49159999999999998	0.44180000000000003	0.36730000000000002	0.063	0.0080000004	6.2999999999999998	99.480003	0	0	\N	115
24051	7308	136	0.20799999999999999	0.46929999999999999	0.94999999999999996	1.3899999999999999	1.677	0.623	0.59150000000000003	0.57050000000000001	0.54430000000000001	0.5181	0.47489999999999999	0.4365	0.3982	0.35980000000000001	0.3407	0.32150000000000001	0.30609999999999998	0.28310000000000002	0.063	0.034000002	2	99.830002	0	0	\N	146
23920	7224	54	7.9850000000000003	2.6644999999999999	0.751	2.7789999999999999	5.157	5.7367999999999997	4.8593000000000002	4.2742000000000004	3.7797999999999998	3.4274	2.7225999999999999	2.0177999999999998	1.5649	1.1186	0.92320000000000002	0.75929999999999997	0.62909999999999999	0.52800000000000002	0.063	0.013	6.2999999999999998	93.850998	0	0	\N	54
23919	7224	64	20.879000000000001	1.2985	1.2749999999999999	1.8029999999999999	1.9570000000000001	2.1793	1.8153999999999999	1.6766000000000001	1.5029999999999999	1.3293999999999999	0.99480000000000002	0.89190000000000003	0.78910000000000002	0.68630000000000002	0.63490000000000002	0.59209999999999996	0.55859999999999999	0.50839999999999996	0.063	0.0060000001	10	99.370003	0	0	\N	64
23918	7224	94	7.1689999999999996	1.1637999999999999	1.4490000000000001	2.0009999999999999	2.343	2.5017	1.78	1.552	1.2669999999999999	0.99590000000000001	0.86739999999999995	0.7389	0.62050000000000005	0.55869999999999997	0.52780000000000005	0.49370000000000003	0.44429999999999997	0.37030000000000002	0.063	0.017999999	6.2999999999999998	99.028999	0	0	\N	94
23917	7224	105	15.08	1.0379	1.486	1.677	1.74	1.8148	1.4642999999999999	1.2305999999999999	0.98850000000000005	0.93400000000000005	0.82499999999999996	0.71599999999999997	0.62109999999999999	0.57920000000000005	0.55820000000000003	0.53720000000000001	0.52039999999999997	0.4743	0.063	0.0060000001	6.2999999999999998	98.773003	0	0	\N	105
23916	7224	133	4.8570000000000002	2.0442999999999998	1.0249999999999999	3.121	5.6120000000000001	5.0068000000000001	3.9460000000000002	3.6095000000000002	3.1888999999999998	2.7684000000000002	1.9401999999999999	1.2486999999999999	0.64449999999999996	0.54049999999999998	0.49419999999999997	0.44469999999999998	0.40510000000000002	0.34570000000000001	0.063	0.0080000004	6.2999999999999998	96.882004	0	0	\N	133
23915	7223	41	22.204000000000001	1.5111000000000001	1.5049999999999999	2.0219999999999998	2.3519999999999999	3.2909000000000002	2.4281999999999999	1.9650000000000001	1.7939000000000001	1.6228	1.2806	0.9788	0.86109999999999998	0.74339999999999995	0.68459999999999999	0.627	0.59399999999999997	0.5444	0.063	0.0020000001	6.2999999999999998	98.928001	0	0	\N	41
23914	7223	57	18.251000000000001	1.2501	1.3340000000000001	1.827	2.0880000000000001	1.9972000000000001	1.7466999999999999	1.5797000000000001	1.371	1.1623000000000001	0.93469999999999998	0.82789999999999997	0.72109999999999996	0.61980000000000002	0.58540000000000003	0.55089999999999995	0.52339999999999998	0.44769999999999999	0.063	0.0020000001	10	99.596001	0	0	\N	57
23913	7223	78	15.702999999999999	2.5766	1.8129999999999999	2.6669999999999998	3.1739999999999999	6.0071000000000003	3.9329000000000001	3.3452000000000002	2.6105999999999998	1.9634	1.5293000000000001	1.0951	0.88060000000000005	0.72770000000000001	0.6512	0.59340000000000004	0.55289999999999995	0.48170000000000002	0.063	0.0020000001	16	98.011002	0	0	\N	78
23912	7223	106	15.079000000000001	1.631	1.522	2.0680000000000001	2.2490000000000001	3.3963000000000001	2.3140999999999998	1.9120999999999999	1.7174	1.5227999999999999	1.1335	0.90690000000000004	0.76529999999999998	0.62719999999999998	0.59640000000000004	0.56559999999999999	0.54100000000000004	0.504	0.063	0.0020000001	10	98.089996	0	0	\N	106
23911	7223	138	3.5990000000000002	1.6428	0.99399999999999999	2.149	2.8540000000000001	3.3948	2.7980999999999998	2.4003000000000001	1.9739	1.8403	1.573	1.3057000000000001	1.0384	0.84060000000000001	0.74760000000000004	0.65449999999999997	0.60570000000000002	0.55120000000000002	0.063	0.003	6.2999999999999998	99.418999	0	0	\N	138
23910	7222	49	20.876999999999999	1.9484999999999999	1.448	2.4009999999999998	2.9049999999999998	4.2991999999999999	3.3435000000000001	2.8290999999999999	2.1861999999999999	1.8729	1.5149999999999999	1.1571	0.91500000000000004	0.76359999999999995	0.68779999999999997	0.61850000000000005	0.57979999999999998	0.52159999999999995	0.063	0.003	10	98.408997	0	0	\N	49
23909	7222	75	22.736000000000001	2.5659000000000001	1.0820000000000001	2.9990000000000001	4.6550000000000002	6.0537000000000001	4.5919999999999996	3.8426999999999998	3.3416999999999999	2.8405999999999998	1.9268000000000001	1.4723999999999999	1.0181	0.76119999999999999	0.63690000000000002	0.56540000000000001	0.51070000000000004	0.41389999999999999	0.063	0.003	10	96.158997	0	0	\N	75
23908	7222	98	32.502000000000002	1.6017999999999999	1.4450000000000001	2.1949999999999998	2.879	3.4131	2.4830999999999999	1.9671000000000001	1.7809999999999999	1.5949	1.2226999999999999	0.94110000000000005	0.79469999999999996	0.6482	0.59630000000000005	0.5514	0.51549999999999996	0.42470000000000002	0.063	0.0080000004	10	98.617996	0	0	\N	98
23907	7222	124	1.1259999999999999	0.62009999999999998	0.999	1.5529999999999999	1.877	0.93530000000000002	0.8397	0.77600000000000002	0.69640000000000002	0.62649999999999995	0.5837	0.54100000000000004	0.49740000000000001	0.43530000000000002	0.4042	0.37309999999999999	0.3483	0.311	0.125	0.0060000001	4	99.691002	0	0	\N	124
23906	7222	149	0.029999999999999999	2.3418000000000001	1.0760000000000001	1.746	2.3700000000000001	3.9097	3.6232000000000002	3.4323000000000001	3.1934999999999998	2.9548000000000001	2.4773999999999998	2	1.7613000000000001	1.5226	1.4032	1.2839	1.1883999999999999	1.0451999999999999	0.063	0.27000001	4	91.891998	0	0	\N	149
23905	7221	39	9.5329999999999995	2.3917000000000002	1.2050000000000001	2.0390000000000001	2.4239999999999999	4.7214	3.6663000000000001	3.3025000000000002	2.8477000000000001	2.3929999999999998	1.8689	1.6380999999999999	1.4073	1.1765000000000001	1.0610999999999999	0.95640000000000003	0.88219999999999998	0.77090000000000003	0.063	0.0020000001	10	97.433998	0	0	\N	39
23904	7221	59	24.739999999999998	2.4407000000000001	1.083	2.29	3.1019999999999999	5.1455000000000002	3.8761999999999999	3.5320999999999998	3.1019000000000001	2.6718000000000002	1.9329000000000001	1.6266	1.3204	1.0141	0.91249999999999998	0.81620000000000004	0.73909999999999998	0.62309999999999999	0.063	0.0020000001	10	97.232002	0	0	\N	59
23903	7221	79	46.337000000000003	2.2765	1.038	2.4820000000000002	3.6200000000000001	4.9114000000000004	3.6888999999999998	3.2988	2.8113000000000001	2.3237000000000001	1.7831999999999999	1.4587000000000001	1.1343000000000001	0.87980000000000003	0.77729999999999999	0.67479999999999996	0.59860000000000002	0.49259999999999998	0.063	0.0020000001	10	97.120003	0	0	\N	79
23902	7221	108	46.643999999999998	2.3935	1.083	2.3540000000000001	3.2370000000000001	5.2096999999999998	3.8248000000000002	3.4359999999999999	2.9500999999999999	2.4641000000000002	1.8494999999999999	1.5615000000000001	1.2734000000000001	0.98919999999999997	0.88239999999999996	0.77569999999999995	0.69030000000000002	0.57140000000000002	0.063	0.001	10	97.242996	0	0	\N	108
23901	7221	139	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	139
23890	7201	52	6.8220000000000001	1.9479	1.266	2.0659999999999998	2.4769999999999999	4.1302000000000003	3.0072000000000001	2.3046000000000002	1.9184000000000001	1.7934000000000001	1.5435000000000001	1.2936000000000001	1.0436000000000001	0.89039999999999997	0.82399999999999995	0.75760000000000005	0.70450000000000002	0.62309999999999999	0.063	0.003	10	98.622002	0	0	\N	52
23889	7201	72	19.736999999999998	1.5872999999999999	1.595	2.202	2.6040000000000001	3.5602999999999998	2.6067	1.9927999999999999	1.7959000000000001	1.5991	1.2053	0.93740000000000001	0.80649999999999999	0.67559999999999998	0.61670000000000003	0.57279999999999998	0.53769999999999996	0.46289999999999998	0.063	0.0020000001	10	99.179001	0	0	\N	72
23888	7201	92	20.925000000000001	1.4689000000000001	1.4079999999999999	2.1200000000000001	2.7090000000000001	3.2526000000000002	2.4283999999999999	1.9690000000000001	1.7930999999999999	1.6171	1.2653000000000001	0.9657	0.82609999999999995	0.68640000000000001	0.62139999999999995	0.57650000000000001	0.54049999999999998	0.46710000000000002	0.063	0.0049999999	6.2999999999999998	98.982002	0	0	\N	92
23887	7201	112	16.295999999999999	1.2378	1.3939999999999999	1.897	2.2010000000000001	2.5331999999999999	1.8469	1.6693	1.4473	1.2252000000000001	0.94210000000000005	0.82469999999999999	0.70730000000000004	0.60709999999999997	0.57369999999999999	0.54020000000000001	0.51339999999999997	0.42799999999999999	0.063	0.003	10	99.625	0	0	\N	112
23886	7201	132	3.9630000000000001	2.5468000000000002	0.69899999999999995	2.722	5.5540000000000003	5.4169	4.5236999999999998	3.968	3.6366999999999998	3.3052999999999999	2.6425999999999998	1.9876	1.5801000000000001	1.1725000000000001	0.96809999999999996	0.76000000000000001	0.61050000000000004	0.4758	0.063	0.003	6.2999999999999998	95.931999	0	0	\N	132
23875	7183	46	21.196999999999999	2.4561000000000002	0.97899999999999998	2.3370000000000002	3.528	5.2549999999999999	3.9910999999999999	3.6821000000000002	3.2957999999999998	2.9096000000000002	2.1372	1.7262999999999999	1.3935	1.0607	0.92979999999999996	0.81940000000000002	0.73099999999999998	0.60570000000000002	0.125	0.0020000001	10	98.684998	0	0	\N	46
23874	7183	65	20.940000000000001	0.9425	1.3600000000000001	1.8380000000000001	2.2200000000000002	1.7902	1.4777	1.2694000000000001	1.0088999999999999	0.93959999999999999	0.81459999999999999	0.6895	0.60150000000000003	0.54720000000000002	0.52000000000000002	0.4844	0.43740000000000001	0.3669	0.125	0.003	4	99.106003	0	0	\N	65
23873	7183	95	14.615	2.2244999999999999	0.90200000000000002	2.5449999999999999	3.8540000000000001	4.9195000000000002	3.8254999999999999	3.4965000000000002	3.0853000000000002	2.6741000000000001	1.9361999999999999	1.5824	1.2284999999999999	0.91169999999999995	0.78710000000000002	0.66239999999999999	0.59040000000000004	0.50239999999999996	0.125	0.0020000001	10	99.523003	0	0	\N	95
23872	7183	115	16.158999999999999	1.4315	1.1990000000000001	1.9259999999999999	2.5920000000000001	2.8487	1.9434	1.8112999999999999	1.6460999999999999	1.4809000000000001	1.1506000000000001	0.92159999999999997	0.77749999999999997	0.63349999999999995	0.59330000000000005	0.55479999999999996	0.52400000000000002	0.44390000000000002	0.063	0.003	10	98.897003	0	0	\N	115
23871	7183	135	14.5	1.2159	1.97	2.1890000000000001	2.1099999999999999	3.0564	1.8384	1.4955000000000001	1.0669	0.91200000000000003	0.70350000000000001	0.59830000000000005	0.5494	0.50049999999999994	0.45910000000000001	0.41720000000000002	0.38369999999999999	0.33339999999999997	0.063	0.0020000001	10	99.541	0	0	\N	135
23870	7182	49	21.472000000000001	1.9351	1.095	2.169	2.8799999999999999	3.8370000000000002	3.3056000000000001	2.9512999999999998	2.5084	2.0655999999999999	1.7385999999999999	1.4563999999999999	1.1740999999999999	0.93600000000000005	0.85260000000000002	0.76910000000000001	0.70230000000000004	0.60370000000000001	0.063	0.0040000002	6.2999999999999998	97.799004	0	0	\N	49
23869	7182	70	21.696000000000002	2.4731999999999998	1.034	2.3050000000000002	3.2410000000000001	5.2243000000000004	3.9068000000000001	3.577	3.1646999999999998	2.7524000000000002	1.9732000000000001	1.6674	1.3615999999999999	1.0557000000000001	0.93100000000000005	0.82240000000000002	0.73550000000000004	0.6089	0.063	0.0020000001	10	97.449997	0	0	\N	70
23868	7182	100	17.722999999999999	1.9924999999999999	1.05	2.3519999999999999	3.2850000000000001	3.8847999999999998	3.2092000000000001	2.7587000000000002	2.1957	1.9063000000000001	1.6189	1.3315999999999999	1.0442	0.83460000000000001	0.7369	0.6391	0.58030000000000004	0.49280000000000002	0.063	0.0020000001	10	97.786003	0	0	\N	100
23867	7182	110	17.094999999999999	2.9836	1.1439999999999999	2.4390000000000001	3.835	6.1590999999999996	4.9591000000000003	4.1590999999999996	3.6777000000000002	3.2945000000000002	2.528	1.9009	1.5824	1.2639	1.1047	0.95009999999999994	0.83379999999999999	0.6593	0.063	0.0020000001	10	95.181999	0	0	\N	110
23866	7182	140	22.503	4.0092999999999996	0.57999999999999996	3.347	6.7649999999999997	9.1524000000000001	6.7228000000000003	5.8944000000000001	5.2081999999999997	4.5220000000000002	3.4792000000000001	2.6385999999999998	1.8347	1.1465000000000001	0.89149999999999996	0.70240000000000002	0.60019999999999996	0.51429999999999998	0.063	0.0070000002	16	97.422997	0	0	\N	140
23865	7181	46	3.5	1.8584000000000001	1.6679999999999999	2.427	2.895	3.9771999999999998	3.2599	2.7816999999999998	2.1839	1.8584000000000001	1.4492	1.0399	0.86250000000000004	0.71009999999999995	0.63400000000000001	0.58840000000000003	0.55330000000000001	0.50060000000000004	0.063	0.030999999	10	98.749001	0	0	\N	46
23864	7181	66	18.122	1.6881999999999999	1.242	1.8320000000000001	2.1800000000000002	2.8237000000000001	1.8991	1.7702	1.609	1.4478	1.1254999999999999	0.93030000000000002	0.81620000000000004	0.70209999999999995	0.64500000000000002	0.59940000000000004	0.56610000000000005	0.51619999999999999	0.063	0.0040000002	10	96.157997	0	0	\N	66
23863	7181	96	23	2.8237999999999999	0.97599999999999998	2.5459999999999998	4.218	5.9635999999999996	4.6871	3.9430999999999998	3.5739000000000001	3.2046999999999999	2.4662999999999999	1.8638999999999999	1.4944999999999999	1.1252	0.95799999999999996	0.8276	0.72330000000000005	0.58460000000000001	0.063	0.0020000001	10	96.146004	0	0	\N	96
23862	7181	106	14.398	1.9339	1.22	2.456	3.2959999999999998	4.0456000000000003	3.3475000000000001	2.9037999999999999	2.3492000000000002	1.9351	1.5847	1.2343	0.93959999999999999	0.7571	0.66590000000000005	0.59770000000000001	0.55510000000000004	0.48080000000000001	0.063	0.0020000001	10	99.116997	0	0	\N	106
23861	7181	135	20.327000000000002	1.7969999999999999	2.2799999999999998	2.5350000000000001	2.4990000000000001	4.5220000000000002	3.2888000000000002	2.6579000000000002	1.9512	1.6572	1.0690999999999999	0.85919999999999996	0.69969999999999999	0.59609999999999996	0.56599999999999995	0.53590000000000004	0.51180000000000003	0.42780000000000001	0.063	0.0040000002	10	98.791	0	0	\N	135
12977	2133	54	23.263999999999999	1.9564999999999999	0.98399999999999999	2.286	3.2160000000000002	3.9304000000000001	3.3955000000000002	3.0388000000000002	2.5931000000000002	2.1473	1.7715000000000001	1.4977	1.224	0.95979999999999999	0.84919999999999995	0.73850000000000005	0.65000000000000002	0.55089999999999995	0.125	0.0080000004	6.2999999999999998	98.262001	2.004	1.157	\N	54
12978	2133	64	7.9909999999999997	1.5128999999999999	0.86799999999999999	1.865	2.7440000000000002	3.0202	2.1383000000000001	1.9288000000000001	1.8124	1.696	1.4631000000000001	1.2302999999999999	0.99829999999999997	0.83720000000000006	0.75670000000000004	0.67620000000000002	0.61460000000000004	0.5333	0.125	0.0070000002	6.2999999999999998	99.365997	22.068000000000001	12.741	\N	64
12979	2133	92	40.703000000000003	2.1324999999999998	1.2230000000000001	2.5339999999999998	3.323	4.9584000000000001	3.7528999999999999	3.3464	2.8382000000000001	2.3300000000000001	1.7336	1.3391	0.97529999999999994	0.79949999999999999	0.71150000000000002	0.62619999999999998	0.58440000000000003	0.52170000000000005	0.125	0.001	10	99.140999	2.9489999999999998	1.7030000000000001	\N	92
12980	2133	103	14.064	1.4779	1.405	1.9550000000000001	2.2570000000000001	3.2038000000000002	1.9812000000000001	1.8109999999999999	1.5983000000000001	1.3855	0.98750000000000004	0.8548	0.72209999999999996	0.60999999999999999	0.57720000000000005	0.54449999999999998	0.51829999999999998	0.43759999999999999	0.125	0.0020000001	10	98.963997	19.977	11.534000000000001	\N	103
12981	2133	143	0.0070000000000000001	0.49180000000000001	1.069	1.631	2.1779999999999999	0.92969999999999997	0.66549999999999998	0.5806	0.50329999999999997	0.47960000000000003	0.43709999999999999	0.39460000000000001	0.35210000000000002	0.30959999999999999	0.28839999999999999	0.2671	0.25009999999999999	0.20069999999999999	0.125	0.83999997	1	91.597	0	0	\N	143
12972	2132	38	0.043999999999999997	0.87129999999999996	1.3999999999999999	2.0409999999999999	2.4089999999999998	1.7991999999999999	1.4626999999999999	1.2383999999999999	0.9879	0.90680000000000005	0.74470000000000003	0.60580000000000001	0.52290000000000003	0.44929999999999998	0.4143	0.37919999999999998	0.35120000000000001	0.30909999999999999	0.125	0.14300001	2	93.581001	0.058999999999999997	0.034000000000000002	\N	38
12973	2132	57	0.76400000000000001	0.52529999999999999	0.96799999999999997	1.427	1.7190000000000001	0.81740000000000002	0.62819999999999998	0.60389999999999999	0.5736	0.54339999999999999	0.4884	0.44750000000000001	0.40670000000000001	0.36580000000000001	0.34539999999999998	0.32500000000000001	0.30859999999999999	0.28410000000000002	0.125	0.0089999996	4	99.863998	0.373	0.216	\N	57
12974	2132	68	11.722	1.0640000000000001	1.4990000000000001	2.036	2.3809999999999998	1.9874000000000001	1.6538999999999999	1.4317	1.1537999999999999	0.96619999999999995	0.81489999999999996	0.66349999999999998	0.58209999999999995	0.52070000000000005	0.48449999999999999	0.43709999999999999	0.39910000000000001	0.3422	0.125	0.003	6.2999999999999998	99.075996	25.776	14.882	\N	68
12975	2132	106	2	0.76859999999999995	1.1080000000000001	1.6970000000000001	2.0089999999999999	1.4878	0.99390000000000001	0.92779999999999996	0.84509999999999996	0.76239999999999997	0.61780000000000002	0.55640000000000001	0.49490000000000001	0.4325	0.4012	0.37	0.34499999999999997	0.30759999999999998	0.125	0.0060000001	6.2999999999999998	99.702003	2.7919999999999998	1.6120000000000001	\N	106
12976	2132	138	3.444	1.4812000000000001	3.1280000000000001	2.7749999999999999	1.929	4.5521000000000003	2.6187	1.5920000000000001	0.92359999999999998	0.73729999999999996	0.58989999999999998	0.53349999999999997	0.47689999999999999	0.4199	0.39140000000000003	0.36280000000000001	0.34000000000000002	0.30580000000000002	0.125	0.012	10	98.047997	5.101	2.9449999999999998	\N	138
12966	2131	49	1.944	0.5171	1.0169999999999999	1.393	1.6020000000000001	0.69820000000000004	0.5867	0.55100000000000005	0.50649999999999995	0.48549999999999999	0.45150000000000001	0.41760000000000003	0.38369999999999999	0.34970000000000001	0.3327	0.31580000000000003	0.30220000000000002	0.28179999999999999	0.125	0.029999999	4	99.628998	1.47	0.84899999999999998	\N	49
12967	2131	60	13.507	1.3956	2.29	2.3220000000000001	2.0289999999999999	3.2801	1.7787999999999999	1.4209000000000001	0.99160000000000004	0.84960000000000002	0.60709999999999997	0.50609999999999999	0.4521	0.40110000000000001	0.37559999999999999	0.35020000000000001	0.32979999999999998	0.29920000000000002	0.125	0.015	10	97.353996	11.542	6.6639999999999997	\N	60
12968	2131	69	29.013999999999999	0.52929999999999999	1.9690000000000001	2.2210000000000001	2.8940000000000001	0.98609999999999998	0.81430000000000002	0.69979999999999998	0.60570000000000002	0.55830000000000002	0.43369999999999997	0.26140000000000002	0.22620000000000001	0.20080000000000001	0.188	0.17530000000000001	0.1651	0.14990000000000001	0.125	0.228	4	99.169998	3.2410000000000001	1.871	\N	69
12969	2131	99	8.9030000000000005	0.65349999999999997	1.3080000000000001	1.6180000000000001	1.659	1.1655	0.80469999999999997	0.64259999999999995	0.58040000000000003	0.52739999999999998	0.47220000000000001	0.43469999999999998	0.3972	0.35970000000000002	0.34100000000000003	0.32219999999999999	0.30719999999999997	0.28470000000000001	0.125	0.011	4	98.612	3.2149999999999999	1.8560000000000001	\N	99
12970	2131	109	19.285	0.87519999999999998	1.6919999999999999	1.964	1.9059999999999999	1.8116000000000001	1.2635000000000001	0.96830000000000005	0.82640000000000002	0.6845	0.56810000000000005	0.4945	0.44540000000000002	0.3962	0.37169999999999997	0.34710000000000002	0.32750000000000001	0.29799999999999999	0.125	0.011	6.2999999999999998	99.164001	9.5419999999999998	5.5090000000000003	\N	109
12971	2131	139	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	139
12946	2130	27	0.069000000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.105	0.060999999999999999	\N	27
12947	2130	37	15.635999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	1.3069999999999999	0.755	\N	37
12948	2130	55	18.280000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	16.498000000000001	9.5250000000000004	\N	55
12949	2130	66	21.978999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	9.0760000000000005	5.2400000000000002	\N	66
12950	2130	135	9.8130000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	33.918999999999997	19.582999999999998	\N	135
12941	2129	29	17.693000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	10.034000000000001	5.7930000000000001	\N	29
12942	2129	47	14.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	7.6529999999999996	4.4180000000000001	\N	47
12943	2129	87	10.249000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	11.144	6.4340000000000002	\N	87
12944	2129	97	19.042000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	18.390000000000001	10.618	\N	97
12945	2129	137	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	137
11079	2127	32	21.103999999999999	2.3176999999999999	1.03	1.996	2.673	3.9297	3.5488	3.2949000000000002	2.9775	2.6600999999999999	2.0251999999999999	1.7518	1.4934000000000001	1.2350000000000001	1.1056999999999999	0.9798	0.89090000000000003	0.75760000000000005	0.5	0.85100001	10	98.769997	0	0	\N	32
12924	2085	146	7.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	1.3720000000000001	0.79200000000000004	\N	146
12913	2084	62	33.802	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	19.658999999999999	11.35	\N	62
12914	2084	72	61.843000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	86.394000000000005	49.878999999999998	\N	72
12915	2084	92	36.006999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	9.1920000000000002	5.3070000000000004	\N	92
12916	2084	102	43.473999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	33.444000000000003	19.309000000000001	\N	102
12917	2084	133	42.389000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	51.740000000000002	29.872	\N	133
12918	2084	142	28.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	10.766	6.2160000000000002	\N	142
12908	2083	52	47.808	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	41.932000000000002	24.209	\N	52
12909	2083	82	69.320999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	46.338999999999999	26.754000000000001	\N	82
12910	2083	92	87.388000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	100.60599999999999	58.085000000000001	\N	92
12911	2083	122	34.506999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	22.135000000000002	12.779999999999999	\N	122
12912	2083	132	29.978999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	11.433999999999999	6.6020000000000003	\N	132
12902	2082	62	69.891999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	79.149000000000001	45.697000000000003	\N	62
12903	2082	70	58.131999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	60.740000000000002	35.067999999999998	\N	70
12904	2082	90	0.53200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	1.8440000000000001	1.0649999999999999	\N	90
12905	2082	100	31.071999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	18.052	10.422000000000001	\N	100
12906	2082	130	39.886000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	24.411999999999999	14.093999999999999	\N	130
12907	2082	140	18.806000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	14.118	8.1509999999999998	\N	140
10918	2079	76	80.177000000000007	6.4642999999999997	1.0129999999999999	1.6930000000000001	2.2919999999999998	11.431699999999999	9.5358999999999998	8.9420000000000002	8.1997	7.4573	6.1726999999999999	5.5952999999999999	5.0179	4.4405000000000001	4.1517999999999997	3.7494999999999998	3.3269000000000002	2.6928999999999998	1	0.064000003	16	99.170998	106.123	61.270000000000003	\N	76
10919	2079	95	48.856000000000002	3.2151999999999998	1.01	1.8460000000000001	2.665	5.4538000000000002	3.9504999999999999	3.7363	3.4685999999999999	3.2008000000000001	2.6652999999999998	2.1297999999999999	1.7984	1.5323	1.3992	1.2661	1.1597	1	0.5	0.152	16	97.726997	59.216999999999999	34.189	\N	95
10920	2079	105	147.04499999999999	4.0263	0.92900000000000005	2.1349999999999998	3.214	8.2117000000000004	6.1477000000000004	5.5753000000000004	4.8597999999999999	4.1443000000000003	3.5207999999999999	2.9878999999999998	2.4548999999999999	1.9382999999999999	1.7276	1.5168999999999999	1.3484	1.0954999999999999	0.5	0.37900001	16	98.332001	149.215	86.150000000000006	\N	105
10921	2079	136	3.9060000000000001	5.2651000000000003	0.40500000000000003	3.2930000000000001	9.577	10.9046	9.1407000000000007	8.3874999999999993	7.4459	6.5042999999999997	5.3860000000000001	4.3608000000000002	3.3302999999999998	2.2970000000000002	1.7623	1.2033	0.8427	0.56240000000000001	0.5	7.1849999	16	98.094002	3.5800000000000001	2.5310000000000001	\N	136
10922	2079	146	14.903	1.9096	4.891	3.403	1.855	7.2111999999999998	4.1177000000000001	1.1765000000000001	0.7732	0.62229999999999996	0.5847	0.54710000000000003	0.50949999999999995	0.4496	0.41599999999999998	0.38240000000000002	0.35549999999999998	0.31509999999999999	0.25	0.31400001	10	95.288002	11.85	6.8419999999999996	\N	146
10913	2078	49	106.59	7.9637000000000002	1.0249999999999999	1.7210000000000001	2.4750000000000001	14.161799999999999	11.697800000000001	10.055099999999999	9.4650999999999996	8.9154999999999998	7.8163	6.7171000000000003	5.8216999999999999	5.0509000000000004	4.6654999999999998	4.2801	3.9517000000000002	3.1583999999999999	2	1.239	16	94.475998	149.12100000000001	105.444	\N	49
10914	2078	70	150.51499999999999	6.5076000000000001	0.94399999999999995	2.7130000000000001	4.7359999999999998	14.4834	11.6631	9.8960000000000008	8.7711000000000006	7.6460999999999997	5.7625000000000002	4.4244000000000003	3.4319000000000002	2.6000000000000001	2.1840000000000002	1.8292999999999999	1.5843	1.2168000000000001	0.25	0.039000001	16	93.225998	282.94799999999998	163.36000000000001	\N	70
10915	2078	95	358.42500000000001	4.4770000000000003	0.67500000000000004	2.4020000000000001	4.9299999999999997	8.9337	7.1238000000000001	6.1879	5.7462999999999997	5.3048000000000002	4.4215999999999998	3.6103999999999998	2.8649	2.1194000000000002	1.7901	1.4813000000000001	1.2343	0.89690000000000003	0.25	0.059999999	16	98.488998	100.527	58.039000000000001	\N	95
10916	2078	119	98.174999999999997	4.8426	6.0389999999999997	4.569	6.6959999999999997	14.033300000000001	10.8072	9.1344999999999992	7.4025999999999996	5.7934999999999999	2.9538000000000002	0.96260000000000001	0.74770000000000003	0.60260000000000002	0.57230000000000003	0.54200000000000004	0.51780000000000004	0.44109999999999999	0.25	0.048	16	93.657997	136.53299999999999	96.543000000000006	\N	119
10917	2078	145	7.306	0.37359999999999999	0.94399999999999995	1.2729999999999999	1.482	0.47810000000000002	0.46250000000000002	0.4521	0.439	0.42599999999999999	0.40000000000000002	0.374	0.34789999999999999	0.32190000000000002	0.30890000000000001	0.2959	0.28549999999999998	0.26979999999999998	0.25	2.381	0.5	98.413002	19.559999999999999	11.292999999999999	\N	145
10908	2077	70	0.042000000000000003	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	70
10909	2077	98	48.023000000000003	3.3675999999999999	0.94099999999999995	2.4540000000000002	4.1619999999999999	7.3681000000000001	5.8685999999999998	5.3113000000000001	4.6147	3.9561000000000002	3.2103999999999999	2.4645999999999999	1.8604000000000001	1.4902	1.3049999999999999	1.1198999999999999	0.97419999999999995	0.77139999999999997	0.5	2.0869999	10	97.153999	0	0	\N	98
10910	2077	108	0.43099999999999999	2.8767	1.0269999999999999	2.2440000000000002	4.8440000000000003	5.9714	4.7885999999999997	4	3.6842000000000001	3.3683999999999998	2.7368000000000001	2.1053000000000002	1.7367999999999999	1.4211	1.2632000000000001	1.1052999999999999	0.95069999999999999	0.56499999999999995	0.5	8.3330002	10	98.333	0	0	\N	108
10911	2077	138	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	138
10912	2077	148	1.222	0.37290000000000001	0.94199999999999995	1.2789999999999999	1.4950000000000001	0.47949999999999998	0.46360000000000001	0.45300000000000001	0.43980000000000002	0.42649999999999999	0.40000000000000002	0.3735	0.34699999999999998	0.32050000000000001	0.30719999999999997	0.29399999999999998	0.28339999999999999	0.26750000000000002	0.25	3.4089999	0.5	97.726997	0	0	\N	148
10903	2076	70	7.1719999999999997	5.8472	1.325	2.2109999999999999	2.8100000000000001	13.5848	9.1839999999999993	7.8639000000000001	6.2656000000000001	5.6079999999999997	4.2929000000000004	3.6082999999999998	3.1042999999999998	2.6004	2.3483999999999998	2.0964	1.8781000000000001	1.5275000000000001	0.5	0.075000003	16	92.376999	9.0229999999999997	6.3799999999999999	\N	70
10904	2076	80	12.063000000000001	6.1554000000000002	1.018	2.4729999999999999	4.1440000000000001	13.441599999999999	10.8491	9.5473999999999997	8.4353999999999996	7.3234000000000004	5.6158000000000001	4.3484999999999996	3.4822000000000002	2.7679	2.4108000000000001	2.0537000000000001	1.7735000000000001	1.3552999999999999	0.5	0.36700001	16	95.920998	13.081	9.25	\N	80
10905	2076	111	98.266999999999996	6.0995999999999997	0.65500000000000003	2.6749999999999998	5.9199999999999999	13.4345	9.8216000000000001	8.9382999999999999	7.8342999999999998	6.7302	5.5134999999999996	4.5368000000000004	3.5655000000000001	2.6009000000000002	2.1185	1.6953	1.3721000000000001	0.93130000000000002	0.5	1.34	16	93.877998	138.94300000000001	80.218999999999994	\N	111
10906	2076	120	63.256999999999998	4.6990999999999996	0.42599999999999999	3.2210000000000001	8.1590000000000007	9.9108000000000001	8.5696999999999992	7.6757	6.5582000000000003	5.9416000000000002	5.0095000000000001	4.0773999999999999	2.9830999999999999	1.8918999999999999	1.4156	0.97609999999999997	0.82620000000000005	0.61399999999999999	0.25	0.045000002	10	90.399002	110.282	63.670999999999999	\N	120
10907	2076	167	0.85399999999999998	0.42149999999999999	0.92900000000000005	1.3149999999999999	1.573	0.52759999999999996	0.48609999999999998	0.47399999999999998	0.45889999999999997	0.44390000000000002	0.41370000000000001	0.3836	0.35339999999999999	0.32329999999999998	0.30819999999999997	0.29310000000000003	0.28110000000000002	0.26300000000000001	0.25	5.691	2	99.186996	0	0	\N	167
10898	2075	77	0.11799999999999999	3.0196999999999998	1.0549999999999999	3.77	7.149	8.3000000000000007	6.7759999999999998	5.8399999999999999	4.8624999999999998	3.9333	2.7999999999999998	1.75	0.96299999999999997	0.64849999999999997	0.58130000000000004	0.52600000000000002	0.47670000000000001	0.39169999999999999	0.5	17.646999	8	88.235001	0	0	\N	77
10899	2075	87	2.1880000000000002	2.0996999999999999	3.661	3.391	3.4460000000000002	5.4831000000000003	4.2316000000000003	3.6000000000000001	2.9079000000000002	2.2158000000000002	1.1120000000000001	0.6522	0.55320000000000003	0.47389999999999999	0.43609999999999999	0.39829999999999999	0.36799999999999999	0.32269999999999999	0.25	0.38	10	97.719002	1.532	1.083	\N	87
10900	2075	97	0.59699999999999998	0.65949999999999998	1.0820000000000001	1.5169999999999999	1.742	0.97219999999999995	0.73360000000000003	0.62219999999999998	0.59419999999999995	0.56630000000000003	0.51039999999999996	0.46500000000000002	0.42199999999999999	0.379	0.35749999999999998	0.33600000000000002	0.31879999999999997	0.29299999999999998	0.5	58.139999	4	98.836998	0	0	\N	97
10901	2075	117	0.36099999999999999	2.7482000000000002	7.0330000000000004	4.2400000000000002	2.2709999999999999	8.5333000000000006	5.8662999999999998	5.1829000000000001	4.3285999999999998	3.2000000000000002	0.66700000000000004	0.52170000000000005	0.45629999999999998	0.40210000000000001	0.375	0.34789999999999999	0.32629999999999998	0.29380000000000001	0.25	1.923	10	94.231003	0	0	\N	117
10902	2075	137	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	137
10893	2074	82	240.40600000000001	5.2721999999999998	0.95599999999999996	4.141	8.1839999999999993	14.8072	11.4169	9.5652000000000008	8.1087000000000007	6.673	4.5557999999999996	2.8188	1.625	0.96409999999999996	0.85750000000000004	0.75090000000000001	0.66559999999999997	0.55669999999999997	0.5	6.652	20	99.190002	148.869	85.950000000000003	\N	82
10894	2074	92	325.09399999999999	2.4207000000000001	2.5819999999999999	2.5760000000000001	2.3889999999999998	5.8513000000000002	3.8534000000000002	3.2113999999999998	2.4089	1.8421000000000001	1.1982999999999999	0.93120000000000003	0.83169999999999999	0.73229999999999995	0.68259999999999998	0.63280000000000003	0.58089999999999997	0.50160000000000005	0.5	9.8800001	20	99.021004	227.13	131.13300000000001	\N	92
10895	2074	102	110.03	3.4601000000000002	1.5	3.6139999999999999	5.8899999999999997	9.0233000000000008	7.0404999999999998	5.9383999999999997	4.9112999999999998	3.9285999999999999	2.6606999999999998	1.5904	0.93810000000000004	0.73829999999999996	0.63839999999999997	0.58140000000000003	0.53900000000000003	0.45179999999999998	0.25	0.28200001	10	92.958	132.81100000000001	76.677999999999997	\N	102
10896	2074	132	70.192999999999998	2.5735000000000001	4.7149999999999999	3.5169999999999999	2.4460000000000002	7.6909000000000001	5.8158000000000003	4.8876999999999997	3.6785999999999999	2.3094999999999999	0.94810000000000005	0.76139999999999997	0.61450000000000005	0.56200000000000006	0.53580000000000005	0.50960000000000005	0.47010000000000002	0.3876	0.5	18.174	10	96.348	102.345	59.088999999999999	\N	132
10897	2074	142	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	142
10889	2073	69	268.154	4.1853999999999996	0.88400000000000001	1.99	3.04	7.5119999999999996	6.0655999999999999	5.6295999999999999	5.0846	4.5396000000000001	3.7452999999999999	3.2408999999999999	2.7364000000000002	2.2320000000000002	1.98	1.7306999999999999	1.5311999999999999	1.2319	0.25	0.050000001	20	98.900002	441.15300000000002	254.69999999999999	\N	69
10890	2073	99	27.407	6.1010999999999997	0.97999999999999998	2.9900000000000002	5.4729999999999999	15.6858	11.3934	9.3688000000000002	7.8643999999999998	6.6295999999999999	5.1230000000000002	3.8504	2.9861	2.1219000000000001	1.7931999999999999	1.5051000000000001	1.2746	0.93610000000000004	0.25	0.083999999	20	96.029999	8.2599999999999998	4.7690000000000001	\N	99
10891	2073	128	16.423999999999999	9.4220000000000006	0.78500000000000003	2.8050000000000002	9.9629999999999992	20.008099999999999	17.695399999999999	16.1572	14.234400000000001	12.3117	9.1676000000000002	7.1219000000000001	5.6050000000000004	4.4225000000000003	3.7604000000000002	2.9207000000000001	2.2490000000000001	0.92020000000000002	0.5	6.131	20	89.992996	17.986000000000001	10.384	\N	128
10892	2073	159	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	159
10883	2072	53	6.9100000000000001	5.5528000000000004	1.0269999999999999	2.1789999999999998	3.1019999999999999	12.8621	7.7066999999999997	6.5444000000000004	5.8243	5.2525000000000004	4.1086999999999998	3.4897	2.9258000000000002	2.3618999999999999	2.0798999999999999	1.8218000000000001	1.6229	1.3245	0.5	0.366	20	93.783997	11.890000000000001	6.8650000000000002	\N	53
10884	2072	83	351.21499999999997	5.0449000000000002	1.2729999999999999	2.0750000000000002	2.6819999999999999	10.502800000000001	7.9977	6.9608999999999996	5.9043999999999999	5.0972999999999997	3.8580999999999999	3.4150999999999998	2.9721000000000002	2.5291999999999999	2.3077000000000001	2.0861999999999998	1.8568	1.4384999999999999	0.25	0.097999997	20	98.305	674.55999999999995	389.45699999999999	\N	83
10885	2072	113	219.56	5.0465	0.68400000000000005	3.121	5.7430000000000003	12.5131	8.5305999999999997	7.0999999999999996	5.9592999999999998	5.3040000000000003	3.9965000000000002	3.3045	2.6124999999999998	1.8955	1.4409000000000001	0.99550000000000005	0.87570000000000003	0.69589999999999996	0.25	0.050000001	20	97.150002	682.25699999999995	393.90100000000001	\N	113
10886	2072	122	177.75999999999999	10.0908	0.71199999999999997	3.1930000000000001	11.641999999999999	24.008099999999999	19.713699999999999	17.951499999999999	15.748900000000001	13.5463	9.5357000000000003	7.3181000000000003	5.6467999999999998	4.2571000000000003	3.4661	2.6185999999999998	1.9333	0.81910000000000005	0.25	0.050000001	20	84.650002	371.29300000000001	214.36600000000001	\N	122
10887	2072	153	8.5760000000000005	0.56779999999999997	0.93300000000000005	1.304	1.55	0.53739999999999999	0.48509999999999998	0.4733	0.45860000000000001	0.44390000000000002	0.41449999999999998	0.3851	0.35570000000000002	0.32629999999999998	0.31159999999999999	0.2969	0.28510000000000002	0.26750000000000002	0.125	0.405	4	97.975998	0	0	\N	153
10888	2072	163	0.47699999999999998	1.8152999999999999	0.56699999999999995	2.7090000000000001	5.2039999999999997	3.4399999999999999	2.6240000000000001	2.0800000000000001	1.8929	1.7714000000000001	1.5286	1.2857000000000001	1.0428999999999999	0.52600000000000002	0.4531	0.40000000000000002	0.35749999999999998	0.29380000000000001	0.25	5.882	10	97.058998	0.35599999999999998	0.252	\N	163
10878	2071	77	9.4719999999999995	1.4232	1.238	1.7789999999999999	2.2949999999999999	2.8704000000000001	1.9622999999999999	1.8464	1.7014	1.5565	1.2666999999999999	0.99129999999999996	0.8821	0.77300000000000002	0.71840000000000004	0.66379999999999995	0.61980000000000002	0.55200000000000005	0.25	0.1	8	99.699997	20.864000000000001	12.045999999999999	\N	77
10879	2071	86	11.715	1.702	1.0509999999999999	1.7849999999999999	2.2570000000000001	3.3029999999999999	2.3938999999999999	1.9692000000000001	1.859	1.7488999999999999	1.5286	1.3084	1.0881000000000001	0.92549999999999999	0.86339999999999995	0.80130000000000001	0.75170000000000003	0.67720000000000002	0.5	1	10	99.5	37.978999999999999	21.927	\N	86
10880	2071	96	24.542000000000002	1.6003000000000001	0.85599999999999998	1.554	2.113	2.8529	1.9964	1.9249000000000001	1.8353999999999999	1.746	1.5670999999999999	1.3882000000000001	1.2093	1.0304	0.95340000000000003	0.88280000000000003	0.82630000000000003	0.74160000000000004	0.5	0.30000001	10	99.900002	42.393000000000001	24.475999999999999	\N	96
10881	2071	125	4.2430000000000003	0.53769999999999996	0.996	1.381	1.6060000000000001	0.62390000000000001	0.57969999999999999	0.55030000000000001	0.51349999999999996	0.48920000000000002	0.45479999999999998	0.42049999999999998	0.38619999999999999	0.35189999999999999	0.3347	0.3175	0.30380000000000001	0.28320000000000001	0.25	0.32699999	6.2999999999999998	99.835999	5.2880000000000003	3.0529999999999999	\N	125
10882	2071	135	0.014	3.4325999999999999	0.60999999999999999	3.085	6.0720000000000001	7.3585000000000003	6.9736000000000002	6.7169999999999996	6.3962000000000003	3.8353000000000002	3.3647	2.8940999999999999	2.4235000000000002	1.8824000000000001	1.2941	0.8972	0.73280000000000001	0.55420000000000003	0.5	7.5	6.2999999999999998	73.5	0	0	\N	135
10873	2070	77	20.59	1.5717000000000001	1.369	2.0459999999999998	2.593	3.3957999999999999	2.1457999999999999	1.8721000000000001	1.6782999999999999	1.4844999999999999	1.0969	0.89649999999999996	0.75839999999999996	0.62439999999999996	0.58450000000000002	0.54469999999999996	0.51280000000000003	0.42309999999999998	0.25	0.1	10	99.099998	50.289999999999999	29.035	\N	77
10874	2070	87	16.687000000000001	1.5097	1.333	1.887	2.2250000000000001	3.2524999999999999	2.0404	1.8643000000000001	1.6857	1.5071000000000001	1.1499999999999999	0.93630000000000002	0.82650000000000001	0.7167	0.66180000000000005	0.61040000000000005	0.57289999999999996	0.51680000000000004	0.25	0.1	10	99.5	15.888	9.173	\N	87
10875	2070	97	6.6870000000000003	2.1515	1.2529999999999999	2.226	2.6779999999999999	4.8274999999999997	3.7793000000000001	3.3759000000000001	2.8717000000000001	2.3675000000000002	1.8123	1.5168999999999999	1.2215	0.96399999999999997	0.89219999999999999	0.82040000000000002	0.76290000000000002	0.67669999999999997	0.25	0.104	10	99.792	15.839	9.1449999999999996	\N	97
10876	2070	127	9.5589999999999993	0.65669999999999995	0.97499999999999998	1.4079999999999999	1.6779999999999999	0.78859999999999997	0.61750000000000005	0.59360000000000002	0.56379999999999997	0.53400000000000003	0.48320000000000002	0.44409999999999999	0.40510000000000002	0.36599999999999999	0.34649999999999997	0.32700000000000001	0.31130000000000002	0.28789999999999999	0.25	0.30000001	8	99.5	14.189	8.1920000000000002	\N	127
10877	2070	137	0.115	9.1082999999999998	0.877	1.845	3.9169999999999998	16.857099999999999	14.971399999999999	13.7143	12.142899999999999	10.571400000000001	9.4000000000000004	8.6667000000000005	7.8867000000000003	6.6399999999999997	5.9166999999999996	5.0732999999999997	4.3986999999999998	2.3999999999999999	0.5	4.5450001	10	68.181999	0	0	\N	137
10923	2081	74	2.6669999999999998	2.2259000000000002	1.522	2.6819999999999999	3.4449999999999998	5.4088000000000003	3.8925000000000001	3.4125000000000001	2.8125	2.2124999999999999	1.6282000000000001	1.1765000000000001	0.8861	0.69910000000000005	0.61880000000000002	0.57579999999999998	0.5413	0.47260000000000002	0.25	0.25999999	10	97.917	3.2360000000000002	1.869	\N	74
10924	2081	89	31.431000000000001	1.6429	1.004	1.722	2.1899999999999999	3.1682999999999999	2.3365999999999998	1.9678	1.8654999999999999	1.7632000000000001	1.5585	1.3537999999999999	1.1491	0.96550000000000002	0.90210000000000001	0.83860000000000001	0.78779999999999994	0.71160000000000001	0.5	0.42899999	6.2999999999999998	99.286003	41.832999999999998	24.152000000000001	\N	89
10925	2081	104	20.007000000000001	2.1414	2.7189999999999999	2.4249999999999998	2.3250000000000002	5.3955000000000002	3.9098000000000002	3.3083	2.5564	1.9312	1.4020999999999999	0.97789999999999999	0.88590000000000002	0.79379999999999995	0.74780000000000002	0.70179999999999998	0.66500000000000004	0.60299999999999998	0.5	1.6	10	98.800003	13.632	7.8710000000000004	\N	104
10926	2081	119	2.9100000000000001	2.1432000000000002	7.5890000000000004	4.008	1.738	8.0105000000000004	5.0909000000000004	2.2999999999999998	0.62480000000000002	0.58530000000000004	0.50639999999999996	0.46100000000000002	0.41860000000000003	0.37619999999999998	0.35499999999999998	0.33379999999999999	0.31680000000000003	0.29139999999999999	0.25	0.23899999	10	94.511002	2.6219999999999999	1.514	\N	119
10927	2081	134	0.23599999999999999	6.0084999999999997	0.78300000000000003	1.702	2.9620000000000002	9.4399999999999995	8.6240000000000006	8.0800000000000001	7.6356999999999999	7.2229000000000001	6.3971	5.7249999999999996	5.0732999999999997	4.4217000000000004	4.0957999999999997	3.52	2.976	2.1600000000000001	0.5	2.941	10	94.117996	0	0	\N	134
34789	10850	31	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	21
34790	10850	51	1.5489999999999999	10.3795	0.60099999999999998	3.1760000000000002	6.8929999999999998	24.442399999999999	20.207899999999999	17.384799999999998	15.1099	13.6448	10.714700000000001	8.2086000000000006	5.8876999999999997	3.8548	3.1934999999999998	2.5320999999999998	2.0030999999999999	1.5544	0.25	0.045000002	16	78.038002	2.1379999999999999	1.2350000000000001	\N	41
34791	10850	71	66.867000000000004	3.6983000000000001	1.2609999999999999	2.3199999999999998	3.0390000000000001	7.8038999999999996	4.5571999999999999	3.7730000000000001	3.3376000000000001	2.9022999999999999	2.0316000000000001	1.7495000000000001	1.4895	1.2296	1.0995999999999999	0.96530000000000005	0.84660000000000002	0.66849999999999998	0.125	0.003	31.5	99.117996	145.64500000000001	84.087999999999994	\N	61
34792	10850	91	0.76400000000000001	3.0933999999999999	1.625	1.887	1.7709999999999999	6.1863999999999999	4.3122999999999996	3.7130000000000001	3.2347999999999999	2.7565	1.9641999999999999	1.7931999999999999	1.6221000000000001	1.4510000000000001	1.3654999999999999	1.2799	1.2115	1.1089	0.5	2.1819999	10	91.636002	2.6459999999999999	1.528	\N	81
34793	10850	101	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	91
34784	10849	39	0.078	1.4581	1.234	3.0169999999999999	4.9029999999999996	3.6000000000000001	2.96	2.5333000000000001	2	1.7455000000000001	1.2363999999999999	0.88319999999999999	0.66510000000000002	0.49569999999999997	0.43480000000000002	0.37390000000000001	0.32519999999999999	0.25219999999999998	0.25	9.8210001	4	93.75	0.012999999999999999	0.0070000000000000001	\N	25
34785	10849	59	0.42599999999999999	3.1265000000000001	0.81200000000000006	2.9510000000000001	6.2290000000000001	6.8003	5.8905000000000003	5.5213000000000001	5.0598000000000001	4.5983000000000001	3.5354999999999999	2.2151000000000001	1.4473	0.9395	0.84560000000000002	0.75170000000000003	0.67659999999999998	0.56759999999999999	0.125	0.32600001	6.2999999999999998	88.435997	0.69499999999999995	0.40100000000000002	\N	45
34786	10849	79	0.41499999999999998	2.5800000000000001	1.1819999999999999	3.069	4.2140000000000004	6.7868000000000004	5.0989000000000004	4.0852000000000004	3.4032	2.7633999999999999	1.8644000000000001	1.5282	1.1920999999999999	0.86519999999999997	0.70799999999999996	0.5958	0.54149999999999998	0.44240000000000002	0.25	0.168	10	98.319	0.33600000000000002	0.19400000000000001	\N	65
34787	10849	99	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	85
34788	10849	109	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	95
34711	10830	40	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	23
34712	10830	50	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	33
34713	10830	80	12.667	1.6727000000000001	1.149	2.2559999999999998	3.2229999999999999	3.5495000000000001	2.6919	2.1202000000000001	1.8734999999999999	1.7214	1.4173	1.1132	0.88600000000000001	0.70440000000000003	0.62080000000000002	0.56989999999999996	0.52910000000000001	0.43969999999999998	0.125	0.011	10	99.253998	23.762	13.718999999999999	\N	63
34714	10830	90	0.29399999999999998	3.7633999999999999	1.071	3.3439999999999999	7.0979999999999999	9.9483999999999995	7.8007	6.3688000000000002	4.6570999999999998	3.7673000000000001	3.0108999999999999	2.2545000000000002	1.7621	1.4034	1.2241	1.0448	0.69769999999999999	0.42420000000000002	0.125	0.48100001	10	90.143997	0.38900000000000001	0.22500000000000001	\N	73
34715	10830	100	0.11700000000000001	2.5703999999999998	1.2370000000000001	2.3039999999999998	3.9289999999999998	5.8670999999999998	4.5519999999999996	3.8666999999999998	3.4167000000000001	2.9666999999999999	2.0667	1.7761	1.5343	1.2925	1.1716	1.0507	0.85760000000000003	0.52600000000000002	0.125	1.235	6.2999999999999998	91.974998	0.40400000000000003	0.23300000000000001	\N	83
29824	10070	46	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	31
29825	10070	61	3.2850000000000001	2.6695000000000002	1.173	2.1360000000000001	2.7160000000000002	5.1075999999999997	3.5912000000000002	3.1463000000000001	2.5901000000000001	2.0339	1.7798	1.5527	1.3254999999999999	1.0984	0.98529999999999995	0.87529999999999997	0.7873	0.65529999999999999	0.25	0.021	16	97.925003	9.9800000000000004	5.7619999999999996	\N	46
29826	10070	76	4.633	1.6498999999999999	0.98299999999999998	2.0110000000000001	2.7799999999999998	3.3403	2.6608000000000001	2.2078000000000002	1.9252	1.8070999999999999	1.5709	1.3347	1.0985	0.89949999999999997	0.81330000000000002	0.72699999999999998	0.65810000000000002	0.56499999999999995	0.25	0.029999999	6.2999999999999998	99.174004	14.141999999999999	8.1649999999999991	\N	61
29827	10070	91	0.35599999999999998	2.4485999999999999	1.2190000000000001	1.9059999999999999	2.476	4.9391999999999996	3.7751000000000001	3.4881000000000002	3.1294	2.7706	2.0531000000000001	1.7944	1.5723	1.3502000000000001	1.2392000000000001	1.1281000000000001	1.0392999999999999	0.82920000000000005	0.25	0.19499999	6.2999999999999998	94.152	0.089999999999999997	0.051999999999999998	\N	76
29828	10070	106	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	91
29819	10069	41	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	27
29820	10069	61	5.0099999999999998	2.3279000000000001	1.8129999999999999	2.7010000000000001	3.1890000000000001	6.0475000000000003	3.9752000000000001	3.3774999999999999	2.6305000000000001	1.9659	1.5296000000000001	1.0931999999999999	0.86880000000000002	0.70199999999999996	0.624	0.58009999999999995	0.54500000000000004	0.47970000000000002	0.25	0.041999999	10	96.214996	2.1930000000000001	1.266	\N	47
29821	10069	81	21.991	1.7271000000000001	1.006	1.5249999999999999	2.04	3.0528	2.3252999999999999	1.9798	1.9033	1.8268	1.6737	1.5206999999999999	1.3675999999999999	1.2145999999999999	1.1379999999999999	1.0615000000000001	1.0003	0.82040000000000002	0.125	0.0099999998	6.2999999999999998	99.291	66.927999999999997	38.640999999999998	\N	67
29822	10069	91	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	77
29823	10069	101	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	87
29814	9653	36	0.47599999999999998	4.2306999999999997	1.028	2.391	3.4550000000000001	8.7637	8.0219000000000005	7.5273000000000003	6.9090999999999996	6.2823000000000002	3.9619	3.3094999999999999	2.6570999999999998	2.0047999999999999	1.7890999999999999	1.575	1.4036999999999999	1.1469	0.25	1.46	6.2999999999999998	70.072998	0	0	\N	22
29815	9653	51	7.4900000000000002	16.598800000000001	0.45300000000000001	2.2890000000000001	6.9299999999999997	28.710999999999999	27.037500000000001	25.921900000000001	24.5274	23.132899999999999	20.343800000000002	17.5548	14.2859	10.412599999999999	8.5556000000000001	6.7201000000000004	5.1582999999999997	2.9356	0.25	0.016000001	16	44.424999	25.062999999999999	14.470000000000001	\N	37
29816	9653	66	5.9169999999999998	5.1527000000000003	1.8959999999999999	3.7250000000000001	5.0140000000000002	15.9069	9.9381000000000004	7.7454000000000001	5.4753999999999996	3.9192	2.8723000000000001	1.9376	1.5633999999999999	1.1891	1.002	0.84309999999999996	0.71619999999999995	0.57279999999999998	0.25	0.118	16	90.093002	7.7210000000000001	4.4580000000000002	\N	52
29817	9653	86	2.4790000000000001	15.7598	0.23200000000000001	3.1669999999999998	11.798999999999999	28.7561	27.1098	26.0122	24.6403	23.2683	20.5245	17.7806	12.581799999999999	7.3647999999999998	5.3380000000000001	3.5430999999999999	2.7031000000000001	1.7394000000000001	0.25	0.046999998	16	43.511002	6.9800000000000004	4.0300000000000002	\N	72
29818	9653	106	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	92
27576	9000	50	92.358999999999995	2.0586000000000002	1.0189999999999999	2.2040000000000002	3.1200000000000001	3.9460000000000002	3.4603999999999999	3.1366000000000001	2.7320000000000002	2.3273000000000001	1.8339000000000001	1.5548999999999999	1.276	0.99780000000000002	0.89590000000000003	0.79390000000000005	0.71230000000000004	0.58779999999999999	0.125	0.0040000002	10	99.571999	139.92699999999999	80.787000000000006	\N	79
27577	9000	70	148.53899999999999	1.8036000000000001	1.762	2.4500000000000002	2.9780000000000002	3.98	3.3073999999999999	2.859	2.2984	1.8971	1.4570000000000001	1.0168999999999999	0.85760000000000003	0.70960000000000001	0.63560000000000005	0.58760000000000001	0.55089999999999995	0.48920000000000002	0.125	0.0060000001	10	99.665001	255.52799999999999	147.529	\N	99
27578	9000	90	10.032	1.0132000000000001	1.6240000000000001	2.097	2.1819999999999999	1.9688000000000001	1.5448	1.2622	0.9748	0.87719999999999998	0.68200000000000005	0.57820000000000005	0.50760000000000005	0.44209999999999999	0.40970000000000001	0.37730000000000002	0.35139999999999999	0.3125	0.125	0.028000001	10	99.695	13.967000000000001	8.0640000000000001	\N	119
27579	9000	110	64.552999999999997	1.4758	1.482	2.593	3.403	3.5070999999999999	2.7820999999999998	2.2988	1.8838999999999999	1.6543000000000001	1.1951000000000001	0.88149999999999995	0.67549999999999999	0.55530000000000002	0.50739999999999996	0.45569999999999999	0.41389999999999999	0.35120000000000001	0.125	0.0070000002	10	99.915001	129.96799999999999	75.037000000000006	\N	139
27580	9000	120	261.79700000000003	0.76419999999999999	1.1220000000000001	1.671	1.9319999999999999	1.4595	0.97240000000000004	0.8972	0.80330000000000001	0.70940000000000003	0.60040000000000004	0.54910000000000003	0.49740000000000001	0.43509999999999999	0.40400000000000003	0.37290000000000001	0.34810000000000002	0.31069999999999998	0.125	0.0080000004	6.2999999999999998	99.924004	288.84399999999999	166.76400000000001	\N	149
27575	8999	49	22.276	5.0731999999999999	0.876	1.794	2.6429999999999998	8.9283999999999999	7.5210999999999997	6.5830000000000002	6.0602999999999998	5.7443999999999997	5.1124999999999998	4.4805999999999999	3.8492000000000002	3.2193999999999998	2.9045000000000001	2.5895999999999999	2.3376999999999999	1.9347000000000001	0.125	0.003	16	99.057999	40.034999999999997	23.114000000000001	\N	68
27574	8999	65	21.225999999999999	3.4716	1.0860000000000001	2.9420000000000002	4.9219999999999997	8.4724000000000004	5.8963999999999999	5.0880000000000001	4.0773999999999999	3.5951	2.718	1.923	1.4981	1.0732999999999999	0.91490000000000005	0.78510000000000002	0.68120000000000003	0.55230000000000001	0.125	0.0070000002	16	98.350998	44.579000000000001	25.738	\N	84
27573	8999	94	79.022000000000006	2.4516	1.24	2.7130000000000001	3.9220000000000002	5.5765000000000002	4.0517000000000003	3.6192000000000002	3.1177000000000001	2.6160999999999999	1.8166	1.341	0.94779999999999998	0.7631	0.67069999999999996	0.59719999999999995	0.55030000000000001	0.46310000000000001	0.125	0.003	16	99.167999	246.90299999999999	142.55000000000001	\N	113
27572	8999	116	8.4969999999999999	2.0398999999999998	0.82399999999999995	2.7629999999999999	4.976	4.2439999999999998	3.6311	3.3451	2.9876999999999998	2.6303000000000001	1.9416	1.4473	0.9728	0.68720000000000003	0.59209999999999996	0.52880000000000005	0.47549999999999998	0.39019999999999999	0.125	0.016000001	10	99.567001	15.340999999999999	8.8569999999999993	\N	135
27571	8999	138	0.091999999999999998	0.7712	1.151	2.3199999999999998	3.0640000000000001	1.6599999999999999	1.1359999999999999	0.93420000000000003	0.79959999999999998	0.66490000000000005	0.54279999999999995	0.45639999999999997	0.38019999999999998	0.30409999999999998	0.26600000000000001	0.2336	0.21099999999999999	0.1772	0.125	0.76300001	4	96.946999	0.183	0.106	\N	157
27910	9142	47	0.83999999999999997	4.1700999999999997	0.96899999999999997	2.3500000000000001	3.5569999999999999	9.0398999999999994	7.3396999999999997	6.2561999999999998	5.5936000000000003	4.931	3.8105000000000002	3.1737000000000002	2.5367999999999999	1.9323999999999999	1.7171000000000001	1.5018	1.3294999999999999	1.0711999999999999	0.25	0.16500001	10	93.388	0.72599999999999998	0.41899999999999998	\N	71
27909	9142	57	436.25099999999998	2.0884	1.25	2.048	2.4180000000000001	3.8801000000000001	3.1627999999999998	2.6846999999999999	2.0870000000000002	1.8911	1.6364000000000001	1.3815999999999999	1.1268	0.93510000000000004	0.87050000000000005	0.80589999999999995	0.75419999999999998	0.67669999999999997	0.25	0.013	16	99.530998	726.95799999999997	419.709	\N	81
27908	9142	87	171.45500000000001	2.9422000000000001	1.2450000000000001	3.27	5.3970000000000002	7.2885	5.6407999999999996	4.9596999999999998	4.1082999999999998	3.5022000000000002	2.3616000000000001	1.5459000000000001	0.95740000000000003	0.71919999999999995	0.61750000000000005	0.5675	0.52739999999999998	0.43759999999999999	0.125	0.013	16	99.486	181.81899999999999	104.973	\N	111
27907	9142	97	396.39800000000002	2.4739	1.0840000000000001	3.0049999999999999	5.0579999999999998	5.7407000000000004	4.6894999999999998	3.9941	3.5381999999999998	3.0823999999999998	2.1707000000000001	1.4990000000000001	0.94869999999999999	0.67910000000000004	0.60109999999999997	0.55559999999999998	0.51919999999999999	0.42920000000000003	0.25	0.17399999	16	99.808998	145.785	84.168999999999997	\N	121
27906	9142	137	12.288	0.48870000000000002	0.98899999999999999	1.371	1.5980000000000001	0.68930000000000002	0.54320000000000002	0.495	0.47889999999999999	0.46279999999999999	0.43059999999999998	0.39829999999999999	0.36609999999999998	0.33389999999999997	0.31780000000000003	0.30170000000000002	0.2888	0.26950000000000002	0.125	0.113	6.2999999999999998	99.920998	18.66	10.773	\N	161
27560	8996	52	75.302999999999997	2.4664000000000001	1.0580000000000001	1.9319999999999999	2.9089999999999998	4.5027999999999997	3.7490999999999999	3.5129000000000001	3.2176999999999998	2.9224000000000001	2.3319000000000001	1.8864000000000001	1.6269	1.3673999999999999	1.2377	1.1080000000000001	1.0042	0.80149999999999999	0.25	0.0070000002	16	99.897003	161.886	93.465000000000003	\N	74
27559	8996	62	57.780000000000001	1.6052	1.399	1.7769999999999999	2.1579999999999999	3.2208999999999999	2.0697999999999999	1.8866000000000001	1.7307999999999999	1.5749	1.2630999999999999	0.9849	0.8881	0.79120000000000001	0.74280000000000002	0.69440000000000002	0.65569999999999995	0.58530000000000004	0.25	0.012	10	99.064003	8.3620000000000001	4.8280000000000003	\N	84
27558	8996	82	213.65100000000001	3.5853999999999999	0.70399999999999996	3.149	6.3689999999999998	8.3252000000000006	6.2267999999999999	5.6973000000000003	5.0354000000000001	4.3735999999999997	3.3132999999999999	2.3567	1.6560999999999999	1.1077999999999999	0.90590000000000004	0.75080000000000002	0.62809999999999999	0.52029999999999998	0.125	0.0020000001	16	99.133003	180.68000000000001	104.316	\N	104
27557	8996	102	191.869	2.4398	1.1200000000000001	2.798	4.2030000000000003	5.6013000000000002	4.3235999999999999	3.7555000000000001	3.2625000000000002	2.7694999999999999	1.9028	1.4601999999999999	1.0175000000000001	0.80330000000000001	0.70079999999999998	0.60829999999999995	0.55210000000000004	0.45269999999999999	0.125	0.0060000001	16	99.606003	167.94999999999999	96.965999999999994	\N	124
27556	8996	122	164.947	1.6186	1.671	2.3780000000000001	3.0419999999999998	3.6215000000000002	2.9222999999999999	2.4561000000000002	1.9520999999999999	1.7316	1.2906	0.95040000000000002	0.80510000000000004	0.65980000000000005	0.60199999999999998	0.55449999999999999	0.51659999999999995	0.42430000000000001	0.125	0.0020000001	16	99.912003	130.751	75.489000000000004	\N	144
24661	7901	47	269.27300000000002	1.5011000000000001	1.367	1.742	2.04	2.9439000000000002	1.954	1.8250999999999999	1.6639999999999999	1.5028999999999999	1.1807000000000001	0.95930000000000004	0.86650000000000005	0.77370000000000005	0.72729999999999995	0.68100000000000005	0.64390000000000003	0.57889999999999997	0.25	0.0020000001	16	99.973999	230.25	132.935	\N	62
24662	7901	73	159.893	2.0137	1.4099999999999999	2.556	3.4689999999999999	4.6764000000000001	3.5497000000000001	3.0823999999999998	2.4982000000000002	1.9704999999999999	1.5701000000000001	1.1696	0.90480000000000005	0.73960000000000004	0.65700000000000003	0.59040000000000004	0.54330000000000001	0.4526	0.25	0.075999998	16	99.889999	233.20500000000001	134.64099999999999	\N	88
24663	7901	93	24.292000000000002	1.9176	1.524	2.8879999999999999	4.2400000000000002	4.7026000000000003	3.6629999999999998	3.2351000000000001	2.7002000000000002	2.1654	1.5545	1.0275000000000001	0.78900000000000003	0.59860000000000002	0.54359999999999997	0.48759999999999998	0.43919999999999998	0.36659999999999998	0.25	0.35600001	10	99.5	53.189999999999998	30.709	\N	108
24664	7901	113	171.35900000000001	1.6060000000000001	1.976	2.375	2.4870000000000001	3.7021000000000002	2.9283000000000001	2.4125000000000001	1.9036999999999999	1.6363000000000001	1.1013999999999999	0.87709999999999999	0.72550000000000003	0.60680000000000001	0.57550000000000001	0.54430000000000001	0.51919999999999999	0.44290000000000002	0.125	0.001	10	99.547997	92.400000000000006	53.347000000000001	\N	128
24665	7901	133	102.14100000000001	1.0265	1.3049999999999999	1.8640000000000001	2.258	1.8508	1.4881	1.2462	0.98919999999999997	0.93110000000000004	0.81489999999999996	0.69869999999999999	0.60550000000000004	0.54559999999999997	0.51559999999999995	0.47310000000000002	0.42830000000000001	0.36099999999999999	0.25	0.109	16	99.936996	127.17100000000001	73.421999999999997	\N	148
24650	7882	60	153.54400000000001	1.5496000000000001	1.5660000000000001	2.1120000000000001	2.294	3.4634	2.4245000000000001	1.9384999999999999	1.7399	1.5412999999999999	1.1439999999999999	0.91759999999999997	0.78820000000000001	0.65890000000000004	0.60970000000000002	0.57299999999999995	0.54369999999999996	0.49869999999999998	0.25	0.42500001	10	99.199997	195.01499999999999	112.592	\N	80
24649	7882	81	27.196999999999999	1.2703	1.861	2.1019999999999999	2.2570000000000001	2.8403999999999998	1.7802	1.4917	1.1311	0.94469999999999998	0.77090000000000003	0.62070000000000003	0.57130000000000003	0.52200000000000002	0.4945	0.44350000000000001	0.40279999999999999	0.34160000000000001	0.25	1.013	10	99.074997	10.843	6.2599999999999998	\N	101
24648	7882	90	19.016999999999999	1.0378000000000001	1.756	2.1720000000000002	2.1419999999999999	2.2307999999999999	1.6241000000000001	1.337	0.99319999999999997	0.88170000000000004	0.65880000000000005	0.56410000000000005	0.49059999999999998	0.42959999999999998	0.39910000000000001	0.36849999999999999	0.34410000000000002	0.3075	0.125	0.043000001	6.2999999999999998	99.014	30.388999999999999	17.545000000000002	\N	110
24647	7882	101	110.779	1.0643	1.6459999999999999	2.0209999999999999	2.085	2.0276999999999998	1.5425	1.2331000000000001	0.9627	0.86890000000000001	0.68130000000000002	0.59470000000000001	0.54620000000000002	0.496	0.45369999999999999	0.41139999999999999	0.3775	0.32679999999999998	0.125	0.014	10	99.656998	107.78400000000001	62.228999999999999	\N	121
24646	7882	121	28.57	0.77969999999999995	1.127	1.677	1.9410000000000001	1.4382999999999999	0.96870000000000001	0.89500000000000002	0.80289999999999995	0.71079999999999999	0.59909999999999997	0.54420000000000002	0.48830000000000001	0.4284	0.39839999999999998	0.36849999999999999	0.34449999999999997	0.30859999999999999	0.125	0.017000001	6.2999999999999998	99.800003	38.933	22.478000000000002	\N	141
24645	7881	37	6.5800000000000001	10.331899999999999	0.92300000000000004	1.6659999999999999	2.681	15.9175	14.827999999999999	14.101599999999999	13.1937	12.2857	10.469799999999999	9.2655999999999992	8.2750000000000004	7.2843999999999998	6.7889999999999997	6.2850999999999999	5.3452999999999999	3.9045999999999998	0.125	0.021	16	90.454002	7.9889999999999999	4.6120000000000001	\N	57
24644	7881	47	264.87099999999998	3.0602999999999998	1.0609999999999999	2.3029999999999999	3.5640000000000001	6.0658000000000003	4.4832000000000001	3.8489	3.5005000000000002	3.1520000000000001	2.4552	1.8900999999999999	1.5731999999999999	1.2563	1.0978000000000001	0.95009999999999994	0.84560000000000002	0.68899999999999995	0.25	0.017999999	16	98.808998	140.36699999999999	81.040999999999997	\N	67
24643	7881	77	147.851	2.2479	1.2989999999999999	2.8090000000000002	3.9849999999999999	5.4177	3.7778	3.2029000000000001	2.4842	1.9380999999999999	1.5589999999999999	1.1798	0.89529999999999998	0.69620000000000004	0.60640000000000005	0.53590000000000004	0.4788	0.39119999999999999	0.25	0.317	16	99.424004	228.489	131.91800000000001	\N	97
24642	7881	87	268.82900000000001	3.4634999999999998	0.88500000000000001	3.3610000000000002	6.8209999999999997	8.3511000000000006	6.2106000000000003	5.5747999999999998	4.7801999999999998	3.9906999999999999	2.9611999999999998	1.9644999999999999	1.4298999999999999	0.93989999999999996	0.78649999999999998	0.63300000000000001	0.54990000000000006	0.43419999999999997	0.25	0.025	16	98.709	160.999	92.953000000000003	\N	107
24641	7881	128	28.222000000000001	1.0459000000000001	1.5700000000000001	2.1000000000000001	2.2629999999999999	2.0800000000000001	1.5373000000000001	1.2153	0.9597	0.87309999999999999	0.69979999999999998	0.58430000000000004	0.50780000000000003	0.44090000000000001	0.40789999999999998	0.375	0.34870000000000001	0.30919999999999997	0.125	0.050000001	10	99.787003	36.515999999999998	21.082000000000001	\N	148
24050	7306	57	116.496	1.9824999999999999	1.3740000000000001	2.6349999999999998	3.6389999999999998	4.7954999999999997	3.6808999999999998	3.2179000000000002	2.6391	2.0602999999999998	1.6067	1.1918	0.89810000000000001	0.70860000000000001	0.62139999999999995	0.57079999999999997	0.53029999999999999	0.44159999999999999	0.25	0.134	10	99.496002	0	0	\N	67
24049	7306	70	35.844000000000001	1.5323	2.04	2.5150000000000001	2.657	3.7423999999999999	2.8025000000000002	2.1758999999999999	1.784	1.5054000000000001	0.98129999999999995	0.78000000000000003	0.6149	0.55549999999999999	0.52580000000000005	0.49199999999999999	0.44290000000000002	0.36930000000000002	0.125	0.033	10	99.130997	0	0	\N	80
24048	7306	87	36.436	1.9186000000000001	1.2529999999999999	2.7599999999999998	4.1040000000000001	4.4951999999999996	3.4935999999999998	2.9962	2.3744000000000001	1.9214	1.5262	1.131	0.85670000000000002	0.64239999999999997	0.5756	0.51400000000000001	0.45860000000000001	0.37190000000000001	0.063	0.037999999	10	98.247002	0	0	\N	97
24047	7306	108	40.106999999999999	1.8524	1.643	3.1259999999999999	4.476	4.8643000000000001	3.7936999999999999	3.3149999999999999	2.7166999999999999	2.1183999999999998	1.4664999999999999	0.94679999999999997	0.69569999999999999	0.53659999999999997	0.4788	0.4284	0.3881	0.3276	0.125	0.035	6.2999999999999998	97.101997	0	0	\N	118
24046	7306	129	25.050999999999998	0.82430000000000003	1.2090000000000001	1.8160000000000001	2.1909999999999998	1.6037999999999999	1.1857	0.98089999999999999	0.9093	0.8377	0.69450000000000001	0.59370000000000001	0.52769999999999995	0.45889999999999997	0.4234	0.38790000000000002	0.35949999999999999	0.31690000000000002	0.063	0.026000001	4	98.856003	0	0	\N	139
24165	7401	51	118.733	2.3403	1.042	2.5230000000000001	3.552	5.3220999999999998	4.2037000000000004	3.7486999999999999	3.3163999999999998	2.8841999999999999	2.0196999999999998	1.6321000000000001	1.2555000000000001	0.93659999999999999	0.83779999999999999	0.73909999999999998	0.66020000000000001	0.56859999999999999	0.063	0.0020000001	6.2999999999999998	95.246002	0	0	\N	61
24164	7401	67	104.032	1.7383	1.3	2.347	2.9500000000000002	3.8338000000000001	3.0579999999999998	2.5407999999999999	1.9728000000000001	1.8068	1.4748000000000001	1.1428	0.9022	0.73050000000000004	0.64470000000000005	0.59189999999999998	0.55510000000000004	0.5	0.125	0.0049999999	6.2999999999999998	97.308998	0	0	\N	77
24163	7401	87	25.657	1.0247999999999999	1.2410000000000001	1.766	2.1989999999999998	1.8059000000000001	1.5390999999999999	1.3613	1.139	0.98140000000000005	0.88190000000000002	0.78239999999999998	0.68289999999999995	0.59670000000000001	0.56110000000000004	0.52549999999999997	0.49349999999999999	0.40100000000000002	0.063	0.0040000002	6.2999999999999998	99.361	0	0	\N	97
24162	7401	109	18.577999999999999	0.81620000000000004	1.2769999999999999	1.734	1.9530000000000001	1.5598000000000001	0.98399999999999999	0.9022	0.79990000000000006	0.6976	0.57869999999999999	0.50209999999999999	0.45019999999999999	0.39889999999999998	0.37330000000000002	0.34760000000000002	0.3271	0.2964	0.063	0.0080000004	6.2999999999999998	99.640999	0	0	\N	119
24161	7401	128	9.0340000000000007	0.68820000000000003	1.181	1.645	1.8720000000000001	0.99539999999999995	0.86780000000000002	0.78269999999999995	0.6764	0.61150000000000004	0.54569999999999996	0.48520000000000002	0.43680000000000002	0.38840000000000002	0.36409999999999998	0.33989999999999998	0.32050000000000001	0.29149999999999998	0.063	0.0040000002	6.2999999999999998	99.661003	0	0	\N	138
24045	7305	51	122.72	2.2296	1.1719999999999999	2.4969999999999999	3.3439999999999999	4.8952	3.6328999999999998	3.2109000000000001	2.6835	2.1560000000000001	1.6982999999999999	1.3442000000000001	0.995	0.8145	0.72419999999999995	0.63390000000000002	0.58279999999999998	0.50780000000000003	0.063	0.0020000001	10	96.905998	0	0	\N	66
24044	7305	60	6.1929999999999996	1.9224000000000001	1.823	2.5139999999999998	3.0710000000000002	4.2518000000000002	3.2984	2.7814000000000001	2.1352000000000002	1.8249	1.3819999999999999	0.97170000000000001	0.76549999999999996	0.60870000000000002	0.57769999999999999	0.54669999999999996	0.52190000000000003	0.45000000000000001	0.063	0.0020000001	10	97.871002	0	0	\N	75
24043	7305	80	22.366	2.3016999999999999	1.954	2.766	3.4300000000000002	5.9550000000000001	3.9607000000000001	3.2904	2.4525999999999999	1.8994	1.4618	1.0242	0.83609999999999995	0.66249999999999998	0.60099999999999998	0.55469999999999997	0.51759999999999995	0.42620000000000002	0.063	0.0049999999	10	95.587997	0	0	\N	95
24042	7305	99	54.783000000000001	1.6142000000000001	1.4810000000000001	2.6280000000000001	3.5329999999999999	3.6977000000000002	2.9597000000000002	2.4676999999999998	1.9455	1.7181999999999999	1.2634000000000001	0.92549999999999999	0.74850000000000005	0.59179999999999999	0.53410000000000002	0.4758	0.42849999999999999	0.35759999999999997	0.063	0.003	10	99.300003	0	0	\N	114
24041	7305	119	72.611000000000004	0.90680000000000005	1.3400000000000001	1.881	2.266	1.7596000000000001	1.3631	1.0989	0.95350000000000001	0.8871	0.75419999999999998	0.62609999999999999	0.56589999999999996	0.50560000000000005	0.46439999999999998	0.42049999999999998	0.38550000000000001	0.33279999999999998	0.063	0.0070000002	6.2999999999999998	99.809998	0	0	\N	134
25913	8443	51	10.833	2.3666999999999998	1.161	2.819	4.0190000000000001	5.5761000000000003	4.4804000000000004	3.8653	3.3734999999999999	2.8816000000000002	1.9507000000000001	1.4752000000000001	0.99980000000000002	0.7994	0.69910000000000005	0.61150000000000004	0.56399999999999995	0.48530000000000001	0.063	0.0020000001	10	98.994003	0	0	\N	71
25912	8443	69	8.3330000000000002	1.2058	1.343	1.9159999999999999	2.3559999999999999	2.3889	1.8222	1.6597	1.4564999999999999	1.2533000000000001	0.95099999999999996	0.82089999999999996	0.69079999999999997	0.59370000000000001	0.55969999999999998	0.52569999999999995	0.49659999999999999	0.4037	0.063	0.003	6.2999999999999998	99.421997	0	0	\N	89
25911	8443	88	7.1870000000000003	1.0763	1.397	2.0019999999999998	2.3900000000000001	1.9741	1.6571	1.4458	1.1817	0.97829999999999995	0.83930000000000005	0.70030000000000003	0.5988	0.53559999999999997	0.504	0.45479999999999998	0.4133	0.35120000000000001	0.063	0.003	6.2999999999999998	99.529999	0	0	\N	108
25910	8443	109	0.54200000000000004	1.8949	1.034	2.3879999999999999	3.4470000000000001	4.0133000000000001	3.4792999999999998	3.1288	2.6907000000000001	2.2524999999999999	1.7641	1.4327000000000001	1.1012999999999999	0.86980000000000002	0.77600000000000002	0.68220000000000003	0.61009999999999998	0.51170000000000004	0.063	0.039000001	4	89.942001	0	0	\N	129
23845	7161	65	14.851000000000001	1.0278	1.532	1.55	1.8089999999999999	1.7506999999999999	1.2049000000000001	0.97929999999999995	0.92000000000000004	0.86080000000000001	0.74229999999999996	0.62809999999999999	0.59089999999999998	0.55369999999999997	0.53510000000000002	0.51649999999999996	0.50170000000000003	0.41039999999999999	0.063	0.0060000001	6.2999999999999998	98.222	0	0	\N	65
23844	7161	85	3.1779999999999999	1.6879999999999999	2.1459999999999999	2.9689999999999999	3.177	4.6813000000000002	3.5084	2.8616999999999999	2.0531999999999999	1.7056	1.0753999999999999	0.80689999999999995	0.6139	0.53110000000000002	0.48759999999999998	0.43790000000000001	0.39810000000000001	0.33850000000000002	0.063	0.015	6.2999999999999998	97.032997	0	0	\N	85
23843	7161	94	6.7060000000000004	2.6545000000000001	1.2010000000000001	3.242	5.3170000000000002	6.0503	5.2716000000000003	4.7523999999999997	4.1035000000000004	3.4535	2.153	1.484	0.96030000000000004	0.73019999999999996	0.62139999999999995	0.55489999999999995	0.50160000000000005	0.40489999999999998	0.063	0.012	10	97.507004	0	0	\N	94
23842	7161	116	4.3470000000000004	1.2168000000000001	1.1679999999999999	1.853	2.395	1.9874000000000001	1.7962	1.6687000000000001	1.5093000000000001	1.3499000000000001	1.0310999999999999	0.89680000000000004	0.78239999999999998	0.66800000000000004	0.61319999999999997	0.56310000000000004	0.52310000000000001	0.4304	0.063	0.018999999	6.2999999999999998	99.474998	0	0	\N	116
23841	7161	126	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	126
10314	1893	43	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	43
10315	1893	47	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	47
10316	1893	53	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	53
10317	1893	61	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	61
10318	1893	71	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	71
10319	1893	77	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	77
10320	1893	86	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	86
10454	2015	48	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	48
10455	2015	58	7.9770000000000003	1.3807	1.4239999999999999	1.774	2.0779999999999998	1.9353	1.5824	1.3471	1.0528999999999999	0.95699999999999996	0.85219999999999996	0.74739999999999995	0.64259999999999995	0.58089999999999997	0.55300000000000005	0.52510000000000001	0.50280000000000002	0.41010000000000002	0.25	0.2	10	97.900002	44.914000000000001	22.457000000000001	\N	58
10456	2015	88	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	88
37396	11378	46	17.486000000000001	1.5248999999999999	1.532	2.2410000000000001	2.6539999999999999	3.7841999999999998	2.0626000000000002	1.8090999999999999	1.5568	1.3045	0.92720000000000002	0.74360000000000004	0.60399999999999998	0.53580000000000005	0.50170000000000003	0.45150000000000001	0.41060000000000002	0.3493	0.125	0.035	16	99.654999	52.688000000000002	30.420000000000002	\N	93
37395	11378	57	23.919	1.0459000000000001	1.238	1.5880000000000001	1.7410000000000001	1.7593000000000001	1.5952	1.4859	1.3492	1.2123999999999999	0.98229999999999995	0.90280000000000005	0.82330000000000003	0.74380000000000002	0.70399999999999996	0.6643	0.63249999999999995	0.56430000000000002	0.125	0.012	6.2999999999999998	99.976997	14.369	8.2959999999999994	\N	104
37394	11378	68	0.13200000000000001	8.1106999999999996	0.91000000000000003	2.6779999999999999	5.7999999999999998	20.091999999999999	14.597899999999999	12.2737	9.7886000000000006	8.8160000000000007	6.8708999999999998	5.7137000000000002	4.8838999999999997	4.0541	3.3599999999999999	2.6240000000000001	2.0352000000000001	1.1846000000000001	0.25	0.54299998	16	86.413002	0.252	0.14499999999999999	\N	115
37401	11379	47	29.363	1.6355	0.93300000000000005	2.1539999999999999	3.1600000000000001	3.3515999999999999	2.7017000000000002	2.2685	1.9357	1.8082	1.5532999999999999	1.2983	1.0434000000000001	0.83860000000000001	0.74129999999999996	0.64410000000000001	0.58230000000000004	0.49149999999999999	0.125	0.0049999999	10	99.835999	58.607999999999997	33.837000000000003	\N	93
37400	11379	56	19.373999999999999	1.6617999999999999	0.85399999999999998	1.7310000000000001	2.5049999999999999	2.9940000000000002	2.1573000000000002	1.9431	1.8440000000000001	1.7450000000000001	1.5468999999999999	1.3488	1.1506000000000001	0.95909999999999995	0.87360000000000004	0.78820000000000001	0.7198	0.61760000000000004	0.125	0.0040000002	10	98.984001	42.104999999999997	24.309000000000001	\N	102
37398	11378	24	0.78900000000000003	2.4369000000000001	1.0600000000000001	2.3679999999999999	3.2570000000000001	5.2655000000000003	3.8767999999999998	3.5072999999999999	3.0453000000000001	2.5832999999999999	1.8895999999999999	1.5902000000000001	1.2907999999999999	0.99380000000000002	0.88590000000000002	0.77790000000000004	0.69159999999999999	0.58020000000000005	0.125	0.071000002	10	97.084	1.3380000000000001	0.77200000000000002	\N	71
37397	11378	35	36.564	1.6025	1.6399999999999999	2.3959999999999999	3.0099999999999998	3.6743999999999999	2.8155000000000001	2.2429000000000001	1.8562000000000001	1.6386000000000001	1.2034	0.91749999999999998	0.76270000000000004	0.61750000000000005	0.5736	0.52959999999999996	0.49049999999999999	0.39979999999999999	0.125	0.0089999996	16	99.964996	97.555000000000007	56.323999999999998	\N	82
37399	11379	65	0.0070000000000000001	1.5468999999999999	1.3360000000000001	2.9540000000000002	4.8150000000000004	3.9066999999999998	3.1307	2.6133000000000002	1.9875	1.7450000000000001	1.26	0.91679999999999995	0.73729999999999996	0.57369999999999999	0.50360000000000005	0.42330000000000001	0.35870000000000002	0.26169999999999999	0.25	9.2779999	4	90.722	0.021000000000000001	0.012	\N	111
37403	11379	29	33.945	2.1499000000000001	1.4390000000000001	2.2919999999999998	2.7690000000000001	4.6361999999999997	3.1657000000000002	2.4779	1.9308000000000001	1.7748999999999999	1.4631000000000001	1.1514	0.92930000000000001	0.79190000000000005	0.72309999999999997	0.65439999999999998	0.60260000000000002	0.52849999999999997	0.125	0.0020000001	16	99.578003	38.218000000000004	22.065000000000001	\N	75
37402	11379	38	32.482999999999997	1.3471	1.2370000000000001	2.0369999999999999	2.5800000000000001	2.2271999999999998	1.7859	1.6240000000000001	1.4216	1.2193000000000001	0.93340000000000001	0.78810000000000002	0.64270000000000005	0.56020000000000003	0.52200000000000002	0.47589999999999999	0.43020000000000003	0.36180000000000001	0.125	0.0099999998	16	99.566002	83.099000000000004	47.976999999999997	\N	84
37411	11381	120	21.405000000000001	14.6557	1.615	3.77	5.7469999999999999	49.3767	24.2254	17.394300000000001	13.789899999999999	11.148400000000001	7.0998999999999999	5.0566000000000004	3.7166999999999999	2.8677999999999999	2.4432999999999998	2.0188000000000001	1.7045999999999999	1.2354000000000001	0.25	0.041999999	63	91.325996	30.774000000000001	17.766999999999999	\N	120
37410	11381	135	3.2749999999999999	10.516500000000001	0.73999999999999999	1.819	3.3559999999999999	17.3062	15.1739	14.523400000000001	13.7103	12.8972	11.271000000000001	9.6936	8.2910000000000004	6.8883000000000001	6.1589999999999998	5.2843	4.5845000000000002	3.3586	0.125	0.041999999	16	89.080002	1.6240000000000001	0.93799999999999994	\N	135
37409	11381	150	6.806	2.7408000000000001	1.1970000000000001	3.242	4.6269999999999998	7.2544000000000004	5.4626999999999999	4.5321999999999996	3.6617999999999999	3.0381999999999998	1.9340999999999999	1.5404	1.1468	0.82110000000000005	0.67849999999999999	0.58020000000000005	0.51980000000000004	0.41799999999999998	0.125	0.02	10	96.904999	20.375	11.763999999999999	\N	150
37416	11382	55	13.814	4.7922000000000002	0.90100000000000002	3.569	6.6349999999999998	12.001300000000001	9.2867999999999995	8.2286999999999999	6.9061000000000003	5.8235000000000001	4.0640000000000001	2.7408000000000001	1.7000999999999999	1.0076000000000001	0.90459999999999996	0.80700000000000005	0.72899999999999998	0.61250000000000004	0.25	0.116	16	96.600998	20.489000000000001	11.829000000000001	\N	99
37415	11382	65	11.26	4.9485999999999999	0.495	3.8879999999999999	8.2400000000000002	12.305400000000001	9.0991	7.7340999999999998	6.2159000000000004	5.6890999999999998	4.6353	3.3254999999999999	1.7623	0.91369999999999996	0.76770000000000005	0.62809999999999999	0.60189999999999999	0.56259999999999999	0.125	0.29800001	16	95.385002	23.314	13.460000000000001	\N	109
37413	11381	88	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	88
37412	11381	105	135.56100000000001	8.6960999999999995	0.90500000000000003	3.9569999999999999	8.8480000000000008	23.535599999999999	17.819199999999999	15.0654	12.8302	10.595000000000001	6.9527000000000001	4.7347000000000001	3.3035999999999999	2.1764000000000001	1.7619	1.4154	1.1382000000000001	0.78580000000000005	0.125	0.0099999998	31.5	98.359001	327.88499999999999	189.30500000000001	\N	105
37414	11382	75	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	119
37418	11382	35	66.474999999999994	2.2078000000000002	1.2310000000000001	1.8080000000000001	2.1339999999999999	3.8140000000000001	3.2753000000000001	2.9163000000000001	2.4674	2.0186000000000002	1.8183	1.6327	1.4471000000000001	1.2615000000000001	1.1687000000000001	1.0759000000000001	1.0017	0.85209999999999997	0.125	0.0049999999	16	99.875	148.11000000000001	85.510999999999996	\N	79
37417	11382	45	44.896999999999998	5.3895999999999997	1.105	2.4510000000000001	3.3860000000000001	11.9239	8.3323	6.6433	5.7723000000000004	5.1421999999999999	3.9344000000000001	3.2339000000000002	2.5335000000000001	1.9108000000000001	1.7236	1.5364	1.3866000000000001	1.1619999999999999	0.125	0.0020000001	31.5	98.889	72.805000000000007	42.033999999999999	\N	89
37421	11383	53	29.815999999999999	2.3925000000000001	1.3779999999999999	2.6800000000000002	3.7850000000000001	5.4663000000000004	4.1677999999999997	3.7231999999999998	3.294	2.8647999999999998	2.0065	1.3249	0.91700000000000004	0.75819999999999999	0.67889999999999995	0.6139	0.58040000000000003	0.53010000000000002	0.25	0.090000004	16	99.810997	58.670000000000002	33.872999999999998	\N	97
37420	11383	63	1.9770000000000001	4.3163	0.45600000000000002	4.5979999999999999	10.904999999999999	11.1502	8.7457999999999991	7.4821999999999997	6.1028000000000002	5.3188000000000004	3.8376999999999999	2.8169	1.8190999999999999	0.84570000000000001	0.51890000000000003	0.45490000000000003	0.41370000000000001	0.35189999999999999	0.125	0.035	16	98.557999	3.681	2.125	\N	107
37419	11383	73	1.9410000000000001	12.417899999999999	0.67000000000000004	2.4540000000000002	5.8680000000000003	25.805800000000001	22.389299999999999	20.111599999999999	17.264500000000002	15.4076	13.276300000000001	11.145	9.0361999999999991	6.9535	5.8586999999999998	4.6738999999999997	3.7193000000000001	2.2625999999999999	0.5	1.4680001	16	72.778999	6.6799999999999997	3.8570000000000002	\N	117
37426	11384	44	10.496	0.98760000000000003	1.3620000000000001	1.837	1.9430000000000001	1.8847	1.1276999999999999	0.92630000000000001	0.80289999999999995	0.67959999999999998	0.58379999999999999	0.52590000000000003	0.46899999999999997	0.4128	0.38469999999999999	0.35659999999999997	0.33410000000000001	0.3004	0.125	0.079999998	10	99.489998	32.606999999999999	18.826000000000001	\N	92
37425	11384	55	7.8940000000000001	1.1498999999999999	1.3540000000000001	1.6100000000000001	1.732	1.8788	1.6654	1.5232000000000001	1.3453999999999999	1.1677	0.9617	0.88919999999999999	0.81669999999999998	0.74419999999999997	0.70789999999999997	0.67159999999999997	0.64259999999999995	0.55520000000000003	0.125	0.124	6.2999999999999998	99.514999	2.0899999999999999	1.2070000000000001	\N	103
37423	11383	33	91.825999999999993	1.9519	1.1539999999999999	1.6279999999999999	1.9390000000000001	3.4127999999999998	2.7494999999999998	2.3071999999999999	1.9651000000000001	1.8864000000000001	1.7291000000000001	1.5717000000000001	1.4144000000000001	1.2571000000000001	1.1783999999999999	1.0998000000000001	1.0367999999999999	0.89180000000000004	0.125	0.0020000001	16	99.804001	128.80099999999999	74.363	\N	77
37422	11383	43	12.663	2.2229999999999999	1.242	1.9890000000000001	2.2989999999999999	4.4729999999999999	3.2894999999999999	2.714	1.9992000000000001	1.8962000000000001	1.6901999999999999	1.4841	1.2781	1.0720000000000001	0.97589999999999999	0.89570000000000005	0.83150000000000002	0.73529999999999995	0.25	0.037999999	10	97.405998	20.097000000000001	11.603	\N	87
37424	11384	64	0.98299999999999998	6.8487	0.85899999999999999	2.0600000000000001	3.5070000000000001	13.2171	11.5474	10.434200000000001	9.5055999999999994	8.7871000000000006	7.3498999999999999	6.0458999999999996	5.1032000000000002	4.1604999999999999	3.6568000000000001	3.1364999999999998	2.7202999999999999	2.0958999999999999	0.125	0.28400001	10	78.440002	1.74	1.0049999999999999	\N	112
37428	11384	24	22.007000000000001	1.4548000000000001	1.1779999999999999	1.885	2.4870000000000001	2.7054	1.9185000000000001	1.7928999999999999	1.6358999999999999	1.4789000000000001	1.1649	0.93810000000000004	0.80769999999999997	0.67730000000000001	0.61809999999999998	0.57479999999999998	0.54020000000000001	0.46839999999999998	0.125	0.082000002	10	98.454002	32.914999999999999	19.003	\N	72
37427	11384	34	13.407999999999999	1.7573000000000001	1.885	2.496	2.9860000000000002	4.1821000000000002	3.2610999999999999	2.7122000000000002	2.0261999999999998	1.7824	1.3298000000000001	0.95140000000000002	0.7722	0.61629999999999996	0.58309999999999995	0.54990000000000006	0.52329999999999999	0.44529999999999997	0.125	0.55000001	10	99.314003	22.224	12.831	\N	82
37431	11385	50	37.728999999999999	8.1155000000000008	0.59599999999999997	3.6299999999999999	13.536	20.713899999999999	15.302300000000001	13.693899999999999	11.683299999999999	9.8024000000000004	7.3742999999999999	5.4589999999999996	3.9599000000000002	2.7355999999999998	2.1234999999999999	1.581	1.1611	0.54479999999999995	0.125	0.0080000004	31.5	99.759003	82.403999999999996	47.576000000000001	\N	91
37430	11385	64	40.841999999999999	7.1528999999999998	0.63500000000000001	2.9060000000000001	6.8819999999999997	14.861599999999999	12.869	11.5406	9.9321999999999999	8.9932999999999996	7.1153000000000004	5.5583999999999998	4.2477	3.0036999999999998	2.3894000000000002	1.8505	1.5239	1.0339	0.125	0.003	16	93.428001	60.012999999999998	34.648000000000003	\N	105
37429	11385	78	1.1579999999999999	7.0370999999999997	0.56699999999999995	1.76	3.6509999999999998	10.8691	9.6986000000000008	9.4185999999999996	9.0686999999999998	8.7187000000000001	8.0188000000000006	7.3189000000000002	6.6189999999999998	5.3970000000000002	4.5674999999999999	3.754	3.1309	2.1962000000000002	0.25	0.059999999	10	88.306	3.8050000000000002	2.1970000000000001	\N	119
37433	11385	25	63.933	5.7348999999999997	1.7529999999999999	3.9409999999999998	5.726	17.7561	12.2658	9.4052000000000007	6.7843999999999998	5.0385	3.3414000000000001	2.3502999999999998	1.7403999999999999	1.3389	1.1380999999999999	0.94089999999999996	0.78959999999999997	0.58350000000000002	0.125	0.0089999996	16	88.722	182.50700000000001	105.37	\N	66
37432	11385	36	10.754	7.5300000000000002	0.81100000000000005	3.468	9.3529999999999998	15.244999999999999	12.6494	10.919	9.2664000000000009	7.9908999999999999	5.7324000000000002	4.0490000000000004	2.9784000000000002	1.9547000000000001	1.6321000000000001	1.3095000000000001	1.0515000000000001	0.6129	0.125	0.013	31.5	95.768997	26.795999999999999	15.470000000000001	\N	77
11080	2127	51	65.281000000000006	1.7898000000000001	1.399	2.3410000000000002	3.032	3.7812000000000001	2.9933999999999998	2.4681999999999999	1.9501999999999999	1.7763	1.4287000000000001	1.081	0.87719999999999998	0.71719999999999995	0.63719999999999999	0.58540000000000003	0.54620000000000002	0.47120000000000001	0.25	0.090000004	10	98.834999	170.154	98.238	\N	51
11081	2127	91	28.632000000000001	4.0029000000000003	0.64000000000000001	2.5870000000000002	5.6020000000000003	8.3018999999999998	6.1920000000000002	5.6772	5.0336999999999996	4.3902000000000001	3.5857000000000001	2.9910000000000001	2.3963999999999999	1.7885	1.4713000000000001	1.1540999999999999	0.92530000000000001	0.64000000000000001	0.25	0.1	16	97.942001	67.447999999999993	38.941000000000003	\N	91
11082	2127	131	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	131
11083	2127	141	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	141
11074	2126	60	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	60
11075	2126	70	70.954999999999998	4.6143000000000001	0.97199999999999998	2.4079999999999999	3.7530000000000001	9.4807000000000006	7.9877000000000002	6.9923999999999999	5.9973000000000001	5.3147000000000002	3.9773000000000001	3.3639999999999999	2.7507000000000001	2.1374	1.8539000000000001	1.5891999999999999	1.3774	1.0598000000000001	0.5	0.63800001	16	98.341003	222.92400000000001	128.70500000000001	\N	70
11076	2126	107	420.88799999999998	3.3631000000000002	0.84699999999999998	2.2109999999999999	3.7269999999999999	6.9374000000000002	5.3185000000000002	4.5143000000000004	3.8765999999999998	3.6240000000000001	3.1187999999999998	2.6135999999999999	2.1084000000000001	1.6724000000000001	1.4638	1.2552000000000001	1.0884	0.83689999999999998	0.25	0.064000003	10	95.373001	238.541	137.721	\N	107
11077	2126	147	415.11599999999999	4.5388999999999999	1.095	2.9329999999999998	4.6859999999999999	10.612	7.3418000000000001	5.9153000000000002	4.9016000000000002	3.9567999999999999	3.1745999999999999	2.3923000000000001	1.7924	1.3757999999999999	1.1675	0.97119999999999995	0.85370000000000001	0.67749999999999999	0.25	0.041999999	31.5	99.061996	756.601	436.82400000000001	\N	147
11078	2126	188	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	188
11069	2125	28	0	1.1152	1.4930000000000001	1.78	2.0190000000000001	2	1.6000000000000001	1.3332999999999999	1	0.94710000000000005	0.84140000000000004	0.73570000000000002	0.63	0.57799999999999996	0.55200000000000005	0.52600000000000002	0.50519999999999998	0.41670000000000001	0.5	15	4	95	0	0	\N	28
11070	2125	52	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	52
11071	2125	78	0.13900000000000001	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	78
11072	2125	102	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	102
11073	2125	128	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	128
11064	2124	28	19.190000000000001	2.0659999999999998	1.153	1.802	2.23	3.6699999999999999	3.2532000000000001	2.9752999999999998	2.6278999999999999	2.2805	1.8808	1.6809000000000001	1.4811000000000001	1.2811999999999999	1.1812	1.0812999999999999	1.0014000000000001	0.84319999999999995	0.5	0.241	10	99.759003	0	0	\N	28
11065	2124	59	353.536	2.5360999999999998	0.95099999999999996	2.1030000000000002	3.21	5.0250000000000004	3.8386999999999998	3.5922999999999998	3.2844000000000002	2.9765000000000001	2.3607	1.8711	1.5598000000000001	1.2484999999999999	1.0929	0.9556	0.86760000000000004	0.73540000000000005	0.25	0.039000001	10	98.911003	136.202	78.637	\N	59
11066	2124	88	50.283000000000001	2.5718000000000001	0.71499999999999997	1.8200000000000001	3.1949999999999998	3.9222000000000001	3.694	3.5419	3.3517000000000001	3.1615000000000002	2.7812000000000001	2.4009	2.0205000000000002	1.6432	1.4547000000000001	1.2661	1.1153	0.87039999999999995	0.25	0.045000002	10	99.325996	41.825000000000003	29.574999999999999	\N	88
11067	2124	129	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	129
11068	2124	139	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	139
11059	2123	34	49.149999999999999	1.1739999999999999	1.409	1.8180000000000001	1.9430000000000001	2.1133000000000002	1.7426999999999999	1.5577000000000001	1.3265	1.0952999999999999	0.91490000000000005	0.80769999999999997	0.70050000000000001	0.6099	0.58040000000000003	0.55100000000000005	0.52749999999999997	0.4708	0.5	11.323	10	99.931999	130.398	75.284999999999997	\N	34
11060	2123	42	149.22999999999999	1.7488999999999999	1.653	2.2410000000000001	2.5019999999999998	3.6825000000000001	2.7406000000000001	2.1126	1.8343	1.6409	1.2541	0.95130000000000003	0.80959999999999999	0.66779999999999995	0.61270000000000002	0.57550000000000001	0.54579999999999995	0.50119999999999998	0.5	9.8330002	10	98.515999	42.32	24.433	\N	42
11061	2123	73	29.992999999999999	1.4510000000000001	1.456	2.1890000000000001	2.8879999999999999	3.2757999999999998	2.4243999999999999	1.9614	1.7699	1.5784	1.1955	0.91779999999999995	0.74980000000000002	0.6089	0.57210000000000005	0.5353	0.50580000000000003	0.41399999999999998	0.25	0.074000001	10	99.777	25.939	14.976000000000001	\N	73
11062	2123	84	47.459000000000003	1.0226	1.611	1.8999999999999999	2.1680000000000001	1.9135	1.5323	1.2781	0.99109999999999998	0.92000000000000004	0.77759999999999996	0.63519999999999999	0.58309999999999995	0.53449999999999998	0.51019999999999999	0.46810000000000002	0.42430000000000001	0.35870000000000002	0.25	0.072999999	8	99.853996	28.852	16.658000000000001	\N	84
11063	2123	123	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	123
11054	2122	65	74.855000000000004	2.452	1.0620000000000001	1.8879999999999999	2.657	3.9613999999999998	3.6185	3.3900000000000001	3.1042000000000001	2.8184999999999998	2.2471000000000001	1.8591	1.6107	1.3624000000000001	1.2383	1.1141000000000001	1.0147999999999999	0.8458	0.5	0.54100001	10	98.649002	194.06100000000001	97.030000000000001	\N	65
11055	2122	74	187.512	2.1819999999999999	0.92300000000000004	1.968	3.0030000000000001	3.7942	3.4801000000000002	3.2707999999999999	3.0089999999999999	2.7473000000000001	2.2238000000000002	1.8404	1.5615000000000001	1.2827	1.1433	1.0038	0.89839999999999998	0.74060000000000004	0.5	1.517	8	99.585999	1103.3230000000001	493.42099999999999	\N	74
11056	2122	114	574.62199999999996	3.1389999999999998	0.78000000000000003	2.0680000000000001	3.6139999999999999	5.7877999999999998	4.6281999999999996	3.9641999999999999	3.7259000000000002	3.4874999999999998	3.0106999999999999	2.5339999999999998	2.0571999999999999	1.6458999999999999	1.4447000000000001	1.2435	1.0825	0.83299999999999996	0.25	0.050000001	10	97	1122.798	561.399	\N	114
11057	2122	155	223.62200000000001	3.7692999999999999	0.82199999999999995	2.1400000000000001	3.5369999999999999	6.7542999999999997	5.0982000000000003	4.1783000000000001	3.8016000000000001	3.5669	3.0973999999999999	2.6278999999999999	2.1585000000000001	1.7151000000000001	1.5	1.2848999999999999	1.1129	0.87570000000000003	0.125	0.025	20	98.25	717.47799999999995	358.73899999999998	\N	155
11058	2122	194	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	194
11049	2121	29	14.868	1.2974000000000001	1.306	2.0640000000000001	2.5819999999999999	2.9676999999999998	2	1.8319000000000001	1.6217999999999999	1.4117999999999999	0.997	0.8478	0.6986	0.58919999999999995	0.5514	0.51359999999999995	0.46939999999999998	0.3861	0.25	0.2	8	99.900002	19.710000000000001	11.380000000000001	\N	29
11050	2121	39	21.707999999999998	1.8966000000000001	1.091	2.3279999999999998	3.1419999999999999	3.8862999999999999	3.3174999999999999	2.9384000000000001	2.4645000000000001	1.9967999999999999	1.6803999999999999	1.3638999999999999	1.0475000000000001	0.85089999999999999	0.76329999999999998	0.67559999999999998	0.61199999999999999	0.53480000000000005	0.25	0.1	8	98.800003	21.003	12.125999999999999	\N	39
11051	2121	69	4.8819999999999997	1.3895999999999999	0.95599999999999996	1.8700000000000001	2.6890000000000001	2.6345999999999998	1.9394	1.8360000000000001	1.7068000000000001	1.5775999999999999	1.3190999999999999	1.0607	0.88149999999999995	0.72670000000000001	0.64929999999999999	0.59350000000000003	0.55459999999999998	0.49059999999999998	0.25	0.142	10	99.716003	2.23	1.2869999999999999	\N	69
11052	2121	79	36.707999999999998	1.653	1.526	2.161	2.5819999999999999	3.4897	2.6621000000000001	2.1103000000000001	1.8552	1.6828000000000001	1.3379000000000001	0.99729999999999996	0.86180000000000001	0.72619999999999996	0.65849999999999997	0.60489999999999999	0.57020000000000004	0.51819999999999999	0.25	0.1	10	99.199997	9.3230000000000004	5.383	\N	79
11053	2121	119	0.48299999999999998	3.0343	0.73599999999999999	1.917	3.778	5.4757999999999996	4.7512999999999996	4.2683	3.8889	3.6888999999999998	3.2888999999999999	2.8889	2.4889000000000001	2.0889000000000002	1.8332999999999999	1.5333000000000001	1.2932999999999999	0.87050000000000005	0.5	4.7620001	8	99.206001	0.68000000000000005	0.39300000000000002	\N	119
11043	2120	29	26.492999999999999	0.86529999999999996	1.2010000000000001	1.653	2.0979999999999999	1.5844	1.1948000000000001	0.98899999999999999	0.93410000000000004	0.87919999999999998	0.76939999999999997	0.65959999999999996	0.59350000000000003	0.54349999999999998	0.51849999999999996	0.48470000000000002	0.4375	0.36670000000000003	0.25	0.1	8	99.900002	22.253	12.848000000000001	\N	29
11044	2120	39	64.578000000000003	1.0432999999999999	1.3540000000000001	1.871	2.2549999999999999	1.8332999999999999	1.5107999999999999	1.2957000000000001	1.0268999999999999	0.94379999999999997	0.81879999999999997	0.69379999999999997	0.60219999999999996	0.5454	0.51700000000000002	0.47720000000000001	0.43149999999999999	0.36299999999999999	0.25	0.1	10	99.800003	64.447999999999993	37.209000000000003	\N	39
11045	2120	48	31.396999999999998	1.2497	1.2989999999999999	1.9390000000000001	2.415	2.4500000000000002	1.8340000000000001	1.6758999999999999	1.4782999999999999	1.2806	0.96179999999999999	0.83009999999999995	0.69850000000000001	0.59530000000000005	0.55920000000000003	0.52310000000000001	0.48799999999999999	0.3982	0.25	0.1	8	99.300003	68.962000000000003	39.814999999999998	\N	48
11046	2120	78	32.743000000000002	1.4946999999999999	1.294	1.9950000000000001	2.5640000000000001	3.1537999999999999	2	1.8412999999999999	1.6429	1.4443999999999999	1.0476000000000001	0.88119999999999998	0.74609999999999999	0.61839999999999995	0.57699999999999996	0.53559999999999997	0.50249999999999995	0.40870000000000001	0.25	0.1	10	99.099998	33.103999999999999	19.113	\N	78
11047	2120	89	28.579000000000001	1.1466000000000001	1.2929999999999999	1.982	2.4470000000000001	1.9781	1.7149000000000001	1.5395000000000001	1.3202	1.1009	0.89600000000000002	0.76100000000000001	0.62790000000000001	0.55920000000000003	0.52480000000000004	0.48359999999999997	0.43659999999999999	0.36620000000000003	0.25	0.1	10	99.800003	77.433000000000007	44.706000000000003	\N	89
11048	2120	129	1.722	0.43680000000000002	0.95899999999999996	1.403	1.6899999999999999	0.60099999999999998	0.55710000000000004	0.52780000000000005	0.49559999999999998	0.47760000000000002	0.44159999999999999	0.40550000000000003	0.3695	0.33339999999999997	0.31540000000000001	0.2974	0.28299999999999997	0.26129999999999998	0.25	6.855	2	99.597	0.55300000000000005	0.31900000000000001	\N	129
11038	2119	39	12.943	3.3386	1.3759999999999999	2.222	2.7440000000000002	6.4375	4.681	3.8654999999999999	3.4371	3.0085999999999999	2.1516999999999999	1.7959000000000001	1.5479000000000001	1.2999000000000001	1.1758999999999999	1.0519000000000001	0.94799999999999995	0.7843	0.25	0.039999999	20	97.987999	44.363	22.181000000000001	\N	39
11039	2119	49	24.905000000000001	2.8437999999999999	1.5269999999999999	2.48	2.7799999999999998	8	4.2556000000000003	3.4215	2.5950000000000002	1.96	1.6742999999999999	1.3886000000000001	1.1029	0.90329999999999999	0.82779999999999998	0.75229999999999997	0.69189999999999996	0.60219999999999996	0.25	0.1	10	93	91.034999999999997	45.518000000000001	\N	49
11040	2119	79	109.155	4.0610999999999997	1.3169999999999999	2.927	4.7590000000000003	9.1795000000000009	6.6966999999999999	5.6996000000000002	4.7271999999999998	3.8803999999999998	2.9319999999999999	1.9934000000000001	1.6164000000000001	1.2393000000000001	1.0508	0.89570000000000005	0.78149999999999997	0.61599999999999999	0.25	0.043000001	20	97.738998	242.94800000000001	121.474	\N	79
11041	2119	120	259.15899999999999	3.1280999999999999	1.2629999999999999	2.431	3.028	6.6966999999999999	3.8620999999999999	3.3332999999999999	2.6724000000000001	2.0114999999999998	1.7081	1.4136	1.1191	0.89659999999999995	0.80969999999999998	0.72289999999999999	0.65339999999999998	0.56410000000000005	0.25	0.043000001	20	97.870003	827.24000000000001	413.62	\N	120
11042	2119	160	0.063	0.90369999999999995	2.2909999999999999	2.4929999999999999	2.194	1.9824999999999999	1.6942999999999999	1.5022	1.262	1.0218	0.50900000000000001	0.4491	0.3972	0.3453	0.31929999999999997	0.29339999999999999	0.27260000000000001	0.23200000000000001	0.125	0.273	4	98.726997	0.14999999999999999	0.086999999999999994	\N	160
11031	2118	24	33.594000000000001	3.4133	1.008	2.4990000000000001	4.0860000000000003	7.2229000000000001	5.5910000000000002	4.8992000000000004	4.0346000000000002	3.6570999999999998	2.9428999999999998	2.2286000000000001	1.75	1.3824000000000001	1.1984999999999999	1.0146999999999999	0.89510000000000001	0.72030000000000005	0.25	0.1	10	94.400002	0.221	0.156	\N	24
11032	2118	32	69.998000000000005	2.9079999999999999	1.2669999999999999	2.298	2.782	7.2713999999999999	4.2556000000000003	3.6617000000000002	3.1642000000000001	2.6667000000000001	1.9119999999999999	1.6453	1.3787	1.1120000000000001	0.98419999999999996	0.88519999999999999	0.80610000000000004	0.68740000000000001	0.5	1.7	10	94.900002	203.97999999999999	117.768	\N	32
11033	2118	62	26.984000000000002	1.5588	1.3089999999999999	1.966	2.4860000000000002	3.2307999999999999	1.9845999999999999	1.8301000000000001	1.6371	1.444	1.0579000000000001	0.88219999999999998	0.74360000000000004	0.61670000000000003	0.57979999999999998	0.54279999999999995	0.51329999999999998	0.42549999999999999	0.25	0.1	10	98.699997	30.045000000000002	21.245000000000001	\N	62
11034	2118	92	8.4109999999999996	2.1211000000000002	1.212	2.6320000000000001	3.8599999999999999	4.6014999999999997	3.4891000000000001	3.0234000000000001	2.4413999999999998	1.9547000000000001	1.5795999999999999	1.2043999999999999	0.89780000000000004	0.67310000000000003	0.5978	0.54559999999999997	0.50380000000000003	0.40920000000000001	0.25	0.118	10	97.275002	10.82	7.6509999999999998	\N	92
11035	2118	102	61.883000000000003	1.6318999999999999	1.3740000000000001	1.9399999999999999	2.3210000000000002	3.0731999999999999	1.9077	1.738	1.5258	1.3137000000000001	0.9667	0.83889999999999998	0.71109999999999995	0.60450000000000004	0.56969999999999998	0.53480000000000005	0.50700000000000001	0.41639999999999999	0.25	0.043000001	20	99.522003	84.686999999999998	59.883000000000003	\N	102
11036	2118	132	73.051000000000002	3.6958000000000002	0.90100000000000002	3.5619999999999998	6.1139999999999999	9.0526	7.3929	6.2156000000000002	5.1605999999999996	4.1055000000000001	3.1162999999999998	2.1859999999999999	1.548	0.98929999999999996	0.81140000000000001	0.63360000000000005	0.58260000000000001	0.50970000000000004	0.25	0.1	10	93.599998	95.186000000000007	54.956000000000003	\N	132
11037	2118	142	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	142
11024	2117	25	5.6349999999999998	1.1851	1.2689999999999999	1.8100000000000001	2.0409999999999999	1.9809000000000001	1.7654000000000001	1.6215999999999999	1.4419999999999999	1.2624	0.97150000000000003	0.86580000000000001	0.7601	0.65439999999999998	0.60899999999999999	0.56989999999999996	0.53869999999999996	0.47599999999999998	0.25	0.14300001	8	99.857002	5.6719999999999997	4.0099999999999998	\N	25
11025	2117	35	5.5209999999999999	1.5952999999999999	1.0409999999999999	1.9870000000000001	2.7970000000000002	3.2484999999999999	2.5181	2.0310999999999999	1.8791	1.7516	1.4966999999999999	1.2419	0.99250000000000005	0.84470000000000001	0.77080000000000004	0.69689999999999996	0.63780000000000003	0.53510000000000002	0.25	0.15899999	10	99.681	4.9500000000000002	3.5	\N	35
11026	2117	45	1.927	3.0013000000000001	0.70499999999999996	2.569	4.9409999999999998	6.0225	5.1551	4.5768000000000004	3.9375	3.6280999999999999	3.0093999999999999	2.3906000000000001	1.8302	1.3697999999999999	1.1395	0.92789999999999995	0.78129999999999999	0.60909999999999997	0.5	0.25299999	10	98.737	0.25	0.17699999999999999	\N	45
11027	2117	75	9.3539999999999992	1.2304999999999999	1.3759999999999999	2.0009999999999999	2.4020000000000001	2.7160000000000002	1.8727	1.6813	1.4419999999999999	1.2027000000000001	0.92600000000000005	0.79759999999999998	0.66930000000000001	0.58140000000000003	0.5464	0.51139999999999997	0.46750000000000003	0.38550000000000001	0.25	0.093000002	8	99.813004	10.666	7.5419999999999998	\N	75
11028	2117	86	20.696999999999999	1.8829	1.869	2.6240000000000001	3.4359999999999999	4.5030999999999999	3.4737	3	2.4079000000000002	1.9205000000000001	1.4091	0.96830000000000005	0.80969999999999998	0.65110000000000001	0.59360000000000002	0.54410000000000003	0.50439999999999996	0.41010000000000002	0.25	0.111	10	99.444	45.829999999999998	26.460000000000001	\N	86
11029	2117	115	34.905999999999999	2.1676000000000002	1.0089999999999999	2.0179999999999998	2.77	3.8782000000000001	3.4935999999999998	3.2372000000000001	2.9167000000000001	2.5962000000000001	1.9819	1.7235	1.4651000000000001	1.2067000000000001	1.0774999999999999	0.9526	0.85770000000000002	0.71540000000000004	0.5	0.1	10	99.800003	19.106999999999999	13.51	\N	115
11030	2117	125	63.835000000000001	1.8097000000000001	1.038	2.5019999999999998	3.8370000000000002	3.7915000000000001	3.3281999999999998	3.0192999999999999	2.6332	2.2471000000000001	1.7190000000000001	1.3058000000000001	0.94020000000000004	0.71040000000000003	0.61599999999999999	0.56920000000000004	0.53180000000000005	0.44800000000000001	0.25	0.1	8	99.300003	250.79900000000001	125.399	\N	125
11019	2116	35	10.153	1.9521999999999999	1.141	2.2000000000000002	2.8889999999999998	3.9085999999999999	3.2995000000000001	2.8934000000000002	2.3858000000000001	1.9662999999999999	1.6854	1.4045000000000001	1.1235999999999999	0.90910000000000002	0.82799999999999996	0.74680000000000002	0.68189999999999995	0.58330000000000004	0.25	0.1	10	99.599998	14.363	8.2919999999999998	\N	35
11020	2116	55	25.224	1.5379	1.2350000000000001	1.8839999999999999	2.3639999999999999	2.8780000000000001	1.9180999999999999	1.7816000000000001	1.6109	1.4402999999999999	1.099	0.91610000000000003	0.79790000000000005	0.67959999999999998	0.62270000000000003	0.57689999999999997	0.5403	0.46489999999999998	0.25	0.2	10	98.699997	51.811	25.905000000000001	\N	55
11021	2116	85	30.213999999999999	3.2103999999999999	1.409	2.7519999999999998	3.5289999999999999	8.375	5.6429	4.5476000000000001	3.6907000000000001	3.1753	2.1442999999999999	1.7270000000000001	1.4095	1.0921000000000001	0.95169999999999999	0.83679999999999999	0.74490000000000001	0.60760000000000003	0.25	0.1	10	93.900002	44.594000000000001	22.297000000000001	\N	85
11022	2116	95	19.140999999999998	2.4678	1.032	2.585	3.7130000000000001	5.4866000000000001	3.9336000000000002	3.5545	3.0806	2.6065999999999998	1.8672	1.4982	1.1292	0.86339999999999995	0.75819999999999999	0.65310000000000001	0.58860000000000001	0.50290000000000001	0.25	0.1	10	97	47.488999999999997	23.744	\N	95
11023	2116	135	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	135
13036	1925	23	0.33300000000000002	1.1820999999999999	1.1930000000000001	2.2330000000000001	3.0009999999999999	2.5735000000000001	1.8623000000000001	1.7098	1.5192000000000001	1.3287	0.97140000000000004	0.76349999999999996	0.59209999999999996	0.48930000000000001	0.44790000000000002	0.40649999999999997	0.37340000000000001	0.32369999999999999	0.125	0.061999999	4	95.940002	0.48099999999999998	0.27700000000000002	\N	23
13037	1925	41	14.757	0.73529999999999995	1.0940000000000001	1.629	1.8979999999999999	1.0918000000000001	0.89910000000000001	0.82289999999999996	0.72760000000000002	0.63229999999999997	0.57920000000000005	0.52780000000000005	0.47410000000000002	0.4178	0.38969999999999999	0.36149999999999999	0.33900000000000002	0.30520000000000003	0.125	0.0060000001	6.2999999999999998	99.152	28.672999999999998	16.553999999999998	\N	41
13038	1925	50	11.375	1.2217	1.466	1.9139999999999999	1.958	1.9214	1.2462	0.95960000000000001	0.84830000000000005	0.7369	0.59840000000000004	0.53759999999999997	0.47810000000000002	0.42059999999999997	0.39179999999999998	0.36309999999999998	0.34010000000000001	0.30559999999999998	0.125	0.0080000004	10	97.924004	12.720000000000001	7.3440000000000003	\N	50
13039	1925	80	0.035000000000000003	0.45129999999999998	0.91600000000000004	1.3480000000000001	1.647	0.56599999999999995	0.49249999999999999	0.47949999999999998	0.4632	0.44700000000000001	0.41439999999999999	0.38179999999999997	0.3493	0.31669999999999998	0.3004	0.28420000000000001	0.27110000000000001	0.25159999999999999	0.125	0.366	2	98.171997	0	0	\N	80
13040	1925	90	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	90
13031	1924	35	1.458	2.7029999999999998	1.236	2.0579999999999998	3.5009999999999999	5.5359999999999996	4.5734000000000004	3.972	3.6429999999999998	3.3138999999999998	2.6558999999999999	1.9991000000000001	1.7286999999999999	1.4583999999999999	1.3231999999999999	1.1879999999999999	1.0798000000000001	0.75860000000000005	0.125	0.039000001	6.2999999999999998	94.762001	2.504	1.446	\N	35
13032	1924	45	2.5760000000000001	0.57010000000000005	1.028	1.4139999999999999	1.623	0.78490000000000004	0.58979999999999999	0.54549999999999998	0.497	0.47989999999999999	0.4456	0.41139999999999999	0.37719999999999998	0.34300000000000003	0.32590000000000002	0.30880000000000002	0.29509999999999997	0.27450000000000002	0.125	0.048	4	98.657997	0.76000000000000001	0.439	\N	45
13033	1924	55	15.853999999999999	2.0102000000000002	1.6200000000000001	2.8079999999999998	3.3889999999999998	4.9585999999999997	3.0320999999999998	2.1082999999999998	1.7978000000000001	1.5746	1.1283000000000001	0.84830000000000005	0.63549999999999995	0.50749999999999995	0.46210000000000001	0.41899999999999998	0.3846	0.33289999999999997	0.125	0.017000001	10	94.383003	14.009	8.0879999999999992	\N	55
13034	1924	85	0.55600000000000005	0.40010000000000001	0.93300000000000005	1.304	1.5489999999999999	0.49980000000000002	0.48230000000000001	0.47060000000000002	0.45600000000000002	0.44140000000000001	0.41220000000000001	0.38300000000000001	0.35370000000000001	0.32450000000000001	0.30990000000000001	0.29530000000000001	0.28360000000000002	0.2661	0.125	0.121	2	99.878998	0.27700000000000002	0.16	\N	85
13035	1924	95	0.028000000000000001	0.374	0.80900000000000005	1.5609999999999999	2.2570000000000001	0.49270000000000003	0.46889999999999998	0.45300000000000001	0.43309999999999998	0.41320000000000001	0.3735	0.33379999999999999	0.29409999999999997	0.25440000000000002	0.2326	0.2102	0.1923	0.16550000000000001	0.125	0.93199998	1	96.502998	0	0	\N	95
12877	1923	27	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	27
12878	1923	40	2.6880000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	1.78	1.028	\N	40
12879	1923	56	4.1109999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	1.9259999999999999	1.1120000000000001	\N	56
12880	1923	72	2.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	3.7000000000000002	2.1360000000000001	\N	72
12881	1923	86	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	86
12872	1922	35	0.23599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	35
12873	1922	45	1.2709999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	45
12874	1922	55	1.6739999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	55
12875	1922	85	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	85
12876	1922	95	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	95
12867	1921	32	0.27100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	32
12868	1921	42	5.2569999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	42
12869	1921	52	1.9690000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	52
12870	1921	82	1.903	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	82
12871	1921	92	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	92
11962	1920	40	0.031	0.3125	0.83399999999999996	1.542	2.1539999999999999	0.46250000000000002	0.44	0.42499999999999999	0.40629999999999999	0.38750000000000001	0.34999999999999998	0.3125	0.27500000000000002	0.23749999999999999	0.21879999999999999	0.20000000000000001	0.185	0.16250000000000001	0.25	33.333	0.25	33.333	0.043999999999999997	0.031	\N	40
11963	1920	51	8.3539999999999992	20.599	0.67400000000000004	2.3849999999999998	5.6900000000000004	44.514899999999997	33.4238	30.204699999999999	28.016100000000002	25.8276	21.450500000000002	17.073399999999999	13.989699999999999	11.3262	9.9901999999999997	7.6226000000000003	5.8773	3.7700999999999998	0.5	0.249	31.5	82.959	25.684999999999999	14.829000000000001	\N	51
11964	1920	60	232.93600000000001	9.3699999999999992	0.80900000000000005	2.2069999999999999	4.008	19.026199999999999	15.1113	14.1166	12.8733	11.630000000000001	9.3884000000000007	7.6131000000000002	5.9932999999999996	4.8155000000000001	4.2264999999999997	3.6099999999999999	3.1030000000000002	2.3424999999999998	0.5	0.066	16	87.573997	257.13600000000002	148.45699999999999	\N	60
11965	1920	90	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	90
11966	1920	100	0.072999999999999995	0.32140000000000002	0.81999999999999995	1.5089999999999999	2.133	0.46500000000000002	0.44400000000000001	0.42999999999999999	0.41249999999999998	0.39500000000000002	0.35999999999999999	0.32500000000000001	0.28999999999999998	0.255	0.2344	0.21249999999999999	0.19500000000000001	0.16880000000000001	0.25	28.570999	0.25	28.570999	0.10299999999999999	0.072999999999999995	\N	100
11957	1919	33	0.19800000000000001	7.2157999999999998	0.82399999999999995	2.5779999999999998	5.4429999999999996	14.3714	13.394299999999999	12.742900000000001	11.928599999999999	11.1143	8.8900000000000006	5.7249999999999996	3.8399999999999999	3.0800000000000001	2.7000000000000002	2.3199999999999998	2.016	1.6333	2	15.789	10	63.158001	0.28000000000000003	0.19800000000000001	\N	33
11958	1919	43	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	43
11959	1919	53	36.838000000000001	9.1097999999999999	1.1259999999999999	2.1110000000000002	3.0409999999999999	19.9984	15.0731	13.603999999999999	11.7677	9.9696999999999996	8.3488000000000007	6.7279999999999998	5.6368	4.7355999999999998	4.2850000000000001	3.8052000000000001	3.3812000000000002	2.7452000000000001	2	2.97	16	86.524002	89.421999999999997	51.628	\N	53
11960	1919	83	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	83
11961	1919	93	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	93
11952	1918	32	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	32
11953	1918	41	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	41
11954	1918	50	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	50
11955	1918	81	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	81
11956	1918	91	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	91
11949	1917	50	20.068999999999999	13.597099999999999	0.59099999999999997	2.6970000000000001	6.5629999999999997	27.6006	24.581800000000001	22.569199999999999	20.0535	17.537800000000001	14.3024	11.8575	9.3547999999999991	6.6691000000000003	5.4238999999999997	4.2157999999999998	3.3788	2.1791999999999998	0.25	0.035	31.5	97.75	55.207000000000001	31.873999999999999	\N	50
11950	1917	59	129.97999999999999	12.963699999999999	0.75600000000000001	2.347	4.3929999999999998	26.3948	23.331800000000001	21.2897	18.737100000000002	16.1845	13.7578	11.4315	9.1793999999999993	7.0461	6.0045000000000002	5.0213999999999999	4.2350000000000003	3.1316999999999999	0.25	0.02	16	69.639	233.333	134.715	\N	59
11951	1917	88	0.035000000000000003	0.53249999999999997	1.0069999999999999	1.5209999999999999	1.8400000000000001	0.85199999999999998	0.76319999999999999	0.70399999999999996	0.63	0.60399999999999998	0.55200000000000005	0.5	0.45000000000000001	0.40000000000000002	0.375	0.34999999999999998	0.33000000000000002	0.29999999999999999	0.5	50	0.63	75	0	0	\N	88
11944	1916	38	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	38
11945	1916	50	0.29199999999999998	1.5129999999999999	1.401	2.5699999999999998	3.4369999999999998	3.6000000000000001	2.7599999999999998	2.2000000000000002	1.8500000000000001	1.6399999999999999	1.22	0.90749999999999997	0.71319999999999995	0.56759999999999999	0.51300000000000001	0.46000000000000002	0.41799999999999998	0.35499999999999998	0.5	23.809999	6.2999999999999998	97.619003	0.51200000000000001	0.29599999999999999	\N	50
11946	1916	62	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	62
11947	1916	74	0.23599999999999999	4.5705	0.50600000000000001	4.5789999999999997	11.867000000000001	13.199999999999999	9.1199999999999992	7.3200000000000003	6.1082999999999998	5.4566999999999997	4.1532999999999998	2.7999999999999998	1.6499999999999999	0.85199999999999998	0.59750000000000003	0.49170000000000003	0.435	0.34999999999999998	0.25	2.941	10	85.293999	0.64600000000000002	0.373	\N	74
11948	1916	87	0.115	0.95269999999999999	1.2150000000000001	1.54	1.788	1.6667000000000001	1.4467000000000001	1.3	1.1167	0.98770000000000002	0.91979999999999995	0.85199999999999998	0.78420000000000001	0.71630000000000005	0.68240000000000001	0.64849999999999997	0.60980000000000001	0.51439999999999997	0.25	4.5450001	2	99.091003	0.16200000000000001	0.115	\N	87
11939	1915	34	0.94799999999999995	1.2316	1.1319999999999999	1.9339999999999999	2.7130000000000001	2.2250000000000001	1.8428	1.7172000000000001	1.5603	1.4034	1.0896999999999999	0.89539999999999997	0.749	0.61419999999999997	0.57199999999999995	0.52969999999999995	0.49270000000000003	0.4017	0.5	16.483999	6.2999999999999998	98.901001	0	0	\N	34
11940	1915	42	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	42
11941	1915	57	0.031	3.0712000000000002	0.55600000000000005	2.323	5.7140000000000004	5.6100000000000003	5.1959999999999997	4.9199999999999999	4.5750000000000002	4.2300000000000004	3.6000000000000001	3	2.3999999999999999	1.8	1.5	1.2	0.96299999999999997	0.63	0.5	3.3329999	4	66.667	0.043999999999999997	0.031	\N	57
11942	1915	72	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	72
11943	1915	88	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	88
11935	1914	27	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	27
11936	1914	45	0.028000000000000001	0.81379999999999997	1.405	1.821	2.2229999999999999	1.6000000000000001	1.3600000000000001	1.2	1	0.92600000000000005	0.77800000000000002	0.63	0.57799999999999996	0.52600000000000002	0.5	0.45000000000000001	0.40999999999999998	0.34999999999999998	0.5	25	1	75	0	0	\N	45
11937	1914	67	6.5	3.5095000000000001	0.95199999999999996	1.8089999999999999	2.456	6.0513000000000003	5.0945	4.4565999999999999	3.9123000000000001	3.7069999999999999	3.2965	2.8860000000000001	2.4754	2.0649000000000002	1.8778999999999999	1.6992	1.5563	1.3420000000000001	0.5	0.107	10	96.902	21.798999999999999	12.586	\N	67
11938	1914	87	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	87
10587	1909	33	0.92500000000000004	0.5998	0.98999999999999999	1.542	1.8640000000000001	0.92259999999999998	0.81059999999999999	0.73599999999999999	0.64259999999999995	0.6119	0.57010000000000005	0.52829999999999999	0.48110000000000003	0.42259999999999998	0.39340000000000003	0.36420000000000002	0.34079999999999999	0.30580000000000002	0.25	0.44999999	2	99.098999	0	0	\N	33
10588	1909	48	0.70499999999999996	0.6885	1.236	1.677	1.8480000000000001	1.3352999999999999	0.91510000000000002	0.79730000000000001	0.65010000000000001	0.60499999999999998	0.54690000000000005	0.49070000000000003	0.442	0.39340000000000003	0.36899999999999999	0.34470000000000001	0.32519999999999999	0.29599999999999999	0.25	0.546	4	99.454002	0.40799999999999997	0.28799999999999998	\N	48
10589	1909	63	0.97399999999999998	5.5217999999999998	2.6720000000000002	4.8070000000000004	5.4089999999999998	19.199999999999999	12.720000000000001	9.1999999999999993	6.8666999999999998	4.6691000000000003	2.4666999999999999	1.619	1.1048	0.81279999999999997	0.69530000000000003	0.60160000000000002	0.55059999999999998	0.45600000000000002	0.25	0.463	20	90.740997	0.52300000000000002	0.37	\N	63
10590	1909	78	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	78
10584	1908	61	0.44800000000000001	4.2644000000000002	0.88300000000000001	3.1230000000000002	5.8550000000000004	11.4	7.5012999999999996	6.5266999999999999	5.6292	4.8049999999999997	3.5110999999999999	2.5556000000000001	1.8	1.3222	1.0832999999999999	0.89639999999999997	0.76910000000000001	0.59970000000000001	0.5	4.651	10	88.372002	0.63300000000000001	0.44800000000000001	\N	61
10585	1908	76	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	76
10586	1908	91	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	91
10579	1907	35	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	35
10580	1907	42	2.2290000000000001	0.71740000000000004	1.0609999999999999	1.6359999999999999	1.9630000000000001	1.3154999999999999	0.96899999999999997	0.91020000000000001	0.8367	0.76319999999999999	0.62529999999999997	0.57499999999999996	0.52480000000000004	0.46329999999999999	0.42709999999999998	0.39100000000000001	0.36199999999999999	0.31859999999999999	0.25	0.52100003	4	99.825996	1.774	1.024	\N	42
10581	1907	56	3.931	0.9012	1.2549999999999999	1.9630000000000001	2.4500000000000002	1.7211000000000001	1.4589000000000001	1.2842	1.0658000000000001	0.94989999999999997	0.80659999999999998	0.6633	0.57079999999999997	0.49340000000000001	0.45229999999999998	0.4113	0.3785	0.32919999999999999	0.25	0.34400001	8	99.828003	11.294	6.5209999999999999	\N	56
10582	1907	71	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	71
10583	1907	87	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	87
10574	1906	34	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	34
10575	1906	43	4.9059999999999997	0.78369999999999995	1.0509999999999999	1.625	1.9530000000000001	1.2604	0.94940000000000002	0.89159999999999995	0.81930000000000003	0.74709999999999999	0.62039999999999995	0.56999999999999995	0.51970000000000005	0.45739999999999997	0.42249999999999999	0.3876	0.35959999999999998	0.31769999999999998	0.25	0.30000001	10	99.800003	3.581	2.0670000000000002	\N	43
10576	1906	57	10.708	0.93220000000000003	1.427	1.996	2.3889999999999998	1.7809999999999999	1.4952000000000001	1.3048	1.0667	0.94259999999999999	0.78310000000000002	0.62719999999999998	0.55769999999999997	0.48649999999999999	0.44679999999999997	0.40710000000000002	0.37540000000000001	0.32779999999999998	0.25	0.2	8	99.900002	22.286999999999999	11.143000000000001	\N	57
10577	1906	72	12.202999999999999	1.1645000000000001	1.2070000000000001	1.923	2.484	1.8818999999999999	1.6736	1.5347	1.3611	1.1875	0.9345	0.79220000000000002	0.64990000000000003	0.57079999999999997	0.53649999999999998	0.50209999999999999	0.45279999999999998	0.37630000000000002	0.25	0.1	10	99.199997	56.335000000000001	28.167000000000002	\N	72
10578	1906	87	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	87
10569	1905	42	21.077999999999999	0.58699999999999997	0.93000000000000005	1.47	1.825	0.87009999999999998	0.76719999999999999	0.6986	0.62660000000000005	0.60960000000000003	0.57550000000000001	0.54139999999999999	0.50729999999999997	0.44790000000000002	0.4148	0.38159999999999999	0.35510000000000003	0.31530000000000002	0.25	0.14300001	6.2999999999999998	99.857002	64.248000000000005	32.124000000000002	\N	42
10570	1905	54	11.923999999999999	0.74309999999999998	1.0429999999999999	1.55	1.9670000000000001	1.1793	0.95040000000000002	0.90369999999999995	0.84519999999999995	0.78669999999999995	0.66969999999999996	0.60070000000000001	0.55630000000000002	0.51190000000000002	0.47870000000000001	0.43259999999999998	0.39579999999999999	0.34050000000000002	0.25	0.175	6.2999999999999998	99.942001	6.3120000000000003	3.6440000000000001	\N	54
10571	1905	66	15.182	1.2861	1.258	2.008	2.5569999999999999	2.6383000000000001	1.8846000000000001	1.7307999999999999	1.5385	1.3462000000000001	0.98509999999999998	0.83650000000000002	0.68799999999999994	0.58520000000000005	0.54849999999999999	0.51180000000000003	0.4672	0.38519999999999999	0.25	0.1	10	99.699997	34.963999999999999	17.481999999999999	\N	66
10572	1905	78	13.047000000000001	1.1240000000000001	1.25	1.5780000000000001	1.7549999999999999	1.8140000000000001	1.6667000000000001	1.5684	1.4456	1.3228	1.0771999999999999	0.94450000000000001	0.86360000000000003	0.78259999999999996	0.74219999999999997	0.70169999999999999	0.66930000000000001	0.61380000000000001	0.25	0.14300001	6.2999999999999998	99.857002	44.009999999999998	22.004999999999999	\N	78
10573	1905	90	4.9420000000000002	11.056100000000001	0.34899999999999998	3.4129999999999998	13.257	23.837599999999998	19.709599999999998	18.5383	17.074100000000001	15.6099	12.6815	9.7752999999999997	7.1024000000000003	4.6214000000000004	3.4622999999999999	2.3433999999999999	1.6921999999999999	0.95660000000000001	0.125	0.083999999	20	84.991997	0	0	\N	90
10560	1903	34	0.072999999999999995	3.1074000000000002	0.82099999999999995	1.952	3.0950000000000002	5.6726999999999999	5.0872999999999999	4.6970000000000001	4.2091000000000003	3.8595999999999999	3.3683999999999998	2.8772000000000002	2.3860000000000001	1.9117999999999999	1.7059	1.5	1.3352999999999999	1.0882000000000001	0.5	1.429	6.2999999999999998	96.429001	0.10299999999999999	0.072999999999999995	\N	34
10561	1903	47	239.65299999999999	10.0421	0.49199999999999999	3.6989999999999998	9.9969999999999999	24.010300000000001	19.749300000000002	18.195900000000002	16.254200000000001	14.3125	10.4291	7.6093000000000002	4.9382000000000001	2.9714999999999998	2.1105	1.7096	1.4430000000000001	1.0431999999999999	0.25	0.043000001	20	84.644997	421.18000000000001	243.16800000000001	\N	47
10562	1903	62	124.53400000000001	6.5923999999999996	0.95299999999999996	5.5890000000000004	12.244	18.475300000000001	15.508800000000001	13.5312	11.059100000000001	8.6727000000000007	4.9413	2.8422999999999998	1.5919000000000001	0.86539999999999995	0.61919999999999997	0.55130000000000001	0.4965	0.40360000000000001	0.25	0.086999997	20	93.084	115.111	66.459999999999994	\N	62
10563	1903	77	161.52500000000001	4.1269	4.6079999999999997	4.3879999999999999	3.5089999999999999	15.222799999999999	8.8691999999999993	5.8691000000000004	2.7917000000000001	1.8262	1.337	0.94159999999999999	0.75380000000000003	0.59930000000000005	0.55430000000000001	0.50929999999999997	0.46060000000000001	0.38100000000000001	0.25	0.13	20	93.822998	395.48399999999998	197.74199999999999	\N	77
10642	1952	85	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	85
10643	1952	100	0.0070000000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.024	0.014	\N	100
10644	1952	113	0.14599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.505	0.29199999999999998	\N	113
10645	1952	129	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	129
10646	1952	144	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	144
10637	1951	67	0.014	1.3141	0.80100000000000005	1.4770000000000001	2.282	1.8714	1.7943	1.7428999999999999	1.6786000000000001	1.6143000000000001	1.4857	1.3571	1.2285999999999999	1.1000000000000001	1.0357000000000001	0.93659999999999999	0.82240000000000002	0.65110000000000001	0.5	5.5560002	1	22.222	0	0	\N	67
10638	1951	86	76.712999999999994	14.072900000000001	0.71599999999999997	2.617	5.0529999999999999	28.888200000000001	24.887599999999999	22.220600000000001	18.886900000000001	15.845700000000001	13.542999999999999	11.2402	8.9309999999999992	6.6140999999999996	5.4903000000000004	4.3794000000000004	3.6351	2.6798999999999999	0.25	0.022	31.5	93.917	113.55500000000001	65.561000000000007	\N	86
10639	1951	106	204.86799999999999	10.535500000000001	0.91300000000000003	2.331	3.9740000000000002	23.471499999999999	17.917300000000001	15.4612	14.064399999999999	12.6676	9.9156999999999993	8.0465999999999998	6.2225000000000001	5.0381	4.4459999999999997	3.8347000000000002	3.2988	2.4950999999999999	0.25	0.044	31.5	98.672997	665.45100000000002	384.19799999999998	\N	106
10640	1951	126	150.09	7.7896000000000001	0.63600000000000001	2.9830000000000001	7.4989999999999997	15.893800000000001	13.970800000000001	12.688800000000001	11.0863	9.6784999999999997	7.6822999999999997	5.8712999999999997	4.4771999999999998	3.1696	2.5383	1.9331	1.5696000000000001	1.0245	0.125	0.021	16	90.331001	432.32100000000003	249.601	\N	126
10641	1951	146	0.40999999999999998	7.7587999999999999	0.92500000000000004	2.2269999999999999	4.7359999999999998	14.434799999999999	13.495699999999999	12.8696	12.087	11.3043	9.4713999999999992	6.2999999999999998	5.3143000000000002	4.3285999999999998	3.7999999999999998	3.2000000000000002	2.7200000000000002	2	0.63	1.6670001	10	61.667	0	0	\N	146
10632	1950	90	7.2290000000000001	3.4691999999999998	1.504	2.6669999999999998	3.0510000000000002	9.3000000000000007	5.0027999999999997	3.7281	3.1433	2.5583999999999998	1.8386	1.5297000000000001	1.2208000000000001	0.94979999999999998	0.8619	0.77390000000000003	0.7036	0.60270000000000001	0.25	0.096000001	20	97.309998	21.579999999999998	12.459	\N	90
10633	1950	97	11.635	4.0114999999999998	3.29	3.5590000000000002	3.3199999999999998	16.179099999999998	5.6486999999999998	3.6236999999999999	2.5762999999999998	1.8595999999999999	1.2354000000000001	0.875	0.67449999999999999	0.57179999999999997	0.53449999999999998	0.49519999999999997	0.44600000000000001	0.37209999999999999	0.25	0.081	20	92.070999	12.949	9.1560000000000006	\N	97
10634	1950	108	0.028000000000000001	0.85089999999999999	1.1699999999999999	2.0230000000000001	2.5739999999999998	1.7	1.46	1.3	1.1000000000000001	0.96299999999999997	0.81499999999999995	0.66700000000000004	0.53249999999999997	0.45000000000000001	0.41670000000000001	0.38329999999999997	0.35670000000000002	0.31669999999999998	0.5	37.5	2	97.5	0	0	\N	108
10635	1950	121	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	121
10636	1950	132	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	132
10623	1948	85	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	85
10624	1948	100	6.2149999999999999	6.6786000000000003	1.6080000000000001	3.6659999999999999	5.6159999999999997	18.798400000000001	14.6357	11.8605	9.3196999999999992	7.7931999999999997	4.827	3.1480999999999999	1.9518	1.5924	1.4127000000000001	1.2329000000000001	1.0891999999999999	0.85960000000000003	0.25	0.112	20	91.732002	16.443999999999999	9.4939999999999998	\N	100
10625	1948	115	38.453000000000003	6.9082999999999997	1.613	3.5110000000000001	4.7830000000000004	20.752300000000002	15.225199999999999	11.621600000000001	8.6804000000000006	6.7057000000000002	4.6058000000000003	3.4138000000000002	2.5516999999999999	1.8434999999999999	1.6261000000000001	1.4087000000000001	1.2347999999999999	0.96299999999999997	0.5	2.45	20	89.300003	138.31899999999999	69.159999999999997	\N	115
10626	1948	128	1.4790000000000001	8.6707999999999998	0.61899999999999999	3.1219999999999999	7.4480000000000004	18.5	16.621700000000001	15.3696	13.8043	12.239100000000001	9.2189999999999994	6.7636000000000003	4.8017000000000003	3.2783000000000002	2.6522000000000001	2.0261	1.7049000000000001	1.2378	0.5	3.4719999	20	94.792	2.0179999999999998	1.427	\N	128
10627	1948	145	3.9510000000000001	2.7928999999999999	1.742	2.6949999999999998	2.8879999999999999	7.2461000000000002	5.1264000000000003	3.9367999999999999	3.1974	2.4579	1.7718	1.4412	1.1106	0.9052	0.83399999999999996	0.76280000000000003	0.70579999999999998	0.61350000000000005	0.25	0.178	10	95.552002	4.0960000000000001	2.3650000000000002	\N	145
10618	1947	88	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	88
10619	1947	93	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	93
10620	1947	108	0.84399999999999997	0.53139999999999998	1.0149999999999999	1.4179999999999999	1.6459999999999999	0.75329999999999997	0.59440000000000004	0.55779999999999996	0.51200000000000001	0.4869	0.45150000000000001	0.41599999999999998	0.38059999999999999	0.34510000000000002	0.32740000000000002	0.30969999999999998	0.29549999999999998	0.27429999999999999	0.125	0.52600002	4	99.473999	0.36799999999999999	0.26000000000000001	\N	108
10621	1947	123	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	123
10622	1947	138	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	138
10613	1946	86	0.016	1.1508	0.65100000000000002	1.9159999999999999	3.3929999999999998	1.8720000000000001	1.7622	1.6890000000000001	1.5975999999999999	1.5061	1.3231999999999999	1.1402000000000001	0.93979999999999997	0.68159999999999998	0.59340000000000004	0.53249999999999997	0.47999999999999998	0.39000000000000001	0.25	0.667	2	97	0	0	\N	86
10614	1946	97	26.565000000000001	4.1219999999999999	2.7370000000000001	3.9049999999999998	3.7999999999999998	12.4498	8.8332999999999995	7.3893000000000004	5.6330999999999998	4.0679999999999996	1.9494	1.3671	0.94079999999999997	0.78049999999999997	0.70040000000000002	0.62329999999999997	0.57920000000000005	0.51300000000000001	0.25	0.043000001	20	98.174004	11.699999999999999	8.2729999999999997	\N	97
10615	1946	111	15.116	1.5696000000000001	1.3899999999999999	2.1469999999999998	2.5819999999999999	2.8148	1.8081	1.6061000000000001	1.3534999999999999	1.101	0.873	0.71419999999999995	0.59340000000000004	0.51559999999999995	0.47299999999999998	0.42809999999999998	0.3921	0.33810000000000001	0.25	0.2	10	96.800003	21.186	14.981	\N	111
10616	1946	126	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	126
10617	1946	141	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	141
10607	1945	85	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	85
10608	1945	94	4.0830000000000002	7.3455000000000004	0.46999999999999997	3.4830000000000001	10.134	16.7483	14.3483	12.7483	10.7483	9.5158000000000005	7.9592000000000001	6.0088999999999997	4.2969999999999997	2.7376999999999998	1.9847999999999999	1.5394000000000001	1.1830000000000001	0.78539999999999999	0.5	3.401	20	98.128998	1.516	0.875	\N	94
10609	1945	104	23.245000000000001	1.2793000000000001	1.5860000000000001	1.879	2.1259999999999999	2.2000000000000002	1.5214000000000001	1.1795	0.96289999999999998	0.89890000000000003	0.77080000000000004	0.64280000000000004	0.58650000000000002	0.53820000000000001	0.51400000000000001	0.47610000000000002	0.43070000000000003	0.36249999999999999	0.25	0.1	10	99.099998	54.268000000000001	27.134	\N	104
10610	1945	114	30.495000000000001	0.98209999999999997	1.4510000000000001	2.0779999999999998	2.532	1.8771	1.6229	1.4534	1.2415	1.0297000000000001	0.83050000000000002	0.6482	0.56279999999999997	0.48730000000000001	0.44750000000000001	0.40760000000000002	0.37580000000000002	0.32800000000000001	0.25	0.2	8	99.800003	112.965	56.481999999999999	\N	114
10611	1945	124	1.5489999999999999	0.52810000000000001	1.022	1.4590000000000001	1.7070000000000001	0.84760000000000002	0.66479999999999995	0.61209999999999998	0.58069999999999999	0.54930000000000001	0.49130000000000001	0.4506	0.40989999999999999	0.36919999999999997	0.3488	0.32850000000000001	0.31219999999999998	0.2878	0.25	0.71399999	2	99.642998	2.335	1.3480000000000001	\N	124
10612	1945	134	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	134
10601	1944	80	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	80
10602	1944	89	74.766999999999996	11.290800000000001	0.67800000000000005	2.3860000000000001	5.4729999999999999	22.383299999999998	19.0519	17.931799999999999	16.531700000000001	15.131500000000001	12.331300000000001	9.7015999999999991	7.9069000000000003	5.9010999999999996	4.9893999999999998	4.0777000000000001	3.3479000000000001	2.2532000000000001	0.25	0.043000001	20	87.386002	106.91800000000001	61.728999999999999	\N	89
10603	1944	95	195.21199999999999	8.1533999999999995	0.83599999999999997	3.0449999999999999	5.8179999999999996	18.521699999999999	16.0318	14.3718	12.296900000000001	10.222	7.6981999999999999	5.7590000000000003	4.2694999999999999	3.0990000000000002	2.5489999999999999	1.9994000000000001	1.7289000000000001	1.3231999999999999	0.25	0.043000001	20	93.561996	462.07900000000001	231.03899999999999	\N	95
10604	1944	109	176.547	10.0868	0.29199999999999998	6.0570000000000004	22.207999999999998	26.130299999999998	21.258199999999999	18.898900000000001	16.652200000000001	14.4055	9.9341000000000008	6.4965000000000002	3.8936999999999999	2.0531000000000001	1.4353	0.84309999999999996	0.57940000000000003	0.44729999999999998	0.25	0.114	31.5	96.612999	571.04999999999995	233.13	\N	109
10605	1944	124	4.8440000000000003	3.9578000000000002	13.298999999999999	5.6040000000000001	2.7090000000000001	14.6351	10.2811	8.1952999999999996	5.0484999999999998	2.0899999999999999	0.80400000000000005	0.50309999999999999	0.44990000000000002	0.39889999999999998	0.37330000000000002	0.3478	0.32740000000000002	0.29680000000000001	0.25	0.838	20	97.392998	3.431	1.9810000000000001	\N	124
10606	1944	139	0.129	2.2292000000000001	1.046	3.173	5.0990000000000002	5.6675000000000004	4.5979999999999999	3.9333	3.4167000000000001	2.8999999999999999	1.9333	1.4167000000000001	0.94450000000000001	0.65769999999999995	0.57579999999999998	0.50870000000000004	0.45669999999999999	0.37919999999999998	0.5	19.355	6.2999999999999998	93.547997	0	0	\N	139
10628	1949	75	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	75
10629	1949	95	104.48399999999999	4.2217000000000002	1.6519999999999999	3.7069999999999999	4.7839999999999998	12.624499999999999	8.2507999999999999	6.4390999999999998	4.8838999999999997	3.7414999999999998	2.4954000000000001	1.7316	1.286	0.91349999999999998	0.79269999999999996	0.67179999999999995	0.60029999999999994	0.52159999999999995	0.25	0.043000001	20	97.347	285.98000000000002	142.99000000000001	\N	95
10630	1949	115	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	115
10631	1949	135	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	135
10595	1943	75	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	75
10596	1943	91	5.3230000000000004	2.9815999999999998	1.9399999999999999	2.8220000000000001	2.778	7.8413000000000004	5.8771000000000004	4.8635000000000002	3.7014999999999998	2.7642000000000002	1.8121	1.4948999999999999	1.1778	0.93730000000000002	0.86609999999999998	0.79479999999999995	0.73780000000000001	0.6522	0.5	3.6619999	10	95.541	5.7889999999999997	4.0940000000000003	\N	91
10597	1943	101	1.6459999999999999	1.0279	1.242	1.7130000000000001	1.9219999999999999	1.8217000000000001	1.5847	1.4267000000000001	1.2292000000000001	1.0317000000000001	0.91849999999999998	0.82989999999999997	0.74139999999999995	0.65280000000000005	0.61080000000000001	0.57130000000000003	0.53969999999999996	0.47789999999999999	0.5	10.97	4	99.578003	2.1970000000000001	1.2689999999999999	\N	101
10598	1943	112	0.23599999999999999	1.1992	1.0029999999999999	2.1629999999999998	3.218	2.5581	1.9184000000000001	1.7864	1.6214	1.4562999999999999	1.1262000000000001	0.88570000000000004	0.70069999999999999	0.55820000000000003	0.5	0.45000000000000001	0.40999999999999998	0.34999999999999998	0.5	25	4	99.117996	0	0	\N	112
10599	1943	121	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	121
10600	1943	137	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	137
10591	1942	81	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	81
10592	1942	109	1.0169999999999999	5.6475999999999997	1.5980000000000001	2.6139999999999999	2.9569999999999999	14.767899999999999	11.6286	9.3499999999999996	7.0750000000000002	5.9032	4.2184999999999997	3.5188999999999999	2.9660000000000002	2.4131999999999998	2.1368	1.8844000000000001	1.7012	1.4266000000000001	0.5	0.34099999	10	80.887001	0.64300000000000002	0.45500000000000002	\N	109
10593	1942	128	3.5230000000000001	6.1590999999999996	0.379	4.8090000000000002	13.628	15.7469	13.1951	11.4938	9.6273	8.3744999999999994	6.0747	4.4577	2.8643999999999998	1.6274	1.2173	0.76019999999999999	0.57050000000000001	0.44569999999999999	0.5	12.772	10	76.487999	4.7839999999999998	3.383	\N	128
10594	1942	153	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	100	\N	\N	0	0	\N	153
34814	10855	25	128.173	4.6013999999999999	2.1059999999999999	3.3199999999999998	3.8969999999999998	13.216100000000001	8.9161000000000001	6.8345000000000002	4.9417	3.7467999999999999	2.6192000000000002	1.8503000000000001	1.5182	1.1860999999999999	1.0201	0.89990000000000003	0.80879999999999996	0.67210000000000003	0.125	0.0049999999	16	93.390999	245.35900000000001	141.65799999999999	\N	65
34815	10855	45	249.66300000000001	2.5699999999999998	1.4670000000000001	2.3540000000000001	2.8130000000000002	5.5890000000000004	3.4738000000000002	2.8422000000000001	2.0527000000000002	1.8522000000000001	1.5354000000000001	1.2184999999999999	0.95730000000000004	0.81969999999999998	0.75090000000000001	0.68210000000000004	0.62709999999999999	0.54590000000000005	0.125	0.0060000001	16	97.864998	397.267	229.36199999999999	\N	85
34816	10855	65	597.63499999999999	4.8377999999999997	0.54900000000000004	3.4039999999999999	7.7830000000000004	10.889799999999999	8.6897000000000002	7.5919999999999996	6.2653999999999996	5.6726999999999999	4.4871999999999996	3.4451999999999998	2.5034000000000001	1.6283000000000001	1.2290000000000001	0.91300000000000003	0.74980000000000002	0.57650000000000001	0.125	0.0040000002	16	97.036003	842.78899999999999	486.58499999999998	\N	105
34817	10855	75	596.08399999999995	7.8030999999999997	0.40300000000000002	4.1470000000000002	14.013	18.072700000000001	14.331	12.864100000000001	11.0306	9.5009999999999994	7.2222	5.4432	4.0038999999999998	2.7505999999999999	2.1242000000000001	1.3969	0.83350000000000002	0.51539999999999997	0.125	0.0049999999	31.5	99.385002	960.976	554.82000000000005	\N	115
34818	10855	85	21.669	8.5134000000000007	0.752	2.4729999999999999	5.2290000000000001	17.019100000000002	14.466900000000001	13.309100000000001	11.861800000000001	10.4145	8.4977	6.7443999999999997	5.3223000000000003	4.0126999999999997	3.4232999999999998	2.8351999999999999	2.3647	1.6253	0.125	0.016000001	16	89.295998	32.740000000000002	18.902999999999999	\N	125
34809	10854	23	3.222	10.371700000000001	0.311	4.8399999999999999	17.876999999999999	25.514399999999998	21.923100000000002	19.5288	16.536000000000001	14.5876	11.1465	8.1165000000000003	5.0846	2.5413000000000001	1.7595000000000001	1.2726999999999999	0.93600000000000005	0.62350000000000005	0.125	0.043000001	16	74.103996	7.1379999999999999	4.1210000000000004	\N	64
34810	10854	33	0.66800000000000004	1.1511	1.1719999999999999	1.7210000000000001	2.0539999999999998	1.8834	1.7189000000000001	1.6092	1.4721	1.335	1.0607	0.9224	0.8226	0.72289999999999999	0.67300000000000004	0.62270000000000003	0.58009999999999995	0.51629999999999998	0.125	0.104	4	98.641998	1.427	0.82399999999999995	\N	74
34811	10854	53	37.505000000000003	4.2999999999999998	0.96899999999999997	2.9849999999999999	5.5090000000000003	10.118600000000001	7.3742000000000001	5.9832000000000001	4.9897	3.9986000000000002	3.2541000000000002	2.5095000000000001	1.8644000000000001	1.4347000000000001	1.2198	1.0049999999999999	0.82789999999999997	0.59060000000000001	0.125	0.0070000002	16	95.932999	29.059000000000001	16.777000000000001	\N	94
34812	10854	73	10.579000000000001	9.7583000000000002	0.90500000000000003	2.024	3.3290000000000002	20.487300000000001	15.4231	14.224399999999999	12.726100000000001	11.2277	9.2626000000000008	8.0135000000000005	6.7643000000000004	5.5338000000000003	4.9240000000000004	4.3143000000000002	3.7665999999999999	2.7822	0.125	0.0070000002	16	85.925003	15.955	9.2119999999999997	\N	114
34813	10854	83	9.1890000000000001	6.8003	0.51000000000000001	3.6669999999999998	11.981999999999999	15.5473	12.557	10.563499999999999	9.1753	8.1096000000000004	6.1026999999999996	4.7960000000000003	3.5524	2.4073000000000002	1.8546	1.3511	0.93389999999999995	0.50929999999999997	0.125	0.015	16	90.907997	15.384	8.8819999999999997	\N	124
34731	10834	22	75.629999999999995	1.2255	1.3100000000000001	1.5940000000000001	1.659	1.8403	1.6606000000000001	1.5408999999999999	1.3912	1.2415	0.98540000000000005	0.90990000000000004	0.83450000000000002	0.75900000000000001	0.72130000000000005	0.6835	0.65329999999999999	0.59399999999999997	0.125	0.0020000001	16	99.870003	131.63200000000001	75.998000000000005	\N	69
34732	10834	32	18.048999999999999	1.7378	0.91900000000000004	1.6830000000000001	2.2789999999999999	3.2299000000000002	2.1070000000000002	1.9288000000000001	1.8249	1.7211000000000001	1.5133000000000001	1.3056000000000001	1.0978000000000001	0.92979999999999996	0.86339999999999995	0.79700000000000004	0.74380000000000002	0.66420000000000001	0.125	0.0080000004	10	98.987	15.611000000000001	9.0129999999999999	\N	79
34733	10834	52	41.383000000000003	3.0015999999999998	0.69699999999999995	3.1920000000000002	5.819	6.7549000000000001	5.6863999999999999	5.1874000000000002	4.5635000000000003	3.9559000000000002	3.0447000000000002	2.1334	1.1307	0.68959999999999999	0.61060000000000003	0.58150000000000002	0.55820000000000003	0.5232	0.125	0.003	10	97.722	62.579000000000001	36.130000000000003	\N	99
34734	10834	62	9.8970000000000002	3.6204000000000001	1.0489999999999999	3.3199999999999998	4.8140000000000001	9.5000999999999998	5.6542000000000003	4.3665000000000003	3.5649999999999999	3.0017999999999998	1.9664999999999999	1.6633	1.3601000000000001	1.0569999999999999	0.85440000000000005	0.62470000000000003	0.5131	0.40849999999999997	0.125	0.021	16	95.522003	24.754000000000001	14.292	\N	109
34735	10834	72	0.74199999999999999	11.6866	0.71699999999999997	2.383	9.5890000000000004	24.904800000000002	20.947600000000001	18.3096	15.6821	14.6212	12.4993	10.3775	8.3838000000000008	6.4177999999999997	5.4992999999999999	4.5895000000000001	3.6877	1.3033999999999999	0.125	0.093999997	16	76.498001	1.429	0.82499999999999996	\N	119
29893	10089	23	54.951999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	33.798999999999999	19.513999999999999	\N	73
29892	10089	33	102.842	1.9248000000000001	1.385	2.2949999999999999	2.8399999999999999	4.0370999999999997	3.1225000000000001	2.5287999999999999	1.9540999999999999	1.7945	1.4752000000000001	1.1557999999999999	0.9274	0.78539999999999999	0.71450000000000002	0.64349999999999996	0.59279999999999999	0.51939999999999997	0.125	0.003	16	99.741997	97.953999999999994	56.554000000000002	\N	83
29891	10089	43	15.246	2.8161999999999998	1.532	3.1059999999999999	4.1799999999999997	7.5606999999999998	4.9404000000000003	3.8209	3.1844000000000001	2.5478000000000001	1.7404999999999999	1.2848999999999999	0.9204	0.7077	0.61460000000000004	0.55759999999999998	0.51200000000000001	0.41639999999999999	0.125	0.0049999999	16	98.559998	32.551000000000002	18.794	\N	93
29890	10089	53	2.782	3.0089999999999999	1.0369999999999999	3.5600000000000001	5.7190000000000003	8.1256000000000004	5.9451000000000001	5.0077999999999996	3.9199000000000002	3.3471000000000002	2.2014	1.6396999999999999	1.2025999999999999	0.83409999999999995	0.6794	0.54490000000000005	0.46910000000000002	0.38490000000000002	0.25	0.375	10	94.605003	3.8210000000000002	2.206	\N	103
29889	10089	63	7.2720000000000002	5.1116999999999999	0.88900000000000001	2.399	4.3540000000000001	9.7459000000000007	8.5762	7.7964000000000002	6.8216999999999999	6.0232000000000001	4.8323999999999998	3.7921	3.1017000000000001	2.4112	2.0659999999999998	1.7437	1.4902	1.1099000000000001	0.125	0.0099999998	16	97.294998	25.192	14.544	\N	113
29883	10087	30	45.131	1.8145	1.9870000000000001	2.0499999999999998	2.0670000000000002	3.8443999999999998	2.7951000000000001	2.0956000000000001	1.8271999999999999	1.6331	1.2450000000000001	0.96719999999999995	0.87829999999999997	0.78939999999999999	0.745	0.70050000000000001	0.66500000000000004	0.60240000000000005	0.125	0.003	10	98.459	175.988	87.994	\N	70
29882	10087	40	51.033999999999999	1.8375999999999999	2.0830000000000002	2.1139999999999999	1.994	4.0216000000000003	2.8811	2.1297000000000001	1.8124	1.5947	1.1594	0.94410000000000005	0.85599999999999998	0.76780000000000004	0.72370000000000001	0.67969999999999997	0.64439999999999997	0.58130000000000004	0.25	0.011	16	99.945	14.444000000000001	8.3390000000000004	\N	80
29881	10087	50	41.168999999999997	2.4051	2.698	2.9119999999999999	2.964	6.3112000000000004	4.6112000000000002	3.7382	3.0249000000000001	2.3117000000000001	1.4998	0.96389999999999998	0.79910000000000003	0.63439999999999996	0.60029999999999994	0.56879999999999997	0.54369999999999996	0.50600000000000001	0.25	0.022	16	99.852997	76.015000000000001	43.887	\N	90
29880	10087	60	132.035	1.6364000000000001	1.9399999999999999	2.1989999999999998	1.905	3.6614	2.7261000000000002	2.1025	1.774	1.5139	0.99870000000000003	0.89000000000000001	0.78139999999999998	0.67269999999999996	0.623	0.59009999999999996	0.56379999999999997	0.52429999999999999	0.125	0.003	10	99.150002	109.321	63.116	\N	100
29879	10087	70	8.7080000000000002	4.4942000000000002	1.21	4.7480000000000002	10.656000000000001	12.318300000000001	9.7042999999999999	8.6979000000000006	7.4398	6.1894999999999998	3.8599999999999999	1.8580000000000001	0.73509999999999998	0.56420000000000003	0.52349999999999997	0.47610000000000002	0.43049999999999999	0.36220000000000002	0.25	0.14399999	16	97.662003	14.875	8.5879999999999992	\N	110
29878	9659	96	45.326999999999998	11.3902	0.54100000000000004	5.0090000000000003	14.553000000000001	29.049600000000002	23.585999999999999	19.9436	15.7751	14.094799999999999	10.7341	6.4053000000000004	2.9337	1.6843999999999999	1.4046000000000001	1.1248	0.94020000000000004	0.73760000000000003	0.125	0.011	31.5	92.691002	113.79000000000001	65.697000000000003	\N	86
29877	9659	106	186.304	6.0891000000000002	1.506	3.242	4.3700000000000001	15.4411	12.440300000000001	10.4398	8.3778000000000006	6.4093999999999998	4.0987999999999998	3.1261999999999999	2.2126000000000001	1.7108000000000001	1.5224	1.3340000000000001	1.1833	0.93799999999999994	0.125	0.0060000001	16	91.117996	499.76100000000002	288.53699999999998	\N	96
29876	9659	116	95.754999999999995	4.9029999999999996	2.1070000000000002	3.2309999999999999	4.0860000000000003	13.414	8.9397000000000002	6.6712999999999996	4.9310999999999998	3.7847	2.7315999999999998	1.9059999999999999	1.5979000000000001	1.2899	1.1358999999999999	0.98160000000000003	0.85629999999999995	0.66849999999999998	0.125	0.0070000002	31.5	99.042999	163.654	94.486000000000004	\N	106
29875	9659	126	443.33199999999999	5.5144000000000002	1.024	2.7309999999999999	4.5279999999999996	13.472799999999999	9.4311000000000007	7.9405999999999999	6.2201000000000004	5.5506000000000002	4.2118000000000002	3.4137	2.7172999999999998	2.0209000000000001	1.7478	1.4795	1.2648999999999999	0.93030000000000002	0.25	0.0070000002	16	93.254997	727.17499999999995	419.834	\N	116
29874	9659	136	216.434	10.489599999999999	0.61099999999999999	2.8740000000000001	7.5620000000000003	24.000299999999999	19.500399999999999	16.500599999999999	14.8933	13.616	11.0616	8.6820000000000004	6.4267000000000003	4.5907	3.7347000000000001	2.9716999999999998	2.3613	1.4628000000000001	0.125	0.003	16	79.333	211.636	122.188	\N	126
27521	8989	22	164.54900000000001	1.6120000000000001	1.2789999999999999	1.7889999999999999	2.173	3.0417000000000001	1.9276	1.8012999999999999	1.6434	1.4855	1.1697	0.95250000000000001	0.84970000000000001	0.74690000000000001	0.6956	0.64419999999999999	0.60209999999999997	0.5383	0.125	0.003	16	99.884003	99.948999999999998	57.704999999999998	\N	72
27522	8989	32	103.063	1.5166999999999999	1.2629999999999999	1.738	2.194	2.6055000000000001	1.8897999999999999	1.7741	1.6295999999999999	1.4850000000000001	1.1959	0.9677	0.86739999999999995	0.7671	0.71699999999999997	0.66690000000000005	0.62570000000000003	0.54520000000000002	0.125	0.0060000001	16	99.880997	265.08300000000003	153.04599999999999	\N	82
27523	8989	42	79.049999999999997	1.4141999999999999	1.321	1.665	1.7569999999999999	1.9021999999999999	1.6819999999999999	1.5353000000000001	1.3517999999999999	1.1684000000000001	0.95760000000000001	0.87919999999999998	0.80069999999999997	0.72230000000000005	0.68310000000000004	0.64390000000000003	0.60699999999999998	0.54500000000000004	0.125	0.0070000002	16	99.822998	182.05199999999999	105.108	\N	92
27524	8989	52	32.649000000000001	2.9401000000000002	1.1659999999999999	2.46	3.6789999999999998	6.3170000000000002	4.8852000000000002	3.9790000000000001	3.5813999999999999	3.1838000000000002	2.3885000000000001	1.8391999999999999	1.5247999999999999	1.2103999999999999	1.0530999999999999	0.91279999999999994	0.80730000000000002	0.6492	0.125	0.0070000002	16	99.633003	35.496000000000002	20.494	\N	102
27525	8989	62	12.41	5.5628000000000002	0.32100000000000001	4.0359999999999996	12.281000000000001	12.446999999999999	9.8903999999999996	9.1212	8.1595999999999993	7.1981000000000002	5.6123000000000003	4.3220000000000001	3.3125	2.3965000000000001	1.8968	1.1286	0.60719999999999996	0.45700000000000002	0.125	0.0060000001	16	97.884003	19.266999999999999	11.124000000000001	\N	112
27520	8988	23	160.11000000000001	4.6180000000000003	2.9449999999999998	3.7000000000000002	2.972	13.4094	10.4293	8.6819000000000006	6.5800999999999998	4.3079000000000001	1.9918	1.6425000000000001	1.2932999999999999	0.97550000000000003	0.8992	0.82289999999999996	0.76180000000000003	0.67030000000000001	0.125	0.0020000001	16	95.216003	222.99299999999999	128.745	\N	73
27519	8988	39	75.356999999999999	3.2355999999999998	1.6579999999999999	2.7450000000000001	2.9540000000000002	8.7331000000000003	5.6334	4.2333999999999996	3.4533	2.8226	1.8952	1.5941000000000001	1.2930999999999999	0.99529999999999996	0.90690000000000004	0.81850000000000001	0.74770000000000003	0.64159999999999995	0.125	0.0049999999	16	98.359001	70.030000000000001	40.432000000000002	\N	89
27518	8988	55	84.822000000000003	4.4767000000000001	1.272	3.1429999999999998	4.9009999999999998	11.6098	8.5440000000000005	6.9467999999999996	5.5662000000000003	4.4809000000000001	3.3039999999999998	2.4098999999999999	1.7847	1.3872	1.1883999999999999	0.99170000000000003	0.86470000000000002	0.67420000000000002	0.125	0.0040000002	16	96.418999	185.458	107.074	\N	105
27517	8988	71	261.35899999999998	3.5689000000000002	0.80900000000000005	3.5800000000000001	7.6459999999999999	8.7786000000000008	6.4760999999999997	5.8023999999999996	5.0998000000000001	4.3971999999999998	3.1692	2.0110000000000001	0.88590000000000002	0.59499999999999997	0.56289999999999996	0.53080000000000005	0.50519999999999998	0.41449999999999998	0.125	0.003	16	98.208	857.34900000000005	428.67500000000001	\N	121
27516	8988	87	8.9039999999999999	3.7252999999999998	0.63200000000000001	3.0070000000000001	7.1120000000000001	8.3510000000000009	6.9010999999999996	6.1360000000000001	5.5937000000000001	5.0514999999999999	3.9670999999999998	2.8879999999999999	1.9083000000000001	1.3903000000000001	1.1313	0.90980000000000005	0.76339999999999997	0.55779999999999996	0.125	0.030999999	10	96.823997	6.8460000000000001	3.952	\N	137
27515	8987	27	400.56200000000001	3.0718999999999999	2.5579999999999998	2.4750000000000001	2.2090000000000001	8.5501000000000005	4.2332999999999998	2.6389	1.8897999999999999	1.7256	1.3974	1.0691999999999999	0.92349999999999999	0.82650000000000001	0.77810000000000001	0.72960000000000003	0.69079999999999997	0.63260000000000005	0.125	0.0049999999	16	95.663002	351.00599999999997	202.65299999999999	\N	77
27514	8987	40	637.625	3.6404999999999998	2.206	3.1619999999999999	3.1120000000000001	10.689399999999999	6.5042	4.8745000000000003	3.5506000000000002	2.7284999999999999	1.7801	1.3852	0.99650000000000005	0.85240000000000005	0.78029999999999999	0.70830000000000004	0.65069999999999995	0.57199999999999995	0.125	0.003	31.5	99.918999	721.06500000000005	416.30700000000002	\N	90
27513	8987	56	612.14099999999996	3.6772	2.294	3.3130000000000002	3.2429999999999999	10.6052	7.8910999999999998	6.2317	4.6745000000000001	3.5748000000000002	2.0743	1.5724	1.1225000000000001	0.90380000000000005	0.83779999999999999	0.77170000000000005	0.71879999999999999	0.63959999999999995	0.125	0.003	31.5	99.919998	1904.9839999999999	1099.8430000000001	\N	106
27512	8987	72	216.785	3.5577000000000001	4.6219999999999999	3.6720000000000002	3.492	9.8183000000000007	7.1508000000000003	5.7972000000000001	4.5922999999999998	3.5264000000000002	1.7517	0.90590000000000004	0.69820000000000004	0.59770000000000001	0.57369999999999999	0.54959999999999998	0.53039999999999998	0.50160000000000005	0.125	0.0049999999	31.5	99.744003	358.77300000000002	207.13800000000001	\N	122
27511	8987	88	0.22600000000000001	1.1504000000000001	1.851	2.0270000000000001	1.8240000000000001	3.3250000000000002	1.3200000000000001	0.87939999999999996	0.65739999999999998	0.60119999999999996	0.5353	0.47860000000000003	0.43230000000000002	0.38600000000000001	0.3629	0.3397	0.32119999999999999	0.29339999999999999	0.25	0.61699998	6.2999999999999998	95.679001	0.58999999999999997	0.34100000000000003	\N	138
27510	8986	23	167.70099999999999	3.4331999999999998	3.6379999999999999	3.0150000000000001	2.363	10.045999999999999	6.2186000000000003	3.9849999999999999	2.4077000000000002	1.8563000000000001	1.4688000000000001	1.0813999999999999	0.92169999999999996	0.82269999999999999	0.7732	0.72360000000000002	0.68400000000000005	0.62160000000000004	0.25	0.0099999998	31.5	99.663002	905.33600000000001	452.66800000000001	\N	73
27509	8986	37	10.654	12.0131	0.20100000000000001	6.4740000000000002	23.001999999999999	28.765999999999998	24.858000000000001	22.252700000000001	18.996099999999998	15.858499999999999	12.322900000000001	8.5650999999999993	4.1624999999999996	1.4094	0.87250000000000005	0.6371	0.59319999999999995	0.53569999999999995	0.25	0.052000001	31.5	94.197998	22.119	12.77	\N	87
27508	8986	52	100.768	5.0693000000000001	3.6539999999999999	4.6379999999999999	5.8819999999999997	14.4838	11.5999	9.7548999999999992	7.9288999999999996	6.1165000000000003	2.9666000000000001	1.3083	0.82969999999999999	0.62039999999999995	0.59140000000000004	0.56240000000000001	0.53920000000000001	0.50429999999999997	0.25	0.048999999	16	93.154999	7.0330000000000004	4.0599999999999996	\N	102
27507	8986	67	306.82299999999998	4.6127000000000002	1.0980000000000001	4.0190000000000001	6.6600000000000001	12.4816	9.2112999999999996	7.6951999999999998	6.0175999999999998	4.9471999999999996	3.351	2.1871999999999998	1.4180999999999999	0.88380000000000003	0.73750000000000004	0.61519999999999997	0.57040000000000002	0.50319999999999998	0.125	0.0049999999	31.5	99.831001	230.767	133.233	\N	117
27506	8986	82	1.0009999999999999	2.9005999999999998	0.82599999999999996	2.0150000000000001	3.5099999999999998	5.6100000000000003	4.6135000000000002	3.9849999999999999	3.7406000000000001	3.4963000000000002	3.0074999999999998	2.5186999999999999	2.0299	1.6532	1.4684999999999999	1.2838000000000001	1.1359999999999999	0.85670000000000002	0.25	0.07	6.2999999999999998	94.153999	3.1150000000000002	1.7989999999999999	\N	132
24571	7803	21	99.691999999999993	1.5794999999999999	1.3979999999999999	1.8320000000000001	1.8839999999999999	2.9510999999999998	1.8319000000000001	1.6415999999999999	1.4037999999999999	1.1658999999999999	0.93920000000000003	0.8458	0.75239999999999996	0.65900000000000003	0.61539999999999995	0.57679999999999998	0.54590000000000005	0.4985	0.25	0.059999999	16	99.776001	135.71100000000001	78.352999999999994	\N	71
24572	7803	32	86.341999999999999	1.5263	1.4470000000000001	2.109	2.488	3.4020999999999999	1.9930000000000001	1.7841	1.5229999999999999	1.2619	0.92869999999999997	0.78580000000000005	0.64290000000000003	0.56759999999999999	0.5333	0.49819999999999998	0.44819999999999999	0.37330000000000002	0.25	0.124	16	99.921997	246.98500000000001	142.59700000000001	\N	82
24573	7803	46	335.02300000000002	1.8039000000000001	1.8169999999999999	2.6179999999999999	2.992	4.1741000000000001	3.0903	2.4413	1.8841000000000001	1.6297999999999999	1.1212	0.87549999999999994	0.71209999999999996	0.58709999999999996	0.54410000000000003	0.501	0.45079999999999998	0.37469999999999998	0.125	0.0089999996	16	99.861	121.779	70.308999999999997	\N	96
24574	7803	59	179.58000000000001	1.9547000000000001	1.419	2.4820000000000002	3.3809999999999998	4.4516999999999998	3.3336999999999999	2.7795999999999998	2.0869	1.8433999999999999	1.4854000000000001	1.1273	0.90190000000000003	0.74970000000000003	0.67359999999999998	0.59899999999999998	0.54100000000000004	0.43930000000000002	0.25	0.086000003	16	99.939003	373.774	215.79900000000001	\N	109
24575	7803	82	5.7329999999999997	4.5149999999999997	0.45100000000000001	2.9700000000000002	9.6790000000000003	9.1537000000000006	7.8658999999999999	7.0073999999999996	6.1490999999999998	5.7061999999999999	4.8205	3.944	3.1831999999999998	2.4224000000000001	2.0419999999999998	1.3872	0.89190000000000003	0.498	0.125	0.025	10	93.943001	9.1349999999999998	5.274	\N	132
24570	7802	23	0.63500000000000001	18.271599999999999	0.36499999999999999	2.2829999999999999	11.917	29.245899999999999	27.8935	26.991800000000001	25.864799999999999	24.7377	22.483599999999999	20.229500000000002	17.9754	15.170400000000001	11.8148	8.2102000000000004	5.3502000000000001	1.8867	0.5	0.221	16	31.236	2.036	1.1759999999999999	\N	73
24569	7802	37	100.758	2.6684000000000001	2.8250000000000002	3.1760000000000002	3.2200000000000002	7.8925000000000001	4.7877999999999998	3.6204000000000001	2.6371000000000002	1.8884000000000001	1.2543	0.89670000000000005	0.72419999999999995	0.5948	0.55589999999999995	0.5171	0.47449999999999998	0.38950000000000001	0.125	0.0099999998	16	98.654999	167.78100000000001	96.869	\N	87
24568	7802	50	57.982999999999997	1.9467000000000001	2.4449999999999998	2.8340000000000001	2.6440000000000001	5.6228999999999996	3.2088000000000001	2.1802000000000001	1.694	1.3381000000000001	0.90500000000000003	0.72399999999999998	0.59570000000000001	0.52449999999999997	0.48509999999999998	0.4375	0.39939999999999998	0.3422	0.125	0.0049999999	10	95.773003	76.991	44.451000000000001	\N	100
24567	7802	64	86.834999999999994	3.0937999999999999	0.75600000000000001	3.4529999999999998	6.6230000000000002	7.1254	5.3532999999999999	4.5190000000000001	3.7812999999999999	3.3460000000000001	2.4752999999999998	1.7827	1.3041	0.81510000000000005	0.60199999999999998	0.499	0.44890000000000002	0.37369999999999998	0.125	0.0049999999	16	98.315002	91.697999999999993	52.942	\N	114
24566	7802	78	12.217000000000001	6.2850000000000001	0.29499999999999998	4.093	13.958	13.670199999999999	11.57	10.1699	9.2673000000000005	8.4558	6.8329000000000004	5.2043999999999997	3.6684000000000001	2.4014000000000002	1.7146999999999999	0.97119999999999995	0.69059999999999999	0.48949999999999999	0.25	0.148	16	96.655998	9.3930000000000007	5.423	\N	128
24565	7801	22	217.42599999999999	2.9752999999999998	3.5209999999999999	3.2599999999999998	2.8900000000000001	8.8872	6.1005000000000003	4.6547999999999998	3.2719	2.1301000000000001	1.5093000000000001	0.99719999999999998	0.86360000000000003	0.72999999999999998	0.66320000000000001	0.60829999999999995	0.57389999999999997	0.5222	0.25	0.050000001	16	98.814003	197.196	113.851	\N	72
24564	7801	37	217.63	2.4702999999999999	2.2080000000000002	2.9039999999999999	3.427	6.5453999999999999	4.0971000000000002	3.3033000000000001	2.3744000000000001	1.8526	1.3588	0.94940000000000002	0.76419999999999999	0.60729999999999995	0.56620000000000004	0.52500000000000002	0.48570000000000002	0.39650000000000002	0.25	0.141	16	98.902	192.49600000000001	111.13800000000001	\N	87
24563	7801	52	176.49199999999999	4.9318999999999997	1.1439999999999999	4.0090000000000003	7.0129999999999999	13.405900000000001	9.8518000000000008	8.2909000000000006	6.3395999999999999	5.2794999999999996	3.5261	2.2976000000000001	1.6011	1.0746	0.88629999999999998	0.72760000000000002	0.61299999999999999	0.50280000000000002	0.25	0.068000004	16	94.280998	286.17599999999999	165.22399999999999	\N	102
24562	7801	67	320.80099999999999	3.4355000000000002	1.028	2.52	4.1230000000000002	7.5795000000000003	5.6600999999999999	4.9379	4.0350999999999999	3.6543000000000001	2.9350000000000001	2.2155999999999998	1.7442	1.379	1.1962999999999999	1.0137	0.89149999999999996	0.71189999999999998	0.25	0.029999999	16	98.836998	580.24699999999996	335.00599999999997	\N	117
24561	7801	81	7.1200000000000001	6.4360999999999997	0.61099999999999999	2.8730000000000002	6.8860000000000001	13.7446	11.5131	10.025399999999999	9.1301000000000005	8.2482000000000006	6.4843000000000002	5.1276000000000002	3.8418000000000001	2.7008000000000001	2.1303999999999998	1.7030000000000001	1.395	0.94159999999999999	0.25	0.068000004	16	96.064003	10.198	5.8879999999999999	\N	131
23990	7282	23	66.977999999999994	1.4104000000000001	1.3640000000000001	1.865	2.105	2.4571000000000001	1.8230999999999999	1.6594	1.4549000000000001	1.2503	0.95450000000000002	0.83720000000000006	0.71989999999999998	0.6149	0.58250000000000002	0.55020000000000002	0.52429999999999999	0.45340000000000003	0.063	0.022	10	97.861	0	0	\N	68
23989	7282	34	222.38200000000001	1.9560999999999999	2.0819999999999999	2.117	2.161	5.5651999999999999	2.2219000000000002	1.7568999999999999	1.4104000000000001	1.0640000000000001	0.87039999999999995	0.72760000000000002	0.61470000000000002	0.56640000000000001	0.54220000000000002	0.5181	0.496	0.40279999999999999	0.125	0.026000001	10	94.005997	0	0	\N	79
23988	7282	46	187.06200000000001	0.91879999999999995	1.4670000000000001	1.962	2.0619999999999998	1.7750999999999999	1.3092999999999999	0.99970000000000003	0.90669999999999995	0.81379999999999997	0.62909999999999999	0.55079999999999996	0.47960000000000003	0.4214	0.39229999999999998	0.36320000000000002	0.34000000000000002	0.30499999999999999	0.125	0.027000001	6.2999999999999998	99.082001	0	0	\N	91
23987	7282	59	164.946	1.3544	1.2030000000000001	1.796	2.286	2.5699999999999998	1.9079999999999999	1.7916000000000001	1.6460999999999999	1.5006999999999999	1.2097	0.96879999999999999	0.85709999999999997	0.74529999999999996	0.68940000000000001	0.63360000000000005	0.59160000000000001	0.52910000000000001	0.063	0.026000001	6.2999999999999998	99.177002	0	0	\N	104
23986	7282	71	1.4279999999999999	4.9810999999999996	0.58699999999999997	2.617	6.6239999999999997	9.8338999999999999	8.7265999999999995	7.9882999999999997	7.0655999999999999	6.2205000000000004	5.2864000000000004	4.3522999999999996	3.4127999999999998	2.4702000000000002	1.9990000000000001	1.5961000000000001	1.2737000000000001	0.79800000000000004	0.125	0.048999999	10	90.900002	0	0	\N	116
24145	7381	22	10.391	1.2323999999999999	1.4379999999999999	1.716	1.74	1.8552999999999999	1.5508999999999999	1.3479000000000001	1.0942000000000001	0.96650000000000003	0.86009999999999998	0.75360000000000005	0.6472	0.59130000000000005	0.56820000000000004	0.54510000000000003	0.52659999999999996	0.49440000000000001	0.063	0.003	10	98.435997	0	0	\N	72
24144	7381	31	140.16	1.6560999999999999	1.512	2.2360000000000002	2.7679999999999998	3.6623999999999999	2.6941999999999999	2.0487000000000002	1.8345	1.6583000000000001	1.306	0.9798	0.82640000000000002	0.67300000000000004	0.61209999999999998	0.57130000000000003	0.53869999999999996	0.47189999999999999	0.063	0.0020000001	10	99.674004	0	0	\N	81
24143	7381	43	12.109999999999999	1.3304	1.6439999999999999	2.23	2.512	2.9504000000000001	1.8359000000000001	1.5720000000000001	1.2421	0.97770000000000001	0.80979999999999996	0.64200000000000002	0.55669999999999997	0.47799999999999998	0.43909999999999999	0.4002	0.36909999999999998	0.32240000000000002	0.063	0.003	10	98.123001	0	0	\N	93
24142	7381	55	46.098999999999997	1.0427999999999999	1.216	1.6890000000000001	2.1080000000000001	1.7934000000000001	1.3909	1.1225000000000001	0.97150000000000003	0.92659999999999998	0.8367	0.74680000000000002	0.65700000000000003	0.58489999999999998	0.55269999999999997	0.52049999999999996	0.48759999999999998	0.39700000000000002	0.063	0.0049999999	6.2999999999999998	99.068001	0	0	\N	105
24141	7381	67	10.016999999999999	4.4162999999999997	0.47499999999999998	2.657	9.4640000000000004	8.9252000000000002	7.4009999999999998	6.3848000000000003	5.9446000000000003	5.5636999999999999	4.8018999999999998	4.0400999999999998	3.1581999999999999	2.2696000000000001	1.8292999999999999	1.3952	1.048	0.50739999999999996	0.063	0.0020000001	10	94.231003	0	0	\N	117
\.


--
-- Data for Name: gprobe; Type: TABLE DATA; Schema: public; Owner: -
--

COPY gprobe (glotrechteid, lfdnr, messdauer, menge, gtrieb, faktor, menge_f, gtrieb_f) FROM stdin;
24573	3	300	8762.7999999999993	182.55799999999999	1.5	13144.200000000001	273.83800000000002
24574	1	300	614.60000000000002	12.804	1	614.60000000000002	12.804
24574	2	300	12210.200000000001	254.37899999999999	1.5	18315.299999999999	381.56900000000002
24574	3	300	4968.3999999999996	103.508	1.395	6929.598	144.36699999999999
24575	1	300	286.80000000000001	5.9749999999999996	1	286.80000000000001	5.9749999999999996
24575	2	300	488.39999999999998	10.175000000000001	1	488.39999999999998	10.175000000000001
24575	3	300	50.399999999999999	1.05	1	50.399999999999999	1.05
24570	1	300	2.6000000000000001	0.053999999999999999	1	2.6000000000000001	0.053999999999999999
24570	2	300	1.8999999999999999	0.040000000000000001	1	1.8999999999999999	0.040000000000000001
24570	3	300	86.900000000000006	1.8100000000000001	1	86.900000000000006	1.8100000000000001
24569	1	300	224.19999999999999	4.6710000000000003	1	224.19999999999999	4.6710000000000003
24569	2	300	5338.1999999999998	111.212	1.434	7652.9279999999999	159.43600000000001
24569	3	300	4813.1999999999998	100.27500000000001	1.378	6632.0330000000004	138.167
24568	1	300	3920.1999999999998	81.671000000000006	1.2309999	4825.491	100.53100000000001
24568	2	300	1227.2	25.567	1	1227.2	25.567
24568	3	300	2296.8000000000002	47.850000000000001	1	2296.8000000000002	47.850000000000001
24567	1	300	3302.8000000000002	68.808000000000007	1.092	3607	75.146000000000001
24567	2	300	4793.8000000000002	99.870999999999995	1.376	6595.0919999999996	137.398
24567	3	300	2302.1999999999998	47.963000000000001	1	2302.1999999999998	47.963000000000001
24566	1	300	357.60000000000002	7.4500000000000002	1	357.60000000000002	7.4500000000000002
24566	2	300	808.29999999999995	16.84	1	808.29999999999995	16.84
24566	3	300	593.29999999999995	12.359999999999999	1	593.29999999999995	12.359999999999999
24565	1	300	4061.5999999999999	84.617000000000004	1.257	5107.2830000000004	106.402
24565	2	300	8035.1999999999998	167.40000000000001	1.5	12052.799999999999	251.09999999999999
24565	3	300	9432.7999999999993	196.517	1.5	14149.200000000001	294.77499999999998
24564	1	300	5177.3999999999996	107.86199999999999	1.4170001	7335.9620000000004	152.833
24564	2	300	5635.1999999999998	117.40000000000001	1.464	8247.991	171.833
24564	3	300	10503.200000000001	218.81700000000001	1.5	15754.799999999999	328.22500000000002
24563	1	300	4460.8000000000002	92.933000000000007	1.33	5934.7730000000001	123.64100000000001
24563	2	300	3078	64.125	1.05	3232.6410000000001	67.346999999999994
24563	3	300	10831.6	225.65799999999999	1.5	16247.4	338.48700000000002
24562	1	300	1697.8	35.371000000000002	1	1697.8	35.371000000000002
24562	2	300	19692.799999999999	410.267	1.5	29539.200000000001	615.39999999999998
24562	3	300	9972.2000000000007	207.75399999999999	1.5	14958.299999999999	311.63099999999997
24561	1	300	225.30000000000001	4.694	1	225.30000000000001	4.694
24561	2	300	177	3.6880000000000002	1	177	3.6880000000000002
24561	3	300	623	12.978999999999999	1	623	12.978999999999999
23990	1	900	6429.8999999999996	44.652000000000001	1.5	9644.8500000000004	66.977999999999994
23989	1	900	21348.700000000001	148.255	1.5	32023.049999999999	222.38200000000001
23988	1	900	17958	124.708	1.5	26937	187.06200000000001
23987	1	900	15834.799999999999	109.964	1.5	23752.200000000001	164.946
23986	1	900	205.59999999999999	1.4279999999999999	1	205.59999999999999	1.4279999999999999
24145	1	900	1496.25	10.391	1	1496.25	10.391
24144	1	900	13455.4	93.439999999999998	1.5	20183.099999999999	140.16
24143	1	900	1743.8499999999999	12.109999999999999	1	1743.8499999999999	12.109999999999999
24142	1	900	4816.4499999999998	33.448	1.378	6638.2269999999999	46.098999999999997
24141	1	900	1442.45	10.016999999999999	1	1442.45	10.016999999999999
23985	1	900	2407.3499999999999	16.718	1	2407.3499999999999	16.718
23984	1	900	2479.4499999999998	17.218	1	2479.4499999999998	17.218
23983	1	900	4141.75	28.762	1.272	5269.6660000000002	36.594999999999999
23982	1	900	3481.5999999999999	24.178000000000001	1.146	3990.3130000000001	27.710999999999999
23981	1	900	2137.4499999999998	14.843	1	2137.4499999999998	14.843
26285	1	300	295	6.1459999999999999	1	295	6.1459999999999999
26284	1	300	260	5.4169999999999998	1	260	5.4169999999999998
26283	1	300	275	5.7290000000000001	1	275	5.7290000000000001
26282	1	300	440	9.1669999999999998	1	440	9.1669999999999998
26281	1	300	40	0.83299999999999996	1	40	0.83299999999999996
23336	1	900	3572.5	24.809000000000001	1.164	4158.4870000000001	28.878
23335	1	900	2212.75	15.366	1	2212.75	15.366
23334	1	900	2718.5999999999999	18.879000000000001	1.011	2749.7530000000002	19.096
23333	1	900	3789.8499999999999	26.318000000000001	1.206	4571.0780000000004	31.744
23332	1	900	243	1.6879999999999999	1	243	1.6879999999999999
23331	1	900	1686.9000000000001	11.715	1	1686.9000000000001	11.715
23330	1	900	939.14999999999998	6.5220000000000002	1	939.14999999999998	6.5220000000000002
23329	1	900	164.94999999999999	1.145	1	164.94999999999999	1.145
23328	1	900	4250.75	29.518999999999998	1.2920001	5493.549	38.149999999999999
23327	1	900	30.149999999999999	0.20899999999999999	1	30.149999999999999	0.20899999999999999
23326	1	900	5595.6000000000004	38.857999999999997	1.46	8167.9390000000003	56.722000000000001
23325	1	900	9066.8500000000004	62.963999999999999	1.5	13600.275	94.445999999999998
23324	1	900	10369.4	72.010000000000005	1.5	15554.1	108.015
23323	1	900	10002.299999999999	69.459999999999994	1.5	15003.450000000001	104.191
23322	1	900	5369.6000000000004	37.289000000000001	1.437	7715.2550000000001	53.578000000000003
23321	1	900	3948.8499999999999	27.422999999999998	1.2359999	4882.1009999999997	33.902999999999999
23405	1	900	2606.0500000000002	18.097999999999999	1.0039999	2615.806	18.164999999999999
23404	1	900	1723.25	11.967000000000001	1	1723.25	11.967000000000001
13299	1	900	428	2.972	1	428	2.972
23403	1	900	1965	13.646000000000001	1	1965	13.646000000000001
13300	1	900	575	3.9929999999999999	1	575	3.9929999999999999
23402	1	900	2738	19.013999999999999	1.013	2773.748	19.262
13301	1	900	410	2.847	1	410	2.847
23401	1	900	80.299999999999997	0.55800000000000005	1	80.299999999999997	0.55800000000000005
13302	1	900	385	2.6739999999999999	1	385	2.6739999999999999
13303	1	900	80	0.55600000000000005	1	80	0.55600000000000005
23385	1	900	2624.3000000000002	18.224	1.005	2636.8490000000002	18.311
13304	1	900	480	3.3330000000000002	1	480	3.3330000000000002
23384	1	900	2421.1500000000001	16.814	1	2421.1500000000001	16.814
13305	1	900	885	6.1459999999999999	1	885	6.1459999999999999
23383	1	900	969.10000000000002	6.7300000000000004	1	969.10000000000002	6.7300000000000004
13306	1	900	421	2.9239999999999999	1	421	2.9239999999999999
23382	1	900	2425.5	16.844000000000001	1	2425.5	16.844000000000001
13307	1	900	970	6.7359999999999998	1	970	6.7359999999999998
23381	1	900	1193	8.2850000000000001	1	1193	8.2850000000000001
13308	1	900	540	3.75	1	540	3.75
23365	1	900	2865.8000000000002	19.901	1.025	2937.424	20.399000000000001
23364	1	900	3711.5500000000002	25.774999999999999	1.191	4420.7550000000001	30.699999999999999
13309	1	900	630	4.375	1	630	4.375
23363	1	900	3756.3000000000002	26.085000000000001	1.2	4506.4359999999997	31.295000000000002
13310	1	900	614	4.2640000000000002	1	614	4.2640000000000002
23362	1	900	2796.6999999999998	19.422000000000001	1.018	2847.7539999999999	19.776
13311	1	900	700	4.8609999999999998	1	700	4.8609999999999998
23361	1	900	274.69999999999999	1.9079999999999999	1	274.69999999999999	1.9079999999999999
13312	1	900	473	3.2850000000000001	1	473	3.2850000000000001
13313	1	900	277	1.9239999999999999	1	277	1.9239999999999999
13016	1	300	639	13.313000000000001	1	639	13.313000000000001
13016	2	300	255	5.3120000000000003	1	255	5.3120000000000003
13016	3	300	70	1.458	1	70	1.458
13017	1	300	442	9.2080000000000002	1	442	9.2080000000000002
13017	2	300	97	2.0209999999999999	1	97	2.0209999999999999
13017	3	300	146	3.0419999999999998	1	146	3.0419999999999998
13018	1	300	277	5.7709999999999999	1	277	5.7709999999999999
13018	2	300	539	11.228999999999999	1	539	11.228999999999999
13018	3	300	440	9.1669999999999998	1	440	9.1669999999999998
13019	1	300	331	6.8959999999999999	1	331	6.8959999999999999
13019	2	300	238	4.9580000000000002	1	238	4.9580000000000002
13019	3	300	215	4.4790000000000001	1	215	4.4790000000000001
13020	1	300	12	0.25	1	12	0.25
13020	2	300	7	0.14599999999999999	1	7	0.14599999999999999
13020	3	300	22	0.45800000000000002	1	22	0.45800000000000002
13011	1	300	952	19.832999999999998	1	952	19.832999999999998
13011	2	300	626	13.042	1	626	13.042
13011	3	300	202	4.2080000000000002	1	202	4.2080000000000002
13012	1	300	1139	23.728999999999999	1	1139	23.728999999999999
13012	2	300	1186	24.707999999999998	1	1186	24.707999999999998
13012	3	300	558	11.625	1	558	11.625
13013	1	300	468	9.75	1	468	9.75
13013	2	300	735	15.313000000000001	1	735	15.313000000000001
13013	3	300	345	7.1870000000000003	1	345	7.1870000000000003
13014	1	300	100	2.0830000000000002	1	100	2.0830000000000002
13014	2	300	1095	22.812000000000001	1	1095	22.812000000000001
13014	3	300	1001	20.853999999999999	1	1001	20.853999999999999
13015	1	300	54	1.125	1	54	1.125
13015	2	300	88	1.833	1	88	1.833
13015	3	300	70	1.458	1	70	1.458
12897	1	300	260	5.4169999999999998	1	260	5.4169999999999998
12897	2	300	402	8.375	1	402	8.375
12897	3	300	167	3.4790000000000001	1	167	3.4790000000000001
12898	1	300	204	4.25	1	204	4.25
12898	2	300	424	8.8330000000000002	1	424	8.8330000000000002
12898	3	300	320	6.6669999999999998	1	320	6.6669999999999998
12899	1	300	140	2.9169999999999998	1	140	2.9169999999999998
12899	2	300	337	7.0209999999999999	1	337	7.0209999999999999
12899	3	300	773	16.103999999999999	1	773	16.103999999999999
12900	1	300	1164	24.25	1	1164	24.25
12900	2	300	710	14.792	1	710	14.792
12900	3	300	408	8.5	1	408	8.5
12901	1	600	0	0	1	0	0
12901	2	300	31	0.64600000000000002	1	31	0.64600000000000002
12892	1	300	1408	29.332999999999998	1	1408	29.332999999999998
12892	2	300	1138	23.707999999999998	1	1138	23.707999999999998
12892	3	300	1260	26.25	1	1260	26.25
12893	1	300	194	4.0419999999999998	1	194	4.0419999999999998
12893	2	300	1343	27.978999999999999	1	1343	27.978999999999999
12893	3	300	1133	23.603999999999999	1	1133	23.603999999999999
12894	1	300	43	0.89600000000000002	1	43	0.89600000000000002
12894	2	300	142	2.9580000000000002	1	142	2.9580000000000002
12894	3	300	372	7.75	1	372	7.75
12895	1	300	71	1.4790000000000001	1	71	1.4790000000000001
12895	2	300	347	7.2290000000000001	1	347	7.2290000000000001
12895	3	300	56	1.167	1	56	1.167
12896	1	300	704	14.667	1	704	14.667
12896	2	300	192	4	1	192	4
12896	3	300	50	1.042	1	50	1.042
10764	1	300	4104	85.5	1.265	5192.9470000000001	108.18600000000001
10764	2	180	4383	152.18700000000001	1.316	5769.857	200.34200000000001
10764	3	180	4381	152.11799999999999	1.316	5765.6409999999996	200.196
10765	1	300	4724	98.417000000000002	1.368	6462.6580000000004	134.63900000000001
10765	2	180	1395	48.438000000000002	1	1395	48.438000000000002
10765	3	180	209	7.2569999999999997	1	209	7.2569999999999997
10766	1	180	2307	80.103999999999999	1	2307	80.103999999999999
10766	2	180	98	3.403	1	98	3.403
10766	3	180	136	4.7220000000000004	1	136	4.7220000000000004
10767	1	300	1240	25.832999999999998	1	1240	25.832999999999998
10767	2	300	514	10.708	1	514	10.708
10767	3	300	22	0.45800000000000002	1	22	0.45800000000000002
10768	1	900	0	0	1	0	0
10759	1	180	5810	201.73599999999999	1.4809999	8603.9159999999993	298.74700000000001
10759	2	180	1547	53.715000000000003	1	1547	53.715000000000003
10759	3	180	5347	185.66	1.4349999	7670.3810000000003	266.33300000000003
10760	1	300	5183	107.979	1.418	7346.9380000000001	153.06100000000001
10760	2	180	6912	240	1.5	10368	360
10760	3	180	473	16.423999999999999	1	473	16.423999999999999
10761	1	300	1146	23.875	1	1146	23.875
10761	2	300	4192	87.332999999999998	1.2819999	5372.4440000000004	111.926
10761	3	300	180	3.75	1	180	3.75
10762	1	300	2847	59.313000000000002	1.023	2912.7570000000001	60.682000000000002
10762	2	300	274	5.7080000000000002	1	274	5.7080000000000002
10762	3	300	4291	89.396000000000001	1.3	5577.1030000000001	116.19
10763	1	900	0	0	1	0	0
10754	1	900	3	0.021000000000000001	1	3	0.021000000000000001
10755	1	900	8	0.056000000000000001	1	8	0.056000000000000001
24746	1	300	6.1299999999999999	0.128	1	6.1299999999999999	0.128
24746	2	300	2.1600000000000001	0.044999999999999998	1	2.1600000000000001	0.044999999999999998
24746	3	300	8.7400000000000002	0.182	1	8.7400000000000002	0.182
24745	1	300	3520.8000000000002	73.349999999999994	1.154	4062.5169999999998	84.635999999999996
24745	2	300	9344.2000000000007	194.67099999999999	1.5	14016.299999999999	292.00599999999997
24745	3	300	7092	147.75	1.5	10638	221.625
24744	1	300	938.35000000000002	19.548999999999999	1	938.35000000000002	19.548999999999999
24744	2	300	2268.4000000000001	47.258000000000003	1	2268.4000000000001	47.258000000000003
24744	3	300	4874.1999999999998	101.54600000000001	1.385	6748.5569999999998	140.595
24743	1	300	6039.3999999999996	125.821	1.5	9059.1000000000004	188.73099999999999
24743	2	300	7515.1999999999998	156.56700000000001	1.5	11272.799999999999	234.84999999999999
24743	3	300	5926.8000000000002	123.47499999999999	1.492	8844.0460000000003	184.251
24742	1	300	3685.4000000000001	76.778999999999996	1.186	4370.973	91.061999999999998
24742	2	300	6241.6000000000004	130.03299999999999	1.5	9362.3999999999996	195.05000000000001
24742	3	300	7747.3999999999996	161.404	1.5	11621.1	242.10599999999999
24741	1	300	7595.3999999999996	158.23699999999999	1.5	11393.1	237.35599999999999
24741	2	300	2095.8000000000002	43.661999999999999	1	2095.8000000000002	43.661999999999999
24741	3	300	13716.200000000001	285.75400000000002	1.5	20574.299999999999	428.63099999999997
24100	1	900	5373.1499999999996	37.314	1.437	7722.3100000000004	53.627000000000002
24099	1	900	1458.3	10.127000000000001	1	1458.3	10.127000000000001
24098	1	900	17662.799999999999	122.658	1.5	26494.200000000001	183.98699999999999
24097	1	900	13235.049999999999	91.909999999999997	1.5	19852.575000000001	137.86500000000001
24096	1	900	9.25	0.064000000000000001	1	9.25	0.064000000000000001
24095	1	900	1770.75	12.297000000000001	1	1770.75	12.297000000000001
24094	1	900	5991.1499999999996	41.604999999999997	1.498	8977.1229999999996	62.341000000000001
24093	1	900	10808.200000000001	75.057000000000002	1.5	16212.299999999999	112.58499999999999
24092	1	900	4359.25	30.273	1.312	5719.8620000000001	39.720999999999997
24091	1	900	1083.1500000000001	7.5220000000000002	1	1083.1500000000001	7.5220000000000002
34874	1	180	825.20000000000005	28.652999999999999	1	825.20000000000005	28.652999999999999
34874	2	180	2681	93.090000000000003	1.0089999	2703.9560000000001	93.887
34874	3	180	4267.8000000000002	148.18700000000001	1.295	5528.8850000000002	191.97499999999999
34875	1	180	3393	117.813	1.118	3792.335	131.678
34875	2	180	1890.8	65.653000000000006	1	1890.8	65.653000000000006
34875	3	180	5270.8000000000002	183.01400000000001	1.427	7519.6189999999997	261.09800000000001
34876	1	180	351.60000000000002	12.208	1	351.60000000000002	12.208
34876	2	180	24	0.83299999999999996	1	24	0.83299999999999996
34876	3	180	876.20000000000005	30.423999999999999	1	876.20000000000005	30.423999999999999
34877	1	300	1839.8	38.329000000000001	1	1839.8	38.329000000000001
34877	2	300	4044.5999999999999	84.263000000000005	1.2539999	5073.0870000000004	105.68899999999999
34877	3	300	683	14.228999999999999	1	683	14.228999999999999
34878	1	300	6403	133.39599999999999	1.5	9604.5	200.09399999999999
34878	2	180	18.399999999999999	0.63900000000000001	1	18.399999999999999	0.63900000000000001
34878	3	180	2567.8000000000002	89.159999999999997	1.002	2572.6880000000001	89.328999999999994
34869	1	300	3195.1999999999998	66.566999999999993	1.069	3415.9740000000002	71.165999999999997
34869	2	300	1644.8	34.267000000000003	1	1644.8	34.267000000000003
34869	3	300	0	0	1	0	0
34870	1	300	11683	243.39599999999999	1.5	17524.5	365.09399999999999
34870	2	180	3859.1999999999998	134	1.219	4705.7889999999998	163.39500000000001
34870	3	180	10546.4	366.19400000000002	1.5	15819.6	549.29200000000003
34871	1	180	1983.4000000000001	68.867999999999995	1	1983.4000000000001	68.867999999999995
34871	2	180	1814.8	63.014000000000003	1	1814.8	63.014000000000003
34871	3	180	4130	143.40299999999999	1.27	5245.7420000000002	182.14400000000001
34872	1	180	3004.5999999999999	104.32599999999999	1.041	3126.4540000000002	108.557
34872	2	180	553.60000000000002	19.222000000000001	1	553.60000000000002	19.222000000000001
34872	3	180	6200.6000000000004	215.29900000000001	1.5	9300.8999999999996	322.94799999999998
34873	1	180	4765	165.45099999999999	1.373	6540.3590000000004	227.096
34873	2	180	866.20000000000005	30.076000000000001	1	866.20000000000005	30.076000000000001
34873	3	180	325.19999999999999	11.292	1	325.19999999999999	11.292
34756	1	300	21.800000000000001	0.45400000000000001	1	21.800000000000001	0.45400000000000001
34756	2	300	2139.8000000000002	44.579000000000001	1	2139.8000000000002	44.579000000000001
34756	3	300	5383	112.146	1.438	7741.8950000000004	161.28899999999999
34757	1	300	5670	118.125	1.467	8318.518	173.30199999999999
34757	2	300	2220.4000000000001	46.258000000000003	1	2220.4000000000001	46.258000000000003
34757	3	300	8070.3999999999996	168.13300000000001	1.5	12105.6	252.19999999999999
34758	1	300	66.400000000000006	1.383	1	66.400000000000006	1.383
34758	2	300	379.80000000000001	7.9130000000000003	1	379.80000000000001	7.9130000000000003
34758	3	300	938.39999999999998	19.550000000000001	1	938.39999999999998	19.550000000000001
34759	1	300	9628.2000000000007	200.58699999999999	1.5	14442.299999999999	300.88099999999997
34759	2	300	3778.5999999999999	78.721000000000004	1.204	4549.3639999999996	94.778000000000006
34759	3	300	7035.3999999999996	146.571	1.5	10553.1	219.85599999999999
34760	1	300	2488.1999999999998	51.838000000000001	1	2488.1999999999998	51.838000000000001
34760	2	300	169.80000000000001	3.5369999999999999	1	169.80000000000001	3.5369999999999999
34760	3	300	77.599999999999994	1.617	1	77.599999999999994	1.617
29956	1	300	4386	91.375	1.317	5776.1840000000002	120.337
29956	2	300	531.60000000000002	11.074999999999999	1	531.60000000000002	11.074999999999999
29956	3	300	8.0999999999999996	0.16900000000000001	1	8.0999999999999996	0.16900000000000001
29957	1	300	1657.2	34.524999999999999	1	1657.2	34.524999999999999
29957	2	300	255	5.3120000000000003	1	255	5.3120000000000003
29957	3	300	361.39999999999998	7.5289999999999999	1	361.39999999999998	7.5289999999999999
29958	1	300	2609.8000000000002	54.371000000000002	1.0039999	2620.1060000000002	54.585999999999999
29958	2	300	1042.4000000000001	21.716999999999999	1	1042.4000000000001	21.716999999999999
29958	3	300	3627.5999999999999	75.575000000000003	1.175	4261.692	88.784999999999997
29959	1	300	1730.9000000000001	36.060000000000002	1	1730.9000000000001	36.060000000000002
29959	2	300	740	15.417	1	740	15.417
29959	3	300	1106	23.042000000000002	1	1106	23.042000000000002
29960	1	300	1.2	0.025000000000000001	1	1.2	0.025000000000000001
29960	2	300	2408	50.167000000000002	1	2408	50.167000000000002
29960	3	300	1416.8	29.516999999999999	1	1416.8	29.516999999999999
29950	1	300	6403	133.39599999999999	1.5	9604.5	200.09399999999999
29950	2	300	6568.3999999999996	136.84200000000001	1.5	9852.6000000000004	205.262
29950	3	300	7170.3999999999996	149.38300000000001	1.5	10755.6	224.07499999999999
29951	1	300	3889	81.021000000000001	1.225	4764.125	99.253
29951	2	300	1846.4000000000001	38.466999999999999	1	1846.4000000000001	38.466999999999999
29951	3	300	4355.6000000000004	90.742000000000004	1.311	5712.1930000000002	119.004
29952	1	300	0	0	1	0	0
29952	2	300	3042	63.375	1.045	3179.8980000000001	66.248000000000005
29952	3	300	4966	103.458	1.3940001	6924.9690000000001	144.27000000000001
29953	1	300	6505	135.52099999999999	1.5	9757.5	203.28100000000001
29953	2	300	1318	27.457999999999998	1	1318	27.457999999999998
29953	3	300	11858.200000000001	247.04599999999999	1.5	17787.299999999999	370.56900000000002
29954	1	300	9906.3999999999996	206.38300000000001	1.5	14859.6	309.57499999999999
29954	2	300	3075.4000000000001	64.070999999999998	1.05	3228.7849999999999	67.266000000000005
29954	3	300	1273	26.521000000000001	1	1273	26.521000000000001
29955	1	300	5377	112.021	1.438	7729.9629999999997	161.041
29955	2	300	524.29999999999995	10.923	1	524.29999999999995	10.923
29955	3	300	1072.4000000000001	22.341999999999999	1	1072.4000000000001	22.341999999999999
27726	1	300	312.80000000000001	6.5170000000000003	1	312.80000000000001	6.5170000000000003
27726	2	300	1812	37.75	1	1812	37.75
27726	3	300	125.59999999999999	2.617	1	125.59999999999999	2.617
27727	1	300	5401.6000000000004	112.533	1.4400001	7778.9160000000002	162.06100000000001
27727	2	300	7609.1999999999998	158.52500000000001	1.5	11413.799999999999	237.78800000000001
27727	3	300	3050	63.542000000000002	1.046	3191.502	66.489999999999995
27728	1	300	9769.3999999999996	203.529	1.5	14654.1	305.29399999999998
27728	2	300	933	19.437000000000001	1	933	19.437000000000001
27728	3	300	2079	43.313000000000002	1	2079	43.313000000000002
27729	1	300	958	19.957999999999998	1	958	19.957999999999998
27729	2	300	958.60000000000002	19.971	1	958.60000000000002	19.971
27729	3	300	3050.8000000000002	63.558	1.0470001	3192.6660000000002	66.513999999999996
27730	1	300	4374	91.125	1.3150001	5750.8919999999998	119.81
27730	2	300	3632	75.667000000000002	1.176	4269.9750000000004	88.957999999999998
27730	3	300	3304.4000000000001	68.841999999999999	1.0930001	3610.0599999999999	75.209999999999994
27725	1	300	899.20000000000005	18.733000000000001	1	899.20000000000005	18.733000000000001
27725	2	300	866.79999999999995	18.058	1	866.79999999999995	18.058
27725	3	300	252.40000000000001	5.258	1	252.40000000000001	5.258
27724	1	300	5171.1999999999998	107.733	1.416	7323.8149999999996	152.57900000000001
27724	2	300	3041.5999999999999	63.366999999999997	1.045	3179.3200000000002	66.236000000000004
27724	3	300	2624.1999999999998	54.670999999999999	1.005	2636.7330000000002	54.932000000000002
27723	1	300	1545	32.188000000000002	1	1545	32.188000000000002
27723	2	300	610.20000000000005	12.712	1	610.20000000000005	12.712
27723	3	300	69.200000000000003	1.4419999999999999	1	69.200000000000003	1.4419999999999999
27722	1	300	8.8000000000000007	0.183	1	8.8000000000000007	0.183
27722	2	300	1.8	0.037999999999999999	1	1.8	0.037999999999999999
27722	3	300	400.19999999999999	8.3369999999999997	1	400.19999999999999	8.3369999999999997
27721	1	300	30.199999999999999	0.629	1	30.199999999999999	0.629
27721	2	300	0	0	1	0	0
27721	3	300	0	0	1	0	0
27711	1	300	6646	138.458	1.5	9969	207.68700000000001
27711	2	300	14615.200000000001	304.483	1.5	21922.799999999999	456.72500000000002
27711	3	300	6585.1999999999998	137.19200000000001	1.5	9877.7999999999993	205.78800000000001
27710	1	300	6542.8000000000002	136.30799999999999	1.5	9814.2000000000007	204.46199999999999
27710	2	300	2779.8000000000002	57.911999999999999	1.017	2826.2379999999998	58.880000000000003
27710	3	300	874.39999999999998	18.216999999999999	1	874.39999999999998	18.216999999999999
27709	1	300	8886.3999999999996	185.13300000000001	1.5	13329.6	277.69999999999999
27709	2	300	16224.4	338.00799999999998	1.5	24336.599999999999	507.012
27709	3	300	2605	54.271000000000001	1.0039999	2614.6039999999998	54.470999999999997
27708	1	300	3169.4000000000001	66.028999999999996	1.064	3373.7950000000001	70.287000000000006
27708	2	300	4443.6000000000004	92.575000000000003	1.327	5898.1629999999996	122.878
27708	3	300	2504.4000000000001	52.174999999999997	1	2504.5419999999999	52.177999999999997
27707	1	900	0	0	1	0	0
27706	1	300	807.60000000000002	16.824999999999999	1	807.60000000000002	16.824999999999999
27706	2	300	5892	122.75	1.489	8772.3089999999993	182.756
27706	3	300	7675	159.89599999999999	1.5	11512.5	239.84399999999999
27705	1	300	1410.5999999999999	29.388000000000002	1	1410.5999999999999	29.388000000000002
27705	2	300	290.60000000000002	6.0540000000000003	1	290.60000000000002	6.0540000000000003
27705	3	300	375.19999999999999	7.8170000000000002	1	375.19999999999999	7.8170000000000002
27704	1	300	6317	131.60400000000001	1.5	9475.5	197.40600000000001
27704	2	300	2360	49.167000000000002	1	2360	49.167000000000002
27704	3	300	40.200000000000003	0.83799999999999997	1	40.200000000000003	0.83799999999999997
27703	1	300	5861	122.104	1.4859999	8708.5419999999995	181.428
27703	2	300	7043.8000000000002	146.74600000000001	1.5	10565.700000000001	220.119
27703	3	300	11250.4	234.38300000000001	1.5	16875.599999999999	351.57499999999999
27702	1	900	0	0	1	0	0
27693	1	300	722	15.042	1	722	15.042
27693	2	300	1684	35.082999999999998	1	1684	35.082999999999998
27693	3	300	1376	28.667000000000002	1	1376	28.667000000000002
27692	1	300	10324	215.083	1.5	15486	322.625
27692	2	300	6598	137.458	1.5	9897	206.18700000000001
27692	3	300	9020	187.917	1.5	13530	281.875
27691	1	300	13026	271.375	1.5	19539	407.06200000000001
27691	2	300	10652	221.917	1.5	15978	332.875
27691	3	300	4008	83.5	1.247	4999.7579999999998	104.16200000000001
27690	1	300	8718	181.625	1.5	13077	272.43700000000001
27690	2	300	1164	24.25	1	1164	24.25
27690	3	300	5984	124.667	1.498	8962.3089999999993	186.715
27689	1	300	1.3999999999999999	0.029000000000000001	1	1.3999999999999999	0.029000000000000001
27689	2	300	288.60000000000002	6.0119999999999996	1	288.60000000000002	6.0119999999999996
27689	3	300	2.5	0.051999999999999998	1	2.5	0.051999999999999998
24791	1	300	3994.4000000000001	83.216999999999999	1.245	4972.6130000000003	103.596
24791	2	300	3253	67.771000000000001	1.081	3515.2089999999998	73.233999999999995
24791	3	300	172	3.5830000000000002	1	172	3.5830000000000002
24792	1	300	6288	131	1.5	9432	196.5
24792	2	300	7370.8000000000002	153.55799999999999	1.5	11056.200000000001	230.33699999999999
11952	1	900	0	0	1	0	0
11953	1	900	0	0	1	0	0
11954	1	900	0	0	1	0	0
11955	1	900	0	0	1	0	0
11956	1	900	0	0	1	0	0
11949	1	300	2486	51.792000000000002	1	2486	51.792000000000002
11949	2	300	73	1.5209999999999999	1	73	1.5209999999999999
11949	3	300	331	6.8959999999999999	1	331	6.8959999999999999
11950	1	300	7265	151.35400000000001	1.5	10897.5	227.03100000000001
11950	2	300	26	0.54200000000000004	1	26	0.54200000000000004
11950	3	300	5409	112.688	1.441	7793.6580000000004	162.36799999999999
11951	1	900	5	0.035000000000000003	1	5	0.035000000000000003
11944	1	900	0	0	1	0	0
11945	1	300	23	0.47899999999999998	1	23	0.47899999999999998
11945	2	300	0	0	1	0	0
11945	3	300	19	0.39600000000000002	1	19	0.39600000000000002
11946	1	900	0	0	1	0	0
11947	1	300	0	0	1	0	0
11947	2	300	29	0.60399999999999998	1	29	0.60399999999999998
11947	3	300	5	0.104	1	5	0.104
11948	1	300	11	0.22900000000000001	1	11	0.22900000000000001
11948	2	600	0	0	1	0	0
11939	1	600	91	0.94799999999999995	1	91	0.94799999999999995
11940	1	900	0	0	1	0	0
11941	1	300	3	0.063	1	3	0.063
11941	2	600	0	0	1	0	0
11942	1	900	0	0	1	0	0
11943	1	900	0	0	1	0	0
11935	1	900	0	0	1	0	0
11936	1	900	4	0.028000000000000001	1	4	0.028000000000000001
11937	1	300	916	19.082999999999998	1	916	19.082999999999998
11937	2	300	20	0.41699999999999998	1	20	0.41699999999999998
11937	3	300	0	0	1	0	0
11938	1	900	0	0	1	0	0
10587	1	1500	222	0.92500000000000004	1	222	0.92500000000000004
10588	1	900	143	0.99299999999999999	1	143	0.99299999999999999
10588	2	600	40	0.41699999999999998	1	40	0.41699999999999998
10589	1	900	87	0.60399999999999998	1	87	0.60399999999999998
10589	2	600	129	1.3440000000000001	1	129	1.3440000000000001
10590	1	300	0	0	1	0	0
10584	1	300	43	0.89600000000000002	1	43	0.89600000000000002
10584	2	1200	0	0	1	0	0
10585	1	300	0	0	1	0	0
10586	1	300	0	0	1	0	0
10579	1	300	0	0	1	0	0
10580	1	300	66	1.375	1	66	1.375
10580	2	600	208	2.1669999999999998	1	208	2.1669999999999998
10580	3	600	302	3.1459999999999999	1	302	3.1459999999999999
10581	1	300	501	10.438000000000001	1	501	10.438000000000001
10581	2	300	50	1.042	1	50	1.042
10581	3	600	30	0.313	1	30	0.313
10582	1	300	0	0	1	0	0
10583	1	300	0	0	1	0	0
10574	1	300	0	0	1	0	0
10575	1	300	145	3.0209999999999999	1	145	3.0209999999999999
10575	2	600	632	6.5830000000000002	1	632	6.5830000000000002
10575	3	600	491	5.1150000000000002	1	491	5.1150000000000002
10576	1	300	425	8.8539999999999992	1	425	8.8539999999999992
10576	2	300	161	3.3540000000000001	1	161	3.3540000000000001
10576	3	600	920	9.5830000000000002	1	920	9.5830000000000002
10576	4	300	1010	21.042000000000002	1	1010	21.042000000000002
10577	1	300	1931	40.228999999999999	1	1931	40.228999999999999
10577	2	300	227	4.7290000000000001	1	227	4.7290000000000001
10577	3	600	342	3.5630000000000002	1	342	3.5630000000000002
10577	4	300	14	0.29199999999999998	1	14	0.29199999999999998
10578	1	300	0	0	1	0	0
10569	1	300	458	9.5419999999999998	1	458	9.5419999999999998
10569	2	300	1189	24.771000000000001	1	1189	24.771000000000001
10569	3	300	25	0.52100000000000002	1	25	0.52100000000000002
10569	4	300	2375	49.478999999999999	1	2375	49.478999999999999
10570	1	300	535	11.146000000000001	1	535	11.146000000000001
10570	2	300	443	9.2289999999999992	1	443	9.2289999999999992
10570	3	300	739	15.396000000000001	1	739	15.396000000000001
10571	1	300	68	1.417	1	68	1.417
10571	2	300	1157	24.103999999999999	1	1157	24.103999999999999
10571	3	300	1227	25.562000000000001	1	1227	25.562000000000001
10571	4	300	463	9.6460000000000008	1	463	9.6460000000000008
10572	1	300	1622	33.792000000000002	1	1622	33.792000000000002
10572	2	300	621	12.938000000000001	1	621	12.938000000000001
10572	3	300	183	3.8130000000000002	1	183	3.8130000000000002
10572	4	300	79	1.6459999999999999	1	79	1.6459999999999999
10573	1	1500	1186	4.9420000000000002	1	1186	4.9420000000000002
10560	1	420	0	0	1	0	0
10560	2	600	14	0.14599999999999999	1	14	0.14599999999999999
10561	1	120	4484	233.542	1.335	5984.2879999999996	311.68200000000002
10561	2	120	48	2.5	1	48	2.5
10561	3	120	5398	281.14600000000002	1.4400001	7771.7470000000003	404.77800000000002
10562	1	120	3140	163.542	1.0599999	3327.0920000000001	173.286
10562	2	120	2656	138.333	1.007	2674.0610000000001	139.274
10562	3	120	1172	61.042000000000002	1	1172	61.042000000000002
10563	1	300	10892	226.917	1.5	16338	340.375
10563	2	120	2876	149.792	1.026	2950.893	153.69200000000001
10563	3	120	456	23.75	1	456	23.75
10563	4	120	2463	128.28100000000001	1	2463	128.28100000000001
10554	1	300	21	0.438	1	21	0.438
10554	2	600	744	7.75	1	744	7.75
10554	3	600	1126	11.728999999999999	1	1126	11.728999999999999
10554	4	780	1319	10.569000000000001	1	1319	10.569000000000001
10555	1	300	331	6.8959999999999999	1	331	6.8959999999999999
10555	2	600	1406	14.646000000000001	1	1406	14.646000000000001
10555	3	600	104	1.083	1	104	1.083
10555	4	600	830	8.6460000000000008	1	830	8.6460000000000008
10556	1	300	33	0.68799999999999994	1	33	0.68799999999999994
10556	2	600	547	5.6980000000000004	1	547	5.6980000000000004
10556	3	600	28	0.29199999999999998	1	28	0.29199999999999998
10556	4	600	173	1.802	1	173	1.802
10557	1	300	53	1.1040000000000001	1	53	1.1040000000000001
10557	2	600	20	0.20799999999999999	1	20	0.20799999999999999
10557	3	600	128	1.333	1	128	1.333
10557	4	600	157	1.635	1	157	1.635
10558	1	300	19	0.39600000000000002	1	19	0.39600000000000002
10558	2	600	135	1.4059999999999999	1	135	1.4059999999999999
10558	3	1200	404	2.1040000000000001	1	404	2.1040000000000001
10558	4	600	78	0.81299999999999994	1	78	0.81299999999999994
10558	5	600	57	0.59399999999999997	1	57	0.59399999999999997
10559	1	300	0	0	1	0	0
10564	1	300	0	0	1	0	0
10565	1	300	0	0	1	0	0
10566	1	300	0	0	1	0	0
10567	1	300	0	0	1	0	0
10568	1	300	0	0	1	0	0
10550	1	1500	4	0.017000000000000001	1	4	0.017000000000000001
10551	1	900	11	0.075999999999999998	1	11	0.075999999999999998
10552	1	900	10	0.069000000000000006	1	10	0.069000000000000006
10553	1	300	0	0	1	0	0
10546	1	300	0	0	1	0	0
10547	1	300	0	0	1	0	0
10548	1	300	0	0	1	0	0
10549	1	300	0	0	1	0	0
10540	1	300	0	0	1	0	0
10541	1	600	10	0.104	1	10	0.104
10541	2	600	525	5.4690000000000003	1	525	5.4690000000000003
10541	3	300	144	3	1	144	3
10541	4	600	7	0.072999999999999995	1	7	0.072999999999999995
10541	5	600	2	0.021000000000000001	1	2	0.021000000000000001
10542	1	1200	9	0.047	1	9	0.047
10543	1	300	0	0	1	0	0
10544	1	300	0	0	1	0	0
10545	1	300	0	0	1	0	0
10536	1	300	0	0	1	0	0
10537	1	300	8	0.16700000000000001	1	8	0.16700000000000001
10538	1	900	37	0.25700000000000001	1	37	0.25700000000000001
10539	1	300	0	0	1	0	0
10530	1	300	0	0	1	0	0
10531	1	1200	116	0.60399999999999998	1	116	0.60399999999999998
10532	1	300	0	0	1	0	0
10533	1	300	340	7.0830000000000002	1	340	7.0830000000000002
10533	2	1200	172	0.89600000000000002	1	172	0.89600000000000002
10534	1	300	0	0	1	0	0
10535	1	300	0	0	1	0	0
10525	1	300	0	0	1	0	0
10526	1	300	0	0	1	0	0
10527	1	900	4	0.028000000000000001	1	4	0.028000000000000001
10528	1	300	13	0.27100000000000002	1	13	0.27100000000000002
10528	2	300	28	0.58299999999999996	1	28	0.58299999999999996
10528	3	300	8400	175	1.5	12600	262.5
10528	4	300	3009	62.688000000000002	1.041	3132.6759999999999	65.263999999999996
10529	1	300	167	3.4790000000000001	1	167	3.4790000000000001
10529	2	300	9523	198.39599999999999	1.5	14284.5	297.59399999999999
10529	3	300	3233	67.353999999999999	1.076	3480.0639999999999	72.501000000000005
10529	4	300	55	1.1459999999999999	1	55	1.1459999999999999
10329	1	300	0	0	1	0	0
10329	2	300	0	0	1	0	0
10330	1	300	0	0	1	0	0
10330	2	300	19	0.39600000000000002	1	19	0.39600000000000002
10330	3	300	0	0	1	0	0
10330	4	300	0	0	1	0	0
10331	1	300	56	1.167	1	56	1.167
10331	2	300	0	0	1	0	0
10331	3	300	0	0	1	0	0
10331	4	300	2	0.042000000000000003	1	2	0.042000000000000003
10332	1	180	7	0.24299999999999999	1	7	0.24299999999999999
10332	2	180	0	0	1	0	0
10332	3	300	23	0.47899999999999998	1	23	0.47899999999999998
10332	4	300	1379	28.728999999999999	1	1379	28.728999999999999
10333	1	300	93	1.9379999999999999	1	93	1.9379999999999999
10333	2	300	20447	425.97899999999998	1.5	30670.5	638.96900000000005
10333	3	300	6998	145.792	1.5	10497	218.68700000000001
10333	4	300	19563	407.56200000000001	1.5	29344.5	611.34400000000005
10334	1	300	68	1.417	1	68	1.417
10334	2	300	38	0.79200000000000004	1	38	0.79200000000000004
10334	3	300	29	0.60399999999999998	1	29	0.60399999999999998
10321	1	300	0	0	1	0	0
10322	1	300	0	0	1	0	0
10323	1	300	2	0.042000000000000003	1	2	0.042000000000000003
10324	1	300	3	0.063	1	3	0.063
10325	1	300	4	0.083000000000000004	1	4	0.083000000000000004
10326	1	300	0	0	1	0	0
10327	1	300	0	0	1	0	0
10328	1	300	0	0	1	0	0
10301	1	300	0	0	1	0	0
10302	1	300	0	0	1	0	0
10303	1	300	0	0	1	0	0
10304	1	300	0	0	1	0	0
10305	1	300	10	0.20799999999999999	1	10	0.20799999999999999
10305	2	300	1	0.021000000000000001	1	1	0.021000000000000001
10305	3	300	4	0.083000000000000004	1	4	0.083000000000000004
10306	1	300	527	10.978999999999999	1	527	10.978999999999999
10306	2	300	0	0	1	0	0
10306	3	300	26	0.54200000000000004	1	26	0.54200000000000004
10307	1	300	0	0	1	0	0
10307	2	300	0	0	1	0	0
10307	3	300	6	0.125	1	6	0.125
10308	1	300	0	0	1	0	0
10308	2	300	3	0.063	1	3	0.063
10308	3	300	4	0.083000000000000004	1	4	0.083000000000000004
10309	1	300	0	0	1	0	0
10310	1	300	0	0	1	0	0
10311	1	300	0	0	1	0	0
10312	1	300	0	0	1	0	0
10295	1	300	0	0	1	0	0
10295	2	300	0	0	1	0	0
10295	3	300	3	0.063	1	3	0.063
10296	1	300	0	0	1	0	0
10296	2	300	4	0.083000000000000004	1	4	0.083000000000000004
10296	3	300	0	0	1	0	0
24648	2	300	295.10000000000002	6.1479999999999997	1	295.10000000000002	6.1479999999999997
24648	3	300	1717.4000000000001	35.779000000000003	1	1717.4000000000001	35.779000000000003
24647	1	300	5646.8000000000002	117.642	1.465	8271.4809999999998	172.32300000000001
24647	2	300	3219.8000000000002	67.078999999999994	1.074	3457.3519999999999	72.028000000000006
24647	3	300	3607.1999999999998	75.150000000000006	1.171	4223.3710000000001	87.986999999999995
24646	1	300	2274.4000000000001	47.383000000000003	1	2274.4000000000001	47.383000000000003
24646	2	300	1431.2	29.817	1	1431.2	29.817
24646	3	300	408.5	8.5099999999999998	1	408.5	8.5099999999999998
24645	1	300	170	3.5419999999999998	1	170	3.5419999999999998
24645	2	300	244.5	5.0940000000000003	1	244.5	5.0940000000000003
24645	3	300	533	11.103999999999999	1	533	11.103999999999999
24644	1	300	11060.799999999999	230.43299999999999	1.5	16591.200000000001	345.64999999999998
24644	2	300	7003	145.89599999999999	1.5	10504.5	218.84399999999999
24644	3	300	7363.8000000000002	153.41300000000001	1.5	11045.700000000001	230.119
24643	1	300	2988.8000000000002	62.267000000000003	1.039	3104.241	64.671999999999997
24643	2	300	3926	81.792000000000002	1.232	4836.9309999999996	100.76900000000001
24643	3	300	8899.6000000000004	185.40799999999999	1.5	13349.4	278.11200000000002
24642	1	300	6685.1999999999998	139.27500000000001	1.5	10027.799999999999	208.91300000000001
24642	2	300	7591.8000000000002	158.16300000000001	1.5	11387.700000000001	237.244
24642	3	300	11530.6	240.221	1.5	17295.900000000001	360.33100000000002
24641	1	300	2243.5999999999999	46.741999999999997	1	2243.5999999999999	46.741999999999997
24641	2	300	1329	27.687000000000001	1	1329	27.687000000000001
24641	3	300	491.39999999999998	10.237	1	491.39999999999998	10.237
24050	1	900	11183.6	77.664000000000001	1.5	16775.400000000001	116.496
24049	1	900	4088.5	28.391999999999999	1.262	5161.5690000000004	35.844000000000001
24048	1	900	4130.5	28.684000000000001	1.27	5246.759	36.436
24047	1	900	4385.6000000000004	30.456	1.317	5775.3400000000001	40.106999999999999
24046	1	900	3303	22.937000000000001	1.092	3607.3820000000001	25.050999999999998
24165	1	900	11398.4	79.156000000000006	1.5	17097.599999999999	118.733
24164	1	900	9987.1000000000004	69.355000000000004	1.5	14980.65	104.032
24163	1	900	3347.0999999999999	23.244	1.104	3694.5900000000001	25.657
24162	1	900	2657	18.451000000000001	1.007	2675.2469999999998	18.577999999999999
24161	1	900	1300.8499999999999	9.0340000000000007	1	1300.8499999999999	9.0340000000000007
24045	1	900	11781.15	81.813999999999993	1.5	17671.724999999999	122.72
24044	1	900	891.85000000000002	6.1929999999999996	1	891.85000000000002	6.1929999999999996
24043	1	900	3069.9499999999998	21.318999999999999	1.049	3220.7269999999999	22.366
24042	1	900	5456.6499999999996	37.893000000000001	1.446	7888.7709999999997	54.783000000000001
24041	1	900	6970.6499999999996	48.406999999999996	1.5	10455.975	72.611000000000004
25913	1	300	520	10.833	1	520	10.833
25912	1	300	400	8.3330000000000002	1	400	8.3330000000000002
25911	1	300	345	7.1870000000000003	1	345	7.1870000000000003
25910	1	300	26	0.54200000000000004	1	26	0.54200000000000004
23845	1	900	2138.5500000000002	14.851000000000001	1	2138.5500000000002	14.851000000000001
23844	1	900	457.60000000000002	3.1779999999999999	1	457.60000000000002	3.1779999999999999
23843	1	900	965.60000000000002	6.7060000000000004	1	965.60000000000002	6.7060000000000004
23842	1	900	625.89999999999998	4.3470000000000004	1	625.89999999999998	4.3470000000000004
23841	1	900	0	0	1	0	0
23835	1	900	1872.4000000000001	13.003	1	1872.4000000000001	13.003
23834	1	900	3972.9000000000001	27.59	1.2410001	4929.8130000000001	34.234999999999999
23833	1	900	839.89999999999998	5.8330000000000002	1	839.89999999999998	5.8330000000000002
23832	1	900	1654.1500000000001	11.487	1	1654.1500000000001	11.487
23831	1	900	3514.8499999999999	24.408999999999999	1.153	4051.5259999999998	28.135999999999999
23830	1	900	3686.3499999999999	25.600000000000001	1.186	4372.7780000000002	30.367000000000001
23829	1	900	3589.6100000000001	24.928000000000001	1.1670001	4190.433	29.100000000000001
23828	1	900	236.15000000000001	1.6399999999999999	1	236.15000000000001	1.6399999999999999
23827	1	900	2889.4000000000001	20.065000000000001	1.027	2968.6799999999998	20.616
23826	1	900	544.64999999999998	3.782	1	544.64999999999998	3.782
23805	1	900	3056.6999999999998	21.227	1.0470001	3201.27	22.231000000000002
23804	1	900	356	2.472	1	356	2.472
23803	1	900	981.35000000000002	6.8150000000000004	1	981.35000000000002	6.8150000000000004
23802	1	900	1528	10.611000000000001	1	1528	10.611000000000001
23801	1	900	1743.95	12.111000000000001	1	1743.95	12.111000000000001
23790	1	900	2702.0999999999999	18.765000000000001	1.01	2729.538	18.954999999999998
23789	1	900	3183.3499999999999	22.106999999999999	1.067	3396.4540000000002	23.585999999999999
23788	1	900	2615.9000000000001	18.166	1.0039999	2627.1280000000002	18.244
23787	1	900	2207.4000000000001	15.329000000000001	1	2207.4000000000001	15.329000000000001
23786	1	900	3032	21.056000000000001	1.044	3165.482	21.983000000000001
23770	1	900	3364.9499999999998	23.367999999999999	1.109	3731.6930000000002	25.914999999999999
23769	1	900	3278.9000000000001	22.77	1.086	3562.1399999999999	24.736999999999998
23768	1	900	3045.5500000000002	21.149999999999999	1.046	3185.04	22.117999999999999
23767	1	900	3008.8000000000002	20.893999999999998	1.041	3132.393	21.753
23766	1	905	2623.5	18.117999999999999	1.005	2635.9209999999998	18.204000000000001
23785	1	900	3382.4000000000001	23.489000000000001	1.114	3769.069	26.173999999999999
23784	1	900	3433.1999999999998	23.841999999999999	1.132	3884.741	26.977
23783	1	900	3507.8000000000002	24.359999999999999	1.151	4038.518	28.045000000000002
23782	1	900	3372.8499999999999	23.422999999999998	1.1109999	3748.4749999999999	26.030999999999999
23781	1	900	1650.3499999999999	11.461	1	1650.3499999999999	11.461
12992	1	300	2040	42.5	1	2040	42.5
12992	2	300	1655	34.478999999999999	1	1655	34.478999999999999
12992	3	300	1785	37.188000000000002	1	1785	37.188000000000002
12993	1	300	132	2.75	1	132	2.75
12993	2	300	534	11.125	1	534	11.125
12993	3	300	355	7.3959999999999999	1	355	7.3959999999999999
12994	1	300	1384	28.832999999999998	1	1384	28.832999999999998
12994	2	300	1508	31.417000000000002	1	1508	31.417000000000002
12994	3	300	441	9.1880000000000006	1	441	9.1880000000000006
12995	1	300	670	13.958	1	670	13.958
12995	2	300	55	1.1459999999999999	1	55	1.1459999999999999
12995	3	300	56	1.167	1	56	1.167
12996	1	300	82	1.708	1	82	1.708
12996	2	300	22	0.45800000000000002	1	22	0.45800000000000002
12996	3	300	64	1.333	1	64	1.333
12987	1	300	128	2.6669999999999998	1	128	2.6669999999999998
12987	2	300	89	1.8540000000000001	1	89	1.8540000000000001
12987	3	300	33	0.68799999999999994	1	33	0.68799999999999994
12988	1	300	96	2	1	96	2
12988	2	303	93	1.9179999999999999	1	93	1.9179999999999999
12988	3	300	82	1.708	1	82	1.708
12989	1	300	82	1.708	1	82	1.708
12989	2	300	174	3.625	1	174	3.625
12989	3	300	99	2.0630000000000002	1	99	2.0630000000000002
12990	1	300	217	4.5209999999999999	1	217	4.5209999999999999
12990	2	300	516	10.75	1	516	10.75
12990	3	300	214	4.4580000000000002	1	214	4.4580000000000002
12991	1	310	16	0.32300000000000001	1	16	0.32300000000000001
12991	2	300	20	0.41699999999999998	1	20	0.41699999999999998
12991	3	300	18	0.375	1	18	0.375
12982	1	300	633	13.188000000000001	1	633	13.188000000000001
12982	2	300	1370	28.542000000000002	1	1370	28.542000000000002
12982	3	300	1344	28	1	1344	28
12983	1	300	1918	39.957999999999998	1	1918	39.957999999999998
12983	2	300	969	20.187000000000001	1	969	20.187000000000001
12983	3	300	1156	24.082999999999998	1	1156	24.082999999999998
12984	1	300	1389	28.937000000000001	1	1389	28.937000000000001
12984	2	300	132	2.75	1	132	2.75
12984	3	300	144	3	1	144	3
12985	1	300	865	18.021000000000001	1	865	18.021000000000001
12985	2	300	544	11.333	1	544	11.333
12985	3	300	1028	21.417000000000002	1	1028	21.417000000000002
12986	1	300	372	7.75	1	372	7.75
12986	2	300	561	11.688000000000001	1	561	11.688000000000001
12986	3	300	268	5.5830000000000002	1	268	5.5830000000000002
12936	1	300	1246	25.957999999999998	1	1246	25.957999999999998
12936	2	300	1080	22.5	1	1080	22.5
12936	3	300	2114	44.042000000000002	1	2114	44.042000000000002
12937	1	303	1256	25.908000000000001	1	1256	25.908000000000001
12937	2	300	249	5.1870000000000003	1	249	5.1870000000000003
12937	3	300	258	5.375	1	258	5.375
12938	1	300	1114	23.207999999999998	1	1114	23.207999999999998
12938	2	300	265	5.5209999999999999	1	265	5.5209999999999999
12938	3	300	929	19.353999999999999	1	929	19.353999999999999
12939	1	302	485	10.037000000000001	1	485	10.037000000000001
12939	2	300	489	10.188000000000001	1	489	10.188000000000001
12939	3	300	448	9.3330000000000002	1	448	9.3330000000000002
12940	1	300	76	1.583	1	76	1.583
12940	2	300	104	2.1669999999999998	1	104	2.1669999999999998
12940	3	300	150	3.125	1	150	3.125
12931	1	300	35	0.72899999999999998	1	35	0.72899999999999998
12931	2	300	15	0.313	1	15	0.313
12931	3	300	5	0.104	1	5	0.104
12932	1	301	40	0.83099999999999996	1	40	0.83099999999999996
12932	2	300	72	1.5	1	72	1.5
12932	3	300	22	0.45800000000000002	1	22	0.45800000000000002
12933	1	301	89	1.8480000000000001	1	89	1.8480000000000001
12933	2	305	192	3.9340000000000002	1	192	3.9340000000000002
12933	3	310	145	2.923	1	145	2.923
12934	1	303	664	13.696	1	664	13.696
12934	2	301	2043	42.420999999999999	1	2043	42.420999999999999
12934	3	302	33	0.68300000000000005	1	33	0.68300000000000005
12935	1	900	0	0	1	0	0
10933	1	300	3504	73	1.151	4031.5129999999999	83.989999999999995
10933	2	300	7123	148.39599999999999	1.5	10684.5	222.59399999999999
10933	3	300	2539	52.896000000000001	1.001	2541.183	52.941000000000003
10934	1	300	6189	128.93700000000001	1.5	9283.5	193.40600000000001
10934	2	300	3572	74.417000000000002	1.164	4157.5550000000003	86.616
10934	3	180	2466	85.625	1	2466	85.625
10935	1	180	2159	74.965000000000003	1	2159	74.965000000000003
10935	2	300	1563	32.563000000000002	1	1563	32.563000000000002
10935	3	300	471	9.8130000000000006	1	471	9.8130000000000006
10936	1	300	329	6.8540000000000001	1	329	6.8540000000000001
10936	2	300	1146	23.875	1	1146	23.875
10936	3	300	7	0.14599999999999999	1	7	0.14599999999999999
10937	1	300	292	6.0830000000000002	1	292	6.0830000000000002
10937	2	300	291	6.0620000000000003	1	291	6.0620000000000003
10937	3	300	187	3.8959999999999999	1	187	3.8959999999999999
10928	1	90	585	40.625	1	585	40.625
10928	2	90	2778	192.917	1.017	2823.9569999999999	196.108
10928	3	90	2854	198.19399999999999	1.024	2921.9180000000001	202.911
10929	1	90	11236	780.27800000000002	1.5	16854	1170.4169999999999
10929	2	90	13913	966.18100000000004	1.5	20869.5	1449.271
10929	3	90	1676	116.389	1	1676	116.389
10930	1	120	3440	179.167	1.1339999	3901.0680000000002	203.18100000000001
10930	2	120	5596	291.45800000000003	1.46	8168.7470000000003	425.45600000000002
10930	3	120	2963	154.32300000000001	1.036	3068.3939999999998	159.81200000000001
10931	1	180	3303	114.688	1.092	3607.3820000000001	125.256
10931	2	180	595	20.66	1	595	20.66
10931	3	180	442	15.347	1	442	15.347
10932	1	300	835	17.396000000000001	1	835	17.396000000000001
10932	2	300	2759	57.478999999999999	1.015	2799.9879999999998	58.332999999999998
10932	3	300	11361	236.68700000000001	1.5	17041.5	355.03100000000001
34854	1	180	28.800000000000001	1	1	28.800000000000001	1
34854	2	180	102.59999999999999	3.5619999999999998	1	102.59999999999999	3.5619999999999998
34854	3	180	20.800000000000001	0.72199999999999998	1	20.800000000000001	0.72199999999999998
34855	1	180	10	0.34699999999999998	1	10	0.34699999999999998
34855	2	180	1527	53.021000000000001	1	1527	53.021000000000001
34855	3	180	150	5.2080000000000002	1	150	5.2080000000000002
34856	1	180	892	30.972000000000001	1	892	30.972000000000001
34856	2	180	782	27.152999999999999	1	782	27.152999999999999
34856	3	180	228	7.9169999999999998	1	228	7.9169999999999998
34857	1	180	4672.1999999999998	162.22900000000001	1.362	6364.8580000000002	221.00200000000001
10297	1	300	63	1.3120000000000001	1	63	1.3120000000000001
10297	2	300	259	5.3959999999999999	1	259	5.3959999999999999
10297	3	300	29	0.60399999999999998	1	29	0.60399999999999998
10298	1	300	0	0	1	0	0
10298	2	300	15	0.313	1	15	0.313
10298	3	300	2	0.042000000000000003	1	2	0.042000000000000003
10299	1	300	0	0	1	0	0
10300	1	300	0	0	1	0	0
10288	1	300	0	0	1	0	0
10289	1	300	9	0.188	1	9	0.188
10289	2	300	8	0.16700000000000001	1	8	0.16700000000000001
10289	3	300	6	0.125	1	6	0.125
10290	1	300	16	0.33300000000000002	1	16	0.33300000000000002
10290	2	300	13	0.27100000000000002	1	13	0.27100000000000002
10290	3	300	1578	32.875	1	1578	32.875
10290	4	300	13	0.27100000000000002	1	13	0.27100000000000002
10290	5	300	237	4.9370000000000003	1	237	4.9370000000000003
10291	1	300	0	0	1	0	0
10292	1	300	0	0	1	0	0
10293	1	300	0	0	1	0	0
10294	1	300	0	0	1	0	0
10278	1	600	0	0	1	0	0
10279	1	900	141	0.97899999999999998	1	141	0.97899999999999998
10280	1	340	33	0.60699999999999998	1	33	0.60699999999999998
10281	1	680	35	0.32200000000000001	1	35	0.32200000000000001
10282	1	300	150	3.125	1	150	3.125
10282	2	300	1736	36.167000000000002	1	1736	36.167000000000002
10282	3	300	338	7.0419999999999998	1	338	7.0419999999999998
10283	1	340	1046	19.228000000000002	1	1046	19.228000000000002
10283	2	300	2994	62.375	1.039	3111.529	64.823999999999998
10283	3	300	0	0	1	0	0
10284	1	340	33	0.60699999999999998	1	33	0.60699999999999998
10285	1	350	10738	191.75	1.5	16107	287.625
10285	2	320	2710	52.93	1.011	2739.194	53.5
10286	1	300	0	0	1	0	0
10287	1	320	1581	30.879000000000001	1	1581	30.879000000000001
10287	2	600	1070	11.146000000000001	1	1070	11.146000000000001
10287	3	280	33	0.73699999999999999	1	33	0.73699999999999999
10273	1	600	0	0	1	0	0
10274	1	1800	177	0.61499999999999999	1	177	0.61499999999999999
10275	1	1200	135	0.70299999999999996	1	135	0.70299999999999996
10275	2	600	163	1.698	1	163	1.698
10276	1	300	0	0	1	0	0
10277	1	300	0	0	1	0	0
34808	1	300	0	0	1	0	0
34808	2	300	0	0	1	0	0
34808	3	300	0	0	1	0	0
34807	1	300	19.600000000000001	0.40799999999999997	1	19.600000000000001	0.40799999999999997
34807	2	300	284.80000000000001	5.9329999999999998	1	284.80000000000001	5.9329999999999998
34807	3	300	199.40000000000001	4.1539999999999999	1	199.40000000000001	4.1539999999999999
34806	1	300	112.8	2.3500000000000001	1	112.8	2.3500000000000001
34806	2	300	8032.1999999999998	167.33699999999999	1.5	12048.299999999999	251.006
34806	3	300	4451.6000000000004	92.742000000000004	1.329	5915.1800000000003	123.233
34805	1	300	17498	364.54199999999997	1.5	26247	546.81200000000001
34805	2	300	1130.2	23.545999999999999	1	1130.2	23.545999999999999
34805	3	300	3381	70.438000000000002	1.114	3766.029	78.459000000000003
34804	1	300	4.4000000000000004	0.091999999999999998	1	4.4000000000000004	0.091999999999999998
34804	2	300	136.19999999999999	2.8380000000000001	1	136.19999999999999	2.8380000000000001
34804	3	300	490.60000000000002	10.221	1	490.60000000000002	10.221
34725	1	300	0	0	1	0	0
34725	2	300	0	0	1	0	0
34725	3	300	0	0	1	0	0
34724	1	300	343.39999999999998	7.1539999999999999	1	343.39999999999998	7.1539999999999999
34724	2	300	894	18.625	1	894	18.625
34724	3	300	858.79999999999995	17.891999999999999	1	858.79999999999995	17.891999999999999
34723	1	300	2977.8000000000002	62.036999999999999	1.0369999	3088.8960000000002	64.352000000000004
34723	2	300	5512.3999999999996	114.842	1.451	8000.4570000000003	166.67599999999999
34723	3	300	3711.4000000000001	77.320999999999998	1.191	4420.4690000000001	92.093000000000004
34722	1	300	6481.3999999999996	135.029	1.5	9722.1000000000004	202.54400000000001
34722	2	300	336.39999999999998	7.008	1	336.39999999999998	7.008
34722	3	300	1365	28.437000000000001	1	1365	28.437000000000001
34721	1	300	145	3.0209999999999999	1	145	3.0209999999999999
34721	2	300	107	2.2290000000000001	1	107	2.2290000000000001
34721	3	300	170	3.5419999999999998	1	170	3.5419999999999998
34726	1	300	0	0	1	0	0
34726	2	300	0	0	1	0	0
34726	3	300	0	0	1	0	0
34727	1	300	6972	145.25	1.5	10458	217.875
34727	2	300	3395	70.728999999999999	1.118	3796.7739999999999	79.099000000000004
34727	3	300	1240.5999999999999	25.846	1	1240.5999999999999	25.846
34728	1	300	7139	148.72900000000001	1.5	10708.5	223.09399999999999
34728	2	300	4361	90.853999999999999	1.312	5723.54	119.23999999999999
34728	3	300	902.60000000000002	18.803999999999998	1	902.60000000000002	18.803999999999998
34729	1	300	1935.5999999999999	40.325000000000003	1	1935.5999999999999	40.325000000000003
34729	2	300	4072.4000000000001	84.841999999999999	1.2589999	5129.0519999999997	106.855
34729	3	300	3687	76.813000000000002	1.186	4374.0129999999999	91.125
34730	1	300	15.4	0.32100000000000001	1	15.4	0.32100000000000001
34730	2	300	26.399999999999999	0.55000000000000004	1	26.399999999999999	0.55000000000000004
34730	3	300	0.20000000000000001	0.0040000000000000001	1	0.20000000000000001	0.0040000000000000001
29864	1	300	787.79999999999995	16.411999999999999	1	787.79999999999995	16.411999999999999
29864	2	300	743.39999999999998	15.487	1	743.39999999999998	15.487
29864	3	300	42	0.875	1	42	0.875
29863	1	300	2273.8000000000002	47.371000000000002	1	2273.8000000000002	47.371000000000002
29863	2	300	1347.2	28.067	1	1347.2	28.067
29863	3	300	2065.4000000000001	43.029000000000003	1	2065.4000000000001	43.029000000000003
29862	1	300	2243.5999999999999	46.741999999999997	1	2243.5999999999999	46.741999999999997
29862	2	300	312.60000000000002	6.5119999999999996	1	312.60000000000002	6.5119999999999996
29862	3	300	1456	30.332999999999998	1	1456	30.332999999999998
29861	1	300	779.20000000000005	16.233000000000001	1	779.20000000000005	16.233000000000001
29861	2	300	1739.4000000000001	36.238	1	1739.4000000000001	36.238
29861	3	300	442.39999999999998	9.2170000000000005	1	442.39999999999998	9.2170000000000005
29860	1	300	0	0	1	0	0
29860	2	300	0	0	1	0	0
29860	3	300	0	0	1	0	0
29854	1	300	1.3	0.027	1	1.3	0.027
29854	2	300	0.80000000000000004	0.017000000000000001	1	0.80000000000000004	0.017000000000000001
29854	3	300	0.20000000000000001	0.0040000000000000001	1	0.20000000000000001	0.0040000000000000001
29853	1	900	0	0	1	0	0
29852	1	300	0	0	1	0	0
29852	2	300	4.2000000000000002	0.087999999999999995	1	4.2000000000000002	0.087999999999999995
29852	3	300	358.10000000000002	7.46	1	358.10000000000002	7.46
29851	1	300	775.60000000000002	16.158000000000001	1	775.60000000000002	16.158000000000001
29851	2	300	4742	98.792000000000002	1.37	6496.7389999999996	135.34899999999999
29851	3	300	2610.8000000000002	54.392000000000003	1.0039999	2621.2550000000001	54.609000000000002
29850	1	300	6930	144.375	1.5	10395	216.56200000000001
29850	2	300	5474	114.042	1.447	7923.482	165.07300000000001
29850	3	300	1748.4000000000001	36.424999999999997	1	1748.4000000000001	36.424999999999997
29849	1	300	0.40000000000000002	0.0080000000000000002	1	0.40000000000000002	0.0080000000000000002
29849	2	300	2.2000000000000002	0.045999999999999999	1	2.2000000000000002	0.045999999999999999
29849	3	300	1.8999999999999999	0.040000000000000001	1	1.8999999999999999	0.040000000000000001
27476	1	300	684.5	14.26	1	684.5	14.26
27476	2	300	3290.4000000000001	68.549999999999997	1.089	3583.5300000000002	74.656999999999996
27476	3	300	0	0	1	0	0
27477	1	300	615.60000000000002	12.824999999999999	1	615.60000000000002	12.824999999999999
27477	2	300	954.20000000000005	19.879000000000001	1	954.20000000000005	19.879000000000001
27477	3	300	2036.8	42.433	1	2036.8	42.433
27478	1	300	2637.8000000000002	54.954000000000001	1.006	2652.5970000000002	55.262
27478	2	300	1277.4000000000001	26.611999999999998	1	1277.4000000000001	26.611999999999998
27478	3	300	218.69999999999999	4.556	1	218.69999999999999	4.556
27479	1	300	336	7	1	336	7
27479	2	300	588.89999999999998	12.269	1	588.89999999999998	12.269
27479	3	300	14.9	0.31	1	14.9	0.31
27480	1	300	3.2999999999999998	0.069000000000000006	1	3.2999999999999998	0.069000000000000006
27480	2	300	0	0	1	0	0
27480	3	300	0	0	1	0	0
27470	1	900	0	0	1	0	0
27469	1	300	82.400000000000006	1.7170000000000001	1	82.400000000000006	1.7170000000000001
27469	2	300	128.59999999999999	2.6789999999999998	1	128.59999999999999	2.6789999999999998
27469	3	300	148.59999999999999	3.0960000000000001	1	148.59999999999999	3.0960000000000001
27468	1	300	128.40000000000001	2.6749999999999998	1	128.40000000000001	2.6749999999999998
27468	2	300	1693.4000000000001	35.279000000000003	1	1693.4000000000001	35.279000000000003
27468	3	300	291	6.0620000000000003	1	291	6.0620000000000003
27467	1	300	2982.5999999999999	62.137	1.038	3095.5799999999999	64.491
27467	2	300	2122.9000000000001	44.226999999999997	1	2122.9000000000001	44.226999999999997
27467	3	300	1468	30.582999999999998	1	1468	30.582999999999998
27466	1	900	0	0	1	0	0
27465	1	900	0	0	1	0	0
27464	1	300	1409	29.353999999999999	1	1409	29.353999999999999
27464	2	300	4781	99.603999999999999	1.374	6570.7510000000002	136.89099999999999
27464	3	300	998	20.792000000000002	1	998	20.792000000000002
27463	1	300	15690	326.875	1.5	23535	490.31200000000001
27463	2	300	17898.599999999999	372.887	1.5	26847.900000000001	559.33100000000002
27463	3	300	1102	22.957999999999998	1	1102	22.957999999999998
27462	1	300	6018.6000000000004	125.38800000000001	1.5	9027.8999999999996	188.08099999999999
27462	2	300	6582	137.125	1.5	9873	205.68700000000001
27462	3	300	159.40000000000001	3.3210000000000002	1	159.40000000000001	3.3210000000000002
27461	1	300	302	6.2919999999999998	1	302	6.2919999999999998
27461	2	300	340	7.0830000000000002	1	340	7.0830000000000002
27461	3	300	90.900000000000006	1.8939999999999999	1	90.900000000000006	1.8939999999999999
27460	1	300	0	0	1	0	0
27460	2	300	27.399999999999999	0.57099999999999995	1	27.399999999999999	0.57099999999999995
27460	3	300	0	0	1	0	0
27459	1	300	8208.6000000000004	171.01300000000001	1.5	12312.9	256.51900000000001
27459	2	300	3352.5999999999999	69.846000000000004	1.105	3705.9050000000002	77.206000000000003
27459	3	300	1463.2	30.483000000000001	1	1463.2	30.483000000000001
27458	1	300	1635	34.063000000000002	1	1635	34.063000000000002
27458	2	300	314	6.5419999999999998	1	314	6.5419999999999998
27458	3	300	472.89999999999998	9.8520000000000003	1	472.89999999999998	9.8520000000000003
27457	1	300	12165.4	253.446	1.5	18248.099999999999	380.16899999999998
27457	2	300	447	9.3130000000000006	1	447	9.3130000000000006
27457	3	300	232.80000000000001	4.8499999999999996	1	232.80000000000001	4.8499999999999996
27456	1	300	37.399999999999999	0.77900000000000003	1	37.399999999999999	0.77900000000000003
27456	2	300	160.19999999999999	3.3380000000000001	1	160.19999999999999	3.3380000000000001
27456	3	300	70.400000000000006	1.4670000000000001	1	70.400000000000006	1.4670000000000001
24551	1	900	0	0	1	0	0
24552	1	300	895.79999999999995	18.661999999999999	1	895.79999999999995	18.661999999999999
24552	2	300	12619.200000000001	262.89999999999998	1.5	18928.799999999999	394.35000000000002
24552	3	300	235.19999999999999	4.9000000000000004	1	235.19999999999999	4.9000000000000004
24553	1	300	8113.1999999999998	169.02500000000001	1.5	12169.799999999999	253.53800000000001
24553	2	300	2472.8000000000002	51.517000000000003	1	2472.8000000000002	51.517000000000003
24554	1	300	7164.1999999999998	149.25399999999999	1.5	10746.299999999999	223.881
24554	2	300	3787	78.896000000000001	1.206	4565.5730000000003	95.116
24554	3	300	200.19999999999999	4.1710000000000003	1	200.19999999999999	4.1710000000000003
24555	1	300	30.399999999999999	0.63300000000000001	1	30.399999999999999	0.63300000000000001
24555	2	300	2.6000000000000001	0.053999999999999999	1	2.6000000000000001	0.053999999999999999
24555	3	300	15	0.313	1	15	0.313
24550	1	900	0	0	1	0	0
24549	1	300	617.37	12.862	1	617.37	12.862
24549	2	300	641.10000000000002	13.356	1	641.10000000000002	13.356
24549	3	300	636.63	13.263	1	636.63	13.263
24548	1	300	1484.8	30.933	1	1484.8	30.933
24548	2	300	8382.3999999999996	174.63300000000001	1.5	12573.6	261.94999999999999
24548	3	300	6647.8000000000002	138.49600000000001	1.5	9971.7000000000007	207.744
24547	1	300	302.19999999999999	6.2960000000000003	1	302.19999999999999	6.2960000000000003
24547	2	300	3043.4000000000001	63.404000000000003	1.046	3181.924	66.290000000000006
24547	3	300	2052.8000000000002	42.767000000000003	1	2052.8000000000002	42.767000000000003
24546	1	300	15.26	0.318	1	15.26	0.318
24546	2	300	134.63	2.8050000000000002	1	134.63	2.8050000000000002
24546	3	300	1.9099999999999999	0.040000000000000001	1	1.9099999999999999	0.040000000000000001
24545	1	900	0	0	1	0	0
24544	1	300	7797.1999999999998	162.44200000000001	1.5	11695.799999999999	243.66300000000001
24544	2	300	1667	34.728999999999999	1	1667	34.728999999999999
37368	3	300	0	0	1	0	0
37367	1	300	949.79999999999995	19.786999999999999	1	949.79999999999995	19.786999999999999
37367	2	300	0	0	1	0	0
37367	3	300	4492	93.582999999999998	1.336	6001.3980000000001	125.029
37366	1	300	3568.8000000000002	74.349999999999994	1.163	4151.5910000000003	86.491
37366	2	300	1194.7	24.890000000000001	1	1194.7	24.890000000000001
37366	3	300	614.60000000000002	12.804	1	614.60000000000002	12.804
37368	1	300	0	0	1	0	0
37368	2	300	0	0	1	0	0
37365	1	300	45.100000000000001	0.93999999999999995	1	45.100000000000001	0.93999999999999995
37365	2	300	18.399999999999999	0.38300000000000001	1	18.399999999999999	0.38300000000000001
37364	1	300	0	0	1	0	0
37364	2	300	0	0	1	0	0
37364	3	300	0	0	1	0	0
37373	3	300	0	0	1	0	0
37372	1	300	0	0	1	0	0
37372	2	300	0	0	1	0	0
37372	3	300	10.52	0.219	1	10.52	0.219
37371	1	300	119.73	2.4940000000000002	1	119.73	2.4940000000000002
37371	2	300	0	0	1	0	0
37371	3	300	0	0	1	0	0
37370	1	300	16.09	0.33500000000000002	1	16.09	0.33500000000000002
37370	2	300	17.329999999999998	0.36099999999999999	1	17.329999999999998	0.36099999999999999
37370	3	300	3.4100000000000001	0.070999999999999994	1	3.4100000000000001	0.070999999999999994
37369	1	300	5.5300000000000002	0.115	1	5.5300000000000002	0.115
37369	2	300	0	0	1	0	0
37369	3	300	0	0	1	0	0
37374	3	300	0.5	0.01	1	0.5	0.01
37375	1	300	0	0	1	0	0
37373	1	300	0	0	1	0	0
37373	2	300	0	0	1	0	0
37375	2	300	124.09999999999999	2.585	1	124.09999999999999	2.585
37375	3	300	25.600000000000001	0.53300000000000003	1	25.600000000000001	0.53300000000000003
37376	1	300	10.9	0.22700000000000001	1	10.9	0.22700000000000001
37376	2	300	0	0	1	0	0
37376	3	300	0	0	1	0	0
37377	1	300	0	0	1	0	0
37377	2	300	0	0	1	0	0
37377	3	300	6.5999999999999996	0.13700000000000001	1	6.5999999999999996	0.13700000000000001
37378	1	300	18.100000000000001	0.377	1	18.100000000000001	0.377
37378	2	300	0	0	1	0	0
37378	3	300	3.5	0.072999999999999995	1	3.5	0.072999999999999995
37383	3	300	8.6999999999999993	0.18099999999999999	1	8.6999999999999993	0.18099999999999999
37382	1	300	54.5	1.135	1	54.5	1.135
37374	1	300	0	0	1	0	0
37374	2	300	22.899999999999999	0.47699999999999998	1	22.899999999999999	0.47699999999999998
37382	2	300	0	0	1	0	0
37382	3	300	205.90000000000001	4.29	1	205.90000000000001	4.29
37381	1	300	0	0	1	0	0
37381	2	300	0	0	1	0	0
37381	3	300	0	0	1	0	0
37380	1	300	47.299999999999997	0.98499999999999999	1	47.299999999999997	0.98499999999999999
37380	2	300	0	0	1	0	0
37380	3	300	0	0	1	0	0
37379	1	300	0	0	1	0	0
37379	2	300	0	0	1	0	0
37379	3	300	0	0	1	0	0
37384	3	300	0	0	1	0	0
37385	1	300	0	0	1	0	0
37383	1	300	0	0	1	0	0
37383	2	300	0	0	1	0	0
37385	2	300	0	0	1	0	0
37385	3	300	0	0	1	0	0
37386	1	300	0	0	1	0	0
37386	2	300	5	0.104	1	5	0.104
37386	3	300	36.399999999999999	0.75800000000000001	1	36.399999999999999	0.75800000000000001
37387	1	300	50	1.042	1	50	1.042
37387	2	300	4840.3000000000002	100.84	1.381	6683.7309999999998	139.244
37387	3	300	0	0	1	0	0
37388	1	300	1610.8	33.558	1	1610.8	33.558
37388	2	300	448	9.3330000000000002	1	448	9.3330000000000002
37388	3	300	364.5	7.5940000000000003	1	364.5	7.5940000000000003
37393	3	300	3077.8000000000002	64.120999999999995	1.05	3232.3449999999998	67.340999999999994
37392	1	300	890	18.542000000000002	1	890	18.542000000000002
37384	1	300	0	0	1	0	0
37384	2	300	0	0	1	0	0
37392	2	300	467.80000000000001	9.7460000000000004	1	467.80000000000001	9.7460000000000004
37392	3	300	787	16.396000000000001	1	787	16.396000000000001
37391	1	300	5301.8000000000002	110.45399999999999	1.4299999	7580.8530000000001	157.934
37391	2	300	3184	66.332999999999998	1.067	3397.518	70.781999999999996
37391	3	300	5715.8000000000002	119.07899999999999	1.472	8411.5900000000001	175.24100000000001
37390	1	300	6071.6000000000004	126.492	1.5	9107.3999999999996	189.738
37390	2	300	4680.1999999999998	97.504000000000005	1.363	6379.9350000000004	132.91499999999999
37390	3	300	8575.7999999999993	178.66300000000001	1.5	12863.700000000001	267.99400000000003
37389	1	300	0	0	1	0	0
37389	2	300	0	0	1	0	0
37389	3	300	11	0.22900000000000001	1	11	0.22900000000000001
37398	3	300	23.800000000000001	0.496	1	23.800000000000001	0.496
37397	1	300	32.200000000000003	0.67100000000000004	1	32.200000000000003	0.67100000000000004
37393	1	300	1481	30.853999999999999	1	1481	30.853999999999999
37393	2	300	0	0	1	0	0
37397	2	300	3711.5999999999999	77.325000000000003	1.191	4420.8500000000004	92.100999999999999
37397	3	300	812.20000000000005	16.920999999999999	1	812.20000000000005	16.920999999999999
37396	1	300	2298.4000000000001	47.883000000000003	1	2298.4000000000001	47.883000000000003
37396	2	300	61.399999999999999	1.2789999999999999	1	61.399999999999999	1.2789999999999999
37396	3	300	158.19999999999999	3.2959999999999998	1	158.19999999999999	3.2959999999999998
37395	1	300	1010.2	21.045999999999999	1	1010.2	21.045999999999999
37395	2	300	1540.5999999999999	32.095999999999997	1	1540.5999999999999	32.095999999999997
37395	3	300	893.60000000000002	18.617000000000001	1	893.60000000000002	18.617000000000001
37394	1	300	6.9299999999999997	0.14399999999999999	1	6.9299999999999997	0.14399999999999999
37394	2	300	0	0	1	0	0
37394	3	300	12.029999999999999	0.251	1	12.029999999999999	0.251
37403	3	300	572	11.917	1	572	11.917
37402	1	300	842.29999999999995	17.547999999999998	1	842.29999999999995	17.547999999999998
37398	1	300	74.599999999999994	1.554	1	74.599999999999994	1.554
37398	2	300	15.199999999999999	0.317	1	15.199999999999999	0.317
37402	2	300	3402.1999999999998	70.879000000000005	1.1210001	3812.8870000000002	79.435000000000002
37402	3	300	22.300000000000001	0.46500000000000002	1	22.300000000000001	0.46500000000000002
37401	1	300	299	6.2290000000000001	1	299	6.2290000000000001
37401	2	300	2906.1999999999998	60.545999999999999	1.029	2991.134	62.314999999999998
37401	3	300	938.10000000000002	19.544	1	938.10000000000002	19.544
37400	1	300	2046.5	42.634999999999998	1	2046.5	42.634999999999998
37400	2	300	78.200000000000003	1.629	1	78.200000000000003	1.629
37400	3	300	665.10000000000002	13.856	1	665.10000000000002	13.856
37399	1	300	0.90000000000000002	0.019	1	0.90000000000000002	0.019
37399	2	300	0	0	1	0	0
37399	3	300	0.10000000000000001	0.002	1	0.10000000000000001	0.002
37403	1	300	2210.9000000000001	46.060000000000002	1	2210.9000000000001	46.060000000000002
37403	2	300	2105.1999999999998	43.857999999999997	1	2105.1999999999998	43.857999999999997
37413	3	300	0	0	1	0	0
37412	1	300	3509.1999999999998	73.108000000000004	1.152	4041.0999999999999	84.189999999999998
37412	2	300	10209.200000000001	212.69200000000001	1.5	15313.799999999999	319.03800000000001
37412	3	300	165.90000000000001	3.456	1	165.90000000000001	3.456
37411	1	300	1871.8	38.996000000000002	1	1871.8	38.996000000000002
37411	2	300	501.39999999999998	10.446	1	501.39999999999998	10.446
37411	3	300	709.10000000000002	14.773	1	709.10000000000002	14.773
37410	1	300	173.59999999999999	3.617	1	173.59999999999999	3.617
37410	2	300	185.30000000000001	3.8599999999999999	1	185.30000000000001	3.8599999999999999
37410	3	300	112.7	2.3479999999999999	1	112.7	2.3479999999999999
37409	1	300	0	0	1	0	0
37409	2	300	91.200000000000003	1.8999999999999999	1	91.200000000000003	1.8999999999999999
37409	3	300	888.89999999999998	18.518999999999998	1	888.89999999999998	18.518999999999998
37418	3	300	5057.1999999999998	105.358	1.404	7101.4700000000003	147.947
37417	1	300	314.69999999999999	6.556	1	314.69999999999999	6.556
37413	1	300	0	0	1	0	0
37413	2	300	0	0	1	0	0
37417	2	300	2359	49.146000000000001	1	2359	49.146000000000001
37417	3	300	3392.5999999999999	70.679000000000002	1.118	3791.4490000000001	78.989000000000004
37416	1	300	616.10000000000002	12.835000000000001	1	616.10000000000002	12.835000000000001
37416	2	300	196.5	4.0940000000000003	1	196.5	4.0940000000000003
37416	3	300	1176.5999999999999	24.513000000000002	1	1176.5999999999999	24.513000000000002
37415	1	300	164.30000000000001	3.423	1	164.30000000000001	3.423
37415	2	300	1183.5	24.655999999999999	1	1183.5	24.655999999999999
37415	3	300	273.69999999999999	5.702	1	273.69999999999999	5.702
37414	1	300	0	0	1	0	0
37414	2	300	0	0	1	0	0
37414	3	300	0	0	1	0	0
37418	1	300	155.90000000000001	3.2480000000000002	1	155.90000000000001	3.2480000000000002
37418	2	300	2315	48.228999999999999	1	2315	48.228999999999999
37423	3	300	3817.5999999999999	79.533000000000001	1.211	4624.8050000000003	96.349999999999994
37422	1	300	880.5	18.344000000000001	1	880.5	18.344000000000001
37422	2	300	892.10000000000002	18.585000000000001	1	892.10000000000002	18.585000000000001
37422	3	300	50.93	1.0609999999999999	1	50.93	1.0609999999999999
37421	1	300	2795.0999999999999	58.231000000000002	1.018	2845.71	59.286000000000001
37421	2	300	29.66	0.61799999999999999	1	29.66	0.61799999999999999
37421	3	300	1418.0999999999999	29.544	1	1418.0999999999999	29.544
37420	1	300	180.94	3.77	1	180.94	3.77
37420	2	300	4.4299999999999997	0.091999999999999998	1	4.4299999999999997	0.091999999999999998
37420	3	300	99.260000000000005	2.0680000000000001	1	99.260000000000005	2.0680000000000001
37419	1	300	0.76000000000000001	0.016	1	0.76000000000000001	0.016
37419	2	300	278.26999999999998	5.7969999999999997	1	278.26999999999998	5.7969999999999997
37419	3	300	0.42999999999999999	0.0089999999999999993	1	0.42999999999999999	0.0089999999999999993
37428	3	300	1233	25.687000000000001	1	1233	25.687000000000001
37427	1	300	242.90000000000001	5.0599999999999996	1	242.90000000000001	5.0599999999999996
37423	1	300	5202.1999999999998	108.379	1.42	7384.6049999999996	153.846
37423	2	300	1213.5999999999999	25.283000000000001	1	1213.5999999999999	25.283000000000001
37427	2	300	1249	26.021000000000001	1	1249	26.021000000000001
37427	3	300	438.89999999999998	9.1440000000000001	1	438.89999999999998	9.1440000000000001
37426	1	300	79.299999999999997	1.6519999999999999	1	79.299999999999997	1.6519999999999999
37426	2	300	25.199999999999999	0.52500000000000002	1	25.199999999999999	0.52500000000000002
37426	3	300	1406.9000000000001	29.309999999999999	1	1406.9000000000001	29.309999999999999
37425	1	300	377.80000000000001	7.8710000000000004	1	377.80000000000001	7.8710000000000004
37425	2	300	329.30000000000001	6.8600000000000003	1	329.30000000000001	6.8600000000000003
37425	3	300	429.60000000000002	8.9499999999999993	1	429.60000000000002	8.9499999999999993
37424	1	300	62.200000000000003	1.296	1	62.200000000000003	1.296
37424	2	300	0	0	1	0	0
37424	3	300	79.400000000000006	1.6539999999999999	1	79.400000000000006	1.6539999999999999
37428	1	300	1743	36.313000000000002	1	1743	36.313000000000002
37428	2	300	193	4.0209999999999999	1	193	4.0209999999999999
37433	3	300	643.20000000000005	13.4	1	643.20000000000005	13.4
37432	1	300	0	0	1	0	0
37432	2	300	1236.5999999999999	25.763000000000002	1	1236.5999999999999	25.763000000000002
37432	3	300	312	6.5	1	312	6.5
37431	1	300	1123.2	23.399999999999999	1	1123.2	23.399999999999999
37431	2	300	269	5.6040000000000001	1	269	5.6040000000000001
37431	3	300	3509	73.103999999999999	1.152	4040.7310000000002	84.182000000000002
37430	1	300	2913.5999999999999	60.700000000000003	1.03	3001.0790000000002	62.521999999999998
37430	2	300	2559.5999999999999	53.325000000000003	1.002	2563.6300000000001	53.408999999999999
37430	3	300	316.60000000000002	6.5960000000000001	1	316.60000000000002	6.5960000000000001
37429	1	300	0	0	1	0	0
37429	2	300	161	3.3540000000000001	1	161	3.3540000000000001
37429	3	300	5.7999999999999998	0.121	1	5.7999999999999998	0.121
37433	1	300	438	9.125	1	438	9.125
37433	2	300	5574.3999999999996	116.133	1.4579999	8125.1719999999996	169.274
34827	2	180	1280.4000000000001	44.457999999999998	1	1280.4000000000001	44.457999999999998
34827	3	180	2900.1999999999998	100.70099999999999	1.029	2983.0949999999998	103.58
34828	1	180	1698.2	58.965000000000003	1	1698.2	58.965000000000003
34828	2	180	1660.2	57.646000000000001	1	1660.2	57.646000000000001
34828	3	180	1208.2	41.951000000000001	1	1208.2	41.951000000000001
34819	1	180	487.60000000000002	16.931000000000001	1	487.60000000000002	16.931000000000001
34819	2	180	10333.200000000001	358.79199999999997	1.5	15499.799999999999	538.18700000000001
34819	3	180	327.19999999999999	11.361000000000001	1	327.19999999999999	11.361000000000001
34820	1	180	3238.8000000000002	112.458	1.0779999	3490.163	121.18600000000001
34820	2	180	3077	106.84	1.05	3231.1570000000002	112.193
34820	3	180	5773.6000000000004	200.47200000000001	1.477	8529.4560000000001	296.16199999999998
34821	1	180	990.60000000000002	34.396000000000001	1	990.60000000000002	34.396000000000001
34821	2	180	4822.3999999999996	167.44399999999999	1.3789999	6649.5709999999999	230.88800000000001
34821	3	180	7870.3999999999996	273.27800000000002	1.5	11805.6	409.91699999999997
34822	1	180	1786.4000000000001	62.027999999999999	1	1786.4000000000001	62.027999999999999
34822	2	180	647.39999999999998	22.478999999999999	1	647.39999999999998	22.478999999999999
34822	3	180	1832	63.610999999999997	1	1832	63.610999999999997
34823	1	180	922	32.014000000000003	1	922	32.014000000000003
34823	2	300	1957	40.771000000000001	1	1957	40.771000000000001
34823	3	300	1416	29.5	1	1416	29.5
34736	1	300	263	5.4790000000000001	1	263	5.4790000000000001
34736	2	300	3179.5999999999999	66.242000000000004	1.066	3390.3290000000002	70.632000000000005
34736	3	300	677.60000000000002	14.117000000000001	1	677.60000000000002	14.117000000000001
34737	1	300	266.19999999999999	5.5460000000000003	1	266.19999999999999	5.5460000000000003
34737	2	300	992.79999999999995	20.683	1	992.79999999999995	20.683
34737	3	300	101	2.1040000000000001	1	101	2.1040000000000001
34738	1	300	4001.1999999999998	83.358000000000004	1.2460001	4986.1790000000001	103.879
34738	2	300	2579	53.728999999999999	1.002	2585.1689999999999	53.857999999999997
34738	3	300	3376	70.332999999999998	1.112	3755.23	78.233999999999995
34739	1	300	5513.1999999999998	114.858	1.451	8002.0630000000001	166.71000000000001
34739	2	300	639.79999999999995	13.329000000000001	1	639.79999999999995	13.329000000000001
34739	3	300	908.39999999999998	18.925000000000001	1	908.39999999999998	18.925000000000001
34740	1	300	3719.4000000000001	77.486999999999995	1.193	4435.7399999999998	92.411000000000001
34740	2	300	1982.4000000000001	41.299999999999997	1	1982.4000000000001	41.299999999999997
34740	3	300	2137.4000000000001	44.529000000000003	1	2137.4000000000001	44.529000000000003
29908	1	300	677.60000000000002	14.117000000000001	1	677.60000000000002	14.117000000000001
29908	2	300	3586.8000000000002	74.724999999999994	1.1670001	4185.1800000000003	87.191000000000003
29908	3	300	2434.1999999999998	50.713000000000001	1	2434.1999999999998	50.713000000000001
29907	1	300	691	14.396000000000001	1	691	14.396000000000001
29907	2	300	1345.4000000000001	28.029	1	1345.4000000000001	28.029
29907	3	300	549.20000000000005	11.442	1	549.20000000000005	11.442
29906	1	300	3283.5999999999999	68.408000000000001	1.087	3570.8389999999999	74.391999999999996
29906	2	300	3370	70.207999999999998	1.1109999	3742.395	77.966999999999999
29906	3	300	2467.5999999999999	51.408000000000001	1	2467.5999999999999	51.408000000000001
29905	1	300	501.60000000000002	10.449999999999999	1	501.60000000000002	10.449999999999999
29905	2	300	565	11.771000000000001	1	565	11.771000000000001
29905	3	300	62.799999999999997	1.3080000000000001	1	62.799999999999997	1.3080000000000001
29904	1	300	48	1	1	48	1
29904	2	300	85.799999999999997	1.7869999999999999	1	85.799999999999997	1.7869999999999999
29904	3	300	225.40000000000001	4.6959999999999997	1	225.40000000000001	4.6959999999999997
29899	1	300	964	20.082999999999998	1	964	20.082999999999998
29899	2	300	2466	51.375	1	2466	51.375
29899	3	300	5210	108.542	1.42	7399.9219999999996	154.16499999999999
29900	1	300	1000.2	20.838000000000001	1	1000.2	20.838000000000001
29900	2	300	199.19999999999999	4.1500000000000004	1	199.19999999999999	4.1500000000000004
29900	3	300	1248	26	1	1248	26
29901	1	300	3820	79.582999999999998	1.212	4629.4629999999997	96.447000000000003
29901	2	300	4694	97.792000000000002	1.365	6405.9660000000003	133.458
29901	3	300	2688	56	1.0089999	2712.4079999999999	56.509
29902	1	300	4646	96.792000000000002	1.363	6334.3270000000002	131.965
29902	2	300	6656	138.667	1.5	9984	208
29902	3	300	5002	104.208	1.398	6994.4939999999997	145.71899999999999
29903	1	300	14.300000000000001	0.29799999999999999	1	14.300000000000001	0.29799999999999999
29903	2	300	209	4.3540000000000001	1	209	4.3540000000000001
29903	3	300	526.79999999999995	10.975	1	526.79999999999995	10.975
29894	1	300	1447.8	30.161999999999999	1	1447.8	30.161999999999999
29894	2	300	1648.4000000000001	34.341999999999999	1	1648.4000000000001	34.341999999999999
29894	3	300	24062	501.29199999999997	1.5	36093	751.93700000000001
29895	1	300	13096	272.83300000000003	1.5	19644	409.25
29895	2	180	12253.799999999999	425.47899999999998	1.5	18380.700000000001	638.21900000000005
29895	3	180	14061.6	488.25	1.5	21092.400000000001	732.375
29896	1	180	1296.3	45.009999999999998	1	1296.3	45.009999999999998
29896	2	300	2327.1999999999998	48.482999999999997	1	2327.1999999999998	48.482999999999997
29896	3	300	2140.1999999999998	44.588000000000001	1	2140.1999999999998	44.588000000000001
29897	1	300	134.30000000000001	2.798	1	134.30000000000001	2.798
29897	2	300	45.600000000000001	0.94999999999999996	1	45.600000000000001	0.94999999999999996
29897	3	300	2658.1999999999998	55.378999999999998	1.007	2676.6729999999998	55.764000000000003
29898	1	300	15615.6	325.32499999999999	1.5	23423.400000000001	487.98700000000002
29898	2	180	2813.8000000000002	97.700999999999993	1.02	2869.6909999999998	99.641999999999996
29898	3	180	3918.1999999999998	136.04900000000001	1.2309999	4821.5479999999998	167.41499999999999
27551	1	300	1012.8	21.100000000000001	1	1012.8	21.100000000000001
27551	2	300	544.79999999999995	11.35	1	544.79999999999995	11.35
27551	3	300	484	10.083	1	484	10.083
27552	1	300	423.60000000000002	8.8249999999999993	1	423.60000000000002	8.8249999999999993
27552	2	300	745	15.521000000000001	1	745	15.521000000000001
27552	3	300	3394.1999999999998	70.712000000000003	1.118	3794.9960000000001	79.061999999999998
27553	1	300	5500.6000000000004	114.596	1.45	7976.7809999999999	166.18299999999999
27553	2	300	4640.1999999999998	96.671000000000006	1.362	6321.6660000000002	131.70099999999999
27553	3	300	1328.5999999999999	27.678999999999998	1	1328.5999999999999	27.678999999999998
27554	1	300	1746	36.375	1	1746	36.375
27554	2	300	1234.8	25.725000000000001	1	1234.8	25.725000000000001
27554	3	300	2595.8000000000002	54.079000000000001	1.003	2604.1170000000002	54.252000000000002
27555	1	300	61	1.2709999999999999	1	61	1.2709999999999999
27555	2	300	55.600000000000001	1.1579999999999999	1	55.600000000000001	1.1579999999999999
27555	3	300	48.399999999999999	1.008	1	48.399999999999999	1.008
27961	1	300	925.29999999999995	19.277000000000001	1	925.29999999999995	19.277000000000001
27961	2	300	590.5	12.302	1	590.5	12.302
27961	3	300	137.80000000000001	2.871	1	137.80000000000001	2.871
27962	1	300	315.30000000000001	6.569	1	315.30000000000001	6.569
27962	2	300	388.5	8.0939999999999994	1	388.5	8.0939999999999994
27962	3	300	978	20.375	1	978	20.375
27963	1	300	2931.5999999999999	61.075000000000003	1.0319999	3025.4169999999999	63.030000000000001
27963	2	300	2553	53.188000000000002	1.001	2556.3890000000001	53.258000000000003
27963	3	300	2109.1999999999998	43.942	1	2109.1999999999998	43.942
27964	1	300	2550.4000000000001	53.133000000000003	1.001	2553.549	53.198999999999998
27964	2	300	2176.5999999999999	45.345999999999997	1	2176.5999999999999	45.345999999999997
27964	3	300	1251.4000000000001	26.071000000000002	1	1251.4000000000001	26.071000000000002
27965	1	300	43.600000000000001	0.90800000000000003	1	43.600000000000001	0.90800000000000003
27965	2	300	29.100000000000001	0.60599999999999998	1	29.100000000000001	0.60599999999999998
27965	3	300	11.800000000000001	0.246	1	11.800000000000001	0.246
27545	1	300	2242.4000000000001	46.716999999999999	1	2242.4000000000001	46.716999999999999
27545	2	300	643.60000000000002	13.407999999999999	1	643.60000000000002	13.407999999999999
27545	3	300	5.0999999999999996	0.106	1	5.0999999999999996	0.106
27544	1	300	1596.0999999999999	33.252000000000002	1	1596.0999999999999	33.252000000000002
27544	2	300	2088.0999999999999	43.502000000000002	1	2088.0999999999999	43.502000000000002
27544	3	300	64	1.333	1	64	1.333
27543	1	300	7905.3999999999996	164.696	1.5	11858.1	247.04400000000001
27543	2	300	3570	74.375	1.164	4153.8270000000002	86.537999999999997
27543	3	300	178.59999999999999	3.7210000000000001	1	178.59999999999999	3.7210000000000001
27542	1	300	1665.3	34.694000000000003	1	1665.3	34.694000000000003
27542	2	300	720.20000000000005	15.004	1	720.20000000000005	15.004
27542	3	300	592.29999999999995	12.34	1	592.29999999999995	12.34
27541	1	300	15.4	0.32100000000000001	1	15.4	0.32100000000000001
27541	2	300	110.09999999999999	2.294	1	110.09999999999999	2.294
27541	3	300	44.600000000000001	0.92900000000000005	1	44.600000000000001	0.92900000000000005
27905	1	300	0	0	1	0	0
27905	2	300	8788	183.083	1.5	13182	274.625
27905	3	300	5218	108.708	1.421	7415.6409999999996	154.49299999999999
27904	1	300	4931	102.729	1.391	6857.5609999999997	142.86600000000001
27904	2	300	16485	343.43700000000001	1.5	24727.5	515.15599999999995
27904	3	300	3083	64.228999999999999	1.051	3240.0790000000002	67.501999999999995
27903	1	300	9284	193.417	1.5	13926	290.125
27903	2	300	12380	257.91699999999997	1.5	18570	386.875
27903	3	300	16945	353.02100000000002	1.5	25417.5	529.53099999999995
27902	1	300	5108	106.417	1.41	7200.3159999999998	150.00700000000001
27902	2	300	3976	82.832999999999998	1.2410001	4935.9750000000004	102.833
27902	3	300	1622	33.792000000000002	1	1622	33.792000000000002
27901	1	300	2590	53.957999999999998	1.003	2597.5450000000001	54.116
27901	2	300	1433	29.853999999999999	1	1433	29.853999999999999
27901	3	300	2150	44.792000000000002	1	2150	44.792000000000002
27535	1	300	8349.6000000000004	173.94999999999999	1.5	12524.4	260.92500000000001
27535	2	300	131.40000000000001	2.738	1	131.40000000000001	2.738
27535	3	300	1687	35.146000000000001	1	1687	35.146000000000001
27534	1	300	14756.200000000001	307.42099999999999	1.5	22134.299999999999	461.13099999999997
27534	2	300	11343.200000000001	236.31700000000001	1.5	17014.799999999999	354.47500000000002
27534	3	300	14146.200000000001	294.71300000000002	1.5	21219.299999999999	442.06900000000002
27533	1	300	273.19999999999999	5.6920000000000002	1	273.19999999999999	5.6920000000000002
27533	2	300	877.79999999999995	18.286999999999999	1	877.79999999999995	18.286999999999999
27533	3	300	8374.6000000000004	174.471	1.5	12561.9	261.70600000000002
27532	1	300	1536.4000000000001	32.008000000000003	1	1536.4000000000001	32.008000000000003
27532	2	300	4152.3999999999996	86.507999999999996	1.274	5291.3869999999997	110.23699999999999
27532	3	300	5795.8000000000002	120.746	1.479	8574.8469999999998	178.643
27531	1	300	2299.4000000000001	47.904000000000003	1	2299.4000000000001	47.904000000000003
27531	2	300	1667.2	34.732999999999997	1	1667.2	34.732999999999997
27531	3	300	675.60000000000002	14.074999999999999	1	675.60000000000002	14.074999999999999
24621	1	300	8097	168.68700000000001	1.5	12145.5	253.03100000000001
24621	2	300	859.79999999999995	17.911999999999999	1	859.79999999999995	17.911999999999999
24621	3	300	5633.1999999999998	117.358	1.4630001	8243.9429999999993	171.749
24622	1	300	2521.1999999999998	52.524999999999999	1	2522.1599999999999	52.545000000000002
24622	2	300	2108.8000000000002	43.933	1	2108.8000000000002	43.933
24622	3	300	3148.8000000000002	65.599999999999994	1.061	3340.9290000000001	69.602999999999994
24623	1	300	218	4.5419999999999998	1	218	4.5419999999999998
24623	2	300	492.60000000000002	10.263	1	492.60000000000002	10.263
24623	3	300	1019.8	21.245999999999999	1	1019.8	21.245999999999999
24624	1	300	6368.1999999999998	132.67099999999999	1.5	9552.2999999999993	199.006
24624	2	300	4096.6000000000004	85.346000000000004	1.2640001	5177.9579999999996	107.874
24624	3	300	7443.3999999999996	155.071	1.5	11165.1	232.60599999999999
24625	1	300	404.80000000000001	8.4329999999999998	1	404.80000000000001	8.4329999999999998
24625	2	300	850.39999999999998	17.716999999999999	1	850.39999999999998	17.716999999999999
24625	3	300	37.600000000000001	0.78300000000000003	1	37.600000000000001	0.78300000000000003
24610	1	300	806.10000000000002	16.794	1	806.10000000000002	16.794
24610	2	300	3247.4000000000001	67.653999999999996	1.079	3505.2759999999998	73.027000000000001
24610	3	300	4754.8000000000002	99.058000000000007	1.3710001	6521.0039999999999	135.85400000000001
24609	1	300	147.80000000000001	3.0790000000000002	1	147.80000000000001	3.0790000000000002
24609	2	300	200.09999999999999	4.1689999999999996	1	200.09999999999999	4.1689999999999996
24609	3	300	438.5	9.1349999999999998	1	438.5	9.1349999999999998
24608	1	300	2799	58.313000000000002	1.018	2850.6950000000002	59.389000000000003
24608	2	300	864.20000000000005	18.004000000000001	1	864.20000000000005	18.004000000000001
24608	3	300	2729.8000000000002	56.871000000000002	1.012	2763.5770000000002	57.575000000000003
24607	1	300	6472	134.833	1.5	9708	202.25
24607	2	300	5867.3999999999996	122.23699999999999	1.4859999	8721.6959999999999	181.702
24607	3	300	5178.6000000000004	107.88800000000001	1.4170001	7338.3140000000003	152.88200000000001
24606	1	300	1016.3	21.172999999999998	1	1016.3	21.172999999999998
24606	3	300	389.69999999999999	8.1189999999999998	1	389.69999999999999	8.1189999999999998
24604	1	300	9563.6000000000004	199.24199999999999	1.5	14345.4	298.86200000000002
24604	2	300	2818.6999999999998	58.722999999999999	1.02	2876.0070000000001	59.917000000000002
24604	3	300	2102.8000000000002	43.808	1	2102.8000000000002	43.808
24605	1	300	19716.599999999999	410.762	1.5	29574.900000000001	616.14400000000001
24605	2	300	12686.799999999999	264.30799999999999	1.5	19030.200000000001	396.46199999999999
24605	3	300	8948.7999999999993	186.43299999999999	1.5	13423.200000000001	279.64999999999998
24603	1	300	2953.5	61.530999999999999	1.034	3055.319	63.652000000000001
24603	2	300	12886.6	268.471	1.5	19329.900000000001	402.70600000000002
24603	3	300	14673.9	305.70600000000002	1.5	22010.849999999999	458.55900000000003
24602	1	300	3380.0999999999999	70.418999999999997	1.114	3764.078	78.418000000000006
24602	2	300	3490.0999999999999	72.709999999999994	1.148	4005.9279999999999	83.456999999999994
24602	3	300	7047.8000000000002	146.82900000000001	1.5	10571.700000000001	220.244
24601	1	300	5180.6000000000004	107.929	1.4170001	7342.2340000000004	152.96299999999999
24601	2	300	510.19999999999999	10.629	1	510.19999999999999	10.629
24601	3	300	2427.4000000000001	50.570999999999998	1	2427.4000000000001	50.570999999999998
25905	1	300	575	11.978999999999999	1	575	11.978999999999999
25904	1	300	695	14.478999999999999	1	695	14.478999999999999
25903	1	300	650	13.542	1	650	13.542
25902	1	300	430	8.9580000000000002	1	430	8.9580000000000002
25901	1	300	54.799999999999997	1.1419999999999999	1	54.799999999999997	1.1419999999999999
24030	1	900	3050.5999999999999	21.184999999999999	1.046	3192.375	22.169
24029	1	900	3467.5999999999999	24.081	1.143	3964.6439999999998	27.532
24028	1	900	6053.1499999999996	42.036000000000001	1.5	9079.7250000000004	63.054000000000002
24027	1	900	6199.6499999999996	43.052999999999997	1.5	9299.4750000000004	64.579999999999998
24026	1	900	195.44999999999999	1.357	1	195.44999999999999	1.357
24005	1	900	2013.45	13.981999999999999	1	2013.45	13.981999999999999
24004	1	900	3809.1999999999998	26.452999999999999	1.21	4608.5169999999998	32.003999999999998
24003	1	900	2775.5999999999999	19.274999999999999	1.016	2820.9169999999999	19.59
24002	1	900	1898.7	13.185	1	1898.7	13.185
24001	1	900	5.25	0.035999999999999997	1	5.25	0.035999999999999997
25909	1	300	250	5.2080000000000002	1	250	5.2080000000000002
25908	1	300	245	5.1040000000000001	1	245	5.1040000000000001
25907	1	300	340	7.0830000000000002	1	340	7.0830000000000002
25906	1	300	245	5.1040000000000001	1	245	5.1040000000000001
23745	1	900	4106.8500000000004	28.52	1.266	5198.7250000000004	36.101999999999997
23744	1	900	797.64999999999998	5.5389999999999997	1	797.64999999999998	5.5389999999999997
23743	1	900	962.95000000000005	6.6870000000000003	1	962.95000000000005	6.6870000000000003
23742	1	900	208.65000000000001	1.4490000000000001	1	208.65000000000001	1.4490000000000001
24606	2	300	113.40000000000001	2.363	1	113.40000000000001	2.363
23741	1	900	27.25	0.189	1	27.25	0.189
23725	1	900	3048.6500000000001	21.170999999999999	1.046	3189.5390000000002	22.149999999999999
23724	1	900	5439.1499999999996	37.771999999999998	1.444	7853.8029999999999	54.539999999999999
23723	1	900	2892.1999999999998	20.085000000000001	1.028	2972.4099999999999	20.641999999999999
23722	1	900	3317.0500000000002	23.035	1.096	3634.5160000000001	25.239999999999998
23721	1	900	302.44999999999999	2.1000000000000001	1	302.44999999999999	2.1000000000000001
23945	1	900	3257.6500000000001	22.623000000000001	1.082	3523.5129999999999	24.469000000000001
23944	1	900	10024.15	69.611999999999995	1.5	15036.225	104.41800000000001
23943	1	900	9982.1000000000004	69.319999999999993	1.5	14973.15	103.98
23942	1	900	2582.4499999999998	17.934000000000001	1.003	2589.038	17.978999999999999
23941	1	900	989.5	6.8719999999999999	1	989.5	6.8719999999999999
23705	1	900	1929.2	13.397	1	1929.2	13.397
23704	1	900	1851.3499999999999	12.856999999999999	1	1851.3499999999999	12.856999999999999
23703	1	900	2167.9499999999998	15.055	1	2167.9499999999998	15.055
23702	1	900	2381.4000000000001	16.538	1	2381.4000000000001	16.538
23701	1	900	30.800000000000001	0.214	1	30.800000000000001	0.214
23687	1	900	3396.4000000000001	23.585999999999999	1.119	3799.8910000000001	26.388000000000002
23686	1	898	280.14999999999998	1.95	1	280.14999999999998	1.95
23685	1	902	2503.9499999999998	17.350000000000001	1	2504.0749999999998	17.350999999999999
23684	1	906	2686.4499999999998	18.532	1.0089999	2710.5340000000001	18.698
23683	1	900	630.5	4.3780000000000001	1	630.5	4.3780000000000001
23682	1	900	1825.3	12.676	1	1825.3	12.676
23681	1	900	43.200000000000003	0.29999999999999999	1	43.200000000000003	0.29999999999999999
13007	1	300	219	4.5620000000000003	1	219	4.5620000000000003
13007	2	300	163	3.3959999999999999	1	163	3.3959999999999999
13007	3	300	18	0.375	1	18	0.375
13008	1	300	550	11.458	1	550	11.458
13008	2	300	823	17.146000000000001	1	823	17.146000000000001
13008	3	300	506	10.542	1	506	10.542
13009	1	300	1599	33.313000000000002	1	1599	33.313000000000002
13009	2	300	207	4.3120000000000003	1	207	4.3120000000000003
13009	3	300	57	1.1870000000000001	1	57	1.1870000000000001
13010	1	300	929	19.353999999999999	1	929	19.353999999999999
13010	2	300	1121	23.353999999999999	1	1121	23.353999999999999
13010	3	300	580	12.083	1	580	12.083
13002	1	300	10	0.20799999999999999	1	10	0.20799999999999999
13002	2	300	21	0.438	1	21	0.438
13002	3	312	146	2.9249999999999998	1	146	2.9249999999999998
13003	1	300	48	1	1	48	1
13003	2	300	43	0.89600000000000002	1	43	0.89600000000000002
13003	3	300	135	2.8130000000000002	1	135	2.8130000000000002
13004	1	300	166	3.4580000000000002	1	166	3.4580000000000002
13004	2	300	110	2.2919999999999998	1	110	2.2919999999999998
13004	3	300	217	4.5209999999999999	1	217	4.5209999999999999
13005	1	300	203	4.2290000000000001	1	203	4.2290000000000001
13005	2	300	185	3.8540000000000001	1	185	3.8540000000000001
13005	3	300	128	2.6669999999999998	1	128	2.6669999999999998
13006	1	300	11	0.22900000000000001	1	11	0.22900000000000001
13006	2	300	16	0.33300000000000002	1	16	0.33300000000000002
13006	3	300	11	0.22900000000000001	1	11	0.22900000000000001
12997	1	300	1189	24.771000000000001	1	1189	24.771000000000001
12997	2	300	527	10.978999999999999	1	527	10.978999999999999
12997	3	300	14	0.29199999999999998	1	14	0.29199999999999998
12998	1	300	295	6.1459999999999999	1	295	6.1459999999999999
12998	2	300	1101	22.937000000000001	1	1101	22.937000000000001
12998	3	300	1577	32.853999999999999	1	1577	32.853999999999999
12999	1	300	881	18.353999999999999	1	881	18.353999999999999
12999	2	300	1185	24.687000000000001	1	1185	24.687000000000001
12999	3	300	1228	25.582999999999998	1	1228	25.582999999999998
13000	1	300	620	12.917	1	620	12.917
13000	2	300	1334	27.792000000000002	1	1334	27.792000000000002
13000	3	300	506	10.542	1	506	10.542
13001	1	300	339	7.0620000000000003	1	339	7.0620000000000003
13001	2	300	126	2.625	1	126	2.625
13001	3	300	354	7.375	1	354	7.375
12925	1	300	51	1.0620000000000001	1	51	1.0620000000000001
12925	2	300	13	0.27100000000000002	1	13	0.27100000000000002
12925	3	300	1	0.021000000000000001	1	1	0.021000000000000001
12926	1	300	84	1.75	1	84	1.75
12926	2	300	265	5.5209999999999999	1	265	5.5209999999999999
12926	3	300	40	0.83299999999999996	1	40	0.83299999999999996
12927	1	300	442	9.2080000000000002	1	442	9.2080000000000002
12927	2	300	711	14.813000000000001	1	711	14.813000000000001
12927	3	300	574	11.958	1	574	11.958
12928	1	300	483	10.063000000000001	1	483	10.063000000000001
12928	2	300	453	9.4380000000000006	1	453	9.4380000000000006
12928	3	300	525	10.938000000000001	1	525	10.938000000000001
12929	1	300	45	0.93799999999999994	1	45	0.93799999999999994
12929	2	300	60	1.25	1	60	1.25
12929	3	300	37	0.77100000000000002	1	37	0.77100000000000002
12930	1	300	329	6.8540000000000001	1	329	6.8540000000000001
10926	1	300	67	1.3959999999999999	1	67	1.3959999999999999
10926	2	300	176	3.6669999999999998	1	176	3.6669999999999998
10926	3	300	176	3.6669999999999998	1	176	3.6669999999999998
10927	1	900	34	0.23599999999999999	1	34	0.23599999999999999
10868	1	300	369	7.6870000000000003	1	369	7.6870000000000003
10868	2	300	901	18.771000000000001	1	901	18.771000000000001
10868	3	300	739	15.396000000000001	1	739	15.396000000000001
10869	1	300	406	8.4580000000000002	1	406	8.4580000000000002
10869	2	300	4405	91.771000000000001	1.3200001	5816.3140000000003	121.173
10869	3	300	2066	43.042000000000002	1	2066	43.042000000000002
10870	1	300	1611	33.563000000000002	1	1611	33.563000000000002
10870	2	300	771	16.062000000000001	1	771	16.062000000000001
10870	3	300	1767	36.813000000000002	1	1767	36.813000000000002
10871	1	300	234	4.875	1	234	4.875
10871	2	300	2044	42.582999999999998	1	2044	42.582999999999998
10871	3	300	174	3.625	1	174	3.625
10871	4	300	2430	50.625	1	2430	50.625
10872	1	900	0	0	1	0	0
10863	1	300	865	18.021000000000001	1	865	18.021000000000001
10863	2	300	569	11.853999999999999	1	569	11.853999999999999
10863	3	300	2734	56.957999999999998	1.013	2768.7809999999999	57.683
10863	4	300	481	10.021000000000001	1	481	10.021000000000001
10864	1	300	2093	43.603999999999999	1	2093	43.603999999999999
10864	2	300	2052	42.75	1	2052	42.75
10864	3	300	1253	26.103999999999999	1	1253	26.103999999999999
10865	1	300	1753	36.521000000000001	1	1753	36.521000000000001
10865	2	300	695	14.478999999999999	1	695	14.478999999999999
10865	3	300	3328	69.332999999999998	1.099	3656.0749999999998	76.168000000000006
10865	4	300	1388	28.917000000000002	1	1388	28.917000000000002
10866	1	300	91	1.8959999999999999	1	91	1.8959999999999999
10866	2	300	85	1.7709999999999999	1	85	1.7709999999999999
10866	3	300	62	1.292	1	62	1.292
10867	1	300	88	1.833	1	88	1.833
10867	2	600	314	3.2709999999999999	1	314	3.2709999999999999
10858	1	600	293	3.052	1	293	3.052
10858	2	600	86	0.89600000000000002	1	86	0.89600000000000002
10858	3	600	723	7.5309999999999997	1	723	7.5309999999999997
10859	1	600	2427	25.280999999999999	1	2427	25.280999999999999
10859	2	600	2078	21.646000000000001	1	2078	21.646000000000001
10859	3	600	656	6.8330000000000002	1	656	6.8330000000000002
10860	1	600	1943	20.239999999999998	1	1943	20.239999999999998
10860	2	600	2134	22.228999999999999	1	2134	22.228999999999999
10860	3	600	694	7.2290000000000001	1	694	7.2290000000000001
10860	4	600	4810	50.103999999999999	1.378	6625.9359999999997	69.019999999999996
10861	1	600	255	2.6560000000000001	1	255	2.6560000000000001
10861	2	600	770	8.0210000000000008	1	770	8.0210000000000008
10861	3	600	632	6.5830000000000002	1	632	6.5830000000000002
10862	1	1800	26	0.089999999999999997	1	26	0.089999999999999997
10851	1	300	91	1.8959999999999999	1	91	1.8959999999999999
10851	2	600	165	1.7190000000000001	1	165	1.7190000000000001
10852	1	300	755	15.728999999999999	1	755	15.728999999999999
10852	2	300	99	2.0630000000000002	1	99	2.0630000000000002
10852	3	300	266	5.5419999999999998	1	266	5.5419999999999998
10853	1	300	582	12.125	1	582	12.125
10853	2	300	2075	43.228999999999999	1	2075	43.228999999999999
10853	3	300	2828	58.917000000000002	1.021	2888.0340000000001	60.167000000000002
10854	1	300	3847	80.146000000000001	1.217	4681.9840000000004	97.540999999999997
10854	2	300	392	8.1669999999999998	1	392	8.1669999999999998
10854	3	300	742	15.458	1	742	15.458
10854	4	300	549	11.438000000000001	1	549	11.438000000000001
10855	1	300	706	14.708	1	706	14.708
10855	2	300	1087	22.646000000000001	1	1087	22.646000000000001
10855	3	300	749	15.603999999999999	1	749	15.603999999999999
10856	1	300	360	7.5	1	360	7.5
10856	2	300	164	3.4169999999999998	1	164	3.4169999999999998
10856	3	300	447	9.3130000000000006	1	447	9.3130000000000006
10857	1	1500	22	0.091999999999999998	1	22	0.091999999999999998
10846	1	300	0	0	1	0	0
10847	1	300	542	11.292	1	542	11.292
10847	2	600	159	1.6559999999999999	1	159	1.6559999999999999
10848	1	300	44	0.91700000000000004	1	44	0.91700000000000004
10848	2	600	202	2.1040000000000001	1	202	2.1040000000000001
10849	1	300	3332	69.417000000000002	1.1	3664.0430000000001	76.334000000000003
10849	2	300	75	1.5629999999999999	1	75	1.5629999999999999
10849	3	300	28	0.58299999999999996	1	28	0.58299999999999996
10850	1	900	177	1.2290000000000001	1	177	1.2290000000000001
10841	1	900	8	0.056000000000000001	1	8	0.056000000000000001
10842	1	300	96	2	1	96	2
10842	2	600	140	1.458	1	140	1.458
10843	1	300	32	0.66700000000000004	1	32	0.66700000000000004
10843	2	300	1894	39.457999999999998	1	1894	39.457999999999998
10843	3	300	1142	23.792000000000002	1	1142	23.792000000000002
10843	4	300	0	0	1	0	0
10844	1	300	2075	43.228999999999999	1	2075	43.228999999999999
10844	2	300	498	10.375	1	498	10.375
10844	3	300	216	4.5	1	216	4.5
10845	1	900	0	0	1	0	0
10835	1	900	0	0	1	0	0
10836	1	1200	23	0.12	1	23	0.12
10837	1	600	137	1.427	1	137	1.427
10837	2	600	171	1.7809999999999999	1	171	1.7809999999999999
10838	1	600	38	0.39600000000000002	1	38	0.39600000000000002
10838	2	600	3145	32.759999999999998	1.0599999	3334.9389999999999	34.738999999999997
10839	1	900	97	0.67400000000000004	1	97	0.67400000000000004
10839	2	300	119	2.4790000000000001	1	119	2.4790000000000001
10840	1	900	0	0	1	0	0
10830	1	1200	0	0	1	0	0
10831	1	600	45	0.46899999999999997	1	45	0.46899999999999997
10831	2	600	5241	54.594000000000001	1.424	7460.8850000000002	77.718000000000004
10832	1	240	817	21.276	1	817	21.276
10832	2	300	7079	147.47900000000001	1.5	10618.5	221.21899999999999
10832	3	360	6599	114.566	1.5	9898.5	171.84899999999999
10833	1	300	6666	138.875	1.5	9999	208.31200000000001
10833	2	160	2264	88.438000000000002	1	2264	88.438000000000002
10833	3	180	0	0	1	0	0
10833	4	240	614	15.99	1	614	15.99
10833	5	240	391	10.182	1	391	10.182
10834	1	1500	128	0.53300000000000003	1	128	0.53300000000000003
10824	1	900	5287	36.715000000000003	1.428	7551.6009999999997	52.442
10825	1	300	1882	39.207999999999998	1	1882	39.207999999999998
10825	2	600	374	3.8959999999999999	1	374	3.8959999999999999
10826	1	300	2952	61.5	1.034	3053.2600000000002	63.609999999999999
10826	2	600	1080	11.25	1	1080	11.25
10827	1	300	1460	30.417000000000002	1	1460	30.417000000000002
10827	2	600	3647	37.990000000000002	1.179	4298.2550000000001	44.773000000000003
10828	1	600	283	2.948	1	283	2.948
10828	2	300	1418	29.542000000000002	1	1418	29.542000000000002
10829	1	1500	438	1.825	1	438	1.825
10817	1	900	99	0.68799999999999994	1	99	0.68799999999999994
10818	1	300	95	1.9790000000000001	1	95	1.9790000000000001
10818	2	300	3609	75.188000000000002	1.171	4226.7470000000003	88.057000000000002
10818	3	300	475	9.8960000000000008	1	475	9.8960000000000008
10819	1	300	4457	92.853999999999999	1.33	5926.6769999999997	123.47199999999999
10819	2	300	1683	35.063000000000002	1	1683	35.063000000000002
10819	3	300	3832	79.832999999999998	1.214	4652.7780000000002	96.933000000000007
10820	1	300	9186	191.375	1.5	13779	287.06200000000001
10820	2	300	72	1.5	1	72	1.5
10820	3	300	9792	204	1.5	14688	306
10820	4	300	157	3.2709999999999999	1	157	3.2709999999999999
10821	1	900	318	2.2080000000000002	1	318	2.2080000000000002
10822	1	900	186	1.292	1	186	1.292
10823	1	900	122	0.84699999999999998	1	122	0.84699999999999998
10810	1	900	0	0	1	0	0
10811	1	300	164	3.4169999999999998	1	164	3.4169999999999998
10811	2	900	6826	47.402999999999999	1.5	10239	71.103999999999999
10812	1	300	117	2.4380000000000002	1	117	2.4380000000000002
10812	2	300	10436	217.417	1.5	15654	326.125
10812	3	300	7627	158.89599999999999	1.5	11440.5	238.34399999999999
10813	1	300	1025	21.353999999999999	1	1025	21.353999999999999
10813	2	300	15733	327.77100000000002	1.5	23599.5	491.65600000000001
10813	3	300	2195	45.728999999999999	1	2195	45.728999999999999
10813	4	300	2853	59.438000000000002	1.024	2920.6080000000002	60.845999999999997
10814	1	600	468	4.875	1	468	4.875
10814	2	600	244	2.5419999999999998	1	244	2.5419999999999998
10815	1	900	3096	21.5	1.053	3259.5549999999998	22.635999999999999
10815	2	300	53	1.1040000000000001	1	53	1.1040000000000001
10816	1	300	131	2.7290000000000001	1	131	2.7290000000000001
10816	2	600	19	0.19800000000000001	1	19	0.19800000000000001
10798	1	900	4	0.028000000000000001	1	4	0.028000000000000001
10799	1	300	381	7.9370000000000003	1	381	7.9370000000000003
10799	2	300	2370	49.375	1	2370	49.375
10799	3	300	1910	39.792000000000002	1	1910	39.792000000000002
10800	1	900	194	1.347	1	194	1.347
10801	1	300	1095	22.812000000000001	1	1095	22.812000000000001
10801	2	300	268	5.5830000000000002	1	268	5.5830000000000002
10801	3	300	563	11.728999999999999	1	563	11.728999999999999
10802	1	600	103	1.073	1	103	1.073
10802	2	300	0	0	1	0	0
10803	1	300	2291	47.728999999999999	1	2291	47.728999999999999
10803	2	300	3378	70.375	1.113	3759.538	78.323999999999998
10803	3	300	190	3.9580000000000002	1	190	3.9580000000000002
10804	1	900	202	1.403	1	202	1.403
10805	1	900	0	0	1	0	0
10806	1	300	227	4.7290000000000001	1	227	4.7290000000000001
10806	2	300	2948	61.417000000000002	1.034	3047.779	63.494999999999997
10806	3	300	3123	65.063000000000002	1.057	3300.6849999999999	68.763999999999996
10807	1	900	140	0.97199999999999998	1	140	0.97199999999999998
10808	1	900	0	0	1	0	0
10809	1	900	0	0	1	0	0
10786	1	900	0	0	1	0	0
10787	1	300	241	5.0209999999999999	1	241	5.0209999999999999
10787	2	600	123	1.2809999999999999	1	123	1.2809999999999999
10788	1	900	4	0.028000000000000001	1	4	0.028000000000000001
10789	1	630	101	1.002	1	101	1.002
10789	2	600	233	2.427	1	233	2.427
10790	1	900	20	0.13900000000000001	1	20	0.13900000000000001
10791	1	300	512	10.667	1	512	10.667
10791	2	300	1893	39.438000000000002	1	1893	39.438000000000002
10791	3	240	1766	45.990000000000002	1	1766	45.990000000000002
10792	1	600	1597	16.635000000000002	1	1597	16.635000000000002
10792	2	300	4127	85.978999999999999	1.27	5239.6400000000003	109.15900000000001
10792	3	600	150	1.5629999999999999	1	150	1.5629999999999999
10793	1	300	746	15.542	1	746	15.542
10793	2	520	0	0	1	0	0
10794	1	300	104	2.1669999999999998	1	104	2.1669999999999998
10794	2	300	1048	21.832999999999998	1	1048	21.832999999999998
10794	3	300	737	15.353999999999999	1	737	15.353999999999999
10795	1	300	505	10.521000000000001	1	505	10.521000000000001
10795	2	300	393	8.1880000000000006	1	393	8.1880000000000006
10795	3	300	124	2.5830000000000002	1	124	2.5830000000000002
10796	1	900	5	0.035000000000000003	1	5	0.035000000000000003
10797	1	900	0	0	1	0	0
10778	1	900	138	0.95799999999999996	1	138	0.95799999999999996
10779	1	300	420	8.75	1	420	8.75
10779	2	600	385	4.0099999999999998	1	385	4.0099999999999998
10780	1	300	3041	63.353999999999999	1.045	3178.4520000000002	66.218000000000004
10780	2	300	3353	69.853999999999999	1.105	3706.732	77.224000000000004
10780	3	300	1453	30.271000000000001	1	1453	30.271000000000001
10781	1	600	92	0.95799999999999996	1	92	0.95799999999999996
10781	2	300	2191	45.646000000000001	1	2191	45.646000000000001
10782	1	300	27	0.56299999999999994	1	27	0.56299999999999994
34789	1	300	0	0	1	0	0
34789	2	300	0	0	1	0	0
34789	3	300	0	0	1	0	0
34790	1	300	15.800000000000001	0.32900000000000001	1	15.800000000000001	0.32900000000000001
34790	2	300	111.59999999999999	2.3250000000000002	1	111.59999999999999	2.3250000000000002
34790	3	300	95.599999999999994	1.992	1	95.599999999999994	1.992
34791	1	300	43.200000000000003	0.90000000000000002	1	43.200000000000003	0.90000000000000002
34791	2	300	4984.3999999999996	103.842	1.396	6960.4799999999996	145.00999999999999
34791	3	300	2614.1999999999998	54.463000000000001	1.0039999	2625.1680000000001	54.691000000000003
34792	1	300	110	2.2919999999999998	1	110	2.2919999999999998
34792	2	300	0	0	1	0	0
34792	3	300	0	0	1	0	0
34793	1	300	0	0	1	0	0
34793	2	300	0	0	1	0	0
34793	3	300	0	0	1	0	0
34784	1	300	3.3999999999999999	0.070999999999999994	1	3.3999999999999999	0.070999999999999994
34784	2	300	4	0.083000000000000004	1	4	0.083000000000000004
34784	3	300	3.7999999999999998	0.079000000000000001	1	3.7999999999999998	0.079000000000000001
34785	1	300	9	0.188	1	9	0.188
34785	2	300	12.800000000000001	0.26700000000000002	1	12.800000000000001	0.26700000000000002
34785	3	300	39.600000000000001	0.82499999999999996	1	39.600000000000001	0.82499999999999996
34786	1	300	29.199999999999999	0.60799999999999998	1	29.199999999999999	0.60799999999999998
34786	2	300	16.199999999999999	0.33700000000000002	1	16.199999999999999	0.33700000000000002
34786	3	300	14.4	0.29999999999999999	1	14.4	0.29999999999999999
34787	1	300	0	0	1	0	0
34787	2	300	0	0	1	0	0
34787	3	300	0	0	1	0	0
34788	1	300	0	0	1	0	0
34788	2	300	0	0	1	0	0
34788	3	300	0	0	1	0	0
34711	1	300	0	0	1	0	0
34711	2	300	0	0	1	0	0
34711	3	300	0	0	1	0	0
34712	1	300	0	0	1	0	0
34712	2	300	0	0	1	0	0
34712	3	300	0	0	1	0	0
34713	1	300	657	13.688000000000001	1	657	13.688000000000001
34713	2	300	14.800000000000001	0.308	1	14.800000000000001	0.308
34713	3	300	1152.2	24.004000000000001	1	1152.2	24.004000000000001
34714	1	300	16	0.33300000000000002	1	16	0.33300000000000002
34714	2	300	22.399999999999999	0.46700000000000003	1	22.399999999999999	0.46700000000000003
34714	3	300	4	0.083000000000000004	1	4	0.083000000000000004
34715	1	300	16.800000000000001	0.34999999999999998	1	16.800000000000001	0.34999999999999998
34715	2	300	0	0	1	0	0
34715	3	300	0	0	1	0	0
29824	1	300	0	0	1	0	0
29824	2	300	0	0	1	0	0
29824	3	300	0	0	1	0	0
29825	1	300	433.30000000000001	9.0269999999999992	1	433.30000000000001	9.0269999999999992
29825	2	300	0	0	1	0	0
29825	3	300	39.700000000000003	0.82699999999999996	1	39.700000000000003	0.82699999999999996
29826	1	300	9.1999999999999993	0.192	1	9.1999999999999993	0.192
29826	2	300	44.200000000000003	0.92100000000000004	1	44.200000000000003	0.92100000000000004
29826	3	300	613.79999999999995	12.788	1	613.79999999999995	12.788
29827	1	300	17.699999999999999	0.36899999999999999	1	17.699999999999999	0.36899999999999999
29827	2	300	18.899999999999999	0.39400000000000002	1	18.899999999999999	0.39400000000000002
29827	3	300	14.699999999999999	0.30599999999999999	1	14.699999999999999	0.30599999999999999
29828	1	300	0	0	1	0	0
29828	2	300	0	0	1	0	0
29828	3	300	0	0	1	0	0
29819	1	300	0	0	1	0	0
29819	2	300	0	0	1	0	0
29819	3	300	0	0	1	0	0
29820	1	300	294	6.125	1	294	6.125
29820	2	300	238.59999999999999	4.9710000000000001	1	238.59999999999999	4.9710000000000001
29820	3	300	188.80000000000001	3.9329999999999998	1	188.80000000000001	3.9329999999999998
29821	1	300	0	0	1	0	0
29821	2	300	2840.4000000000001	59.174999999999997	1.022	2904.1460000000002	60.503
29821	3	300	262.60000000000002	5.4710000000000001	1	262.60000000000002	5.4710000000000001
29822	1	300	0	0	1	0	0
29822	2	300	0	0	1	0	0
29822	3	300	0	0	1	0	0
29823	1	300	0	0	1	0	0
29823	2	300	0	0	1	0	0
29823	3	300	0	0	1	0	0
29814	1	180	13.699999999999999	0.47599999999999998	1	13.699999999999999	0.47599999999999998
29815	1	180	1.8999999999999999	0.066000000000000003	1	1.8999999999999999	0.066000000000000003
12943	1	305	804	16.475000000000001	1	804	16.475000000000001
12943	2	301	276	5.7309999999999999	1	276	5.7309999999999999
12943	3	300	410	8.5419999999999998	1	410	8.5419999999999998
12944	1	300	1226	25.542000000000002	1	1226	25.542000000000002
12944	2	300	409	8.5210000000000008	1	409	8.5210000000000008
12944	3	300	1107	23.062000000000001	1	1107	23.062000000000001
12945	1	900	0	0	1	0	0
11079	1	600	2026	21.103999999999999	1	2026	21.103999999999999
11080	1	300	676	14.083	1	676	14.083
11080	2	300	877	18.271000000000001	1	877	18.271000000000001
11080	3	300	5436	113.25	1.444	7847.5129999999999	163.49000000000001
11081	1	300	3083	64.228999999999999	1.051	3240.0790000000002	67.501999999999995
11081	2	300	343	7.1459999999999999	1	343	7.1459999999999999
11081	3	300	540	11.25	1	540	11.25
11082	1	900	0	0	1	0	0
11083	1	900	0	0	1	0	0
11074	1	900	0	0	1	0	0
11075	1	180	165	5.7290000000000001	1	165	5.7290000000000001
11075	2	300	6389	133.10400000000001	1.5	9583.5	199.65600000000001
11075	3	300	359	7.4790000000000001	1	359	7.4790000000000001
11076	1	120	4836	251.875	1.38	6675.5200000000004	347.68299999999999
11076	2	120	4924	256.45800000000003	1.39	6844.1009999999997	356.464
11076	3	120	7149	372.34399999999999	1.5	10723.5	558.51599999999996
11077	1	180	9474	328.95800000000003	1.5	14211	493.43700000000001
11077	2	180	14364	498.75	1.5	21546	748.125
11077	3	180	109	3.7850000000000001	1	109	3.7850000000000001
11078	1	900	0	0	1	0	0
11069	1	900	0	0	1	0	0
11070	1	900	0	0	1	0	0
11071	1	900	20	0.13900000000000001	1	20	0.13900000000000001
11072	1	900	0	0	1	0	0
11073	1	900	0	0	1	0	0
11064	1	540	1658	19.190000000000001	1	1658	19.190000000000001
11065	1	300	10962	228.375	1.5	16443	342.56200000000001
11065	2	180	8188	284.30599999999998	1.5	12282	426.45800000000003
11065	3	180	5709	198.22900000000001	1.471	8397.7530000000006	291.589
11066	1	600	5345	55.677	1.434	7666.4139999999998	79.858000000000004
11066	2	300	994	20.707999999999998	1	994	20.707999999999998
11067	1	900	0	0	1	0	0
11068	1	900	0	0	1	0	0
11059	1	300	157	3.2709999999999999	1	157	3.2709999999999999
11059	2	300	979	20.396000000000001	1	979	20.396000000000001
11059	3	300	4464	93	1.331	5941.5929999999998	123.783
11060	1	300	4517	94.103999999999999	1.34	6054.9849999999997	126.146
11060	2	300	5202	108.375	1.419	7384.2120000000004	153.83799999999999
11060	3	300	5537	115.354	1.454	8049.8770000000004	167.70599999999999
11061	1	300	1586	33.042000000000002	1	1586	33.042000000000002
11061	2	300	1976	41.167000000000002	1	1976	41.167000000000002
11061	3	300	757	15.771000000000001	1	757	15.771000000000001
11062	1	300	1511	31.478999999999999	1	1511	31.478999999999999
11062	2	300	2466	51.375	1	2466	51.375
11062	3	300	2804	58.417000000000002	1.0190001	2857.098	59.523000000000003
11063	1	300	0	0	1	0	0
11054	1	120	12	0.625	1	12	0.625
11054	2	180	3240	112.5	1.0779999	3492.2620000000002	121.259
11054	3	180	3449	119.75700000000001	1.137	3923.0059999999999	136.21600000000001
11054	4	180	1190	41.319000000000003	1	1190	41.319000000000003
11055	1	120	8617	448.80200000000002	1.5	12925.5	673.20299999999997
11055	2	120	664	34.582999999999998	1	664	34.582999999999998
11055	3	120	63	3.2810000000000001	1	63	3.2810000000000001
11055	4	180	3209	111.42400000000001	1.072	3439.0390000000002	119.411
11055	5	120	2056	107.083	1	2056	107.083
11056	1	180	15975	554.68700000000001	1.5	23962.5	832.03099999999995
11056	2	120	8953	466.30200000000002	1.5	13429.5	699.45299999999997
11056	3	120	370	19.271000000000001	1	370	19.271000000000001
11056	4	120	9571	498.49000000000001	1.5	14356.5	747.73400000000004
11057	1	300	16012	333.58300000000003	1.5	24018	500.375
11057	2	180	6641	230.59	1.5	9961.5	345.88499999999999
11057	3	180	265	9.2010000000000005	1	265	9.2010000000000005
11057	4	180	1124	39.027999999999999	1	1124	39.027999999999999
11058	1	1500	0	0	1	0	0
11049	1	300	360	7.5	1	360	7.5
11049	2	300	1251	26.062000000000001	1	1251	26.062000000000001
11049	3	300	530	11.042	1	530	11.042
11050	1	300	932	19.417000000000002	1	932	19.417000000000002
11050	2	300	602	12.542	1	602	12.542
11050	3	300	1592	33.167000000000002	1	1592	33.167000000000002
11051	1	300	296	6.1669999999999998	1	296	6.1669999999999998
11051	2	300	207	4.3120000000000003	1	207	4.3120000000000003
11051	3	300	200	4.1669999999999998	1	200	4.1669999999999998
11052	1	300	1879	39.146000000000001	1	1879	39.146000000000001
11052	2	300	1903	39.646000000000001	1	1903	39.646000000000001
11052	3	300	1504	31.332999999999998	1	1504	31.332999999999998
11053	1	300	13	0.27100000000000002	1	13	0.27100000000000002
11053	2	600	84	0.875	1	84	0.875
11053	3	600	29	0.30199999999999999	1	29	0.30199999999999999
11043	1	300	659	13.728999999999999	1	659	13.728999999999999
11043	2	300	1639	34.146000000000001	1	1639	34.146000000000001
11043	3	300	1517	31.603999999999999	1	1517	31.603999999999999
11044	1	300	3797	79.103999999999999	1.2079999	4584.8980000000001	95.519000000000005
11044	2	300	3067	63.896000000000001	1.049	3216.3780000000002	67.007999999999996
11044	3	300	1498	31.207999999999998	1	1498	31.207999999999998
11045	1	300	69	1.4370000000000001	1	69	1.4370000000000001
11045	2	300	1136	23.667000000000002	1	1136	23.667000000000002
11045	3	300	3133	65.271000000000001	1.058	3316.1680000000001	69.087000000000003
11046	1	300	1574	32.792000000000002	1	1574	32.792000000000002
11046	2	300	776	16.167000000000002	1	776	16.167000000000002
11046	3	300	2365	49.271000000000001	1	2365	49.271000000000001
11047	1	300	418	8.7080000000000002	1	418	8.7080000000000002
11047	2	300	184	3.8330000000000002	1	184	3.8330000000000002
11047	3	300	3252	67.75	1.08	3513.4299999999998	73.195999999999998
11048	1	300	75	1.5629999999999999	1	75	1.5629999999999999
11048	2	300	98	2.0419999999999998	1	98	2.0419999999999998
11048	3	300	75	1.5629999999999999	1	75	1.5629999999999999
11038	1	300	785	16.353999999999999	1	785	16.353999999999999
11038	2	300	1555	32.396000000000001	1	1555	32.396000000000001
11038	3	300	0	0	1	0	0
11038	4	300	145	3.0209999999999999	1	145	3.0209999999999999
11039	1	300	814	16.957999999999998	1	814	16.957999999999998
11039	2	300	325	6.7709999999999999	1	325	6.7709999999999999
11039	3	300	3155	65.728999999999999	1.062	3350.7489999999998	69.807000000000002
11039	4	300	292	6.0830000000000002	1	292	6.0830000000000002
11040	1	300	7284	151.75	1.5	10926	227.625
11040	2	180	1287	44.688000000000002	1	1287	44.688000000000002
11040	3	180	2264	78.611000000000004	1	2264	78.611000000000004
11040	4	180	2468	85.694000000000003	1	2468	85.694000000000003
11041	1	300	1250	26.042000000000002	1	1250	26.042000000000002
11041	2	300	1029	21.437000000000001	1	1029	21.437000000000001
11041	3	300	17638	367.45800000000003	1.5	26457	551.18700000000001
11041	4	180	8409	291.97899999999998	1.5	12613.5	437.96899999999999
11042	1	300	7	0.14599999999999999	1	7	0.14599999999999999
11042	2	600	4	0.042000000000000003	1	4	0.042000000000000003
11042	3	600	0	0	1	0	0
11031	1	300	1620	33.75	1	1620	33.75
11031	2	300	1605	33.438000000000002	1	1605	33.438000000000002
11032	1	300	81	1.6879999999999999	1	81	1.6879999999999999
11032	2	300	5996	124.917	1.499	8987.1749999999993	187.233
11032	3	600	2023	21.073	1	2023	21.073
11033	1	300	2315	48.228999999999999	1	2315	48.228999999999999
11033	2	600	551	5.7400000000000002	1	551	5.7400000000000002
11034	1	300	771	16.062000000000001	1	771	16.062000000000001
11034	2	600	73	0.76000000000000001	1	73	0.76000000000000001
11035	1	600	7793	81.177000000000007	1.5	11689.5	121.76600000000001
11035	2	300	96	2	1	96	2
11036	1	300	3941	82.103999999999999	1.235	4866.5649999999996	101.387
11036	2	300	869	18.103999999999999	1	869	18.103999999999999
11036	3	300	3899	81.228999999999999	1.227	4783.7610000000004	99.662000000000006
11037	1	900	0	0	1	0	0
11024	1	900	234	1.625	1	234	1.625
11024	2	300	463	9.6460000000000008	1	463	9.6460000000000008
11025	1	300	433	9.0210000000000008	1	433	9.0210000000000008
11025	2	600	194	2.0209999999999999	1	194	2.0209999999999999
11026	1	900	303	2.1040000000000001	1	303	2.1040000000000001
11026	2	300	84	1.75	1	84	1.75
11027	1	300	811	16.896000000000001	1	811	16.896000000000001
11027	2	900	261	1.8129999999999999	1	261	1.8129999999999999
11028	1	300	429	8.9380000000000006	1	429	8.9380000000000006
11028	2	900	871	6.0490000000000004	1	871	6.0490000000000004
11028	3	300	2261	47.103999999999999	1	2261	47.103999999999999
11029	1	600	2054	21.396000000000001	1	2054	21.396000000000001
11029	2	300	2324	48.417000000000002	1	2324	48.417000000000002
11030	1	300	36	0.75	1	36	0.75
11030	2	600	274	2.8540000000000001	1	274	2.8540000000000001
11030	3	300	5796	120.75	1.48	8575.2559999999994	178.65100000000001
11030	4	300	3249	67.688000000000002	1.08	3508.107	73.085999999999999
11019	1	300	401	8.3539999999999992	1	401	8.3539999999999992
11019	2	300	194	4.0419999999999998	1	194	4.0419999999999998
11019	3	300	867	18.062000000000001	1	867	18.062000000000001
11020	1	300	2440	50.832999999999998	1	2440	50.832999999999998
11020	2	300	656	13.667	1	656	13.667
11020	3	300	786	16.375	1	786	16.375
11020	4	300	961	20.021000000000001	1	961	20.021000000000001
11021	1	300	1940	40.417000000000002	1	1940	40.417000000000002
11021	2	300	399	8.3130000000000006	1	399	8.3130000000000006
11021	3	300	1842	38.375	1	1842	38.375
11021	4	300	1620	33.75	1	1620	33.75
11022	1	300	1620	33.75	1	1620	33.75
11022	2	300	1532	31.917000000000002	1	1532	31.917000000000002
11022	3	300	271	5.6459999999999999	1	271	5.6459999999999999
11022	4	300	252	5.25	1	252	5.25
11023	1	1500	0	0	1	0	0
11015	1	300	110	2.2919999999999998	1	110	2.2919999999999998
11015	2	300	609	12.688000000000001	1	609	12.688000000000001
11015	3	300	1898	39.542000000000002	1	1898	39.542000000000002
11016	1	300	238	4.9580000000000002	1	238	4.9580000000000002
11016	2	300	412	8.5830000000000002	1	412	8.5830000000000002
11016	3	300	1165	24.271000000000001	1	1165	24.271000000000001
11017	1	300	4089	85.188000000000002	1.263	5162.5799999999999	107.554
11017	2	300	2193	45.688000000000002	1	2193	45.688000000000002
11017	3	300	1373	28.603999999999999	1	1373	28.603999999999999
11018	1	300	219	4.5620000000000003	1	219	4.5620000000000003
11018	2	600	424	4.4169999999999998	1	424	4.4169999999999998
11018	3	1200	1175	6.1200000000000001	1	1175	6.1200000000000001
11010	1	300	295	6.1459999999999999	1	295	6.1459999999999999
11010	2	300	747	15.563000000000001	1	747	15.563000000000001
11010	3	300	434	9.0419999999999998	1	434	9.0419999999999998
11011	1	300	1289	26.853999999999999	1	1289	26.853999999999999
11011	2	300	1800	37.5	1	1800	37.5
11011	3	300	722	15.042	1	722	15.042
11012	1	300	4327	90.146000000000001	1.306	5652.2359999999999	117.755
11012	2	300	1152	24	1	1152	24
11012	3	300	2859	59.563000000000002	1.024	2928.4789999999998	61.009999999999998
11013	1	300	699	14.563000000000001	1	699	14.563000000000001
11013	2	300	2003	41.728999999999999	1	2003	41.728999999999999
11013	3	300	1005	20.937000000000001	1	1005	20.937000000000001
11014	1	300	742	15.458	1	742	15.458
11014	2	300	460	9.5830000000000002	1	460	9.5830000000000002
12930	2	300	481	10.021000000000001	1	481	10.021000000000001
12930	3	300	373	7.7709999999999999	1	373	7.7709999999999999
12919	1	307	295	6.0060000000000002	1	295	6.0060000000000002
12919	2	300	159	3.3130000000000002	1	159	3.3130000000000002
12919	3	300	345	7.1870000000000003	1	345	7.1870000000000003
12920	1	300	166	3.4580000000000002	1	166	3.4580000000000002
12920	2	300	69	1.4370000000000001	1	69	1.4370000000000001
12920	3	302	384	7.9470000000000001	1	384	7.9470000000000001
12921	1	300	1419	29.562000000000001	1	1419	29.562000000000001
12921	2	300	402	8.375	1	402	8.375
12921	3	300	1419	29.562000000000001	1	1419	29.562000000000001
12922	1	301	1677	34.820999999999998	1	1677	34.820999999999998
12922	2	300	1424	29.667000000000002	1	1424	29.667000000000002
12922	3	300	1968	41	1	1968	41
12923	1	302	926	19.164000000000001	1	926	19.164000000000001
12923	2	300	719	14.978999999999999	1	719	14.978999999999999
12923	3	302	974	20.157	1	974	20.157
12924	1	300	402	8.375	1	402	8.375
12924	2	300	350	7.2919999999999998	1	350	7.2919999999999998
12924	3	300	341	7.1040000000000001	1	341	7.1040000000000001
12913	1	180	1046	36.319000000000003	1	1046	36.319000000000003
12913	2	181	1220	42.127000000000002	1	1220	42.127000000000002
12913	3	300	1102	22.957999999999998	1	1102	22.957999999999998
12914	1	180	3055	106.07599999999999	1.0470001	3198.7869999999998	111.069
12914	2	180	1273	44.201000000000001	1	1273	44.201000000000001
12914	3	183	886	30.260000000000002	1	886	30.260000000000002
12915	1	180	1141	39.618000000000002	1	1141	39.618000000000002
12915	2	180	888	30.832999999999998	1	888	30.832999999999998
12915	3	181	1088	37.569000000000003	1	1088	37.569000000000003
12916	1	181	968	33.424999999999997	1	968	33.424999999999997
12916	2	180	1808	62.777999999999999	1	1808	62.777999999999999
12916	3	181	991	34.219999999999999	1	991	34.219999999999999
12917	1	180	2078	72.153000000000006	1	2078	72.153000000000006
12917	2	186	753	25.302	1	753	25.302
12917	3	183	870	29.713000000000001	1	870	29.713000000000001
12918	1	180	791	27.465	1	791	27.465
12918	2	180	668	23.193999999999999	1	668	23.193999999999999
12918	3	180	976	33.889000000000003	1	976	33.889000000000003
12908	1	180	2071	71.909999999999997	1	2071	71.909999999999997
12908	2	180	973	33.784999999999997	1	973	33.784999999999997
12908	3	300	1811	37.728999999999999	1	1811	37.728999999999999
12909	1	180	1226	42.569000000000003	1	1226	42.569000000000003
12909	2	182	2400	82.418000000000006	1	2400	82.418000000000006
12909	3	181	2403	82.977000000000004	1	2403	82.977000000000004
12910	1	180	3149	109.34	1.061	3341.2449999999999	116.015
12910	2	180	844	29.306000000000001	1	844	29.306000000000001
12910	3	180	3164	109.861	1.064	3365.1129999999998	116.84399999999999
12911	1	300	1579	32.896000000000001	1	1579	32.896000000000001
12911	2	300	2222	46.292000000000002	1	2222	46.292000000000002
12911	3	300	1168	24.332999999999998	1	1168	24.332999999999998
12912	1	180	987	34.271000000000001	1	987	34.271000000000001
12912	2	182	937	32.177	1	937	32.177
12912	3	182	684	23.489000000000001	1	684	23.489000000000001
12902	1	180	2912	101.111	1.03	2998.9259999999999	104.129
12902	2	182	2300	78.983999999999995	1	2300	78.983999999999995
12902	3	180	765	26.562000000000001	1	765	26.562000000000001
12903	1	180	2650	92.013999999999996	1.006	2666.9560000000001	92.602999999999994
12903	2	180	1017	35.313000000000002	1	1017	35.313000000000002
12903	3	183	1361	46.481999999999999	1	1361	46.481999999999999
12904	1	180	0	0	1	0	0
12904	2	183	0	0	1	0	0
12904	3	180	46	1.597	1	46	1.597
12905	1	182	1155	39.662999999999997	1	1155	39.662999999999997
12905	2	187	954	31.885000000000002	1	954	31.885000000000002
12905	3	180	624	21.667000000000002	1	624	21.667000000000002
12906	1	306	2504	51.143999999999998	1	2504.127	51.146000000000001
12906	2	180	1198	41.597000000000001	1	1198	41.597000000000001
12906	3	186	801	26.914999999999999	1	801	26.914999999999999
12907	1	300	1227	25.562000000000001	1	1227	25.562000000000001
12907	2	300	930	19.375	1	930	19.375
12907	3	300	551	11.478999999999999	1	551	11.478999999999999
10918	1	300	4754	99.042000000000002	1.3710001	6519.4870000000001	135.82300000000001
10918	2	300	3288	68.5	1.089	3579.0369999999998	74.563000000000002
10918	3	300	1447	30.146000000000001	1	1447	30.146000000000001
10919	1	180	1188	41.25	1	1188	41.25
10919	2	300	1142	23.792000000000002	1	1142	23.792000000000002
10919	3	300	3445	71.771000000000001	1.136	3913.2089999999998	81.525000000000006
10920	1	300	5690	118.542	1.469	8359.125	174.148
10920	2	300	2919	60.813000000000002	1.031	3008.3589999999999	62.673999999999999
10920	3	300	6538	136.208	1.5	9807	204.31200000000001
10921	1	300	66	1.375	1	66	1.375
10921	2	600	618	6.4370000000000003	1	618	6.4370000000000003
10922	1	300	971	20.228999999999999	1	971	20.228999999999999
10922	2	300	409	8.5210000000000008	1	409	8.5210000000000008
10922	3	300	766	15.958	1	766	15.958
10913	1	180	4541	157.67400000000001	1.345	6106.5969999999998	212.035
10913	2	360	66	1.1459999999999999	1	66	1.1459999999999999
10914	1	180	3879	134.68700000000001	1.223	4744.5190000000002	164.74000000000001
10914	2	180	5606	194.65299999999999	1.461	8188.942	284.33800000000002
10914	3	180	71	2.4649999999999999	1	71	2.4649999999999999
10915	1	180	6948	241.25	1.5	10422	361.875
10915	2	180	5919	205.52099999999999	1.4910001	8827.9529999999995	306.52600000000001
10915	3	180	7812	271.25	1.5	11718	406.875
10916	1	300	6231	129.81200000000001	1.5	9346.5	194.71899999999999
10916	2	360	94	1.6319999999999999	1	94	1.6319999999999999
10917	1	300	891	18.562000000000001	1	891	18.562000000000001
10917	2	300	43	0.89600000000000002	1	43	0.89600000000000002
10917	3	300	118	2.4580000000000002	1	118	2.4580000000000002
10908	1	900	6	0.042000000000000003	1	6	0.042000000000000003
10909	1	900	4961	34.451000000000001	1.3940001	6915.3280000000004	48.023000000000003
10910	1	900	62	0.43099999999999999	1	62	0.43099999999999999
10911	1	900	0	0	1	0	0
10912	1	900	176	1.222	1	176	1.222
10903	1	300	38	0.79200000000000004	1	38	0.79200000000000004
10903	2	600	1301	13.552	1	1301	13.552
10904	1	300	135	2.8130000000000002	1	135	2.8130000000000002
10904	2	600	2046	21.312000000000001	1	2046	21.312000000000001
10905	1	300	1569	32.688000000000002	1	1569	32.688000000000002
10905	2	300	3685	76.771000000000001	1.186	4370.2129999999997	91.046000000000006
10905	3	300	5617	117.021	1.462	8211.1730000000007	171.066
10906	1	300	4174	86.957999999999998	1.278	5335.5420000000004	111.157
10906	2	300	3315	69.063000000000002	1.095	3630.5210000000002	75.635999999999996
10906	3	300	143	2.9790000000000001	1	143	2.9790000000000001
10907	1	900	123	0.85399999999999998	1	123	0.85399999999999998
10898	1	900	17	0.11799999999999999	1	17	0.11799999999999999
10899	1	600	106	1.1040000000000001	1	106	1.1040000000000001
10899	2	300	157	3.2709999999999999	1	157	3.2709999999999999
10900	1	900	86	0.59699999999999998	1	86	0.59699999999999998
10901	1	900	52	0.36099999999999999	1	52	0.36099999999999999
10902	1	900	0	0	1	0	0
10893	1	300	8034	167.375	1.5	12051	251.06200000000001
10893	2	300	9886	205.958	1.5	14829	308.93700000000001
10893	3	180	3827	132.88200000000001	1.2130001	4643.058	161.21700000000001
10894	1	300	6719	139.97900000000001	1.5	10078.5	209.96899999999999
10894	2	300	13985	291.35399999999998	1.5	20977.5	437.03100000000001
10894	3	180	6303	218.85400000000001	1.5	9454.5	328.28100000000001
10895	1	300	4671	97.313000000000002	1.362	6362.5969999999998	132.554
10895	2	300	1694	35.292000000000002	1	1694	35.292000000000002
10895	3	300	5406	112.625	1.441	7787.6809999999996	162.24299999999999
10896	1	300	3934	81.957999999999998	1.234	4852.7269999999999	101.098
10896	2	300	3867	80.563000000000002	1.221	4721.0320000000002	98.355000000000004
10896	3	300	534	11.125	1	534	11.125
10897	1	900	0	0	1	0	0
10889	1	180	781	27.117999999999999	1	781	27.117999999999999
10889	2	180	8831	306.63200000000001	1.5	13246.5	459.94799999999998
10889	3	180	6094	211.59700000000001	1.5	9141	317.39600000000002
10890	1	180	652	22.638999999999999	1	652	22.638999999999999
10890	2	180	857	29.757000000000001	1	857	29.757000000000001
10890	3	180	859	29.826000000000001	1	859	29.826000000000001
10891	1	180	694	24.097000000000001	1	694	24.097000000000001
10891	2	180	537	18.646000000000001	1	537	18.646000000000001
10891	3	180	188	6.5279999999999996	1	188	6.5279999999999996
10892	1	540	0	0	1	0	0
10883	1	180	396	13.75	1	396	13.75
10883	2	180	115	3.9929999999999999	1	115	3.9929999999999999
10883	3	180	86	2.9860000000000002	1	86	2.9860000000000002
10884	1	180	13004	451.52800000000002	1.5	19506	677.29200000000003
10884	2	180	108	3.75	1	108	3.75
10884	3	180	7154	248.40299999999999	1.5	10731	372.60399999999998
10885	1	180	11772	408.75	1.5	17658	613.125
10885	2	180	1062	36.875	1	1062	36.875
10885	3	180	250	8.6809999999999992	1	250	8.6809999999999992
10886	1	180	7510	260.76400000000001	1.5	11265	391.14600000000002
10886	2	180	1536	53.332999999999998	1	1536	53.332999999999998
10886	3	180	2554	88.680999999999997	1.001	2557.4830000000002	88.801000000000002
10887	1	180	247	8.5760000000000005	1	247	8.5760000000000005
10888	1	180	21	0.72899999999999998	1	21	0.72899999999999998
10888	2	360	13	0.22600000000000001	1	13	0.22600000000000001
10878	1	300	277	5.7709999999999999	1	277	5.7709999999999999
10878	2	300	67	1.3959999999999999	1	67	1.3959999999999999
10878	3	300	1020	21.25	1	1020	21.25
10879	1	300	73	1.5209999999999999	1	73	1.5209999999999999
10879	2	300	1614	33.625	1	1614	33.625
10879	3	300	0	0	1	0	0
10880	1	300	447	9.3130000000000006	1	447	9.3130000000000006
10880	2	300	2340	48.75	1	2340	48.75
10880	3	300	747	15.563000000000001	1	747	15.563000000000001
10881	1	300	83	1.7290000000000001	1	83	1.7290000000000001
10881	2	300	336	7	1	336	7
10881	3	300	192	4	1	192	4
10882	1	900	2	0.014	1	2	0.014
10873	1	300	2382	49.625	1	2382	49.625
10873	2	300	296	6.1669999999999998	1	296	6.1669999999999998
10873	3	300	287	5.9790000000000001	1	287	5.9790000000000001
10874	1	300	443	9.2289999999999992	1	443	9.2289999999999992
10874	2	300	1202	25.042000000000002	1	1202	25.042000000000002
10874	3	300	758	15.792	1	758	15.792
10875	1	300	59	1.2290000000000001	1	59	1.2290000000000001
10875	2	300	147	3.0630000000000002	1	147	3.0630000000000002
10875	3	300	757	15.771000000000001	1	757	15.771000000000001
10876	1	600	1507	15.698	1	1507	15.698
10876	2	300	537	11.188000000000001	1	537	11.188000000000001
10876	3	300	86	1.792	1	86	1.792
10877	1	1200	22	0.115	1	22	0.115
10923	1	300	40	0.83299999999999996	1	40	0.83299999999999996
10923	2	300	157	3.2709999999999999	1	157	3.2709999999999999
10923	3	300	187	3.8959999999999999	1	187	3.8959999999999999
10924	1	300	1861	38.771000000000001	1	1861	38.771000000000001
10924	2	300	376	7.8330000000000002	1	376	7.8330000000000002
10924	3	300	2289	47.688000000000002	1	2289	47.688000000000002
10925	1	300	1241	25.853999999999999	1	1241	25.853999999999999
10925	2	300	1039	21.646000000000001	1	1039	21.646000000000001
10925	3	300	601	12.521000000000001	1	601	12.521000000000001
34857	2	180	770.79999999999995	26.763999999999999	1	770.79999999999995	26.763999999999999
34857	3	180	3751.1999999999998	130.25	1.199	4496.6400000000003	156.13300000000001
34858	1	180	86	2.9860000000000002	1	86	2.9860000000000002
34858	2	180	116	4.0279999999999996	1	116	4.0279999999999996
34858	3	180	384	13.333	1	384	13.333
34853	1	180	877.20000000000005	30.457999999999998	1	877.20000000000005	30.457999999999998
34853	2	180	2359.4000000000001	81.924000000000007	1	2359.4000000000001	81.924000000000007
34853	3	180	501.60000000000002	17.417000000000002	1	501.60000000000002	17.417000000000002
34852	1	180	8824.2000000000007	306.39600000000002	1.5	13236.299999999999	459.59399999999999
34852	2	180	2456.8000000000002	85.305999999999997	1	2456.8000000000002	85.305999999999997
34852	3	180	456.60000000000002	15.853999999999999	1	456.60000000000002	15.853999999999999
34851	1	180	5938.3999999999996	206.19399999999999	1.493	8867.9940000000006	307.916
34851	2	180	3589.4000000000001	124.63200000000001	1.1670001	4190.04	145.488
34851	3	180	4635.8000000000002	160.965	1.362	6312.067	219.16900000000001
34850	1	180	14377.6	499.22199999999998	1.5	21566.400000000001	748.83299999999997
34850	2	180	2590.5999999999999	89.950999999999993	1.003	2598.2240000000002	90.215999999999994
34850	3	180	0	0	1	0	0
34849	1	180	0	0	1	0	0
34849	2	180	0	0	1	0	0
34849	3	180	0	0	1	0	0
34746	1	300	6824	142.167	1.5	10236	213.25
34746	2	300	2801	58.353999999999999	1.0190001	2853.2539999999999	59.442999999999998
34746	3	300	1703.8	35.496000000000002	1	1703.8	35.496000000000002
34747	1	300	792	16.5	1	792	16.5
34747	2	300	1235	25.728999999999999	1	1235	25.728999999999999
34747	3	300	1091.2	22.733000000000001	1	1091.2	22.733000000000001
34748	1	300	2657.8000000000002	55.371000000000002	1.007	2676.1970000000001	55.753999999999998
34748	2	300	1372	28.582999999999998	1	1372	28.582999999999998
34748	3	300	1475	30.728999999999999	1	1475	30.728999999999999
34749	1	300	2406	50.125	1	2406	50.125
34749	2	300	3094	64.457999999999998	1.053	3256.5450000000001	67.844999999999999
34749	3	300	343500	7156.25	1.5	515250	10734.375
34750	1	300	362.19999999999999	7.5460000000000003	1	362.19999999999999	7.5460000000000003
34750	2	300	258.80000000000001	5.3920000000000003	1	258.80000000000001	5.3920000000000003
34750	3	300	89	1.8540000000000001	1	89	1.8540000000000001
29929	1	300	3041.1999999999998	63.357999999999997	1.045	3178.7420000000002	66.224000000000004
29929	2	300	3790.5999999999999	78.971000000000004	1.206	4572.527	95.260999999999996
29929	3	300	1027	21.396000000000001	1	1027	21.396000000000001
29930	1	300	2876.8000000000002	59.933	1.026	2951.9520000000002	61.499000000000002
29930	2	300	1625.4000000000001	33.863	1	1625.4000000000001	33.863
29930	3	300	4821	100.438	1.3789999	6646.9009999999998	138.477
29931	1	300	2750.8000000000002	57.308	1.0140001	2789.71	58.119
29931	2	300	2611	54.396000000000001	1.0039999	2621.4850000000001	54.613999999999997
29931	3	300	1636.4000000000001	34.091999999999999	1	1636.4000000000001	34.091999999999999
29932	1	300	8071.6000000000004	168.15799999999999	1.5	12107.4	252.238
29932	2	300	3277.8000000000002	68.287999999999997	1.086	3560.1120000000001	74.168999999999997
29932	3	300	6929.8000000000002	144.37100000000001	1.5	10394.700000000001	216.55600000000001
29933	1	300	1997.4000000000001	41.613	1	1997.4000000000001	41.613
29933	2	300	818	17.042000000000002	1	818	17.042000000000002
29933	3	300	1994.5999999999999	41.554000000000002	1	1994.5999999999999	41.554000000000002
29924	1	300	631.29999999999995	13.151999999999999	1	631.29999999999995	13.151999999999999
29924	2	300	1026.5999999999999	21.388000000000002	1	1026.5999999999999	21.388000000000002
29924	3	300	1002	20.875	1	1002	20.875
29925	1	300	6916	144.083	1.5	10374	216.125
29925	2	300	195.90000000000001	4.0810000000000004	1	195.90000000000001	4.0810000000000004
29925	3	300	1714.4000000000001	35.716999999999999	1	1714.4000000000001	35.716999999999999
29926	1	300	15012	312.75	1.5	22518	469.125
29926	2	300	5996	124.917	1.499	8987.1749999999993	187.233
29926	3	300	10961.6	228.36699999999999	1.5	16442.400000000001	342.55000000000001
29927	1	300	32.399999999999999	0.67500000000000004	1	32.399999999999999	0.67500000000000004
29927	2	300	193.5	4.0309999999999997	1	193.5	4.0309999999999997
29927	3	300	3292.4000000000001	68.591999999999999	1.09	3587.2869999999998	74.734999999999999
29928	1	300	2959.4000000000001	61.654000000000003	1.035	3063.4319999999998	63.820999999999998
29928	2	300	36.700000000000003	0.76500000000000001	1	36.700000000000003	0.76500000000000001
29928	3	300	3334	69.457999999999998	1.1	3668.047	76.418000000000006
27612	1	300	2132	44.417000000000002	1	2132	44.417000000000002
27612	2	300	1038.8	21.641999999999999	1	1038.8	21.641999999999999
27612	3	300	1425.5999999999999	29.699999999999999	1	1425.5999999999999	29.699999999999999
27613	1	300	1886	39.292000000000002	1	1886	39.292000000000002
27613	2	300	1357.4000000000001	28.279	1	1357.4000000000001	28.279
27613	3	300	2036.8	42.433	1	2036.8	42.433
27614	1	300	3296.8000000000002	68.683000000000007	1.091	3595.5900000000001	74.908000000000001
27614	2	300	3322.4000000000001	69.216999999999999	1.097	3645.0030000000002	75.938000000000002
27614	3	300	919.60000000000002	19.158000000000001	1	919.60000000000002	19.158000000000001
27615	1	300	7867	163.89599999999999	1.5	11800.5	245.84399999999999
27615	2	300	792	16.5	1	792	16.5
27615	3	300	12.4	0.25800000000000001	1	12.4	0.25800000000000001
27616	1	900	0	0	1	0	0
34406	1	300	3165	65.938000000000002	1.064	3366.7170000000001	70.140000000000001
34406	2	300	2854.1999999999998	59.463000000000001	1.024	2922.1799999999998	60.878999999999998
34406	3	300	2900.8000000000002	60.433	1.029	2983.8980000000001	62.164999999999999
34405	1	300	93	1.9379999999999999	1	93	1.9379999999999999
34405	2	300	1869.4000000000001	38.945999999999998	1	1869.4000000000001	38.945999999999998
34405	3	300	5445.1999999999998	113.44199999999999	1.4450001	7865.8869999999997	163.87299999999999
34404	1	300	3108	64.75	1.0549999	3277.7179999999998	68.286000000000001
34404	2	300	3046.4000000000001	63.466999999999999	1.046	3186.2730000000001	66.381
34404	3	300	3303	68.813000000000002	1.092	3607.3820000000001	75.153999999999996
34403	1	300	7381	153.77099999999999	1.5	11071.5	230.65600000000001
34403	2	300	4576.1999999999998	95.337000000000003	1.351	6182.5919999999996	128.804
34403	3	300	4733.3999999999996	98.611999999999995	1.369	6480.4489999999996	135.00899999999999
34402	1	300	31	0.64600000000000002	1	31	0.64600000000000002
34402	2	300	27.399999999999999	0.57099999999999995	1	27.399999999999999	0.57099999999999995
34402	3	300	0	0	1	0	0
27606	1	300	4875.3999999999996	101.571	1.385	6750.8549999999996	140.643
27606	2	300	2186.4000000000001	45.549999999999997	1	2186.4000000000001	45.549999999999997
27606	3	300	6330	131.875	1.5	9495	197.81200000000001
27605	1	300	0	0	1	0	0
27604	1	300	7543	157.14599999999999	1.5	11314.5	235.71899999999999
27604	2	300	10243.799999999999	213.41300000000001	1.5	15365.700000000001	320.11900000000003
27604	3	300	14846	309.29199999999997	1.5	22269	463.93700000000001
27603	1	300	1724	35.917000000000002	1	1724	35.917000000000002
27603	2	300	25437	529.93700000000001	1.5	38155.5	794.90599999999995
27603	3	300	22121	460.85399999999998	1.5	33181.5	691.28099999999995
27602	1	300	3922	81.707999999999998	1.2309999	4829.04	100.605
27602	2	0	10479	\N	1.5	15718.5	\N
27602	3	300	6544	136.333	1.5	9816	204.5
27601	1	300	1563.2	32.567	1	1563.2	32.567
27601	2	300	1129	23.521000000000001	1	1129	23.521000000000001
27601	3	300	2560.1999999999998	53.338000000000001	1.002	2564.29	53.423000000000002
27595	1	300	3751.5999999999999	78.158000000000001	1.199	4497.4080000000004	93.695999999999998
27595	2	300	3860.5999999999999	80.429000000000002	1.22	4708.5230000000001	98.093999999999994
27595	3	300	5007.8000000000002	104.32899999999999	1.399	7005.7129999999997	145.952
27594	1	300	4524.8000000000002	94.266999999999996	1.342	6071.741	126.495
27594	2	300	5796.8000000000002	120.767	1.48	8576.893	178.685
27594	3	300	2861.8000000000002	59.621000000000002	1.025	2932.1590000000001	61.087000000000003
27593	1	300	1149	23.937000000000001	1	1149	23.937000000000001
27593	2	300	1457.8	30.370999999999999	1	1457.8	30.370999999999999
27593	3	300	7931.3999999999996	165.23699999999999	1.5	11897.1	247.85599999999999
27592	1	300	4328.6000000000004	90.179000000000002	1.307	5655.5839999999998	117.825
27592	2	300	7790.1999999999998	162.29599999999999	1.5	11685.299999999999	243.44399999999999
27592	3	300	19037.200000000001	396.608	1.5	28555.799999999999	594.91300000000001
27591	1	900	0	0	1	0	0
27590	1	300	503.80000000000001	10.496	1	503.80000000000001	10.496
27590	2	300	499.60000000000002	10.407999999999999	1	499.60000000000002	10.407999999999999
27590	3	300	957	19.937000000000001	1	957	19.937000000000001
27587	1	300	4117.3999999999996	85.778999999999996	1.268	5220.1319999999996	108.753
27587	2	300	4105.6000000000004	85.533000000000001	1.266	5196.1899999999996	108.254
27587	3	300	4269.8000000000002	88.953999999999994	1.296	5533.0349999999999	115.27200000000001
27589	1	300	1382	28.792000000000002	1	1382	28.792000000000002
27589	2	300	3273.8000000000002	68.203999999999994	1.085	3552.7660000000001	74.016000000000005
27589	3	300	4275.3999999999996	89.070999999999998	1.2970001	5544.6629999999996	115.514
27588	1	300	2847.8000000000002	59.329000000000001	1.023	2913.8029999999999	60.704000000000001
27588	2	300	3980.5999999999999	82.929000000000002	1.242	4945.125	103.023
27588	3	300	2821.4000000000001	58.779000000000003	1.021	2879.4940000000001	59.988999999999997
27586	1	900	0	0	1	0	0
24721	1	300	4573	95.271000000000001	1.35	6175.6679999999997	128.66
24721	2	300	3546.1999999999998	73.879000000000005	1.159	4109.5609999999997	85.616
24721	3	300	5321.8000000000002	110.871	1.432	7620.4309999999996	158.75899999999999
24722	1	300	832.79999999999995	17.350000000000001	1	832.79999999999995	17.350000000000001
24722	2	300	73.200000000000003	1.5249999999999999	1	73.200000000000003	1.5249999999999999
24722	3	300	133.40000000000001	2.7789999999999999	1	133.40000000000001	2.7789999999999999
24723	1	900	0	0	1	0	0
24724	1	300	426.39999999999998	8.8829999999999991	1	426.39999999999998	8.8829999999999991
24724	2	300	213.19999999999999	4.4420000000000002	1	213.19999999999999	4.4420000000000002
24724	3	300	129.19999999999999	2.6920000000000002	1	129.19999999999999	2.6920000000000002
24725	1	300	4621	96.271000000000001	1.359	6279.8220000000001	130.83000000000001
24725	2	300	584.60000000000002	12.179	1	584.60000000000002	12.179
24725	3	300	2026.5999999999999	42.220999999999997	1	2026.5999999999999	42.220999999999997
24726	1	900	0	0	1	0	0
24705	1	300	4257.1999999999998	88.691999999999993	1.294	5506.9070000000002	114.727
24705	2	300	4677.1999999999998	97.441999999999993	1.363	6374.2799999999997	132.797
24705	3	300	4752.1999999999998	99.004000000000005	1.3710001	6516.0730000000003	135.75200000000001
24704	1	300	3660.1999999999998	76.254000000000005	1.181	4323.1999999999998	90.066999999999993
24704	2	300	565.60000000000002	11.782999999999999	1	565.60000000000002	11.782999999999999
24704	3	300	767.60000000000002	15.992000000000001	1	767.60000000000002	15.992000000000001
24703	1	300	6812	141.917	1.5	10218	212.875
24703	2	300	2175.4000000000001	45.320999999999998	1	2175.4000000000001	45.320999999999998
24703	3	300	5190	108.125	1.418	7360.665	153.34700000000001
24702	1	300	2801	58.353999999999999	1.0190001	2853.2539999999999	59.442999999999998
24702	2	300	8479.2000000000007	176.65000000000001	1.5	12718.799999999999	264.97500000000002
24702	3	300	2627	54.728999999999999	1.005	2639.9870000000001	55
24701	1	300	59.780000000000001	1.2450000000000001	1	59.780000000000001	1.2450000000000001
24701	2	300	0	0	1	0	0
24701	3	300	0	0	1	0	0
24685	1	300	1040.5999999999999	21.678999999999998	1	1040.5999999999999	21.678999999999998
24685	2	300	9053.3999999999996	188.61199999999999	1.5	13580.1	282.91899999999998
24685	3	300	530.60000000000002	11.054	1	530.60000000000002	11.054
24684	1	300	6189.6000000000004	128.94999999999999	1.5	9284.3999999999996	193.42500000000001
24684	2	300	973.79999999999995	20.286999999999999	1	973.79999999999995	20.286999999999999
24684	3	300	12707.799999999999	264.74599999999998	1.5	19061.700000000001	397.11900000000003
24683	1	300	1800.8	37.517000000000003	1	1800.8	37.517000000000003
24683	2	300	884	18.417000000000002	1	884	18.417000000000002
24683	3	300	4879.1999999999998	101.65000000000001	1.385	6758.1329999999998	140.79400000000001
24682	1	300	2960	61.667000000000002	1.035	3064.2579999999998	63.838999999999999
24682	2	300	7903.3999999999996	164.654	1.5	11855.1	246.98099999999999
24682	3	300	10604.200000000001	220.92099999999999	1.5	15906.299999999999	331.38099999999997
24681	1	900	0	0	1	0	0
24090	1	900	17649.900000000001	122.569	1.5	26474.849999999999	183.85300000000001
24089	1	900	4142.6000000000004	28.768000000000001	1.272	5271.3990000000003	36.606999999999999
24088	1	900	14516.1	100.806	1.5	21774.150000000001	151.209
24087	1	900	25371.599999999999	176.19200000000001	1.5	38057.400000000001	264.28699999999998
24086	1	900	3.6499999999999999	0.025000000000000001	1	3.6499999999999999	0.025000000000000001
24085	1	900	8734.2999999999993	60.655000000000001	1.5	13101.450000000001	90.981999999999999
24084	1	900	13244.25	91.974000000000004	1.5	19866.375	137.96100000000001
10756	1	900	6	0.042000000000000003	1	6	0.042000000000000003
10757	1	900	0	0	1	0	0
10758	1	900	0	0	1	0	0
10749	1	900	340	2.3610000000000002	1	340	2.3610000000000002
10750	1	900	646	4.4859999999999998	1	646	4.4859999999999998
10751	1	900	253	1.7569999999999999	1	253	1.7569999999999999
10752	1	600	35	0.36499999999999999	1	35	0.36499999999999999
10752	2	300	1000	20.832999999999998	1	1000	20.832999999999998
10753	1	900	0	0	1	0	0
10744	1	900	1080	7.5	1	1080	7.5
10745	1	300	4038	84.125	1.253	5059.8339999999998	105.413
10745	2	300	644	13.417	1	644	13.417
10745	3	300	1768	36.832999999999998	1	1768	36.832999999999998
10746	1	900	42	0.29199999999999998	1	42	0.29199999999999998
10747	1	300	198	4.125	1	198	4.125
10747	2	600	197	2.052	1	197	2.052
10748	1	900	0	0	1	0	0
10740	1	600	184	1.917	1	184	1.917
10740	2	600	467	4.8650000000000002	1	467	4.8650000000000002
10741	1	900	1302	9.0419999999999998	1	1302	9.0419999999999998
10741	2	300	436	9.0830000000000002	1	436	9.0830000000000002
10742	1	900	0	0	1	0	0
10743	1	900	0	0	1	0	0
10735	1	300	110	2.2919999999999998	1	110	2.2919999999999998
10735	2	300	2511	52.313000000000002	1	2511.424	52.320999999999998
10735	3	300	145	3.0209999999999999	1	145	3.0209999999999999
10736	1	300	2694	56.125	1.01	2719.6799999999998	56.659999999999997
10736	2	300	1359	28.312000000000001	1	1359	28.312000000000001
10736	3	300	280	5.8330000000000002	1	280	5.8330000000000002
10737	1	300	2352	49	1	2352	49
10737	2	300	7222	150.458	1.5	10833	225.68700000000001
10737	3	300	5053	105.271	1.404	7093.3149999999996	147.77699999999999
10738	1	300	33	0.68799999999999994	1	33	0.68799999999999994
10738	2	600	61	0.63500000000000001	1	61	0.63500000000000001
10739	1	900	0	0	1	0	0
10731	1	900	1420	9.8610000000000007	1	1420	9.8610000000000007
10731	2	600	1354	14.103999999999999	1	1354	14.103999999999999
10731	3	300	734	15.292	1	734	15.292
10732	1	1500	0	0	1	0	0
10733	1	300	722	15.042	1	722	15.042
10733	2	300	1263	26.312000000000001	1	1263	26.312000000000001
10733	3	300	85	1.7709999999999999	1	85	1.7709999999999999
10734	1	1500	0	0	1	0	0
10727	1	300	110	2.2919999999999998	1	110	2.2919999999999998
10727	2	300	1615	33.646000000000001	1	1615	33.646000000000001
10727	3	300	292	6.0830000000000002	1	292	6.0830000000000002
10727	4	300	361	7.5209999999999999	1	361	7.5209999999999999
10728	1	300	31	0.64600000000000002	1	31	0.64600000000000002
10728	2	300	438	9.125	1	438	9.125
10728	3	300	351	7.3120000000000003	1	351	7.3120000000000003
10728	4	300	53	1.1040000000000001	1	53	1.1040000000000001
10729	1	300	11	0.22900000000000001	1	11	0.22900000000000001
10730	1	1500	0	0	1	0	0
10722	1	300	408	8.5	1	408	8.5
10722	2	300	79	1.6459999999999999	1	79	1.6459999999999999
10722	3	300	708	14.75	1	708	14.75
10723	1	300	253	5.2709999999999999	1	253	5.2709999999999999
10723	2	300	1253	26.103999999999999	1	1253	26.103999999999999
10723	3	300	153	3.1880000000000002	1	153	3.1880000000000002
10723	4	300	274	5.7080000000000002	1	274	5.7080000000000002
10724	1	900	136	0.94399999999999995	1	136	0.94399999999999995
10724	2	600	72	0.75	1	72	0.75
10725	1	900	59	0.40999999999999998	1	59	0.40999999999999998
10725	2	600	42	0.438	1	42	0.438
10726	1	1500	0	0	1	0	0
10717	1	300	1057	22.021000000000001	1	1057	22.021000000000001
10717	2	300	798	16.625	1	798	16.625
10717	3	600	3546	36.938000000000002	1.159	4109.1899999999996	42.804000000000002
10717	4	300	2315	48.228999999999999	1	2315	48.228999999999999
10718	1	0	0	\N	1	0	\N
10718	2	0	0	\N	1	0	\N
10719	1	600	38	0.39600000000000002	1	38	0.39600000000000002
10719	2	300	92	1.917	1	92	1.917
10719	3	300	227	4.7290000000000001	1	227	4.7290000000000001
10720	1	1500	18	0.074999999999999997	1	18	0.074999999999999997
10721	1	900	0	0	1	0	0
10713	1	300	1788	37.25	1	1788	37.25
10713	2	300	1879	39.146000000000001	1	1879	39.146000000000001
10713	3	300	492	10.25	1	492	10.25
10713	4	300	291	6.0620000000000003	1	291	6.0620000000000003
10714	1	300	142	2.9580000000000002	1	142	2.9580000000000002
10714	2	300	199	4.1459999999999999	1	199	4.1459999999999999
10714	3	300	1343	27.978999999999999	1	1343	27.978999999999999
10714	4	300	1228	25.582999999999998	1	1228	25.582999999999998
10715	1	900	356	2.472	1	356	2.472
10715	2	300	0	0	1	0	0
10716	1	1800	0	0	1	0	0
10708	1	300	362	7.5419999999999998	1	362	7.5419999999999998
10708	2	900	39	0.27100000000000002	1	39	0.27100000000000002
10709	1	300	6982	145.458	1.5	10473	218.18700000000001
10709	2	300	3028	63.082999999999998	1.044	3159.7420000000002	65.828000000000003
10709	3	300	182	3.7919999999999998	1	182	3.7919999999999998
10709	4	300	2718	56.625	1.011	2749.0149999999999	57.271000000000001
10710	1	300	131	2.7290000000000001	1	131	2.7290000000000001
10710	2	300	53	1.1040000000000001	1	53	1.1040000000000001
10710	3	300	43	0.89600000000000002	1	43	0.89600000000000002
10711	1	300	58	1.208	1	58	1.208
10711	2	300	80	1.667	1	80	1.667
10711	3	300	58	1.208	1	58	1.208
10712	1	1800	0	0	1	0	0
10699	1	300	0	0	1	0	0
10700	1	300	2845	59.271000000000001	1.023	2910.145	60.628
10700	2	300	2259	47.063000000000002	1	2259	47.063000000000002
10700	3	300	2557	53.271000000000001	1.001	2560.7719999999999	53.348999999999997
10700	4	600	147	1.5309999999999999	1	147	1.5309999999999999
10700	5	600	25	0.26000000000000001	1	25	0.26000000000000001
10701	1	1500	589	2.4540000000000002	1	589	2.4540000000000002
10702	1	300	1032	21.5	1	1032	21.5
10702	2	600	2996	31.207999999999998	1.039	3114.3380000000002	32.441000000000003
10703	1	300	95	1.9790000000000001	1	95	1.9790000000000001
10703	2	300	168	3.5	1	168	3.5
10703	3	300	0	0	1	0	0
10704	1	900	203	1.4099999999999999	1	203	1.4099999999999999
10705	1	900	0	0	1	0	0
10706	1	300	0	0	1	0	0
10707	1	1500	0	0	1	0	0
10693	1	900	101	0.70099999999999996	1	101	0.70099999999999996
10694	1	300	972	20.25	1	972	20.25
10694	2	300	151	3.1459999999999999	1	151	3.1459999999999999
10694	3	300	1796	37.417000000000002	1	1796	37.417000000000002
10695	1	300	2165	45.103999999999999	1	2165	45.103999999999999
10695	2	300	2281	47.521000000000001	1	2281	47.521000000000001
10695	3	300	3089	64.353999999999999	1.052	3249.0430000000001	67.688000000000002
10696	1	300	361	7.5209999999999999	1	361	7.5209999999999999
10696	2	300	775	16.146000000000001	1	775	16.146000000000001
10696	3	300	2545	53.021000000000001	1.001	2547.674	53.076999999999998
10697	1	900	22	0.153	1	22	0.153
10698	1	900	0	0	1	0	0
10688	1	180	4015	139.41	1.249	5013.7520000000004	174.089
10688	2	180	5365	186.285	1.436	7706.1149999999998	267.57299999999998
10688	3	120	455	23.698	1	455	23.698
10689	1	180	566	19.652999999999999	1	566	19.652999999999999
10689	2	360	1849	32.100999999999999	1	1849	32.100999999999999
10690	1	180	2478	86.042000000000002	1	2478	86.042000000000002
10690	2	180	1987	68.992999999999995	1	1987	68.992999999999995
10690	3	180	789	27.396000000000001	1	789	27.396000000000001
10690	4	180	276	9.5830000000000002	1	276	9.5830000000000002
10691	1	300	4724	98.417000000000002	1.368	6462.6580000000004	134.63900000000001
10691	2	180	1058	36.735999999999997	1	1058	36.735999999999997
10691	3	180	1912	66.388999999999996	1	1912	66.388999999999996
10691	4	180	1305	45.313000000000002	1	1305	45.313000000000002
10692	1	1380	38	0.17199999999999999	1	38	0.17199999999999999
10684	1	600	36	0.375	1	36	0.375
10684	2	600	361	3.7599999999999998	1	361	3.7599999999999998
10685	1	1200	5	0.025999999999999999	1	5	0.025999999999999999
10686	1	300	0	0	1	0	0
10687	1	300	0	0	1	0	0
10678	1	1200	570	2.9689999999999999	1	570	2.9689999999999999
10679	1	300	273	5.6870000000000003	1	273	5.6870000000000003
10679	2	300	2418	50.375	1	2418	50.375
10679	3	300	297	6.1870000000000003	1	297	6.1870000000000003
10679	4	300	338	7.0419999999999998	1	338	7.0419999999999998
10680	1	300	57	1.1870000000000001	1	57	1.1870000000000001
10680	2	300	41	0.85399999999999998	1	41	0.85399999999999998
10680	3	600	63	0.65600000000000003	1	63	0.65600000000000003
10681	1	300	21	0.438	1	21	0.438
10681	2	300	4645	96.771000000000001	1.363	6332.143	131.91999999999999
10681	3	300	58	1.208	1	58	1.208
10681	4	300	434	9.0419999999999998	1	434	9.0419999999999998
10682	1	1200	0	0	1	0	0
10683	1	900	0	0	1	0	0
10673	1	900	25	0.17399999999999999	1	25	0.17399999999999999
10674	1	300	3053	63.603999999999999	1.0470001	3195.8699999999999	66.581000000000003
10674	2	300	431	8.9789999999999992	1	431	8.9789999999999992
10674	3	600	89	0.92700000000000005	1	89	0.92700000000000005
10675	1	900	0	0	1	0	0
10676	1	900	0	0	1	0	0
10677	1	900	0	0	1	0	0
10668	1	300	48	1	1	48	1
10668	2	600	111	1.1559999999999999	1	111	1.1559999999999999
10669	1	300	24398	508.29199999999997	1.5	36597	762.43700000000001
10669	2	300	2135	44.478999999999999	1	2135	44.478999999999999
10669	3	300	1097	22.853999999999999	1	1097	22.853999999999999
10669	4	300	15201	316.68700000000001	1.5	22801.5	475.03100000000001
10670	1	300	374	7.7919999999999998	1	374	7.7919999999999998
10670	2	300	4271	88.978999999999999	1.296	5535.5259999999998	115.32299999999999
10670	3	300	261	5.4370000000000003	1	261	5.4370000000000003
10671	1	900	0	0	1	0	0
10672	1	900	166	1.153	1	166	1.153
10662	1	300	5447	113.479	1.4450001	7869.4830000000002	163.94800000000001
10662	2	300	3735	77.813000000000002	1.196	4465.5770000000002	93.033000000000001
10663	1	300	1121	23.353999999999999	1	1121	23.353999999999999
10663	2	300	2757	57.438000000000002	1.015	2797.4769999999999	58.280999999999999
10663	3	300	1981	41.271000000000001	1	1981	41.271000000000001
10664	1	300	382	7.9580000000000002	1	382	7.9580000000000002
10664	2	300	2138	44.542000000000002	1	2138	44.542000000000002
10664	3	300	1851	38.563000000000002	1	1851	38.563000000000002
10665	1	900	158	1.097	1	158	1.097
10666	1	900	173	1.2010000000000001	1	173	1.2010000000000001
10667	1	900	11	0.075999999999999998	1	11	0.075999999999999998
10657	1	900	86	0.59699999999999998	1	86	0.59699999999999998
10658	1	1200	19	0.099000000000000005	1	19	0.099000000000000005
10659	1	900	0	0	1	0	0
10660	1	1200	0	0	1	0	0
10661	1	1200	185	0.96399999999999997	1	185	0.96399999999999997
34824	1	300	463.39999999999998	9.6539999999999999	1	463.39999999999998	9.6539999999999999
34824	2	300	3259.1999999999998	67.900000000000006	1.082	3526.2930000000001	73.463999999999999
34824	3	300	138.19999999999999	2.879	1	138.19999999999999	2.879
34825	1	300	4047.8000000000002	84.328999999999994	1.255	5079.5169999999998	105.82299999999999
34825	2	300	15964.200000000001	332.58800000000002	1.5	23946.299999999999	498.88099999999997
34825	3	300	9348.2000000000007	194.75399999999999	1.5	14022.299999999999	292.13099999999997
34826	1	300	29062.799999999999	605.47500000000002	1.5	43594.199999999997	908.21199999999999
34826	2	180	32	1.111	1	32	1.111
34826	3	180	7922.6000000000004	275.08999999999997	1.5	11883.9	412.63499999999999
34827	1	180	5067	175.93700000000001	1.405	7120.509	247.24000000000001
10451	1	300	0	0	1	0	0
10451	2	600	0	0	1	0	0
10451	3	600	79	0.82299999999999995	1	79	0.82299999999999995
10452	1	300	0	0	1	0	0
10453	1	300	0	0	1	0	0
10437	1	300	0	0	1	0	0
10438	1	300	0	0	1	0	0
10439	1	600	54	0.56299999999999994	1	54	0.56299999999999994
10439	2	600	174	1.8129999999999999	1	174	1.8129999999999999
10440	1	300	0	0	1	0	0
10441	1	300	0	0	1	0	0
10442	1	300	0	0	1	0	0
10431	1	600	0	0	1	0	0
10431	2	300	2	0.042000000000000003	1	2	0.042000000000000003
10432	1	300	0	0	1	0	0
10433	1	600	0	0	1	0	0
10433	2	300	15	0.313	1	15	0.313
10434	1	600	0	0	1	0	0
10434	2	300	8	0.16700000000000001	1	8	0.16700000000000001
10435	1	300	0	0	1	0	0
10436	1	300	0	0	1	0	0
10425	1	300	1	0.021000000000000001	1	1	0.021000000000000001
10425	2	300	6	0.125	1	6	0.125
10425	3	300	1	0.021000000000000001	1	1	0.021000000000000001
10425	4	300	0	0	1	0	0
10426	1	300	1	0.021000000000000001	1	1	0.021000000000000001
10426	2	300	12	0.25	1	12	0.25
10426	3	300	1	0.021000000000000001	1	1	0.021000000000000001
10427	1	300	42	0.875	1	42	0.875
10427	2	300	18	0.375	1	18	0.375
10427	3	300	47	0.97899999999999998	1	47	0.97899999999999998
10428	1	300	245	5.1040000000000001	1	245	5.1040000000000001
10428	2	300	39	0.81299999999999994	1	39	0.81299999999999994
10428	3	300	2	0.042000000000000003	1	2	0.042000000000000003
10429	1	300	0	0	1	0	0
10429	2	300	5	0.104	1	5	0.104
10429	3	300	0	0	1	0	0
10429	4	300	0	0	1	0	0
10430	1	300	0	0	1	0	0
10421	1	300	0	0	1	0	0
10422	1	300	40	0.83299999999999996	1	40	0.83299999999999996
10422	2	300	7	0.14599999999999999	1	7	0.14599999999999999
10422	3	300	4	0.083000000000000004	1	4	0.083000000000000004
10422	4	300	9	0.188	1	9	0.188
10423	1	300	73	1.5209999999999999	1	73	1.5209999999999999
10423	2	300	145	3.0209999999999999	1	145	3.0209999999999999
10423	3	300	30	0.625	1	30	0.625
10423	4	300	19	0.39600000000000002	1	19	0.39600000000000002
10424	1	300	0	0	1	0	0
10416	1	300	0	0	1	0	0
10417	1	300	0	0	1	0	0
10417	2	300	4	0.083000000000000004	1	4	0.083000000000000004
10417	3	300	0	0	1	0	0
10417	4	300	3	0.063	1	3	0.063
10418	1	300	0	0	1	0	0
10418	2	300	19	0.39600000000000002	1	19	0.39600000000000002
10418	3	300	13	0.27100000000000002	1	13	0.27100000000000002
10419	1	300	0	0	1	0	0
10419	2	300	176	3.6669999999999998	1	176	3.6669999999999998
10419	3	300	0	0	1	0	0
10419	4	300	0	0	1	0	0
10420	1	300	0	0	1	0	0
10413	1	300	0	0	1	0	0
10414	1	300	0	0	1	0	0
10414	2	600	0	0	1	0	0
10414	3	600	15	0.156	1	15	0.156
10414	4	600	0	0	1	0	0
10415	1	300	0	0	1	0	0
10408	1	600	0	0	1	0	0
10409	1	600	0	0	1	0	0
10410	1	1200	56	0.29199999999999998	1	56	0.29199999999999998
10411	1	300	0	0	1	0	0
10411	2	600	70	0.72899999999999998	1	70	0.72899999999999998
10411	3	600	882	9.1880000000000006	1	882	9.1880000000000006
10412	1	300	0	0	1	0	0
10404	1	300	4	0.083000000000000004	1	4	0.083000000000000004
10404	2	300	0	0	1	0	0
10405	1	300	28	0.58299999999999996	1	28	0.58299999999999996
10405	2	300	3	0.063	1	3	0.063
10405	3	300	6	0.125	1	6	0.125
10406	1	300	5	0.104	1	5	0.104
10406	2	300	3	0.063	1	3	0.063
10406	3	300	3	0.063	1	3	0.063
10407	1	600	0	0	1	0	0
10399	1	300	0	0	1	0	0
10400	1	300	4	0.083000000000000004	1	4	0.083000000000000004
10400	2	300	0	0	1	0	0
10400	3	300	2	0.042000000000000003	1	2	0.042000000000000003
10401	1	300	26	0.54200000000000004	1	26	0.54200000000000004
10401	2	300	87	1.8129999999999999	1	87	1.8129999999999999
10401	3	300	71	1.4790000000000001	1	71	1.4790000000000001
10401	4	300	45	0.93799999999999994	1	45	0.93799999999999994
10402	1	300	22	0.45800000000000002	1	22	0.45800000000000002
10402	2	300	71	1.4790000000000001	1	71	1.4790000000000001
10402	3	300	15	0.313	1	15	0.313
10402	4	300	70	1.458	1	70	1.458
10403	1	300	0	0	1	0	0
10395	1	300	0	0	1	0	0
10396	1	300	0	0	1	0	0
10396	2	300	6	0.125	1	6	0.125
10396	3	300	536	11.167	1	536	11.167
10397	1	300	7	0.14599999999999999	1	7	0.14599999999999999
10397	2	300	0	0	1	0	0
10397	3	240	0	0	1	0	0
10398	1	300	0	0	1	0	0
10390	1	300	0	0	1	0	0
10391	1	300	7	0.14599999999999999	1	7	0.14599999999999999
10391	2	300	0	0	1	0	0
10391	3	300	0	0	1	0	0
10392	1	300	0	0	1	0	0
10392	2	300	30	0.625	1	30	0.625
10392	3	300	94	1.958	1	94	1.958
10393	1	300	32	0.66700000000000004	1	32	0.66700000000000004
10393	2	300	76	1.583	1	76	1.583
10393	3	300	1290	26.875	1	1290	26.875
10393	4	300	12	0.25	1	12	0.25
10394	1	300	0	0	1	0	0
10384	1	300	0	0	1	0	0
10385	1	900	6	0.042000000000000003	1	6	0.042000000000000003
10386	1	600	40	0.41699999999999998	1	40	0.41699999999999998
10386	2	300	137	2.8540000000000001	1	137	2.8540000000000001
10386	3	900	6	0.042000000000000003	1	6	0.042000000000000003
10387	1	300	0	0	1	0	0
10388	1	900	13	0.089999999999999997	1	13	0.089999999999999997
10389	1	300	0	0	1	0	0
10378	1	300	0	0	1	0	0
10379	1	300	0	0	1	0	0
10379	2	300	0	0	1	0	0
10379	3	300	7	0.14599999999999999	1	7	0.14599999999999999
10380	1	300	0	0	1	0	0
10380	2	300	0	0	1	0	0
10380	3	300	17	0.35399999999999998	1	17	0.35399999999999998
10381	1	300	0	0	1	0	0
10381	2	300	0	0	1	0	0
10381	3	300	11	0.22900000000000001	1	11	0.22900000000000001
10382	1	300	0	0	1	0	0
10382	2	300	34	0.70799999999999996	1	34	0.70799999999999996
10382	3	300	0	0	1	0	0
10383	1	300	0	0	1	0	0
10371	1	300	0	0	1	0	0
10372	1	900	33	0.22900000000000001	1	33	0.22900000000000001
10373	1	300	0	0	1	0	0
10373	2	300	0	0	1	0	0
10373	3	300	5	0.104	1	5	0.104
10374	1	600	0	0	1	0	0
10374	2	600	14	0.14599999999999999	1	14	0.14599999999999999
10375	1	300	0	0	1	0	0
10376	1	300	0	0	1	0	0
10377	1	300	0	0	1	0	0
10361	1	300	0	0	1	0	0
10362	1	300	0	0	1	0	0
10363	1	300	0	0	1	0	0
10364	1	300	19	0.39600000000000002	1	19	0.39600000000000002
10364	2	300	2	0.042000000000000003	1	2	0.042000000000000003
10364	3	300	10	0.20799999999999999	1	10	0.20799999999999999
10365	1	300	0	0	1	0	0
10366	1	300	0	0	1	0	0
10367	1	300	2	0.042000000000000003	1	2	0.042000000000000003
10367	2	300	1	0.021000000000000001	1	1	0.021000000000000001
10367	3	300	1	0.021000000000000001	1	1	0.021000000000000001
10368	1	300	0	0	1	0	0
10368	2	300	2	0.042000000000000003	1	2	0.042000000000000003
10368	3	300	0	0	1	0	0
10369	1	300	4	0.083000000000000004	1	4	0.083000000000000004
10369	2	300	1	0.021000000000000001	1	1	0.021000000000000001
10369	3	300	2	0.042000000000000003	1	2	0.042000000000000003
10370	1	300	0	0	1	0	0
34799	1	300	0	0	1	0	0
34799	2	300	0	0	1	0	0
34799	3	300	0	0	1	0	0
34800	1	300	0	0	1	0	0
34800	2	300	0	0	1	0	0
34800	3	300	506.60000000000002	10.554	1	506.60000000000002	10.554
34801	1	300	156.80000000000001	3.2669999999999999	1	156.80000000000001	3.2669999999999999
34801	2	300	44.299999999999997	0.92300000000000004	1	44.299999999999997	0.92300000000000004
34801	3	300	36	0.75	1	36	0.75
34802	1	300	0	0	1	0	0
34802	2	300	0	0	1	0	0
34802	3	300	0	0	1	0	0
34803	1	300	0	0	1	0	0
34803	2	300	0	0	1	0	0
34803	3	300	0	0	1	0	0
34794	1	300	0	0	1	0	0
34794	2	300	0	0	1	0	0
34794	3	300	0	0	1	0	0
34795	1	300	18	0.375	1	18	0.375
34795	2	300	0	0	1	0	0
34795	3	300	0	0	1	0	0
34796	1	300	51.899999999999999	1.081	1	51.899999999999999	1.081
34796	2	300	12.9	0.26900000000000002	1	12.9	0.26900000000000002
34796	3	300	12.699999999999999	0.26500000000000001	1	12.699999999999999	0.26500000000000001
34797	1	300	0	0	1	0	0
34797	2	300	0	0	1	0	0
34797	3	300	0	0	1	0	0
34798	1	300	0	0	1	0	0
34798	2	300	0	0	1	0	0
34798	3	300	0	0	1	0	0
34716	1	300	535.79999999999995	11.163	1	535.79999999999995	11.163
34716	2	300	4028.1999999999998	83.921000000000006	1.251	5040.1800000000003	105.004
34716	3	300	996.79999999999995	20.766999999999999	1	996.79999999999995	20.766999999999999
34717	1	300	11.5	0.23999999999999999	1	11.5	0.23999999999999999
34717	2	300	0	0	1	0	0
34717	3	300	0	0	1	0	0
34718	1	300	0	0	1	0	0
34718	2	300	0	0	1	0	0
34718	3	300	23.199999999999999	0.48299999999999998	1	23.199999999999999	0.48299999999999998
34719	1	300	0	0	1	0	0
34719	2	300	5.2999999999999998	0.11	1	5.2999999999999998	0.11
34719	3	300	1.2	0.025000000000000001	1	1.2	0.025000000000000001
34720	1	300	0	0	1	0	0
34720	2	300	0	0	1	0	0
34720	3	300	0	0	1	0	0
29839	1	300	0	0	1	0	0
29839	2	300	0	0	1	0	0
29839	3	300	0	0	1	0	0
29840	1	300	39.100000000000001	0.81499999999999995	1	39.100000000000001	0.81499999999999995
29840	2	300	399.10000000000002	8.3149999999999995	1	399.10000000000002	8.3149999999999995
29840	3	300	1078.2	22.463000000000001	1	1078.2	22.463000000000001
29841	1	300	0	0	1	0	0
29841	2	300	20.600000000000001	0.42899999999999999	1	20.600000000000001	0.42899999999999999
29841	3	300	0	0	1	0	0
29842	1	300	0	0	1	0	0
29842	2	300	0	0	1	0	0
29842	3	300	0	0	1	0	0
29843	1	300	0	0	1	0	0
29843	2	300	15.800000000000001	0.32900000000000001	1	15.800000000000001	0.32900000000000001
29843	3	300	0	0	1	0	0
29834	1	300	920.20000000000005	19.170999999999999	1	920.20000000000005	19.170999999999999
29834	2	300	1998.4000000000001	41.633000000000003	1	1998.4000000000001	41.633000000000003
29834	3	300	3165.4000000000001	65.945999999999998	1.064	3367.3589999999999	70.153000000000006
29835	1	300	74	1.542	1	74	1.542
29835	2	300	4.4000000000000004	0.091999999999999998	1	4.4000000000000004	0.091999999999999998
29835	3	300	12.800000000000001	0.26700000000000002	1	12.800000000000001	0.26700000000000002
29836	1	300	47.100000000000001	0.98099999999999998	1	47.100000000000001	0.98099999999999998
29836	2	300	370.69999999999999	7.7229999999999999	1	370.69999999999999	7.7229999999999999
29836	3	300	18.300000000000001	0.38100000000000001	1	18.300000000000001	0.38100000000000001
29837	1	300	19.300000000000001	0.40200000000000002	1	19.300000000000001	0.40200000000000002
29837	2	300	9.0999999999999996	0.19	1	9.0999999999999996	0.19
24792	3	300	3716.1999999999998	77.421000000000006	1.192	4429.6289999999999	92.284000000000006
24793	1	300	8637.2000000000007	179.94200000000001	1.5	12955.799999999999	269.91300000000001
24793	2	300	5875.3999999999996	122.404	1.487	8738.1470000000008	182.04499999999999
24793	3	300	8495.6000000000004	176.99199999999999	1.5	12743.4	265.48700000000002
24794	1	300	1081.5999999999999	22.533000000000001	1	1081.5999999999999	22.533000000000001
24794	2	300	2843	59.228999999999999	1.023	2907.5349999999999	60.573999999999998
24794	3	300	771.60000000000002	16.074999999999999	1	771.60000000000002	16.074999999999999
24795	1	900	0	0	1	0	0
24790	1	300	4134.1999999999998	86.129000000000005	1.271	5254.2889999999998	109.464
24790	2	300	4828.6000000000004	100.596	1.38	6661.3969999999999	138.779
24790	3	300	5660	117.917	1.466	8298.2340000000004	172.88
24789	1	300	600.70000000000005	12.515000000000001	1	600.70000000000005	12.515000000000001
24789	2	300	7236.6000000000004	150.76300000000001	1.5	10854.9	226.14400000000001
24789	3	300	5487.1999999999998	114.31699999999999	1.449	7949.9189999999999	165.62299999999999
24788	1	300	4318	89.957999999999998	1.3049999	5633.4170000000004	117.363
24788	2	300	5196.8000000000002	108.267	1.419	7374.0060000000003	153.625
24788	3	300	2781.1999999999998	57.942	1.017	2828.0140000000001	58.917000000000002
24787	1	300	2848	59.332999999999998	1.023	2914.0639999999999	60.710000000000001
24787	2	300	5021.6000000000004	104.617	1.4	7032.4269999999997	146.50899999999999
24787	3	300	5147.8000000000002	107.246	1.414	7278.0209999999997	151.625
24786	1	300	1.7	0.035000000000000003	1	1.7	0.035000000000000003
24786	2	300	97	2.0209999999999999	1	97	2.0209999999999999
24786	3	300	38.299999999999997	0.79800000000000004	1	38.299999999999997	0.79800000000000004
27688	1	300	2451.5999999999999	51.075000000000003	1	2451.5999999999999	51.075000000000003
27688	2	300	0	0	1	0	0
27688	3	300	84.5	1.76	1	84.5	1.76
27687	1	300	4482.8000000000002	93.391999999999996	1.334	5981.723	124.619
27687	2	300	4324.1999999999998	90.087000000000003	1.306	5646.3779999999997	117.633
27687	3	300	1004.6	20.928999999999998	1	1004.6	20.928999999999998
27686	1	300	4898	102.042	1.387	6794.1719999999996	141.54499999999999
27686	2	300	4020.6999999999998	83.765000000000001	1.25	5025.1580000000004	104.691
27686	3	300	4243.5	88.406000000000006	1.291	5478.549	114.136
27685	1	300	1449.0999999999999	30.190000000000001	1	1449.0999999999999	30.190000000000001
27685	2	300	8242.7999999999993	171.72499999999999	1.5	12364.200000000001	257.58699999999999
27685	3	300	12806.9	266.81	1.5	19210.349999999999	400.21600000000001
24785	1	300	2451.5999999999999	51.075000000000003	1	2451.5999999999999	51.075000000000003
24785	2	300	0	0	1	0	0
24785	3	300	84.5	1.76	1	84.5	1.76
24784	1	300	4482.8000000000002	93.391999999999996	1.334	5981.723	124.619
24784	2	300	4324.1999999999998	90.087000000000003	1.306	5646.3779999999997	117.633
24784	3	300	1004.6	20.928999999999998	1	1004.6	20.928999999999998
24783	1	300	4898	102.042	1.387	6794.1719999999996	141.54499999999999
24783	2	300	4020.6999999999998	83.765000000000001	1.25	5025.1580000000004	104.691
24783	3	300	4243.5	88.406000000000006	1.291	5478.549	114.136
24782	1	300	1449.0999999999999	30.190000000000001	1	1449.0999999999999	30.190000000000001
24782	2	300	8242.7999999999993	171.72499999999999	1.5	12364.200000000001	257.58699999999999
24782	3	300	12806.9	266.81	1.5	19210.349999999999	400.21600000000001
24781	1	900	0	0	1	0	0
24070	1	900	7187.3000000000002	49.911999999999999	1.5	10780.950000000001	74.867999999999995
24069	1	900	14359.9	99.721999999999994	1.5	21539.849999999999	149.58199999999999
24068	1	900	9707.6000000000004	67.414000000000001	1.5	14561.4	101.121
24067	1	900	4661.5	32.372	1.3609999	6344.7070000000003	44.060000000000002
24066	1	900	0	0	1	0	0
24185	1	900	9756.5	67.753	1.5	14634.75	101.63
24184	1	900	6095.6499999999996	42.331000000000003	1.5	9143.4750000000004	63.496000000000002
24183	1	900	3065.6500000000001	21.289000000000001	1.049	3214.3919999999998	22.321999999999999
24182	1	900	5875.1499999999996	40.799999999999997	1.487	8737.6329999999998	60.677999999999997
24181	1	900	0	0	1	0	0
24061	1	900	6184.3999999999996	42.947000000000003	1.5	9276.6000000000004	64.421000000000006
24060	1	900	839.29999999999995	5.8280000000000003	1	839.29999999999995	5.8280000000000003
24059	1	900	7457.4499999999998	51.787999999999997	1.5	11186.174999999999	77.682000000000002
24058	1	900	15570.950000000001	108.13200000000001	1.5	23356.424999999999	162.197
24057	1	900	9281.0499999999993	64.451999999999998	1.5	13921.575000000001	96.677999999999997
24056	1	900	4.4000000000000004	0.031	1	4.4000000000000004	0.031
24055	1	900	6412	44.527999999999999	1.5	9618	66.792000000000002
24054	1	900	6082.1999999999998	42.237000000000002	1.5	9123.2999999999993	63.356000000000002
24053	1	900	12555.6	87.191999999999993	1.5	18833.400000000001	130.78800000000001
24052	1	900	309.39999999999998	2.149	1	309.39999999999998	2.149
24051	1	900	29.949999999999999	0.20799999999999999	1	29.949999999999999	0.20799999999999999
23920	1	900	1149.8	7.9850000000000003	1	1149.8	7.9850000000000003
23919	1	900	2917.6999999999998	20.262	1.03	3006.605	20.879000000000001
23918	1	900	1032.3499999999999	7.1689999999999996	1	1032.3499999999999	7.1689999999999996
23917	1	900	2171.5	15.08	1	2171.5	15.08
23916	1	900	699.35000000000002	4.8570000000000002	1	699.35000000000002	4.8570000000000002
23915	1	900	3054.0500000000002	21.209	1.0470001	3197.4009999999998	22.204000000000001
23914	1	900	2616.8000000000002	18.172000000000001	1.0039999	2628.1660000000002	18.251000000000001
23913	1	900	2261.1999999999998	15.702999999999999	1	2261.1999999999998	15.702999999999999
23912	1	900	2171.3499999999999	15.079000000000001	1	2171.3499999999999	15.079000000000001
23911	1	900	518.25	3.5990000000000002	1	518.25	3.5990000000000002
23910	1	900	2917.5	20.260000000000002	1.03	3006.335	20.876999999999999
23909	1	900	3105.5500000000002	21.565999999999999	1.054	3273.9940000000001	22.736000000000001
23908	1	900	3846.0999999999999	26.709	1.217	4680.2299999999996	32.502000000000002
23907	1	900	162.09999999999999	1.1259999999999999	1	162.09999999999999	1.1259999999999999
23906	1	900	4.25	0.029999999999999999	1	4.25	0.029999999999999999
23905	1	900	1372.7	9.5329999999999995	1	1372.7	9.5329999999999995
23904	1	905	3289.8000000000002	22.719999999999999	1.089	3582.4050000000002	24.739999999999998
23903	1	901	4838.3000000000002	33.561999999999998	1.381	6679.9110000000001	46.337000000000003
23902	1	900	4857.5500000000002	33.732999999999997	1.383	6716.6959999999999	46.643999999999998
23901	1	900	0	0	1	0	0
23890	1	900	982.29999999999995	6.8220000000000001	1	982.29999999999995	6.8220000000000001
23889	1	900	2792.25	19.390999999999998	1.018	2842.0720000000001	19.736999999999998
23888	1	900	2922.5500000000002	20.295000000000002	1.031	3013.1550000000002	20.925000000000001
23887	1	900	2346.5999999999999	16.295999999999999	1	2346.5999999999999	16.295999999999999
23886	1	900	570.70000000000005	3.9630000000000001	1	570.70000000000005	3.9630000000000001
23875	1	900	2951.4000000000001	20.495999999999999	1.034	3052.4369999999999	21.196999999999999
23874	1	900	2924.1500000000001	20.306999999999999	1.031	3015.319	20.940000000000001
23873	1	900	2104.5999999999999	14.615	1	2104.5999999999999	14.615
23872	1	900	2326.8499999999999	16.158999999999999	1	2326.8499999999999	16.158999999999999
23871	1	900	2088.0500000000002	14.5	1	2088.0500000000002	14.5
23870	1	900	2980.0500000000002	20.695	1.038	3092.027	21.472000000000001
23869	1	900	3003.0500000000002	20.855	1.04	3124.2649999999999	21.696000000000002
23868	1	900	2549.0500000000002	17.702000000000002	1.001	2552.0770000000002	17.722999999999999
23867	1	900	2461.6999999999998	17.094999999999999	1	2461.6999999999998	17.094999999999999
23866	1	900	3083.25	21.411000000000001	1.051	3240.4520000000002	22.503
23865	1	900	504.05000000000001	3.5	1	504.05000000000001	3.5
23864	1	900	2600.5999999999999	18.059999999999999	1.003	2609.5790000000002	18.122
23863	1	900	3130.3499999999999	21.739000000000001	1.058	3312.0509999999999	23
23862	1	900	2073.25	14.398	1	2073.25	14.398
23861	1	900	2857.9499999999998	19.847000000000001	1.024	2927.0999999999999	20.327000000000002
12977	1	300	1120	23.332999999999998	1	1120	23.332999999999998
12977	2	300	1163	24.228999999999999	1	1163	24.228999999999999
12977	3	300	1067	22.228999999999999	1	1067	22.228999999999999
12978	1	300	995	20.728999999999999	1	995	20.728999999999999
12978	2	301	89	1.8480000000000001	1	89	1.8480000000000001
12978	3	300	67	1.3959999999999999	1	67	1.3959999999999999
12979	1	300	2000	41.667000000000002	1	2000	41.667000000000002
12979	2	300	1989	41.438000000000002	1	1989	41.438000000000002
12979	3	303	1891	39.006	1	1891	39.006
12980	1	305	183	3.75	1	183	3.75
12980	2	300	708	14.75	1	708	14.75
12980	3	301	1141	23.692	1	1141	23.692
12981	1	902	1	0.0070000000000000001	1	1	0.0070000000000000001
12972	1	300	2.6499999999999999	0.055	1	2.6499999999999999	0.055
12972	2	300	3.1499999999999999	0.066000000000000003	1	3.1499999999999999	0.066000000000000003
12972	3	300	0.5	0.01	1	0.5	0.01
12973	1	300	47	0.97899999999999998	1	47	0.97899999999999998
12973	2	300	32	0.66700000000000004	1	32	0.66700000000000004
12973	3	300	31	0.64600000000000002	1	31	0.64600000000000002
12974	1	300	1277	26.603999999999999	1	1277	26.603999999999999
12974	2	300	203	4.2290000000000001	1	203	4.2290000000000001
12974	3	300	208	4.3330000000000002	1	208	4.3330000000000002
12975	1	300	64	1.333	1	64	1.333
12975	2	300	173	3.6040000000000001	1	173	3.6040000000000001
12975	3	300	51	1.0620000000000001	1	51	1.0620000000000001
12976	1	300	28	0.58299999999999996	1	28	0.58299999999999996
12976	2	300	263	5.4790000000000001	1	263	5.4790000000000001
12976	3	300	205	4.2709999999999999	1	205	4.2709999999999999
12966	1	300	71	1.4790000000000001	1	71	1.4790000000000001
12966	2	300	134	2.7919999999999998	1	134	2.7919999999999998
12966	3	300	75	1.5629999999999999	1	75	1.5629999999999999
12967	1	300	938	19.542000000000002	1	938	19.542000000000002
12967	2	300	621	12.938000000000001	1	621	12.938000000000001
12967	3	300	386	8.0419999999999998	1	386	8.0419999999999998
12968	1	300	1303	27.146000000000001	1	1303	27.146000000000001
12968	2	300	1442	30.042000000000002	1	1442	30.042000000000002
12968	3	300	1433	29.853999999999999	1	1433	29.853999999999999
12969	1	300	412	8.5830000000000002	1	412	8.5830000000000002
12969	2	300	511	10.646000000000001	1	511	10.646000000000001
12969	3	300	359	7.4790000000000001	1	359	7.4790000000000001
12970	1	300	1040	21.667000000000002	1	1040	21.667000000000002
12970	2	300	662	13.792	1	662	13.792
12970	3	300	1075	22.396000000000001	1	1075	22.396000000000001
12971	1	900	0	0	1	0	0
12946	1	300	3	0.063	1	3	0.063
12946	2	300	1	0.021000000000000001	1	1	0.021000000000000001
12946	3	300	6	0.125	1	6	0.125
12947	1	300	718	14.958	1	718	14.958
12947	2	300	753	15.688000000000001	1	753	15.688000000000001
12947	3	304	791	16.262	1	791	16.262
12948	1	302	991	20.509	1	991	20.509
12948	2	300	439	9.1460000000000008	1	439	9.1460000000000008
12948	3	303	1221	25.186	1	1221	25.186
12949	1	300	849	17.687000000000001	1	849	17.687000000000001
12949	2	300	1033	21.521000000000001	1	1033	21.521000000000001
12949	3	300	1283	26.728999999999999	1	1283	26.728999999999999
12950	1	300	1	0.021000000000000001	1	1	0.021000000000000001
12950	2	300	1	0.021000000000000001	1	1	0.021000000000000001
12950	3	300	1411	29.396000000000001	1	1411	29.396000000000001
12941	1	306	1122	22.917000000000002	1	1122	22.917000000000002
12941	2	300	828	17.25	1	828	17.25
12941	3	303	626	12.913	1	626	12.913
12942	1	303	644	13.284000000000001	1	644	13.284000000000001
12942	2	300	516	10.75	1	516	10.75
12942	3	300	877	18.271000000000001	1	877	18.271000000000001
11014	3	300	822	17.125	1	822	17.125
11004	1	300	2142	44.625	1	2142	44.625
11004	2	300	4021	83.771000000000001	1.25	5025.7579999999998	104.703
11004	3	300	3157	65.771000000000001	1.062	3353.9299999999998	69.873999999999995
11005	1	300	4103	85.478999999999999	1.265	5190.9210000000003	108.14400000000001
11005	2	300	4750	98.957999999999998	1.3710001	6511.902	135.66499999999999
11005	3	300	592	12.333	1	592	12.333
11006	1	300	771	16.062000000000001	1	771	16.062000000000001
11006	2	300	2160	45	1	2160	45
11006	3	300	742	15.458	1	742	15.458
11007	1	300	2313	48.188000000000002	1	2313	48.188000000000002
11007	2	300	1055	21.978999999999999	1	1055	21.978999999999999
11007	3	300	4208	87.667000000000002	1.285	5405.3249999999998	112.611
11008	1	300	1125	23.437000000000001	1	1125	23.437000000000001
11008	2	300	1837	38.271000000000001	1	1837	38.271000000000001
11008	3	300	659	13.728999999999999	1	659	13.728999999999999
11009	1	300	1383	28.812000000000001	1	1383	28.812000000000001
11009	2	300	471	9.8130000000000006	1	471	9.8130000000000006
11009	3	600	1254	13.063000000000001	1	1254	13.063000000000001
10995	1	300	3128	65.167000000000002	1.058	3308.4090000000001	68.924999999999997
10995	2	300	801	16.687000000000001	1	801	16.687000000000001
10995	3	300	1497	31.187000000000001	1	1497	31.187000000000001
10996	1	300	1876	39.082999999999998	1	1876	39.082999999999998
10996	2	300	1728	36	1	1728	36
10996	3	300	1419	29.562000000000001	1	1419	29.562000000000001
10996	4	300	994	20.707999999999998	1	994	20.707999999999998
10997	1	300	1820	37.917000000000002	1	1820	37.917000000000002
10997	2	300	1786	37.207999999999998	1	1786	37.207999999999998
10997	3	300	943	19.646000000000001	1	943	19.646000000000001
10998	1	300	101	2.1040000000000001	1	101	2.1040000000000001
10998	2	300	2001	41.688000000000002	1	2001	41.688000000000002
10998	3	300	1702	35.457999999999998	1	1702	35.457999999999998
10998	4	300	977	20.353999999999999	1	977	20.353999999999999
10998	5	300	3861	80.438000000000002	1.22	4709.3050000000003	98.111000000000004
10999	1	300	1210	25.207999999999998	1	1210	25.207999999999998
10999	2	300	843	17.562000000000001	1	843	17.562000000000001
10999	3	300	429	8.9380000000000006	1	429	8.9380000000000006
10999	4	300	1740	36.25	1	1740	36.25
11000	1	300	2238	46.625	1	2238	46.625
11000	2	300	284	5.9169999999999998	1	284	5.9169999999999998
11000	3	300	1929	40.188000000000002	1	1929	40.188000000000002
11000	4	300	1892	39.417000000000002	1	1892	39.417000000000002
11001	1	300	664	13.833	1	664	13.833
11001	2	300	1692	35.25	1	1692	35.25
11001	3	300	851	17.728999999999999	1	851	17.728999999999999
11001	4	300	1054	21.957999999999998	1	1054	21.957999999999998
11002	1	300	501	10.438000000000001	1	501	10.438000000000001
11002	2	300	143	2.9790000000000001	1	143	2.9790000000000001
11002	3	300	786	16.375	1	786	16.375
11003	1	300	116	2.4169999999999998	1	116	2.4169999999999998
11003	2	600	1845	19.219000000000001	1	1845	19.219000000000001
11003	3	300	362	7.5419999999999998	1	362	7.5419999999999998
11003	4	300	867	18.062000000000001	1	867	18.062000000000001
11003	5	300	1093	22.771000000000001	1	1093	22.771000000000001
10989	1	300	451	9.3960000000000008	1	451	9.3960000000000008
10989	2	300	685	14.271000000000001	1	685	14.271000000000001
10989	3	300	182	3.7919999999999998	1	182	3.7919999999999998
10990	1	300	898	18.707999999999998	1	898	18.707999999999998
10990	2	300	1291	26.896000000000001	1	1291	26.896000000000001
10990	3	300	2781	57.938000000000002	1.017	2827.761	58.911999999999999
10991	1	300	4951	103.146	1.393	6896.058	143.66800000000001
10991	2	300	639	13.313000000000001	1	639	13.313000000000001
10991	3	300	3408	71	1.123	3826.02	79.709000000000003
10992	1	300	924	19.25	1	924	19.25
10992	2	300	3192	66.5	1.069	3410.6770000000001	71.055999999999997
10992	3	300	1543	32.146000000000001	1	1543	32.146000000000001
10993	1	300	979	20.396000000000001	1	979	20.396000000000001
10993	2	300	1003	20.896000000000001	1	1003	20.896000000000001
10993	3	300	689	14.353999999999999	1	689	14.353999999999999
10994	1	300	728	15.167	1	728	15.167
10994	2	300	1499	31.228999999999999	1	1499	31.228999999999999
10994	3	300	686	14.292	1	686	14.292
10982	1	300	150	3.125	1	150	3.125
10982	2	600	342	3.5630000000000002	1	342	3.5630000000000002
10983	1	300	4943	102.979	1.392	6880.652	143.34700000000001
10983	2	300	1087	22.646000000000001	1	1087	22.646000000000001
10983	3	300	6839	142.47900000000001	1.5	10258.5	213.71899999999999
10983	4	300	2958	61.625	1.035	3061.5039999999999	63.780999999999999
10984	1	600	5089	53.009999999999998	1.408	7163.3019999999997	74.617999999999995
10984	2	300	111	2.3130000000000002	1	111	2.3130000000000002
10985	1	300	45	0.93799999999999994	1	45	0.93799999999999994
10985	2	300	158	3.2919999999999998	1	158	3.2919999999999998
10985	3	300	5756	119.917	1.476	8493.518	176.94800000000001
10985	4	300	390	8.125	1	390	8.125
10986	1	360	563	9.7739999999999991	1	563	9.7739999999999991
10986	2	300	53	1.1040000000000001	1	53	1.1040000000000001
10987	1	300	345	7.1870000000000003	1	345	7.1870000000000003
10987	2	300	15	0.313	1	15	0.313
10987	3	300	193	4.0209999999999999	1	193	4.0209999999999999
10987	4	300	428	8.9169999999999998	1	428	8.9169999999999998
10988	1	900	0	0	1	0	0
10975	1	600	161	1.677	1	161	1.677
10975	2	300	86	1.792	1	86	1.792
10976	1	900	46	0.31900000000000001	1	46	0.31900000000000001
10977	1	300	247	5.1459999999999999	1	247	5.1459999999999999
10977	2	300	984	20.5	1	984	20.5
10977	3	300	47	0.97899999999999998	1	47	0.97899999999999998
10977	4	300	58	1.208	1	58	1.208
10978	1	300	457	9.5210000000000008	1	457	9.5210000000000008
10978	2	300	158	3.2919999999999998	1	158	3.2919999999999998
10978	3	300	117	2.4380000000000002	1	117	2.4380000000000002
10979	1	900	7	0.049000000000000002	1	7	0.049000000000000002
10980	1	300	58	1.208	1	58	1.208
10980	2	300	76	1.583	1	76	1.583
10980	3	300	36	0.75	1	36	0.75
10981	1	900	19	0.13200000000000001	1	19	0.13200000000000001
10968	1	600	177	1.8440000000000001	1	177	1.8440000000000001
10968	2	600	772	8.0419999999999998	1	772	8.0419999999999998
10969	1	900	874	6.069	1	874	6.069
10970	1	300	475	9.8960000000000008	1	475	9.8960000000000008
10970	2	300	386	8.0419999999999998	1	386	8.0419999999999998
10970	3	600	640	6.6669999999999998	1	640	6.6669999999999998
10971	1	600	292	3.0419999999999998	1	292	3.0419999999999998
10971	2	1200	3243	16.890999999999998	1.0779999	3497.5230000000001	18.216000000000001
10972	1	300	558	11.625	1	558	11.625
10972	2	900	72	0.5	1	72	0.5
10972	3	300	3532	73.582999999999998	1.156	4083.2359999999999	85.066999999999993
10973	1	300	44	0.91700000000000004	1	44	0.91700000000000004
10973	2	300	929	19.353999999999999	1	929	19.353999999999999
10973	3	300	585	12.188000000000001	1	585	12.188000000000001
10973	4	300	976	20.332999999999998	1	976	20.332999999999998
10974	1	900	0	0	1	0	0
10963	1	300	437	9.1039999999999992	1	437	9.1039999999999992
10963	2	300	95	1.9790000000000001	1	95	1.9790000000000001
10963	3	300	417	8.6880000000000006	1	417	8.6880000000000006
10963	4	300	19	0.39600000000000002	1	19	0.39600000000000002
10964	1	300	35	0.72899999999999998	1	35	0.72899999999999998
10964	2	300	571	11.896000000000001	1	571	11.896000000000001
10964	3	300	2791	58.146000000000001	1.018	2840.4789999999998	59.177
10964	4	300	4360	90.832999999999998	1.312	5721.4380000000001	119.197
10964	5	300	147	3.0630000000000002	1	147	3.0630000000000002
10965	1	300	95	1.9790000000000001	1	95	1.9790000000000001
10965	2	300	1280	26.667000000000002	1	1280	26.667000000000002
10965	3	600	53	0.55200000000000005	1	53	0.55200000000000005
10966	1	600	77	0.80200000000000005	1	77	0.80200000000000005
10966	2	300	749	15.603999999999999	1	749	15.603999999999999
10966	3	300	2454	51.125	1	2454	51.125
10967	1	600	27	0.28100000000000003	1	27	0.28100000000000003
10967	2	300	1116	23.25	1	1116	23.25
10967	3	300	375	7.8120000000000003	1	375	7.8120000000000003
10955	1	300	201	4.1870000000000003	1	201	4.1870000000000003
10955	2	300	1711	35.646000000000001	1	1711	35.646000000000001
10955	3	300	3195	66.563000000000002	1.069	3415.6419999999998	71.159000000000006
10956	1	300	327	6.8120000000000003	1	327	6.8120000000000003
10956	2	300	1655	34.478999999999999	1	1655	34.478999999999999
10956	3	300	1409	29.353999999999999	1	1409	29.353999999999999
10957	1	900	114	0.79200000000000004	1	114	0.79200000000000004
10958	1	600	22	0.22900000000000001	1	22	0.22900000000000001
10958	2	300	910	18.957999999999998	1	910	18.957999999999998
10959	1	300	157	3.2709999999999999	1	157	3.2709999999999999
10959	2	300	3554	74.042000000000002	1.16	4124.049	85.918000000000006
10959	3	300	4203	87.563000000000002	1.284	5395.0410000000002	112.39700000000001
10960	1	300	168	3.5	1	168	3.5
10960	2	300	1636	34.082999999999998	1	1636	34.082999999999998
10960	3	300	1468	30.582999999999998	1	1468	30.582999999999998
10961	1	300	259	5.3959999999999999	1	259	5.3959999999999999
10961	2	300	3393	70.688000000000002	1.118	3792.335	79.007000000000005
10961	3	300	238	4.9580000000000002	1	238	4.9580000000000002
10962	1	300	47	0.97899999999999998	1	47	0.97899999999999998
10962	2	300	124	2.5830000000000002	1	124	2.5830000000000002
10962	3	300	84	1.75	1	84	1.75
10947	1	900	156	1.083	1	156	1.083
10948	1	300	338	7.0419999999999998	1	338	7.0419999999999998
10948	2	300	540	11.25	1	540	11.25
10948	3	300	265	5.5209999999999999	1	265	5.5209999999999999
10949	1	300	2822	58.792000000000002	1.021	2880.2689999999998	60.006
10949	2	300	2949	61.438000000000002	1.034	3049.1480000000001	63.524000000000001
10949	3	300	224	4.6669999999999998	1	224	4.6669999999999998
10950	1	300	1941	40.438000000000002	1	1941	40.438000000000002
10950	2	300	2132	44.417000000000002	1	2132	44.417000000000002
10950	3	300	3695	76.978999999999999	1.188	4389.2240000000002	91.441999999999993
10951	1	300	1034	21.542000000000002	1	1034	21.542000000000002
10951	2	300	591	12.313000000000001	1	591	12.313000000000001
10951	3	300	201	4.1870000000000003	1	201	4.1870000000000003
10952	1	300	140	2.9169999999999998	1	140	2.9169999999999998
10952	2	300	226	4.7080000000000002	1	226	4.7080000000000002
10952	3	300	6717	139.93700000000001	1.5	10075.5	209.90600000000001
10953	1	600	1568	16.332999999999998	1	1568	16.332999999999998
10953	2	300	1323	27.562000000000001	1	1323	27.562000000000001
10953	3	300	1198	24.957999999999998	1	1198	24.957999999999998
10954	1	1200	3	0.016	1	3	0.016
10938	1	600	17	0.17699999999999999	1	17	0.17699999999999999
10938	2	300	1895	39.478999999999999	1	1895	39.478999999999999
10939	1	900	44	0.30599999999999999	1	44	0.30599999999999999
10940	1	300	4250	88.542000000000002	1.2920001	5491.9970000000003	114.417
10940	2	300	768	16	1	768	16
10940	3	300	4744	98.832999999999998	1.37	6500.5280000000002	135.428
10941	1	300	355	7.3959999999999999	1	355	7.3959999999999999
10941	2	300	3072	64	1.049	3223.7539999999999	67.162000000000006
10941	3	300	169	3.5209999999999999	1	169	3.5209999999999999
10942	1	900	41	0.28499999999999998	1	41	0.28499999999999998
10943	1	300	13	0.27100000000000002	1	13	0.27100000000000002
10943	2	300	37	0.77100000000000002	1	37	0.77100000000000002
10943	3	300	2181	45.438000000000002	1	2181	45.438000000000002
10944	1	900	82	0.56899999999999995	1	82	0.56899999999999995
10945	1	900	1135	7.8819999999999997	1	1135	7.8819999999999997
10946	1	900	0	0	1	0	0
37348	3	300	0	0	1	0	0
37347	1	300	0	0	1	0	0
37347	2	300	0	0	1	0	0
37347	3	300	0	0	1	0	0
37346	1	300	0	0	1	0	0
37346	2	300	0	0	1	0	0
37346	3	300	0	0	1	0	0
37345	1	300	0	0	1	0	0
37345	2	300	0	0	1	0	0
37345	3	300	0	0	1	0	0
37344	1	300	0	0	1	0	0
37344	2	300	0	0	1	0	0
37344	3	300	0	0	1	0	0
37349	3	300	0.38	0.0080000000000000002	1	0.38	0.0080000000000000002
37350	1	300	2.1299999999999999	0.043999999999999997	1	2.1299999999999999	0.043999999999999997
37348	1	300	0	0	1	0	0
37348	2	300	91.599999999999994	1.9079999999999999	1	91.599999999999994	1.9079999999999999
37350	2	300	3.6000000000000001	0.074999999999999997	1	3.6000000000000001	0.074999999999999997
37350	3	300	1.79	0.036999999999999998	1	1.79	0.036999999999999998
37351	1	300	2315.1999999999998	48.232999999999997	1	2315.1999999999998	48.232999999999997
37351	2	300	1365	28.437000000000001	1	1365	28.437000000000001
37351	3	300	270.60000000000002	5.6369999999999996	1	270.60000000000002	5.6369999999999996
37352	1	300	8.5099999999999998	0.17699999999999999	1	8.5099999999999998	0.17699999999999999
37352	2	300	0	0	1	0	0
37352	3	300	0.91000000000000003	0.019	1	0.91000000000000003	0.019
37353	1	300	0	0	1	0	0
37353	2	300	0	0	1	0	0
37353	3	300	0	0	1	0	0
37359	3	300	8.5	0.17699999999999999	1	8.5	0.17699999999999999
37360	1	300	0.11	0.002	1	0.11	0.002
37349	1	300	4.7599999999999998	0.099000000000000005	1	4.7599999999999998	0.099000000000000005
37349	2	300	0	0	1	0	0
37360	2	300	603	12.563000000000001	1	603	12.563000000000001
37360	3	300	11.210000000000001	0.23400000000000001	1	11.210000000000001	0.23400000000000001
37361	1	300	1.3300000000000001	0.028000000000000001	1	1.3300000000000001	0.028000000000000001
37361	2	300	8.9700000000000006	0.187	1	8.9700000000000006	0.187
37361	3	300	12.98	0.27000000000000002	1	12.98	0.27000000000000002
37362	1	300	0.90000000000000002	0.019	1	0.90000000000000002	0.019
37362	2	300	12.73	0.26500000000000001	1	12.73	0.26500000000000001
37362	3	300	0.40000000000000002	0.0080000000000000002	1	0.40000000000000002	0.0080000000000000002
37363	1	300	0	0	1	0	0
37363	2	300	0	0	1	0	0
37363	3	300	0	0	1	0	0
37359	1	300	8.3499999999999996	0.17399999999999999	1	8.3499999999999996	0.17399999999999999
37359	2	300	102.17	2.129	1	102.17	2.129
10782	2	300	26	0.54200000000000004	1	26	0.54200000000000004
10782	3	300	2428	50.582999999999998	1	2428	50.582999999999998
10783	1	300	179	3.7290000000000001	1	179	3.7290000000000001
10783	2	300	612	12.75	1	612	12.75
10783	3	300	448	9.3330000000000002	1	448	9.3330000000000002
10784	1	300	777	16.187000000000001	1	777	16.187000000000001
10784	2	300	397	8.2710000000000008	1	397	8.2710000000000008
10784	3	300	523	10.896000000000001	1	523	10.896000000000001
10785	1	1200	10	0.051999999999999998	1	10	0.051999999999999998
10769	1	300	0	0	1	0	0
10770	1	900	0	0	1	0	0
10771	1	600	4854	50.563000000000002	1.382	6709.9080000000004	69.894999999999996
10771	2	300	45	0.93799999999999994	1	45	0.93799999999999994
10772	1	300	1334	27.792000000000002	1	1334	27.792000000000002
10772	2	300	503	10.478999999999999	1	503	10.478999999999999
10772	3	300	2818	58.707999999999998	1.02	2875.1039999999998	59.898000000000003
10773	1	600	70	0.72899999999999998	1	70	0.72899999999999998
10773	2	300	0	0	1	0	0
10774	1	300	5564	115.917	1.457	8104.2150000000001	168.83799999999999
10774	2	300	3183	66.313000000000002	1.067	3395.8809999999999	70.748000000000005
10774	3	300	5561	115.854	1.456	8098.1719999999996	168.71199999999999
10775	1	300	1348	28.082999999999998	1	1348	28.082999999999998
10775	2	600	996	10.375	1	996	10.375
10776	1	300	0	0	1	0	0
10777	1	300	1529	31.853999999999999	1	1529	31.853999999999999
10777	2	300	138	2.875	1	138	2.875
10777	3	300	592	12.333	1	592	12.333
34844	1	180	1375.2	47.75	1	1375.2	47.75
34844	2	180	650.60000000000002	22.59	1	650.60000000000002	22.59
34844	3	180	331.19999999999999	11.5	1	331.19999999999999	11.5
34845	1	180	97.799999999999997	3.3959999999999999	1	97.799999999999997	3.3959999999999999
34845	2	180	65	2.2570000000000001	1	65	2.2570000000000001
34845	3	180	147.59999999999999	5.125	1	147.59999999999999	5.125
34846	1	180	2196.8000000000002	76.278000000000006	1	2196.8000000000002	76.278000000000006
34846	2	180	2388.1999999999998	82.924000000000007	1	2388.1999999999998	82.924000000000007
34846	3	180	2184.8000000000002	75.861000000000004	1	2184.8000000000002	75.861000000000004
34847	1	180	5127.8000000000002	178.04900000000001	1.4119999	7238.9449999999997	251.352
34847	2	180	5928.8000000000002	205.86099999999999	1.492	8848.1740000000009	307.22800000000001
34847	3	180	3133.4000000000001	108.79900000000001	1.059	3316.79	115.166
34848	1	180	2710.8000000000002	94.125	1.011	2740.174	95.144999999999996
34848	2	180	3206	111.319	1.071	3433.9929999999999	119.236
34848	3	180	3680.4000000000001	127.792	1.1849999	4361.4790000000003	151.44
34839	1	180	1798.2	62.438000000000002	1	1798.2	62.438000000000002
34839	2	180	24230.400000000001	841.33299999999997	1.5	36345.599999999999	1262
34839	3	180	11837.799999999999	411.03500000000003	1.5	17756.700000000001	616.55200000000002
34840	1	180	3512	121.944	1.152	4046.2649999999999	140.495
34840	2	180	2042	70.903000000000006	1	2042	70.903000000000006
34840	3	180	1621	56.284999999999997	1	1621	56.284999999999997
34841	1	180	763.79999999999995	26.521000000000001	1	763.79999999999995	26.521000000000001
34841	2	180	4571.1999999999998	158.72200000000001	1.35	6171.7749999999996	214.298
34841	3	180	913.79999999999995	31.728999999999999	1	913.79999999999995	31.728999999999999
34842	1	180	2297	79.757000000000005	1	2297	79.757000000000005
34842	2	180	1270.4000000000001	44.110999999999997	1	1270.4000000000001	44.110999999999997
34842	3	180	1777.2	61.707999999999998	1	1777.2	61.707999999999998
34843	1	180	593.79999999999995	20.617999999999999	1	593.79999999999995	20.617999999999999
34843	2	180	429.80000000000001	14.923999999999999	1	429.80000000000001	14.923999999999999
34843	3	180	915.20000000000005	31.777999999999999	1	915.20000000000005	31.777999999999999
34741	1	300	45	0.93799999999999994	1	45	0.93799999999999994
34741	2	300	2448.1999999999998	51.003999999999998	1	2448.1999999999998	51.003999999999998
34741	3	300	659.60000000000002	13.742000000000001	1	659.60000000000002	13.742000000000001
34742	1	300	3939.5999999999999	82.075000000000003	1.235	4863.7960000000003	101.32899999999999
34742	2	300	1577.2	32.857999999999997	1	1577.2	32.857999999999997
34742	3	300	2401	50.021000000000001	1	2401	50.021000000000001
34743	1	300	837.20000000000005	17.442	1	837.20000000000005	17.442
34743	2	300	560.39999999999998	11.675000000000001	1	560.39999999999998	11.675000000000001
34743	3	300	260	5.4169999999999998	1	260	5.4169999999999998
34744	1	300	3715.1999999999998	77.400000000000006	1.192	4427.7200000000003	92.244
34744	2	300	3976.4000000000001	82.841999999999999	1.242	4936.7709999999997	102.849
34744	3	300	4797.6000000000004	99.950000000000003	1.376	6602.3239999999996	137.548
34745	1	300	3511.1999999999998	73.150000000000006	1.152	4044.7890000000002	84.266000000000005
34745	2	300	5504.8000000000002	114.68300000000001	1.451	7985.2060000000001	166.358
34745	3	300	1144.4000000000001	23.841999999999999	1	1144.4000000000001	23.841999999999999
29919	1	300	727.70000000000005	15.16	1	727.70000000000005	15.16
29919	2	300	2814.8000000000002	58.642000000000003	1.02	2870.9789999999998	59.811999999999998
29919	3	300	283.19999999999999	5.9000000000000004	1	283.19999999999999	5.9000000000000004
29920	1	300	2196	45.75	1	2196	45.75
29920	2	300	3339.8000000000002	69.578999999999994	1.102	3679.7289999999998	76.661000000000001
29920	3	300	3181.8000000000002	66.287999999999997	1.067	3393.9189999999999	70.706999999999994
29921	1	300	1375.7	28.66	1	1375.7	28.66
29921	2	300	1702.2	35.463000000000001	1	1702.2	35.463000000000001
29921	3	300	793.89999999999998	16.539999999999999	1	793.89999999999998	16.539999999999999
29922	1	300	1346.5	28.052	1	1346.5	28.052
29922	2	300	416.69999999999999	8.6809999999999992	1	416.69999999999999	8.6809999999999992
29922	3	300	617.60000000000002	12.867000000000001	1	617.60000000000002	12.867000000000001
29923	1	300	1487.0999999999999	30.981000000000002	1	1487.0999999999999	30.981000000000002
29923	2	300	526.79999999999995	10.975	1	526.79999999999995	10.975
29923	3	300	388.19999999999999	8.0869999999999997	1	388.19999999999999	8.0869999999999997
29914	1	300	4592	95.667000000000002	1.354	6216.817	129.517
29914	2	300	2759.8000000000002	57.496000000000002	1.015	2800.9920000000002	58.353999999999999
29914	3	300	91.099999999999994	1.8979999999999999	1	91.099999999999994	1.8979999999999999
29915	1	300	1155.3	24.068999999999999	1	1155.3	24.068999999999999
29915	2	300	3195	66.563000000000002	1.069	3415.6419999999998	71.159000000000006
29915	3	300	7703.1999999999998	160.483	1.5	11554.799999999999	240.72499999999999
29916	1	300	3354.1999999999998	69.879000000000005	1.1059999	3709.2159999999999	77.275000000000006
29916	2	300	3599	74.978999999999999	1.169	4208.0039999999999	87.667000000000002
29916	3	300	5880	122.5	1.488	8747.6100000000006	182.24199999999999
29917	1	300	8524.6000000000004	177.596	1.5	12786.9	266.39400000000001
29917	2	300	6808	141.833	1.5	10212	212.75
29917	3	300	5803	120.896	1.48	8589.5830000000005	178.94999999999999
29918	1	300	1863	38.813000000000002	1	1863	38.813000000000002
29918	2	300	2123	44.228999999999999	1	2123	44.228999999999999
29918	3	300	2322	48.375	1	2322	48.375
27576	1	300	4835	100.729	1.38	6673.6109999999999	139.03399999999999
27576	2	300	4516.6000000000004	94.096000000000004	1.34	6054.1270000000004	126.128
27576	3	300	572	11.917	1	572	11.917
27577	1	300	3482	72.542000000000002	1.146	3991.047	83.147000000000006
27577	2	300	9464.3999999999996	197.17500000000001	1.5	14196.6	295.762
27577	3	300	3057.1999999999998	63.692	1.0470001	3202.0010000000002	66.707999999999998
27578	1	300	146	3.0419999999999998	1	146	3.0419999999999998
27578	2	300	482.19999999999999	10.045999999999999	1	482.19999999999999	10.045999999999999
27578	3	300	816.39999999999998	17.007999999999999	1	816.39999999999998	17.007999999999999
27579	1	300	4699.3999999999996	97.903999999999996	1.365	6416.1610000000001	133.66999999999999
27579	2	300	225.40000000000001	4.6959999999999997	1	225.40000000000001	4.6959999999999997
27579	3	300	2639	54.978999999999999	1.006	2654.0039999999999	55.292000000000002
27580	1	123	2150.5999999999999	109.27800000000001	1	2150.5999999999999	109.27800000000001
27580	2	300	12686.799999999999	264.30799999999999	1.5	19030.200000000001	396.46199999999999
27580	3	300	8948.7999999999993	186.43299999999999	1.5	13423.200000000001	279.64999999999998
27575	1	300	15.1	0.315	1	15.1	0.315
27575	2	300	1896	39.5	1	1896	39.5
27575	3	300	1296.5999999999999	27.013000000000002	1	1296.5999999999999	27.013000000000002
27574	1	300	2138.4000000000001	44.549999999999997	1	2138.4000000000001	44.549999999999997
27574	2	300	6.7000000000000002	0.14000000000000001	1	6.7000000000000002	0.14000000000000001
27574	3	300	911.39999999999998	18.986999999999998	1	911.39999999999998	18.986999999999998
27573	1	300	7089	147.68700000000001	1.5	10633.5	221.53100000000001
27573	2	300	513.10000000000002	10.69	1	513.10000000000002	10.69
27573	3	300	232.5	4.8440000000000003	1	232.5	4.8440000000000003
27572	1	300	108	2.25	1	108	2.25
27572	2	300	296.80000000000001	6.1829999999999998	1	296.80000000000001	6.1829999999999998
27572	3	300	818.79999999999995	17.058	1	818.79999999999995	17.058
27571	1	300	9.3000000000000007	0.19400000000000001	1	9.3000000000000007	0.19400000000000001
27571	2	300	3.1000000000000001	0.065000000000000002	1	3.1000000000000001	0.065000000000000002
27571	3	300	0.80000000000000004	0.017000000000000001	1	0.80000000000000004	0.017000000000000001
27910	1	300	60.399999999999999	1.258	1	60.399999999999999	1.258
27910	2	300	31.600000000000001	0.65800000000000003	1	31.600000000000001	0.65800000000000003
27910	3	300	29	0.60399999999999998	1	29	0.60399999999999998
27909	1	300	24010	500.20800000000003	1.5	36015	750.31200000000001
27909	2	300	16651	346.89600000000002	1.5	24976.5	520.34400000000005
27909	3	300	1828.5999999999999	38.095999999999997	1	1828.5999999999999	38.095999999999997
27908	1	300	4076	84.917000000000002	1.26	5136.317	107.00700000000001
27908	2	300	4645	96.771000000000001	1.363	6332.143	131.91999999999999
27908	3	300	8814	183.625	1.5	13221	275.43700000000001
27907	1	300	15027.4	313.07100000000003	1.5	22541.099999999999	469.60599999999999
27907	2	300	12664.4	263.84199999999998	1.5	18996.599999999999	395.762
27907	3	300	10362.4	215.88300000000001	1.5	15543.6	323.82499999999999
27906	1	300	125.40000000000001	2.613	1	125.40000000000001	2.613
27906	2	300	1019	21.228999999999999	1	1019	21.228999999999999
27906	3	300	625	13.021000000000001	1	625	13.021000000000001
27560	1	300	2342.4000000000001	48.799999999999997	1	2342.4000000000001	48.799999999999997
27560	2	300	524.79999999999995	10.933	1	524.79999999999995	10.933
27560	3	300	5500.3999999999996	114.592	1.45	7976.3800000000001	166.17500000000001
27559	1	300	2915	60.728999999999999	1.03	3002.9650000000001	62.561999999999998
27559	2	300	2666.4000000000001	55.549999999999997	1.008	2686.4409999999998	55.968000000000004
27559	3	300	2619.1999999999998	54.567	1.0039999	2630.9400000000001	54.811
27558	1	300	10062	209.625	1.5	15093	314.43700000000001
27558	2	300	5980.3999999999996	124.592	1.497	8954.8529999999992	186.559
27558	3	300	4858.1999999999998	101.212	1.383	6717.9390000000003	139.95699999999999
27557	1	300	3945	82.188000000000002	1.2359999	4874.4790000000003	101.55200000000001
27557	2	300	6607	137.64599999999999	1.5	9910.5	206.46899999999999
27557	3	300	8562.7999999999993	178.392	1.5	12844.200000000001	267.58800000000002
27556	1	300	6242.1999999999998	130.04599999999999	1.5	9363.2999999999993	195.06899999999999
27556	2	300	3657	76.188000000000002	1.181	4317.1480000000001	89.941000000000003
27556	3	300	6714.6000000000004	139.88800000000001	1.5	10071.9	209.83099999999999
24661	1	300	12870.4	268.13299999999998	1.5	19305.599999999999	402.19999999999999
24661	2	300	6530	136.042	1.5	9795	204.06200000000001
24661	3	300	6449.8000000000002	134.37100000000001	1.5	9674.7000000000007	201.55600000000001
24662	1	300	9355.2000000000007	194.90000000000001	1.5	14032.799999999999	292.35000000000002
24662	2	300	4253.8000000000002	88.620999999999995	1.293	5499.8639999999996	114.58
24662	3	300	3239.8000000000002	67.495999999999995	1.0779999	3491.9119999999998	72.748000000000005
24663	1	300	382.19999999999999	7.9619999999999997	1	382.19999999999999	7.9619999999999997
24663	2	300	476.80000000000001	9.9329999999999998	1	476.80000000000001	9.9329999999999998
24663	3	300	2626.1999999999998	54.713000000000001	1.005	2639.056	54.979999999999997
24664	1	300	7123.1999999999998	148.40000000000001	1.5	10684.799999999999	222.59999999999999
24664	2	300	4679.3999999999996	97.486999999999995	1.363	6378.4269999999997	132.88399999999999
24664	3	300	5317.8000000000002	110.788	1.432	7612.5110000000004	158.59399999999999
24665	1	300	4240.1999999999998	88.337000000000003	1.29	5471.7269999999999	113.994
24665	2	300	1606.2	33.463000000000001	1	1606.2	33.463000000000001
24665	3	300	5326.8000000000002	110.97499999999999	1.432	7630.335	158.965
24650	1	300	2946.5999999999999	61.387	1.034	3045.8620000000001	63.454999999999998
24650	2	300	8226.3999999999996	171.38300000000001	1.5	12339.6	257.07499999999999
24650	3	300	4861.8000000000002	101.288	1.383	6724.8239999999996	140.101
24649	1	300	1106.5999999999999	23.053999999999998	1	1106.5999999999999	23.053999999999998
24649	2	300	1600	33.332999999999998	1	1600	33.332999999999998
24649	3	300	1209.8	25.204000000000001	1	1209.8	25.204000000000001
24648	1	300	726	15.125	1	726	15.125
24083	1	900	10290.299999999999	71.459999999999994	1.5	15435.450000000001	107.191
24082	1	900	12216.5	84.837000000000003	1.5	18324.75	127.255
24081	1	900	195.34999999999999	1.357	1	195.34999999999999	1.357
34864	1	180	84.400000000000006	2.931	1	84.400000000000006	2.931
34864	2	180	31.5	1.0940000000000001	1	31.5	1.0940000000000001
34864	3	180	6095.6000000000004	211.65299999999999	1.5	9143.3999999999996	317.47899999999998
34865	1	180	285.10000000000002	9.8989999999999991	1	285.10000000000002	9.8989999999999991
34865	2	180	467.30000000000001	16.225999999999999	1	467.30000000000001	16.225999999999999
34865	3	180	136.40000000000001	4.7359999999999998	1	136.40000000000001	4.7359999999999998
34866	1	180	4651.6000000000004	161.51400000000001	1.36	6326.0789999999997	219.65600000000001
34866	2	180	3351.5999999999999	116.375	1.105	3703.8400000000001	128.60599999999999
34866	3	180	76.5	2.6560000000000001	1	76.5	2.6560000000000001
34867	1	180	2397.8000000000002	83.257000000000005	1	2397.8000000000002	83.257000000000005
34867	2	180	18791.799999999999	652.49300000000005	1.5	28187.700000000001	978.74000000000001
34867	3	180	11207.6	389.15300000000002	1.5	16811.400000000001	583.72900000000004
34868	1	180	3131.5999999999999	108.736	1.058	3313.9920000000002	115.069
34868	2	180	3048.4000000000001	105.84699999999999	1.046	3189.1759999999999	110.735
34868	3	180	1922.4000000000001	66.75	1	1922.4000000000001	66.75
34859	1	180	6718.6000000000004	233.285	1.5	10077.9	349.92700000000002
34859	2	180	1981	68.784999999999997	1	1981	68.784999999999997
34859	3	180	3211.5999999999999	111.514	1.072	3443.4259999999999	119.563
34860	1	180	743.60000000000002	25.818999999999999	1	743.60000000000002	25.818999999999999
34860	2	180	950.20000000000005	32.993000000000002	1	950.20000000000005	32.993000000000002
34860	3	180	1125	39.063000000000002	1	1125	39.063000000000002
34861	1	180	8682.7999999999993	301.48599999999999	1.5	13024.200000000001	452.22899999999998
34861	2	180	4928	171.11099999999999	1.39	6851.7920000000004	237.90899999999999
34861	3	180	10468	363.47199999999998	1.5	15702	545.20799999999997
34862	1	180	210.19999999999999	7.2990000000000004	1	210.19999999999999	7.2990000000000004
34862	2	180	67.200000000000003	2.3330000000000002	1	67.200000000000003	2.3330000000000002
34862	3	180	24	0.83299999999999996	1	24	0.83299999999999996
34863	1	180	11321.799999999999	393.11799999999999	1.5	16982.700000000001	589.67700000000002
34863	2	180	8851.7999999999993	307.35399999999998	1.5	13277.700000000001	461.03100000000001
34863	3	180	5758	199.93100000000001	1.476	8497.6000000000004	295.05599999999998
34751	1	300	3895	81.146000000000001	1.226	4775.9030000000002	99.498000000000005
34751	2	300	4026	83.875	1.251	5035.7719999999999	104.91200000000001
34751	3	300	4690	97.707999999999998	1.364	6398.4179999999997	133.30000000000001
34752	1	300	2539.5999999999999	52.908000000000001	1.001	2541.8299999999999	52.954999999999998
34752	2	300	6968.8000000000002	145.18299999999999	1.5	10453.200000000001	217.77500000000001
34752	3	300	4323.8000000000002	90.078999999999994	1.306	5645.5420000000004	117.61499999999999
34753	1	300	6217	129.52099999999999	1.5	9325.5	194.28100000000001
34753	2	300	8577.6000000000004	178.69999999999999	1.5	12866.4	268.05000000000001
34753	3	300	3580.1999999999998	74.587000000000003	1.166	4172.8519999999999	86.933999999999997
34754	1	300	5461.1999999999998	113.77500000000001	1.446	7897.8699999999999	164.53899999999999
34754	2	300	3179.8000000000002	66.245999999999995	1.066	3390.6550000000002	70.638999999999996
34754	3	300	3115.8000000000002	64.912999999999997	1.056	3289.623	68.534000000000006
34755	1	300	1124.4000000000001	23.425000000000001	1	1124.4000000000001	23.425000000000001
34755	2	300	2303.1999999999998	47.982999999999997	1	2303.1999999999998	47.982999999999997
34755	3	300	7096.8000000000002	147.84999999999999	1.5	10645.200000000001	221.77500000000001
29939	1	300	1683.5999999999999	35.075000000000003	1	1683.5999999999999	35.075000000000003
29939	2	300	2029.2	42.274999999999999	1	2029.2	42.274999999999999
29939	3	300	3689.4000000000001	76.861999999999995	1.187	4378.5739999999996	91.219999999999999
29940	1	300	1461.4000000000001	30.446000000000002	1	1461.4000000000001	30.446000000000002
29940	2	300	1199.5999999999999	24.992000000000001	1	1199.5999999999999	24.992000000000001
29940	3	300	3621.4000000000001	75.445999999999998	1.174	4250.0320000000002	88.542000000000002
29941	1	300	455.80000000000001	9.4960000000000004	1	455.80000000000001	9.4960000000000004
29941	2	300	135.80000000000001	2.8290000000000002	1	135.80000000000001	2.8290000000000002
29941	3	300	708	14.75	1	708	14.75
29942	1	300	214.59999999999999	4.4710000000000001	1	214.59999999999999	4.4710000000000001
29942	2	300	154.59999999999999	3.2210000000000001	1	154.59999999999999	3.2210000000000001
29942	3	300	147	3.0630000000000002	1	147	3.0630000000000002
29943	1	300	19.800000000000001	0.41299999999999998	1	19.800000000000001	0.41299999999999998
29943	2	300	13.4	0.27900000000000003	1	13.4	0.27900000000000003
29943	3	300	316.39999999999998	6.5919999999999996	1	316.39999999999998	6.5919999999999996
29934	1	300	5647.1999999999998	117.65000000000001	1.465	8272.2919999999995	172.339
29934	2	300	2130.8000000000002	44.392000000000003	1	2130.8000000000002	44.392000000000003
29934	3	300	2069.1999999999998	43.107999999999997	1	2069.1999999999998	43.107999999999997
29935	1	300	0	0	1	0	0
29935	2	300	2611	54.396000000000001	1.0039999	2621.4850000000001	54.613999999999997
29935	3	300	2032.4000000000001	42.341999999999999	1	2032.4000000000001	42.341999999999999
29936	1	300	3313.4000000000001	69.028999999999996	1.095	3627.4110000000001	75.570999999999998
29936	2	300	3604	75.082999999999998	1.17	4217.3720000000003	87.861999999999995
29936	3	300	4682	97.542000000000002	1.363	6383.3289999999997	132.98599999999999
29937	1	300	6352	132.333	1.5	9528	198.5
29937	2	300	3238	67.457999999999998	1.077	3488.7660000000001	72.683000000000007
29937	3	300	5384	112.167	1.438	7743.884	161.33099999999999
29938	1	300	4014.1999999999998	83.629000000000005	1.249	5012.152	104.42
29938	2	300	2720	56.667000000000002	1.012	2751.4769999999999	57.322000000000003
29938	3	300	940	19.582999999999998	1	940	19.582999999999998
27658	1	300	1656.2	34.503999999999998	1	1656.2	34.503999999999998
27658	2	300	2011.5999999999999	41.908000000000001	1	2011.5999999999999	41.908000000000001
27658	3	300	6749.8000000000002	140.62100000000001	1.5	10124.700000000001	210.93100000000001
27659	1	300	474.60000000000002	9.8879999999999999	1	474.60000000000002	9.8879999999999999
27659	2	300	1937	40.353999999999999	1	1937	40.353999999999999
27659	3	300	3997	83.271000000000001	1.245	4977.7979999999998	103.70399999999999
27660	1	300	4371	91.063000000000002	1.314	5744.576	119.679
27660	2	300	6465	134.68700000000001	1.5	9697.5	202.03100000000001
27660	3	300	3581	74.603999999999999	1.166	4174.3459999999995	86.965999999999994
27661	1	300	5495	114.479	1.45	7965.5519999999997	165.94900000000001
27661	2	300	4557	94.938000000000002	1.348	6141.0959999999995	127.94
27661	3	300	2697.5999999999999	56.200000000000003	1.01	2724.056	56.750999999999998
27662	1	300	74.400000000000006	1.55	1	74.400000000000006	1.55
27662	2	300	6	0.125	1	6	0.125
27662	3	300	822	17.125	1	822	17.125
27652	1	300	2455.8000000000002	51.161999999999999	1	2455.8000000000002	51.161999999999999
27652	2	300	315.80000000000001	6.5789999999999997	1	315.80000000000001	6.5789999999999997
27652	3	300	964.79999999999995	20.100000000000001	1	964.79999999999995	20.100000000000001
27651	1	300	3816.4000000000001	79.507999999999996	1.211	4622.4769999999999	96.302000000000007
27651	2	300	2168.5999999999999	45.179000000000002	1	2168.5999999999999	45.179000000000002
27651	3	300	1314.5999999999999	27.388000000000002	1	1314.5999999999999	27.388000000000002
27650	1	300	2062	42.957999999999998	1	2062	42.957999999999998
27650	2	300	1657	34.521000000000001	1	1657	34.521000000000001
27650	3	300	1311	27.312000000000001	1	1311	27.312000000000001
27649	1	300	9171	191.06200000000001	1.5	13756.5	286.59399999999999
27649	2	300	8000	166.667	1.5	12000	250
27649	3	300	2885.1999999999998	60.107999999999997	1.027	2963.0929999999998	61.731000000000002
27648	1	300	151.80000000000001	3.1619999999999999	1	151.80000000000001	3.1619999999999999
27648	2	300	490.89999999999998	10.227	1	490.89999999999998	10.227
27648	3	300	1004	20.917000000000002	1	1004	20.917000000000002
27647	1	300	4684	97.582999999999998	1.364	6387.1000000000004	133.065
27647	2	300	3256	67.832999999999998	1.081	3520.5610000000001	73.344999999999999
27647	3	300	4606	95.957999999999998	1.3559999	6247.2030000000004	130.15000000000001
27646	1	300	6012	125.25	1.5	9018	187.875
27646	2	300	6054	126.125	1.5	9081	189.18700000000001
27646	3	300	4921	102.521	1.39	6838.335	142.465
27645	1	300	639	13.313000000000001	1	639	13.313000000000001
27645	2	300	8660	180.417	1.5	12990	270.625
27645	3	300	7493	156.10400000000001	1.5	11239.5	234.15600000000001
27644	1	300	5147	107.229	1.414	7276.4570000000003	151.59299999999999
27644	2	0	3306	\N	1.0930001	3613.127	\N
27644	3	300	4333	90.271000000000001	1.307	5664.7939999999999	118.017
27643	1	300	2663	55.478999999999999	1.007	2682.384	55.883000000000003
27643	2	300	4227	88.063000000000002	1.288	5444.4690000000001	113.426
27643	3	300	1398	29.125	1	1398	29.125
27634	1	300	6964.8000000000002	145.09999999999999	1.5	10447.200000000001	217.65000000000001
27634	2	300	5554	115.708	1.456	8084.0780000000004	168.41800000000001
27634	3	300	1481.5999999999999	30.867000000000001	1	1481.5999999999999	30.867000000000001
27635	1	300	3313.8000000000002	69.037999999999997	1.095	3628.1880000000001	75.587000000000003
27635	2	300	3345.8000000000002	69.703999999999994	1.103	3691.931	76.915000000000006
27635	3	300	7392	154	1.5	11088	231
27636	1	300	417.60000000000002	8.6999999999999993	1	417.60000000000002	8.6999999999999993
27636	2	300	7352.6000000000004	153.179	1.5	11028.9	229.76900000000001
27636	3	300	6502.1999999999998	135.46199999999999	1.5	9753.2999999999993	203.19399999999999
27637	1	300	5476	114.083	1.448	7927.4859999999999	165.15600000000001
27637	2	300	4000	83.332999999999998	1.2460001	4983.7839999999997	103.82899999999999
27637	3	300	7287.1999999999998	151.81700000000001	1.5	10930.799999999999	227.72499999999999
27633	1	300	6353.6000000000004	132.36699999999999	1.5	9530.3999999999996	198.55000000000001
27633	2	300	6124.1999999999998	127.587	1.5	9186.2999999999993	191.381
27633	3	300	902.39999999999998	18.800000000000001	1	902.39999999999998	18.800000000000001
27632	1	300	1212.8	25.266999999999999	1	1212.8	25.266999999999999
27632	2	300	438.80000000000001	9.1419999999999995	1	438.80000000000001	9.1419999999999995
27632	3	300	524.20000000000005	10.920999999999999	1	524.20000000000005	10.920999999999999
27631	1	300	7549.6000000000004	157.28299999999999	1.5	11324.4	235.92500000000001
27631	2	300	5188.3999999999996	108.092	1.418	7357.5259999999998	153.28200000000001
27631	3	300	5457.1999999999998	113.69199999999999	1.446	7889.8710000000001	164.37200000000001
27630	1	300	9730.6000000000004	202.721	1.5	14595.9	304.08100000000002
27630	2	300	5827.6000000000004	121.408	1.483	8639.9830000000002	180
27630	3	300	12383.799999999999	257.99599999999998	1.5	18575.700000000001	386.99400000000003
27629	1	300	3480.1999999999998	72.504000000000005	1.146	3987.7429999999999	83.078000000000003
27629	2	300	4337.8000000000002	90.370999999999995	1.308	5674.8490000000002	118.226
27629	3	300	357.60000000000002	7.4500000000000002	1	357.60000000000002	7.4500000000000002
27628	1	300	192.19999999999999	4.0039999999999996	1	192.19999999999999	4.0039999999999996
27628	2	300	584.60000000000002	12.179	1	584.60000000000002	12.179
27628	3	300	1368.9000000000001	28.518999999999998	1	1368.9000000000001	28.518999999999998
24761	1	300	2655.8000000000002	55.329000000000001	1.007	2673.8229999999999	55.704999999999998
24761	2	300	1661.4000000000001	34.613	1	1661.4000000000001	34.613
24761	3	300	1570	32.707999999999998	1	1570	32.707999999999998
24762	1	300	5855	121.979	1.485	8696.2150000000001	181.17099999999999
24762	2	300	20688	431	1.5	31032	646.5
24762	3	300	10093.6	210.28299999999999	1.5	15140.4	315.42500000000001
24763	1	300	4946.3999999999996	103.05	1.392	6887.1980000000003	143.483
24763	2	300	14134.799999999999	294.47500000000002	1.5	21202.200000000001	441.71199999999999
24763	3	300	17742.799999999999	369.642	1.5	26614.200000000001	554.46199999999999
24764	1	300	11170	232.708	1.5	16755	349.06200000000001
24764	2	300	3110.5999999999999	64.804000000000002	1.0549999	3281.6770000000001	68.367999999999995
24764	3	300	10938.4	227.88300000000001	1.5	16407.599999999999	341.82499999999999
24765	1	300	1038.8	21.641999999999999	1	1038.8	21.641999999999999
24765	2	300	1036.8	21.600000000000001	1	1036.8	21.600000000000001
24765	3	300	473.19999999999999	9.8580000000000005	1	473.19999999999999	9.8580000000000005
24750	1	300	3466.4000000000001	72.216999999999999	1.143	3962.4459999999999	82.551000000000002
24750	2	300	3033.5999999999999	63.200000000000003	1.044	3167.7820000000002	65.995000000000005
24750	3	300	2429.1999999999998	50.607999999999997	1	2429.1999999999998	50.607999999999997
24749	1	300	2630.1999999999998	54.795999999999999	1.005	2643.7130000000002	55.076999999999998
24749	2	300	2225	46.353999999999999	1	2225	46.353999999999999
24749	3	300	2363	49.228999999999999	1	2363	49.228999999999999
24748	1	300	1548.2	32.253999999999998	1	1548.2	32.253999999999998
24748	2	300	2695.8000000000002	56.161999999999999	1.01	2721.8670000000002	56.706000000000003
24748	3	300	1545	32.188000000000002	1	1545	32.188000000000002
24747	1	300	231.94	4.8319999999999999	1	231.94	4.8319999999999999
24747	2	300	59.850000000000001	1.2470000000000001	1	59.850000000000001	1.2470000000000001
24747	3	300	149.25	3.109	1	149.25	3.109
29815	2	180	12.800000000000001	0.44400000000000001	1	12.800000000000001	0.44400000000000001
29815	3	180	632.39999999999998	21.957999999999998	1	632.39999999999998	21.957999999999998
29816	1	180	241.80000000000001	8.3960000000000008	1	241.80000000000001	8.3960000000000008
29816	2	180	227.09999999999999	7.8849999999999998	1	227.09999999999999	7.8849999999999998
29816	3	180	42.299999999999997	1.4690000000000001	1	42.299999999999997	1.4690000000000001
29817	1	180	21.399999999999999	0.74299999999999999	1	21.399999999999999	0.74299999999999999
29817	2	180	5.7000000000000002	0.19800000000000001	1	5.7000000000000002	0.19800000000000001
29817	3	180	187.09999999999999	6.4969999999999999	1	187.09999999999999	6.4969999999999999
29818	1	300	0	0	1	0	0
29818	2	300	0	0	1	0	0
29818	3	300	0	0	1	0	0
27386	1	900	0	0	1	0	0
27387	1	900	0	0	1	0	0
27388	1	300	37.700000000000003	0.78500000000000003	1	37.700000000000003	0.78500000000000003
27388	2	300	11.800000000000001	0.246	1	11.800000000000001	0.246
27388	3	300	0.80000000000000004	0.017000000000000001	1	0.80000000000000004	0.017000000000000001
27389	1	300	0	0	1	0	0
27389	2	300	164.19999999999999	3.4209999999999998	1	164.19999999999999	3.4209999999999998
27389	3	300	0	0	1	0	0
27390	1	300	0	0	1	0	0
27390	2	300	0	0	1	0	0
27390	3	300	5.5999999999999996	0.11700000000000001	1	5.5999999999999996	0.11700000000000001
27381	1	920	0	0	1	0	0
27382	1	910	0	0	1	0	0
27383	1	300	15	0.313	1	15	0.313
27383	2	300	16.800000000000001	0.34999999999999998	1	16.800000000000001	0.34999999999999998
27383	3	300	11.199999999999999	0.23300000000000001	1	11.199999999999999	0.23300000000000001
27384	1	300	0	0	1	0	0
27384	2	300	15.199999999999999	0.317	1	15.199999999999999	0.317
27384	3	300	0	0	1	0	0
27385	1	900	0	0	1	0	0
27380	1	300	0	0	1	0	0
27380	2	300	0	0	1	0	0
27380	3	300	110.40000000000001	2.2999999999999998	1	110.40000000000001	2.2999999999999998
27379	1	900	0	0	1	0	0
27378	1	300	0	0	1	0	0
27378	2	300	0	0	1	0	0
27378	3	300	1057.2	22.024999999999999	1	1057.2	22.024999999999999
27377	1	300	5997	124.938	1.499	8989.2479999999996	187.27600000000001
27377	2	300	3253.4000000000001	67.778999999999996	1.081	3515.922	73.248000000000005
27377	3	300	3833.4000000000001	79.861999999999995	1.214	4655.5010000000002	96.989999999999995
27376	1	900	0	0	1	0	0
27375	1	300	6	0.125	1	6	0.125
27375	2	300	1	0.021000000000000001	1	1	0.021000000000000001
27375	3	300	15.5	0.32300000000000001	1	15.5	0.32300000000000001
27374	1	300	293	6.1040000000000001	1	293	6.1040000000000001
27374	2	300	45.5	0.94799999999999995	1	45.5	0.94799999999999995
27374	3	300	9.5	0.19800000000000001	1	9.5	0.19800000000000001
27373	1	300	3.5	0.072999999999999995	1	3.5	0.072999999999999995
27373	2	300	58.5	1.2190000000000001	1	58.5	1.2190000000000001
27373	3	300	1196	24.917000000000002	1	1196	24.917000000000002
27372	1	300	75	1.5629999999999999	1	75	1.5629999999999999
27372	2	300	3	0.063	1	3	0.063
27372	3	300	2.5	0.051999999999999998	1	2.5	0.051999999999999998
27371	1	300	0.5	0.01	1	0.5	0.01
27371	2	300	0.5	0.01	1	0.5	0.01
27371	3	300	1	0.021000000000000001	1	1	0.021000000000000001
27370	1	900	0	0	1	0	0
27369	1	300	0	0	1	0	0
27369	2	300	0	0	1	0	0
27369	3	300	9	0.188	1	9	0.188
27368	1	300	40.200000000000003	0.83799999999999997	1	40.200000000000003	0.83799999999999997
27368	2	300	14.4	0.29999999999999999	1	14.4	0.29999999999999999
27368	3	300	3.6000000000000001	0.074999999999999997	1	3.6000000000000001	0.074999999999999997
27367	1	300	85.599999999999994	1.7829999999999999	1	85.599999999999994	1.7829999999999999
27367	2	300	2353.4000000000001	49.029000000000003	1	2353.4000000000001	49.029000000000003
27367	3	300	1183.2	24.649999999999999	1	1183.2	24.649999999999999
27366	1	300	0	0	1	0	0
27366	2	300	0	0	1	0	0
27366	3	300	50	1.042	1	50	1.042
27365	1	900	0	0	1	0	0
24481	1	300	13.4	0.27900000000000003	1	13.4	0.27900000000000003
24481	2	300	19.800000000000001	0.41299999999999998	1	19.800000000000001	0.41299999999999998
24481	3	300	46.600000000000001	0.97099999999999997	1	46.600000000000001	0.97099999999999997
24482	1	300	9.1999999999999993	0.192	1	9.1999999999999993	0.192
24482	2	300	249.59999999999999	5.2000000000000002	1	249.59999999999999	5.2000000000000002
24482	3	300	0	0	1	0	0
24483	1	300	229	4.7709999999999999	1	229	4.7709999999999999
24483	2	300	130.80000000000001	2.7250000000000001	1	130.80000000000001	2.7250000000000001
24483	3	300	0	0	1	0	0
24484	1	900	0	0	1	0	0
24485	1	900	0	0	1	0	0
34400	1	300	1482.8	30.891999999999999	1	1482.8	30.891999999999999
34400	2	300	4480.1999999999998	93.337000000000003	1.334	5976.1670000000004	124.503
34400	3	300	367.80000000000001	7.6630000000000003	1	367.80000000000001	7.6630000000000003
34401	1	300	358.89999999999998	7.4770000000000003	1	358.89999999999998	7.4770000000000003
34401	2	300	0	0	1	0	0
34401	3	300	0	0	1	0	0
23965	1	900	19.449999999999999	0.13500000000000001	1	19.449999999999999	0.13500000000000001
23964	1	900	21.899999999999999	0.152	1	21.899999999999999	0.152
23963	1	900	14.1	0.098000000000000004	1	14.1	0.098000000000000004
23962	1	900	136	0.94399999999999995	1	136	0.94399999999999995
23961	1	900	0	0	1	0	0
23640	1	900	0	0	1	0	0
23639	1	900	0	0	1	0	0
23638	1	900	150	1.042	1	150	1.042
23637	1	900	0	0	1	0	0
23636	1	900	0	0	1	0	0
23635	1	900	0	0	1	0	0
23634	1	900	134.15000000000001	0.93200000000000005	1	134.15000000000001	0.93200000000000005
23633	1	900	2428.3499999999999	16.864000000000001	1	2428.3499999999999	16.864000000000001
23632	1	900	0	0	1	0	0
23631	1	900	0	0	1	0	0
23630	1	900	120.09999999999999	0.83399999999999996	1	120.09999999999999	0.83399999999999996
23629	1	900	2571.4000000000001	17.856999999999999	1.002	2576.6860000000001	17.893999999999998
23628	1	900	3239.8000000000002	22.498999999999999	1.0779999	3491.9119999999998	24.248999999999999
23627	1	900	0	0	1	0	0
23626	1	900	0	0	1	0	0
23625	1	900	348.60000000000002	2.4209999999999998	1	348.60000000000002	2.4209999999999998
23624	1	900	953.20000000000005	6.6189999999999998	1	953.20000000000005	6.6189999999999998
23623	1	900	4683	32.521000000000001	1.363	6385.2139999999999	44.341999999999999
23622	1	900	585.04999999999995	4.0629999999999997	1	585.04999999999995	4.0629999999999997
23621	1	900	0	0	1	0	0
23615	1	900	256.5	1.7809999999999999	1	256.5	1.7809999999999999
23614	1	900	1901.25	13.202999999999999	1	1901.25	13.202999999999999
23613	1	900	156.30000000000001	1.085	1	156.30000000000001	1.085
23612	1	900	197.09999999999999	1.369	1	197.09999999999999	1.369
23611	1	900	0	0	1	0	0
23610	1	900	20.399999999999999	0.14199999999999999	1	20.399999999999999	0.14199999999999999
23609	1	900	18.100000000000001	0.126	1	18.100000000000001	0.126
23608	1	900	965.25	6.7030000000000003	1	965.25	6.7030000000000003
23607	1	900	323.69999999999999	2.2480000000000002	1	323.69999999999999	2.2480000000000002
23606	1	900	83.849999999999994	0.58199999999999996	1	83.849999999999994	0.58199999999999996
23605	1	900	813.20000000000005	5.6470000000000002	1	813.20000000000005	5.6470000000000002
23604	1	900	1268.5999999999999	8.8100000000000005	1	1268.5999999999999	8.8100000000000005
23603	1	900	3016.3000000000002	20.946999999999999	1.0420001	3143.0369999999998	21.827000000000002
23602	1	1500	0	0	1	0	0
23601	1	1200	0	0	1	0	0
13041	1	900	0	0	1	0	0
13042	1	300	64	1.333	1	64	1.333
13042	2	300	106	2.2080000000000002	1	106	2.2080000000000002
13042	3	300	122	2.5419999999999998	1	122	2.5419999999999998
13043	1	300	412	8.5830000000000002	1	412	8.5830000000000002
13043	2	300	81	1.6879999999999999	1	81	1.6879999999999999
13043	3	300	105	2.1880000000000002	1	105	2.1880000000000002
13044	1	300	984	20.5	1	984	20.5
13044	2	300	388	8.0830000000000002	1	388	8.0830000000000002
13044	3	300	421	8.7710000000000008	1	421	8.7710000000000008
13045	1	900	0	0	1	0	0
12862	1	900	0	0	1	0	0
12863	1	300	944	19.667000000000002	1	944	19.667000000000002
12863	2	300	210	4.375	1	210	4.375
12863	3	300	1200	25	1	1200	25
12864	1	302	174	3.601	1	174	3.601
12864	2	317	395	7.7880000000000003	1	395	7.7880000000000003
12864	3	300	98	2.0419999999999998	1	98	2.0419999999999998
12865	1	900	0	0	1	0	0
12866	1	900	0	0	1	0	0
12856	1	900	0	0	1	0	0
12857	1	300	0	0	1	0	0
12857	2	300	6	0.125	1	6	0.125
12857	3	300	138	2.875	1	138	2.875
12858	1	300	70	1.458	1	70	1.458
12858	2	300	9	0.188	1	9	0.188
12858	3	300	0	0	1	0	0
12859	1	300	100	2.0830000000000002	1	100	2.0830000000000002
12859	2	300	1547	32.228999999999999	1	1547	32.228999999999999
12859	3	300	141	2.9380000000000002	1	141	2.9380000000000002
12860	1	900	0	0	1	0	0
12861	1	900	0	0	1	0	0
11930	1	300	149	3.1040000000000001	1	149	3.1040000000000001
11930	2	300	0	0	1	0	0
11930	3	300	227	4.7290000000000001	1	227	4.7290000000000001
11931	1	300	2	0.042000000000000003	1	2	0.042000000000000003
11931	2	300	3	0.063	1	3	0.063
11931	3	300	573	11.938000000000001	1	573	11.938000000000001
11932	1	300	320	6.6669999999999998	1	320	6.6669999999999998
11932	2	300	194	4.0419999999999998	1	194	4.0419999999999998
11932	3	300	496	10.333	1	496	10.333
11933	1	300	12	0.25	1	12	0.25
11933	2	300	745	15.521000000000001	1	745	15.521000000000001
11933	3	300	13	0.27100000000000002	1	13	0.27100000000000002
11934	1	900	0	0	1	0	0
11925	1	900	0	0	1	0	0
11926	1	900	0	0	1	0	0
11927	1	900	0	0	1	0	0
11928	1	900	0	0	1	0	0
11929	1	900	0	0	1	0	0
11920	1	900	0	0	1	0	0
11921	1	300	0	0	1	0	0
11921	2	300	18	0.375	1	18	0.375
11921	3	300	0	0	1	0	0
11922	1	300	0	0	1	0	0
11922	2	300	1	0.021000000000000001	1	1	0.021000000000000001
11922	3	300	1	0.021000000000000001	1	1	0.021000000000000001
11923	1	900	0	0	1	0	0
11924	1	900	0	0	1	0	0
11917	1	1500	0	0	1	0	0
11918	1	300	53	1.1040000000000001	1	53	1.1040000000000001
11918	2	300	0	0	1	0	0
11918	3	300	0	0	1	0	0
11919	1	900	0	0	1	0	0
10457	1	1500	0	0	1	0	0
10458	1	300	0	0	1	0	0
10458	2	600	0	0	1	0	0
10458	3	600	0	0	1	0	0
10459	1	300	68	1.417	1	68	1.417
10459	2	600	183	1.9059999999999999	1	183	1.9059999999999999
10459	3	600	230	2.3959999999999999	1	230	2.3959999999999999
10460	1	300	0	0	1	0	0
10461	1	1500	0	0	1	0	0
10443	1	600	24	0.25	1	24	0.25
10443	2	600	61	0.63500000000000001	1	61	0.63500000000000001
10443	3	600	3	0.031	1	3	0.031
10444	1	600	0	0	1	0	0
10444	2	600	174	1.8129999999999999	1	174	1.8129999999999999
10444	3	600	1220	12.708	1	1220	12.708
10445	1	600	341	3.552	1	341	3.552
10445	2	600	14	0.14599999999999999	1	14	0.14599999999999999
10445	3	600	15	0.156	1	15	0.156
10446	1	300	12	0.25	1	12	0.25
10446	2	600	0	0	1	0	0
10446	3	600	0	0	1	0	0
10447	1	300	0	0	1	0	0
10448	1	300	0	0	1	0	0
10449	1	300	0	0	1	0	0
10450	1	300	0	0	1	0	0
10314	1	300	0	0	1	0	0
10315	1	300	0	0	1	0	0
10316	1	300	0	0	1	0	0
10317	1	300	0	0	1	0	0
10318	1	300	0	0	1	0	0
10319	1	300	0	0	1	0	0
10320	1	300	0	0	1	0	0
10455	2	600	0	0	1	0	0
10455	3	600	144	1.5	1	144	1.5
10455	4	600	2852	29.707999999999998	1.024	2919.2979999999998	30.408999999999999
10456	1	300	0	0	1	0	0
10454	1	300	0	0	1	0	0
10455	1	300	0	0	1	0	0
10604	6	60	2747	286.14600000000002	1.0140001	2784.9609999999998	290.10000000000002
10605	1	300	320	6.6669999999999998	1	320	6.6669999999999998
10605	2	600	442	4.6040000000000001	1	442	4.6040000000000001
10605	3	600	313	3.2599999999999998	1	313	3.2599999999999998
10606	1	1500	31	0.129	1	31	0.129
10628	1	1200	0	0	1	0	0
10629	1	300	5291	110.229	1.429	7559.5039999999999	157.49000000000001
10629	2	300	325	6.7709999999999999	1	325	6.7709999999999999
10629	3	300	2086	43.457999999999998	1	2086	43.457999999999998
10629	4	300	6727	140.14599999999999	1.5	10090.5	210.21899999999999
10630	1	300	0	0	1	0	0
10631	1	300	0	0	1	0	0
10595	1	300	0	0	1	0	0
10596	1	900	177	1.2290000000000001	1	177	1.2290000000000001
10596	2	300	452	9.4169999999999998	1	452	9.4169999999999998
10597	1	300	58	1.208	1	58	1.208
10597	2	300	139	2.8959999999999999	1	139	2.8959999999999999
10597	3	300	40	0.83299999999999996	1	40	0.83299999999999996
10598	1	900	34	0.23599999999999999	1	34	0.23599999999999999
10599	1	900	0	0	1	0	0
10600	1	300	0	0	1	0	0
10591	1	300	0	0	1	0	0
10592	1	900	212	1.472	1	212	1.472
10592	2	900	81	0.56299999999999994	1	81	0.56299999999999994
10593	1	1200	27	0.14099999999999999	1	27	0.14099999999999999
10593	2	600	663	6.9059999999999997	1	663	6.9059999999999997
10594	1	300	0	0	1	0	0
34814	1	300	822.79999999999995	17.141999999999999	1	822.79999999999995	17.141999999999999
34814	2	300	8316	173.25	1.5	12474	259.875
34814	3	300	4087.8000000000002	85.162999999999997	1.262	5160.1540000000005	107.503
34815	1	300	14918.4	310.80000000000001	1.5	22377.599999999999	466.19999999999999
34815	2	300	6620.3999999999996	137.92500000000001	1.5	9930.6000000000004	206.887
34815	3	180	2186	75.903000000000006	1	2186	75.903000000000006
34816	1	180	19969.400000000001	693.38199999999995	1.5	29954.099999999999	1040.0730000000001
34816	2	180	10594.6	367.86799999999999	1.5	15891.9	551.80200000000002
34816	3	180	4392.3999999999996	152.51400000000001	1.318	5789.6899999999996	201.03100000000001
34817	1	180	3214	111.59699999999999	1.073	3447.4879999999998	119.70399999999999
34817	2	180	11289	391.97899999999998	1.5	16933.5	587.96900000000005
34817	3	180	20747.099999999999	720.38499999999999	1.5	31120.650000000001	1080.578
34818	1	300	136.40000000000001	2.8420000000000001	1	136.40000000000001	2.8420000000000001
34818	2	300	1422.2	29.629000000000001	1	1422.2	29.629000000000001
34818	3	300	1561.8	32.536999999999999	1	1561.8	32.536999999999999
34809	1	300	95.200000000000003	1.9830000000000001	1	95.200000000000003	1.9830000000000001
34809	2	300	21	0.438	1	21	0.438
34809	3	300	347.80000000000001	7.2460000000000004	1	347.80000000000001	7.2460000000000004
34810	1	300	12.199999999999999	0.254	1	12.199999999999999	0.254
34810	2	300	71.599999999999994	1.492	1	71.599999999999994	1.492
34810	3	300	12.4	0.25800000000000001	1	12.4	0.25800000000000001
34811	1	300	1740.2	36.253999999999998	1	1740.2	36.253999999999998
34811	2	300	2524.5999999999999	52.595999999999997	1	2525.7660000000001	52.619999999999997
34811	3	300	1134.8	23.641999999999999	1	1134.8	23.641999999999999
34812	1	300	747.79999999999995	15.579000000000001	1	747.79999999999995	15.579000000000001
34812	2	300	66.200000000000003	1.379	1	66.200000000000003	1.379
34812	3	300	709.39999999999998	14.779	1	709.39999999999998	14.779
34813	1	300	388.39999999999998	8.0920000000000005	1	388.39999999999998	8.0920000000000005
34813	2	300	833.79999999999995	17.370999999999999	1	833.79999999999995	17.370999999999999
34813	3	300	101	2.1040000000000001	1	101	2.1040000000000001
34731	1	300	683	14.228999999999999	1	683	14.228999999999999
34731	2	300	4987	103.896	1.397	6965.5020000000004	145.11500000000001
34731	3	300	3084.4000000000001	64.257999999999996	1.051	3242.1669999999999	67.545000000000002
34732	1	300	729.39999999999998	15.196	1	729.39999999999998	15.196
34732	2	300	579.39999999999998	12.071	1	579.39999999999998	12.071
34732	3	300	1290.2	26.879000000000001	1	1290.2	26.879000000000001
34733	1	300	3014.8000000000002	62.808	1.0420001	3140.904	65.436000000000007
34733	2	300	2528.4000000000001	52.674999999999997	1.001	2529.8119999999999	52.704000000000001
34733	3	300	288.39999999999998	6.008	1	288.39999999999998	6.008
34734	1	300	1141.2	23.774999999999999	1	1141.2	23.774999999999999
34734	2	300	0	0	1	0	0
34734	3	300	284	5.9169999999999998	1	284	5.9169999999999998
34735	1	300	1.3999999999999999	0.029000000000000001	1	1.3999999999999999	0.029000000000000001
34735	2	300	70	1.458	1	70	1.458
34735	3	300	35.399999999999999	0.73699999999999999	1	35.399999999999999	0.73699999999999999
29893	1	300	2653	55.271000000000001	1.007	2670.5050000000001	55.636000000000003
29893	2	300	3204.8000000000002	66.766999999999996	1.071	3431.98	71.5
29893	3	300	1810.5999999999999	37.720999999999997	1	1810.5999999999999	37.720999999999997
29892	1	300	3243.5999999999999	67.575000000000003	1.079	3498.578	72.887
29892	2	300	5336.3999999999996	111.175	1.433	7649.3590000000004	159.36199999999999
29892	3	300	3330.5999999999999	69.388000000000005	1.099	3661.2489999999998	76.275999999999996
29891	1	300	1631.4000000000001	33.988	1	1631.4000000000001	33.988
29891	2	300	224	4.6669999999999998	1	224	4.6669999999999998
29891	3	300	340	7.0830000000000002	1	340	7.0830000000000002
29890	1	300	82.599999999999994	1.7210000000000001	1	82.599999999999994	1.7210000000000001
29890	2	300	239.40000000000001	4.9880000000000004	1	239.40000000000001	4.9880000000000004
29890	3	300	78.599999999999994	1.637	1	78.599999999999994	1.637
29889	1	300	1047.2	21.817	1	1047.2	21.817
29889	2	300	0	0	1	0	0
29889	3	300	0	0	1	0	0
29883	1	300	1280	26.667000000000002	1	1280	26.667000000000002
29883	2	300	62.200000000000003	1.296	1	62.200000000000003	1.296
29883	3	300	4638	96.625	1.362	6316.866	131.601
29883	4	300	1006	20.957999999999998	1	1006	20.957999999999998
29882	1	300	2050	42.707999999999998	1	2050	42.707999999999998
29882	2	300	2652	55.25	1.007	2669.3209999999999	55.610999999999997
29882	3	300	2618	54.542000000000002	1.0039999	2629.5520000000001	54.781999999999996
29881	1	300	360	7.5	1	360	7.5
29881	2	300	3462	72.125	1.142	3954.393	82.382999999999996
29881	3	300	1614	33.625	1	1614	33.625
29880	1	300	5160	107.5	1.415	7301.8869999999997	152.12299999999999
29880	2	300	5682	118.375	1.4680001	8342.8760000000002	173.81
29880	3	300	3166	65.957999999999998	1.064	3368.3229999999999	70.173000000000002
29879	1	300	815.60000000000002	16.992000000000001	1	815.60000000000002	16.992000000000001
29879	2	300	313.5	6.5309999999999997	1	313.5	6.5309999999999997
29879	3	300	124.90000000000001	2.6019999999999999	1	124.90000000000001	2.6019999999999999
29878	1	300	4166	86.792000000000002	1.277	5319.1719999999996	110.816
29878	2	300	387	8.0630000000000006	1	387	8.0630000000000006
29878	3	300	820.89999999999998	17.102	1	820.89999999999998	17.102
29877	1	120	1702	88.646000000000001	1	1702	88.646000000000001
29877	2	120	6019.3999999999996	313.50999999999999	1.5	9029.1000000000004	470.26600000000002
29877	3	120	0	0	1	0	0
29876	1	300	315.39999999999998	6.5709999999999997	1	315.39999999999998	6.5709999999999997
29876	2	300	5529	115.188	1.4529999	8033.7960000000003	167.37100000000001
29876	3	300	4224.6000000000004	88.013000000000005	1.288	5439.5190000000002	113.32299999999999
29875	1	180	1814	62.985999999999997	1	1814	62.985999999999997
29875	2	180	9207.6000000000004	319.70800000000003	1.5	13811.4	479.56299999999999
29875	3	180	15119	524.96500000000003	1.5	22678.5	787.44799999999998
29874	1	180	6088	211.38900000000001	1.5	9132	317.08300000000003
29874	2	180	2954	102.569	1.035	3056.0059999999999	106.111
29874	3	180	4750	164.93100000000001	1.3710001	6511.902	226.108
27521	1	300	5382.6000000000004	112.13800000000001	1.438	7741.1000000000004	161.273
27521	2	300	6914.6000000000004	144.054	1.5	10371.9	216.08099999999999
27521	3	300	4293.3999999999996	89.445999999999998	1.3	5582.1000000000004	116.294
27522	1	300	2602.4000000000001	54.216999999999999	1.0039999	2611.6329999999998	54.408999999999999
27522	2	300	82.799999999999997	1.7250000000000001	1	82.799999999999997	1.7250000000000001
27522	3	300	8097.8000000000002	168.70400000000001	1.5	12146.700000000001	253.05600000000001
27523	1	300	5904.3999999999996	123.008	1.49	8797.8520000000008	183.28899999999999
27523	2	300	1853.5999999999999	38.616999999999997	1	1853.5999999999999	38.616999999999997
27523	3	300	731.79999999999995	15.246	1	731.79999999999995	15.246
27524	1	300	678.79999999999995	14.141999999999999	1	678.79999999999995	14.141999999999999
27524	2	300	1645.4000000000001	34.279000000000003	1	1645.4000000000001	34.279000000000003
27524	3	300	2377.1999999999998	49.524999999999999	1	2377.1999999999998	49.524999999999999
27525	1	300	1052	21.917000000000002	1	1052	21.917000000000002
27525	2	300	607.60000000000002	12.657999999999999	1	607.60000000000002	12.657999999999999
27525	3	300	127.40000000000001	2.6539999999999999	1	127.40000000000001	2.6539999999999999
27520	1	300	2017.8	42.036999999999999	1	2017.8	42.036999999999999
27520	2	300	8435	175.72900000000001	1.5	12652.5	263.59399999999999
27520	3	300	5703	118.813	1.47	8385.5499999999993	174.69900000000001
27519	1	300	3838.8000000000002	79.974999999999994	1.215	4666.009	97.209000000000003
27519	2	300	3756.5	78.260000000000005	1.2	4506.8209999999999	93.891999999999996
27519	3	300	1678.5999999999999	34.970999999999997	1	1678.5999999999999	34.970999999999997
27518	1	300	6130.1999999999998	127.712	1.5	9195.2999999999993	191.56899999999999
27518	2	300	1161.8	24.204000000000001	1	1161.8	24.204000000000001
27518	3	300	1857.2	38.692	1	1857.2	38.692
27517	1	300	13.199999999999999	0.27500000000000002	1	13.199999999999999	0.27500000000000002
27517	2	300	1494	31.125	1	1494	31.125
27517	3	300	14955.1	311.565	1.5	22432.650000000001	467.34699999999998
27517	4	300	17494	364.45800000000003	1.5	26241	546.68700000000001
27516	1	300	375.39999999999998	7.8209999999999997	1	375.39999999999998	7.8209999999999997
27516	2	300	611.39999999999998	12.737	1	611.39999999999998	12.737
27516	3	300	295.39999999999998	6.1539999999999999	1	295.39999999999998	6.1539999999999999
27515	1	300	11826	246.375	1.5	17739	369.56200000000001
27515	2	300	18864	393	1.5	28296	589.5
27515	3	300	7764	161.75	1.5	11646	242.625
27514	1	300	33554	699.04200000000003	1.5	50331	1048.5630000000001
27514	2	300	15676	326.58300000000003	1.5	23514	489.875
27514	3	300	11982	249.625	1.5	17973	374.43700000000001
27513	1	300	54729	1140.1880000000001	1.5	82093.5	1710.2809999999999
27513	2	300	484	10.083	1	484	10.083
27513	3	300	4288	89.332999999999998	1.299	5570.8590000000004	116.06
27512	1	300	11846	246.792	1.5	17769	370.18700000000001
27512	2	300	938	19.542000000000002	1	938	19.542000000000002
27512	3	300	8340	173.75	1.5	12510	260.625
27511	1	300	26.879999999999999	0.56000000000000005	1	26.879999999999999	0.56000000000000005
27511	2	300	5.6699999999999999	0.11799999999999999	1	5.6699999999999999	0.11799999999999999
27511	3	300	0	0	1	0	0
27510	1	300	1774.4000000000001	36.966999999999999	1	1774.4000000000001	36.966999999999999
27510	2	300	19835.599999999999	413.24200000000002	1.5	29753.400000000001	619.86300000000006
27510	3	300	451.80000000000001	9.4130000000000003	1	451.80000000000001	9.4130000000000003
27510	4	300	219	4.5620000000000003	1	219	4.5620000000000003
27509	1	300	1063.4000000000001	22.154	1	1063.4000000000001	22.154
27509	2	300	466.19999999999999	9.7119999999999997	1	466.19999999999999	9.7119999999999997
27509	3	300	4.5999999999999996	0.096000000000000002	1	4.5999999999999996	0.096000000000000002
27508	1	300	3951	82.313000000000002	1.237	4886.3590000000004	101.79900000000001
27508	2	300	3830	79.792000000000002	1.214	4648.8890000000001	96.852000000000004
27508	3	300	3995.8000000000002	83.245999999999995	1.245	4975.4049999999997	103.654
27507	1	300	7625.1999999999998	158.858	1.5	11437.799999999999	238.28800000000001
27507	2	300	14081.200000000001	293.358	1.5	21121.799999999999	440.03800000000001
27507	3	300	7748.6000000000004	161.429	1.5	11622.9	242.14400000000001
27506	1	300	5.2000000000000002	0.108	1	5.2000000000000002	0.108
27506	2	300	134.40000000000001	2.7999999999999998	1	134.40000000000001	2.7999999999999998
27506	3	300	4.5999999999999996	0.096000000000000002	1	4.5999999999999996	0.096000000000000002
24571	1	300	4536	94.5	1.344	6095.8310000000001	126.996
24571	2	300	1077	22.437000000000001	1	1077	22.437000000000001
24571	3	300	5099	106.229	1.409	7182.7759999999998	149.64099999999999
24572	1	300	7314.3999999999996	152.38300000000001	1.5	10971.6	228.57499999999999
24572	2	300	1153.8	24.036999999999999	1	1153.8	24.036999999999999
24572	3	300	307.80000000000001	6.4130000000000003	1	307.80000000000001	6.4130000000000003
24573	1	300	12659.6	263.74200000000002	1.5	18989.400000000001	395.61200000000002
24573	2	300	10739.799999999999	223.74600000000001	1.5	16109.700000000001	335.61900000000003
10946	2	900	0	0	1	0	0
29837	3	300	16.100000000000001	0.33500000000000002	1	16.100000000000001	0.33500000000000002
29838	1	300	1.8999999999999999	0.040000000000000001	1	1.8999999999999999	0.040000000000000001
29838	2	300	0.90000000000000002	0.019	1	0.90000000000000002	0.019
29838	3	300	2.5	0.051999999999999998	1	2.5	0.051999999999999998
29829	1	300	364	7.5830000000000002	1	364	7.5830000000000002
29829	2	300	0	0	1	0	0
29829	3	300	497.10000000000002	10.356	1	497.10000000000002	10.356
29830	1	300	62.600000000000001	1.304	1	62.600000000000001	1.304
29830	2	300	592	12.333	1	592	12.333
29830	3	300	106.7	2.2229999999999999	1	106.7	2.2229999999999999
29831	1	300	123.09999999999999	2.5649999999999999	1	123.09999999999999	2.5649999999999999
29831	2	300	182.5	3.802	1	182.5	3.802
29831	3	300	30.300000000000001	0.63100000000000001	1	30.300000000000001	0.63100000000000001
29832	1	300	0	0	1	0	0
29832	2	300	0	0	1	0	0
29832	3	300	0	0	1	0	0
29833	1	300	0	0	1	0	0
29833	2	300	0	0	1	0	0
29833	3	300	0	0	1	0	0
27417	1	300	1053.5999999999999	21.949999999999999	1	1053.5999999999999	21.949999999999999
27417	2	300	4009.1999999999998	83.525000000000006	1.248	5002.1559999999999	104.212
27417	3	300	827.20000000000005	17.233000000000001	1	827.20000000000005	17.233000000000001
27418	1	300	0	0	1	0	0
27418	2	300	2.2999999999999998	0.048000000000000001	1	2.2999999999999998	0.048000000000000001
27418	3	300	5.7999999999999998	0.121	1	5.7999999999999998	0.121
27419	1	300	2953.5	61.530999999999999	1.034	3055.319	63.652000000000001
27419	2	300	9	0.188	1	9	0.188
27419	3	300	81.299999999999997	1.694	1	81.299999999999997	1.694
27420	1	300	1.6000000000000001	0.033000000000000002	1	1.6000000000000001	0.033000000000000002
27420	2	300	1.5	0.031	1	1.5	0.031
27420	3	300	0.90000000000000002	0.019	1	0.90000000000000002	0.019
27421	1	300	1	0.021000000000000001	1	1	0.021000000000000001
27421	2	300	8.1999999999999993	0.17100000000000001	1	8.1999999999999993	0.17100000000000001
27421	3	300	30.199999999999999	0.629	1	30.199999999999999	0.629
27416	1	360	0	0	1	0	0
27416	2	360	63.5	1.1020000000000001	1	63.5	1.1020000000000001
27416	3	360	0	0	1	0	0
27415	1	1020	0	0	1	0	0
27414	1	300	4.2999999999999998	0.089999999999999997	1	4.2999999999999998	0.089999999999999997
27414	2	360	28.100000000000001	0.48799999999999999	1	28.100000000000001	0.48799999999999999
27414	3	360	57.5	0.998	1	57.5	0.998
27413	1	960	0	0	1	0	0
27412	1	300	0	0	1	0	0
27412	2	300	768.89999999999998	16.018999999999998	1	768.89999999999998	16.018999999999998
27412	3	300	0	0	1	0	0
27411	1	300	78.950000000000003	1.645	1	78.950000000000003	1.645
27411	2	300	173.80000000000001	3.621	1	173.80000000000001	3.621
27411	3	300	29.010000000000002	0.60399999999999998	1	29.010000000000002	0.60399999999999998
27410	1	300	6783.8000000000002	141.32900000000001	1.5	10175.700000000001	211.994
27410	2	300	21560.400000000001	449.17500000000001	1.5	32340.599999999999	673.76300000000003
27410	3	300	20973	436.93700000000001	1.5	31459.5	655.40599999999995
27409	1	300	820.79999999999995	17.100000000000001	1	820.79999999999995	17.100000000000001
27409	2	300	1789.8	37.286999999999999	1	1789.8	37.286999999999999
27409	3	300	1897.8	39.536999999999999	1	1897.8	39.536999999999999
27408	1	900	0	0	1	0	0
27407	1	180	4.0300000000000002	0.14000000000000001	1	4.0300000000000002	0.14000000000000001
27407	2	300	1.1399999999999999	0.024	1	1.1399999999999999	0.024
27407	3	300	0	0	1	0	0
27406	1	300	0	0	1	0	0
27406	2	300	2.3399999999999999	0.049000000000000002	1	2.3399999999999999	0.049000000000000002
27406	3	300	0.39000000000000001	0.0080000000000000002	1	0.39000000000000001	0.0080000000000000002
27405	1	300	484.19999999999999	10.087	1	484.19999999999999	10.087
27405	2	300	1262.4000000000001	26.300000000000001	1	1262.4000000000001	26.300000000000001
27405	3	300	118.40000000000001	2.4670000000000001	1	118.40000000000001	2.4670000000000001
27404	1	300	1446.2	30.129000000000001	1	1446.2	30.129000000000001
27404	2	300	3528.8000000000002	73.516999999999996	1.155	4077.3119999999999	84.944000000000003
27404	3	300	2739.8000000000002	57.079000000000001	1.013	2775.9870000000001	57.832999999999998
27403	1	300	5225.3999999999996	108.86199999999999	1.4220001	7430.1899999999996	154.79599999999999
27403	2	300	5568.8000000000002	116.017	1.457	8113.8860000000004	169.03899999999999
27403	3	300	2192.8000000000002	45.683	1	2192.8000000000002	45.683
27402	1	300	9.5999999999999996	0.20000000000000001	1	9.5999999999999996	0.20000000000000001
27402	2	300	6.4000000000000004	0.13300000000000001	1	6.4000000000000004	0.13300000000000001
27402	3	300	90.799999999999997	1.8919999999999999	1	90.799999999999997	1.8919999999999999
27401	1	900	0	0	1	0	0
24531	1	300	1983.4000000000001	41.320999999999998	1	1983.4000000000001	41.320999999999998
24531	2	300	1878	39.125	1	1878	39.125
24531	3	300	1299.4000000000001	27.071000000000002	1	1299.4000000000001	27.071000000000002
24532	1	300	3461.4000000000001	72.111999999999995	1.142	3953.2959999999998	82.359999999999999
24532	2	300	1564.4000000000001	32.591999999999999	1	1564.4000000000001	32.591999999999999
24532	3	300	1747.2	36.399999999999999	1	1747.2	36.399999999999999
24533	1	300	53.799999999999997	1.121	1	53.799999999999997	1.121
24533	2	300	698	14.542	1	698	14.542
24533	3	300	857.39999999999998	17.861999999999998	1	857.39999999999998	17.861999999999998
24534	1	300	67.799999999999997	1.4119999999999999	1	67.799999999999997	1.4119999999999999
24534	2	300	24.199999999999999	0.504	1	24.199999999999999	0.504
24534	3	300	0	0	1	0	0
24535	1	900	0	0	1	0	0
24525	1	300	11.35	0.23599999999999999	1	11.35	0.23599999999999999
24525	2	300	262.94999999999999	5.4779999999999998	1	262.94999999999999	5.4779999999999998
24525	3	300	0	0	1	0	0
24524	1	300	737.20000000000005	15.358000000000001	1	737.20000000000005	15.358000000000001
24524	2	300	919.89999999999998	19.164999999999999	1	919.89999999999998	19.164999999999999
24524	3	300	699	14.563000000000001	1	699	14.563000000000001
24523	1	300	586.70000000000005	12.223000000000001	1	586.70000000000005	12.223000000000001
24523	2	300	3148.8000000000002	65.599999999999994	1.061	3340.9290000000001	69.602999999999994
24523	3	300	1445.4000000000001	30.111999999999998	1	1445.4000000000001	30.111999999999998
24522	1	300	13.83	0.28799999999999998	1	13.83	0.28799999999999998
24522	2	300	0	0	1	0	0
24522	3	300	0	0	1	0	0
24521	1	900	0	0	1	0	0
23970	1	900	1779.25	12.356	1	1779.25	12.356
23969	1	900	2575.8000000000002	17.888000000000002	1.002	2581.5900000000001	17.928000000000001
23968	1	900	2345.1999999999998	16.286000000000001	1	2345.1999999999998	16.286000000000001
23967	1	900	33.899999999999999	0.23499999999999999	1	33.899999999999999	0.23499999999999999
23966	1	900	17.100000000000001	0.11899999999999999	1	17.100000000000001	0.11899999999999999
23600	1	900	2303.75	15.997999999999999	1	2303.75	15.997999999999999
23599	1	900	772.5	5.3650000000000002	1	772.5	5.3650000000000002
23598	1	900	747.79999999999995	5.1929999999999996	1	747.79999999999995	5.1929999999999996
23597	1	900	2.7000000000000002	0.019	1	2.7000000000000002	0.019
23596	1	900	0	0	1	0	0
23595	1	900	616.14999999999998	4.2789999999999999	1	616.14999999999998	4.2789999999999999
23594	1	900	2209.3499999999999	15.343	1	2209.3499999999999	15.343
23593	1	900	1631.75	11.332000000000001	1	1631.75	11.332000000000001
23592	1	900	18.399999999999999	0.128	1	18.399999999999999	0.128
23591	1	900	0	0	1	0	0
23590	1	900	42.5	0.29499999999999998	1	42.5	0.29499999999999998
23589	1	900	3513.9499999999998	24.402000000000001	1.153	4049.864	28.123999999999999
23588	1	900	5061.4499999999998	35.149000000000001	1.405	7109.7250000000004	49.372999999999998
23587	1	900	0	0	1	0	0
23586	1	900	0	0	1	0	0
23585	1	900	0	0	1	0	0
23584	1	900	3486.5500000000002	24.212	1.147	3999.4029999999998	27.774000000000001
23583	1	900	3318.5999999999999	23.045999999999999	1.096	3637.5450000000001	25.260999999999999
23582	1	900	594.54999999999995	4.1289999999999996	1	594.54999999999995	4.1289999999999996
23581	1	900	0	0	1	0	0
23565	1	900	711.10000000000002	4.9379999999999997	1	711.10000000000002	4.9379999999999997
23564	1	900	1013.65	7.0389999999999997	1	1013.65	7.0389999999999997
23563	1	1500	13.85	0.058000000000000003	1	13.85	0.058000000000000003
23562	1	900	12.6	0.087999999999999995	1	12.6	0.087999999999999995
23561	1	900	0	0	1	0	0
23555	1	900	2749.9000000000001	19.097000000000001	1.0140001	2788.5839999999998	19.364999999999998
23554	1	900	3081.6500000000001	21.399999999999999	1.051	3238.0680000000002	22.486999999999998
23553	1	900	3177.0999999999999	22.062999999999999	1.066	3386.2600000000002	23.515999999999998
23552	1	1500	0	0	1	0	0
23551	1	900	0	0	1	0	0
23545	1	1500	1200.05	5	1	1200.05	5
23544	1	900	2554.4499999999998	17.739000000000001	1.001	2557.9760000000001	17.763999999999999
23543	1	900	3888.9499999999998	27.007000000000001	1.225	4764.027	33.084000000000003
23542	1	1500	0	0	1	0	0
23541	1	1500	0	0	1	0	0
23525	1	1500	1262.25	5.2590000000000003	1	1262.25	5.2590000000000003
23524	1	900	2063.1500000000001	14.327	1	2063.1500000000001	14.327
23523	1	900	2163.6500000000001	15.025	1	2163.6500000000001	15.025
23522	1	1500	0	0	1	0	0
23521	1	900	0	0	1	0	0
13036	1	300	15	0.313	1	15	0.313
13036	2	300	5	0.104	1	5	0.104
13036	3	300	28	0.58299999999999996	1	28	0.58299999999999996
13037	1	300	278	5.7919999999999998	1	278	5.7919999999999998
13037	2	300	345	7.1870000000000003	1	345	7.1870000000000003
13037	3	300	1502	31.292000000000002	1	1502	31.292000000000002
13038	1	300	229	4.7709999999999999	1	229	4.7709999999999999
13038	2	300	838	17.457999999999998	1	838	17.457999999999998
13038	3	300	571	11.896000000000001	1	571	11.896000000000001
13039	1	900	5	0.035000000000000003	1	5	0.035000000000000003
13040	1	900	0	0	1	0	0
13031	1	300	74	1.542	1	74	1.542
13031	2	300	8	0.16700000000000001	1	8	0.16700000000000001
13031	3	300	128	2.6669999999999998	1	128	2.6669999999999998
13032	1	300	127	2.6459999999999999	1	127	2.6459999999999999
13032	2	300	104	2.1669999999999998	1	104	2.1669999999999998
13032	3	300	140	2.9169999999999998	1	140	2.9169999999999998
13033	1	300	604	12.583	1	604	12.583
13033	2	300	1147	23.896000000000001	1	1147	23.896000000000001
13033	3	300	532	11.083	1	532	11.083
13034	1	300	19	0.39600000000000002	1	19	0.39600000000000002
13034	2	300	31	0.64600000000000002	1	31	0.64600000000000002
13034	3	300	30	0.625	1	30	0.625
13035	1	900	4	0.028000000000000001	1	4	0.028000000000000001
12877	1	900	0	0	1	0	0
12878	1	300	174	3.625	1	174	3.625
12878	2	300	89	1.8540000000000001	1	89	1.8540000000000001
12878	3	300	124	2.5830000000000002	1	124	2.5830000000000002
12879	1	300	154	3.2080000000000002	1	154	3.2080000000000002
12879	2	300	246	5.125	1	246	5.125
12879	3	300	192	4	1	192	4
12880	1	300	144	3	1	144	3
12880	2	300	0	0	1	0	0
12880	3	300	162	3.375	1	162	3.375
12881	1	900	0	0	1	0	0
12872	1	900	34	0.23599999999999999	1	34	0.23599999999999999
12873	1	900	183	1.2709999999999999	1	183	1.2709999999999999
12874	1	900	241	1.6739999999999999	1	241	1.6739999999999999
12875	1	900	0	0	1	0	0
12876	1	900	0	0	1	0	0
12867	1	900	39	0.27100000000000002	1	39	0.27100000000000002
12868	1	900	757	5.2569999999999997	1	757	5.2569999999999997
12869	1	1200	378	1.9690000000000001	1	378	1.9690000000000001
12870	1	900	274	1.903	1	274	1.903
12871	1	900	0	0	1	0	0
11962	1	300	3	0.063	1	3	0.063
11962	2	600	0	0	1	0	0
11963	1	300	75	1.5629999999999999	1	75	1.5629999999999999
11963	2	300	16	0.33300000000000002	1	16	0.33300000000000002
11963	3	300	1112	23.167000000000002	1	1112	23.167000000000002
11964	1	300	4025	83.853999999999999	1.251	5033.768	104.87
11964	2	300	11584	241.333	1.5	17376	362
11964	3	300	7422	154.625	1.5	11133	231.93700000000001
11965	1	900	0	0	1	0	0
11966	1	300	7	0.14599999999999999	1	7	0.14599999999999999
11966	2	600	0	0	1	0	0
11957	1	600	0	0	1	0	0
11957	2	300	19	0.39600000000000002	1	19	0.39600000000000002
11958	1	900	0	0	1	0	0
11959	1	300	631	13.146000000000001	1	631	13.146000000000001
11959	2	300	3618	75.375	1.173	4243.643	88.409000000000006
11959	3	300	430	8.9580000000000002	1	430	8.9580000000000002
11960	1	900	0	0	1	0	0
11961	1	900	0	0	1	0	0
24544	3	300	1097.5999999999999	22.867000000000001	1	1097.5999999999999	22.867000000000001
24543	1	300	1362.2	28.379000000000001	1	1362.2	28.379000000000001
24543	2	300	7626.6000000000004	158.88800000000001	1.5	11439.9	238.33099999999999
24543	3	300	529.79999999999995	11.038	1	529.79999999999995	11.038
24542	1	300	8329.3999999999996	173.529	1.5	12494.1	260.29399999999998
24542	2	300	8184.1999999999998	170.50399999999999	1.5	12276.299999999999	255.756
24542	3	300	4732.8000000000002	98.599999999999994	1.369	6479.3130000000001	134.98599999999999
24541	1	300	36.509999999999998	0.76100000000000001	1	36.509999999999998	0.76100000000000001
24541	2	300	136.5	2.8439999999999999	1	136.5	2.8439999999999999
24541	3	300	12.4	0.25800000000000001	1	12.4	0.25800000000000001
23980	1	900	12572.5	87.308999999999997	1.5	18858.75	130.964
23979	1	900	10397.9	72.207999999999998	1.5	15596.85	108.31100000000001
23978	1	900	13188.700000000001	91.587999999999994	1.5	19783.049999999999	137.38200000000001
23977	1	900	13597.799999999999	94.429000000000002	1.5	20396.700000000001	141.64400000000001
23976	1	900	11.6	0.081000000000000003	1	11.6	0.081000000000000003
23975	1	900	277.85000000000002	1.9299999999999999	1	277.85000000000002	1.9299999999999999
23974	1	900	11158.4	77.489000000000004	1.5	16737.599999999999	116.233
23973	1	900	6149.8999999999996	42.707999999999998	1.5	9224.8500000000004	64.061000000000007
23972	1	900	1412.45	9.8089999999999993	1	1412.45	9.8089999999999993
23971	1	900	0	0	1	0	0
23495	1	900	583.85000000000002	4.0549999999999997	1	583.85000000000002	4.0549999999999997
23494	1	900	274.69999999999999	1.9079999999999999	1	274.69999999999999	1.9079999999999999
23493	1	900	1566.75	10.880000000000001	1	1566.75	10.880000000000001
23492	1	900	1503.5999999999999	10.442	1	1503.5999999999999	10.442
23491	1	900	0	0	1	0	0
23490	1	900	0	0	1	0	0
23489	1	900	1985.0999999999999	13.785	1	1985.0999999999999	13.785
23488	1	900	3740.8499999999999	25.978000000000002	1.197	4476.7849999999999	31.088999999999999
23487	1	900	1321.7	9.1780000000000008	1	1321.7	9.1780000000000008
23486	1	900	0	0	1	0	0
23470	1	900	0	0	1	0	0
23469	1	900	6169.1499999999996	42.841000000000001	1.5	9253.7250000000004	64.262
23468	1	900	3876.3499999999999	26.919	1.223	4739.3280000000004	32.911999999999999
23467	1	900	3562.0999999999999	24.736999999999998	1.1619999	4139.1139999999996	28.744
23466	1	900	10.300000000000001	0.071999999999999995	1	10.300000000000001	0.071999999999999995
23465	1	900	2055.25	14.273	1	2055.25	14.273
23464	1	900	2638.0500000000002	18.32	1.006	2652.8899999999999	18.422999999999998
23463	1	900	2692.1999999999998	18.696000000000002	1.0089999	2717.4960000000001	18.872
23462	1	900	714.64999999999998	4.9630000000000001	1	714.64999999999998	4.9630000000000001
23461	1	900	217.94999999999999	1.514	1	217.94999999999999	1.514
23445	1	900	13.25	0.091999999999999998	1	13.25	0.091999999999999998
23444	1	900	3758	26.097000000000001	1.2	4509.7030000000004	31.317
23443	1	900	4136.6999999999998	28.727	1.271	5259.3789999999999	36.523000000000003
23442	1	900	3481.25	24.175000000000001	1.146	3989.6700000000001	27.706
23441	1	900	1170.3499999999999	8.1270000000000007	1	1170.3499999999999	8.1270000000000007
23425	1	900	4162.75	28.908000000000001	1.276	5312.527	36.893000000000001
23424	1	900	3944.9000000000001	27.395	1.2359999	4874.2809999999999	33.848999999999997
23423	1	900	3617.0500000000002	25.117999999999999	1.173	4241.8580000000002	29.457000000000001
23422	1	900	2937.5500000000002	20.399999999999999	1.033	3033.509	21.065999999999999
23421	1	900	57.149999999999999	0.39700000000000002	1	57.149999999999999	0.39700000000000002
13026	1	900	0	0	1	0	0
13027	1	300	145	3.0209999999999999	1	145	3.0209999999999999
13027	2	300	119	2.4790000000000001	1	119	2.4790000000000001
13027	3	300	103	2.1459999999999999	1	103	2.1459999999999999
13028	1	300	314	6.5419999999999998	1	314	6.5419999999999998
13028	2	300	292	6.0830000000000002	1	292	6.0830000000000002
13028	3	300	236	4.9169999999999998	1	236	4.9169999999999998
13029	1	300	244	5.0830000000000002	1	244	5.0830000000000002
13029	2	300	293	6.1040000000000001	1	293	6.1040000000000001
13029	3	300	202	4.2080000000000002	1	202	4.2080000000000002
13030	1	600	0	0	1	0	0
13030	2	300	20	0.41699999999999998	1	20	0.41699999999999998
13021	1	300	31	0.64600000000000002	1	31	0.64600000000000002
13021	2	600	0	0	1	0	0
13022	1	300	832	17.332999999999998	1	832	17.332999999999998
13022	2	300	83	1.7290000000000001	1	83	1.7290000000000001
13022	3	300	1450	30.207999999999998	1	1450	30.207999999999998
13023	1	300	568	11.833	1	568	11.833
13023	2	300	460	9.5830000000000002	1	460	9.5830000000000002
13023	3	300	388	8.0830000000000002	1	388	8.0830000000000002
13024	1	300	241	5.0209999999999999	1	241	5.0209999999999999
13024	2	300	133	2.7709999999999999	1	133	2.7709999999999999
13024	3	300	110	2.2919999999999998	1	110	2.2919999999999998
13025	1	900	0	0	1	0	0
12887	1	900	0	0	1	0	0
12888	1	300	107	2.2290000000000001	1	107	2.2290000000000001
12888	2	300	279	5.8120000000000003	1	279	5.8120000000000003
12888	3	300	182	3.7919999999999998	1	182	3.7919999999999998
12889	1	300	1106	23.042000000000002	1	1106	23.042000000000002
12889	2	300	1279	26.646000000000001	1	1279	26.646000000000001
12889	3	300	663	13.813000000000001	1	663	13.813000000000001
12890	1	900	215	1.4930000000000001	1	215	1.4930000000000001
12891	1	900	65	0.45100000000000001	1	65	0.45100000000000001
12882	1	900	0	0	1	0	0
12883	1	300	1057	22.021000000000001	1	1057	22.021000000000001
12883	2	300	755	15.728999999999999	1	755	15.728999999999999
12883	3	300	68	1.417	1	68	1.417
12884	1	300	996	20.75	1	996	20.75
12884	2	302	875	18.108000000000001	1	875	18.108000000000001
12884	3	302	435	9.0020000000000007	1	435	9.0020000000000007
12885	1	303	736	15.182	1	736	15.182
12885	2	302	1109	22.951000000000001	1	1109	22.951000000000001
12885	3	303	59	1.2170000000000001	1	59	1.2170000000000001
12886	1	300	0	0	1	0	0
12886	2	302	209	4.3250000000000002	1	209	4.3250000000000002
12886	3	303	1728	35.643999999999998	1	1728	35.643999999999998
10652	1	900	2	0.014	1	2	0.014
10653	1	300	501	10.438000000000001	1	501	10.438000000000001
10653	2	600	329	3.427	1	329	3.427
10654	1	300	2903	60.478999999999999	1.029	2986.8440000000001	62.225999999999999
10654	2	180	18266	634.23599999999999	1.5	27399	951.35400000000004
10654	3	180	5048	175.27799999999999	1.403	7083.6099999999997	245.959
10655	1	300	111	2.3130000000000002	1	111	2.3130000000000002
10655	2	300	198	4.125	1	198	4.125
10655	3	300	78	1.625	1	78	1.625
10656	1	300	0	0	1	0	0
10647	1	300	0	0	1	0	0
10648	1	180	111	3.8540000000000001	1	111	3.8540000000000001
10648	2	480	196	2.552	1	196	2.552
10649	1	300	5098	106.208	1.409	7180.8280000000004	149.601
10649	2	300	5510	114.792	1.451	7995.6400000000003	166.57599999999999
10649	3	180	2723	94.549000000000007	1.012	2755.174	95.665999999999997
10650	1	300	623	12.978999999999999	1	623	12.978999999999999
10650	2	300	1246	25.957999999999998	1	1246	25.957999999999998
10650	3	300	837	17.437000000000001	1	837	17.437000000000001
10651	1	300	603	12.563000000000001	1	603	12.563000000000001
10651	2	300	879	18.312000000000001	1	879	18.312000000000001
10651	3	300	718	14.958	1	718	14.958
10642	1	300	0	0	1	0	0
10643	1	300	1	0.021000000000000001	1	1	0.021000000000000001
10643	2	300	0	0	1	0	0
10643	3	300	0	0	1	0	0
10644	1	300	0	0	1	0	0
10644	2	300	0	0	1	0	0
10644	3	300	21	0.438	1	21	0.438
10645	1	300	0	0	1	0	0
10646	1	300	0	0	1	0	0
10637	1	900	2	0.014	1	2	0.014
10638	1	300	1692	35.25	1	1692	35.25
10638	2	300	2562	53.375	1.002	2566.2739999999999	53.463999999999999
10638	3	300	4895	101.979	1.387	6788.4179999999997	141.42500000000001
10639	1	150	9425	392.70800000000003	1.5	14137.5	589.06200000000001
10639	2	150	272	11.333	1	272	11.333
10639	3	150	341	14.208	1	341	14.208
10640	1	300	1270	26.457999999999998	1	1270	26.457999999999998
10640	2	300	1158	24.125	1	1158	24.125
10640	3	300	12790	266.45800000000003	1.5	19185	399.68700000000001
10641	1	900	59	0.40999999999999998	1	59	0.40999999999999998
10632	1	300	79	1.6459999999999999	1	79	1.6459999999999999
10632	2	300	18	0.375	1	18	0.375
10632	3	300	944	19.667000000000002	1	944	19.667000000000002
10633	1	600	238	2.4790000000000001	1	238	2.4790000000000001
10633	2	300	998	20.792000000000002	1	998	20.792000000000002
10634	1	900	4	0.028000000000000001	1	4	0.028000000000000001
10635	1	300	0	0	1	0	0
10636	1	300	0	0	1	0	0
10623	1	300	0	0	1	0	0
10624	1	300	125	2.6040000000000001	1	125	2.6040000000000001
10624	2	300	750	15.625	1	750	15.625
10624	3	300	20	0.41699999999999998	1	20	0.41699999999999998
10625	1	300	3973	82.771000000000001	1.2410001	4930.0110000000004	102.709
10625	2	300	1940	40.417000000000002	1	1940	40.417000000000002
10625	3	300	11	0.22900000000000001	1	11	0.22900000000000001
10625	4	300	502	10.458	1	502	10.458
10626	1	600	279	2.9060000000000001	1	279	2.9060000000000001
10626	2	600	5	0.051999999999999998	1	5	0.051999999999999998
10627	1	300	297	6.1870000000000003	1	297	6.1870000000000003
10627	2	300	104	2.1669999999999998	1	104	2.1669999999999998
10627	3	300	168	3.5	1	168	3.5
10618	1	300	0	0	1	0	0
10619	1	300	0	0	1	0	0
10620	1	900	84	0.58299999999999996	1	84	0.58299999999999996
10620	2	600	106	1.1040000000000001	1	106	1.1040000000000001
10621	1	300	0	0	1	0	0
10622	1	300	0	0	1	0	0
10613	1	1200	3	0.016	1	3	0.016
10614	1	600	3151	32.823	1.061	3344.4070000000002	34.838000000000001
10614	2	600	1756	18.292000000000002	1	1756	18.292000000000002
10615	1	600	13	0.13500000000000001	1	13	0.13500000000000001
10615	2	600	2829	29.469000000000001	1.021	2889.3299999999999	30.097000000000001
10616	1	300	0	0	1	0	0
10617	1	300	0	0	1	0	0
10607	1	300	0	0	1	0	0
10608	1	300	175	3.6459999999999999	1	175	3.6459999999999999
10608	2	300	238	4.9580000000000002	1	238	4.9580000000000002
10608	3	300	175	3.6459999999999999	1	175	3.6459999999999999
10609	1	300	1331	27.728999999999999	1	1331	27.728999999999999
10609	2	300	170	3.5419999999999998	1	170	3.5419999999999998
10609	3	300	2207	45.978999999999999	1	2207	45.978999999999999
10609	4	300	755	15.728999999999999	1	755	15.728999999999999
10610	1	600	75	0.78100000000000003	1	75	0.78100000000000003
10610	2	600	5613	58.469000000000001	1.461	8203.0869999999995	85.448999999999998
10610	3	300	665	13.853999999999999	1	665	13.853999999999999
10610	4	300	1051	21.896000000000001	1	1051	21.896000000000001
10611	1	300	137	2.8540000000000001	1	137	2.8540000000000001
10611	2	300	29	0.60399999999999998	1	29	0.60399999999999998
10611	3	600	114	1.1870000000000001	1	114	1.1870000000000001
10612	1	300	0	0	1	0	0
10601	1	300	0	0	1	0	0
10602	1	120	442	23.021000000000001	1	442	23.021000000000001
10602	2	300	4598	95.792000000000002	1.355	6229.8329999999996	129.78800000000001
10602	3	240	2715	70.703000000000003	1.011	2745.3270000000002	71.492999999999995
10603	1	180	1872	65	1	1872	65
10603	2	120	5530	288.02100000000002	1.4529999	8035.8059999999996	418.53199999999998
10603	3	120	2837	147.75999999999999	1.022	2899.7199999999998	151.02699999999999
10603	4	120	2766	144.06200000000001	1.015	2808.7930000000001	146.291
10604	1	240	1707	44.453000000000003	1	1707	44.453000000000003
10604	2	600	8956	93.292000000000002	1.5	13434	139.93700000000001
10604	3	300	6535	136.14599999999999	1.5	9802.5	204.21899999999999
10604	4	180	6097	211.70099999999999	1.5	9145.5	317.55200000000002
10604	5	180	1815	63.021000000000001	1	1815	63.021000000000001
\.


--
-- Data for Name: gsiebsatz; Type: TABLE DATA; Schema: public; Owner: -
--

COPY gsiebsatz (gsiebsatzid, name, istaktiv, sieb01, sieb02, sieb03, sieb04, sieb05, sieb06, sieb07, sieb08, sieb09, sieb10, sieb11, sieb12, sieb13, sieb14, sieb15, sieb16, sieb17, sieb18, sieb19, sieb20, sieb21, bemerkung) FROM stdin;
1	Siebsatz 1	1	100	90	80	63	50	40	31.5	20	16	10	8	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.20000000000000001	0.125	0.063	Siebsatz alt
3	Siebsatz 2000	1	100	63	31.5	16	10	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
5	Siebsatz Elbe	1	50	40	31.5	20	10	8	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	0.032000000000000001	\N	\N	\N	\N	\N	\N
10	Siebsatz Niederrhein	1	100	63	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
11	Plittersdorf_2002	1	125	100	63	45	31.5	16	10	8	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	0.02	\N	\N	\N	\N
12	Braubach_2001	1	200	125	100	63	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N
14	Siebsatz Braubach	1	90	80	63	40	20	10	8	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	0.032000000000000001	0.02	\N	\N	\N	\N
15	Elbe alt	1	50	40	20	10	8	6.2999999999999998	4	2	1	0.63	0.5	0.35499999999999998	0.25	0.20000000000000001	0.125	0.063	0.032000000000000001	\N	\N	\N	\N	\N
16	Elbe 1994	1	40	20	10	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.20000000000000001	0.125	0.063	0.032000000000000001	\N	\N	\N	\N	\N	\N	\N	\N
17	Elbe_1993	1	40	20	16	10	8	6.2999999999999998	4	2	1	0.70999999999999996	0.5	0.35499999999999998	0.25	0.17999999999999999	0.125	0.063	\N	\N	\N	\N	\N	\N
18	Elbe 2002	1	63	31.5	16	10	8	4	2	1	0.63	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N
19	GGU	1	100	63	31.5	16	8	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
20	Oder 2002	1	90	80	63	31.5	16	10	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N
21	Oder 2001	1	40	20	10	8	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N
25	1996	1	40	20	10	8	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	0.032000000000000001	\N	\N	\N	\N	\N	\N	\N	\N
50	z.ISBW Siebsatz 17	0	63	20	6.2999999999999998	2	0.63	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
51	z.ISBW Siebsatz 34	0	31	20	10	8	6.2999999999999998	4	2	1	0.70999999999999996	0.5	0.35499999999999998	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
52	z.ISBW Siebsatz 27	0	40	20	10	6.2999999999999998	4	2	1	0.63	0.40000000000000002	0.20000000000000001	0.10000000000000001	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
53	z.ISBW Siebsatz 32	0	16	10	8	6.2999999999999998	4	2	1	0.70999999999999996	0.5	0.35499999999999998	0.25	0.17999999999999999	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N
54	z.ISBW Siebsatz 6	0	100	80	63	40	20	10	6.2999999999999998	4	2	1	0.63	0.40000000000000002	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	\N
55	z.ISBW Siebsatz 4	0	100	80	63	40	20	10	6.2999999999999998	4	2	1	0.63	0.40000000000000002	0.20000000000000001	0.10000000000000001	0.063	\N	\N	\N	\N	\N	\N	\N
56	z.ISBW Siebsatz 9	0	80	63	50	40	20	10	6.2999999999999998	4	2	1	0.63	0.40000000000000002	0.20000000000000001	0.10000000000000001	0.063	\N	\N	\N	\N	\N	\N	\N
57	z.ISBW Siebsatz 38	0	10	8	6.2999999999999998	4	2	1	0.63	0.5	0.40000000000000002	0.20000000000000001	0.10000000000000001	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
58	z.ISBW Siebsatz 11	0	80	63	40	20	10	6.2999999999999998	4	2	1	0.63	0.40000000000000002	0.20000000000000001	0.10000000000000001	0.063	0.040000000000000001	0	\N	\N	\N	\N	\N	\N
59	z.ISBW Siebsatz 18	0	63	40	20	10	6.2999999999999998	4	2	1	0.63	0.40000000000000002	0.20000000000000001	0.10000000000000001	0.063	0.040000000000000001	0.032000000000000001	0.02	\N	\N	\N	\N	\N	\N
60	z.ISBW Siebsatz 2	0	100	80	63	40	20	10	6.2999999999999998	4	2	1	0.63	0.40000000000000002	0.20000000000000001	0.10000000000000001	0.063	0.0315	\N	\N	\N	\N	\N	\N
61	z.ISBW Siebsatz 5	0	80	63	40	20	10	6.2999999999999998	4	2	1	0.63	0.40000000000000002	0.20000000000000001	0.10000000000000001	0.063	0.02	\N	\N	\N	\N	\N	\N	\N
62	z.ISBW Siebsatz 21	0	80	63	40	20	10	6.2999999999999998	4	2	1	0.63	0.40000000000000002	0.20000000000000001	0.10000000000000001	0.063	0.040000000000000001	0.02	0.0060000000000000001	\N	\N	\N	\N	\N
63	z.ISBW Siebsatz 33	0	10	6.2999999999999998	4	2	1	0.63	0.5	0.40000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
64	Siebsatz Sohle 2006	0	200	100	63	45	31.5	16	10	8	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N
86	Sohle + Sieb 200	0	200	100	63	31.5	16	10	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N
124	Bingen 2002	0	200	125	100	63	45	31.5	16	10	8	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	0.02	\N	\N	\N
125	SedImport Id 125	1	125	90	70	50	30	20	15	10	7	3	2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Import am 13.11.2007, alte Nr.: 4
126	SedImport Id 126	1	225	200	160	125	100	63	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	Import am 13.11.2007, alte Nr.: 1
127	SedImport Id 127	1	200	125	100	80	63	40	31.5	20	16	10	6.2999999999999998	4	2	1	0.63	0.5	0.20000000000000001	0.125	0.063	0.032000000000000001	0.02	Import am 13.11.2007, alte Nr.: 2
128	SedImport Id 128	1	160	125	100	90	80	63	50	40	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	0.032000000000000001	0.02	\N	Import am 13.11.2007, alte Nr.: 5
129	SedImport Id 129	1	200	160	125	100	63	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	Import am 13.11.2007, alte Nr.: 3
130	SedImport Id 130	1	125	100	63	40	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	0.032000000000000001	\N	\N	\N	\N	\N	\N	Import am 13.11.2007, alte Nr.: 7
131	SedImport Id 131	1	100	63	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	0.032000000000000001	\N	\N	\N	\N	\N	\N	\N	Import am 13.11.2007, alte Nr.: 9
140	GK Elbe 2007	1	200	100	63	31.5	20	16	10	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N
160	Rhein 2008	0	200	125	100	63	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
180	EXPORT	0	200	125	100	63	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
200	Rhein Frings	1	125	80	56.799999999999997	40	25.199999999999999	14.4	8	4	2.52	1.6000000000000001	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
240	Oder Riehl1	1	63	40	20	10	6.2999999999999998	4	2	1	0.63	0.40000000000000002	0.20000000000000001	0.10000000000000001	0.063	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	\N
241	Oder Riehl2	1	20	10	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.20000000000000001	0.125	0.063	0.032000000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N
260	Niederrhein Frings1	1	250	200	100	63	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
280	Niederrhein Frings2	1	125	100	63	31.5	16	10	8	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N
281	Niederrhein Frings3	1	125	80	63	56	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N
282	Niederrhein Frings4	1	125	100	80	63	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N
300	Niederrhein Frings5	1	200	100	63	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N
301	Niederrhein Frings6	1	100	80	63	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
320	Niederrhein Frings 7	1	125	90	74	63	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N
321	Niederrhein Frings 8	0	125	100	90	63	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N
322	Niederrhein Frings 9	1	90	63	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N
323	Niederrhein Roy1	1	63	56	45	31.5	16	8	4	2	1	0.5	0.25	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
324	Niederrhein Roy2	1	180	150	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N
325	Niederrhein Roy3	1	250	180	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N
326	Niederrhein Roy4	1	180	130	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N
327	Niederrhein Roy5	1	200	100	63	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N
328	Niederrhein Roy6	1	100	80	56	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
329	Niederrhein Roy7	1	90	71	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N
330	Niederrhein Roy8	1	180	125	80	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
331	Niederrhein Roy9	1	180	125	90	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
332	Niederrhein Roy10	1	125	110	63	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
333	Niederrhein Roy11	1	180	160	95	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
334	Niederrhein Roy12	1	125	120	63	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
335	Niederrhein Roy13	1	125	100	63	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
336	Niederrhein Roy14	1	250	160	80	63	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N
337	Niederrhein Roy15	1	100	63	31.5	16	10	8	6.2999999999999998	4	2	1	0.63	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N
338	Niederrhein Roy16	1	200	100	80	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
339	Niederrhein Roy17	1	63	56	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N
340	Niederrhein Roy18	1	125	100	80	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
341	Niederrhein Roy19	1	125	80	63	56	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N
342	Niederrhein Roy20	1	63	45	31.5	16	8	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
343	Niederrhein Roy21	1	125	100	80	45	31.5	16	9	4	2	1	0.5	0.25	0.125	0.063	\N	\N	\N	\N	\N	\N	\N	\N
\.


--
-- Data for Name: gsiebung; Type: TABLE DATA; Schema: public; Owner: -
--

COPY gsiebung (glotrechteid, gmasse, rsieb01, rsieb02, rsieb03, rsieb04, rsieb05, rsieb06, rsieb07, rsieb08, rsieb09, rsieb10, rsieb11, rsieb12, rsieb13, rsieb14, rsieb15, rsieb16, rsieb17, rsieb18, rsieb19, rsieb20, rsieb21, rest, bemerkung) FROM stdin;
27511	32.399999999999999	0	0	0	0	0	1.3999999999999999	1.3	1.6000000000000001	1.3	2.7000000000000002	6.4000000000000004	17.5	0.20000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27510	22268.099999999999	0	0	75	808.20000000000005	1354	1293.4000000000001	912.39999999999998	1411.8	5746.8000000000002	8318	1875.2	471.10000000000002	2.2000000000000002	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27509	1532.0999999999999	0	0	88.900000000000006	364.60000000000002	260	135.5	75.599999999999994	97.200000000000003	85.799999999999997	120.40000000000001	208.09999999999999	95.200000000000003	0.80000000000000004	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27508	11745.200000000001	0	0	0	804	1466.2	1190	794	859.10000000000002	1097.7	1816.2	2631.1999999999998	1081	5.7999999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27507	29431.5	0	0	49.799999999999997	1258	2788.8000000000002	2873.0999999999999	3161.8000000000002	5057.6000000000004	4244.5	3721.5999999999999	3416.5999999999999	2850.6999999999998	7.5999999999999996	1.3999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
27506	143.69999999999999	0	0	0	0	0	8.4000000000000004	19.899999999999999	58.799999999999997	38.899999999999999	8.5999999999999996	3.7999999999999998	5.2000000000000002	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24571	10711	0	0	0	24	200.59999999999999	319	236	555.79999999999995	2251.4000000000001	4243.3999999999996	1803.4000000000001	1071	6.4000000000000004	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24572	8729.6000000000004	0	0	0	6.7999999999999998	122.40000000000001	244.19999999999999	281.19999999999999	730.39999999999998	1671.5999999999999	2259.8000000000002	1654.5999999999999	1747.8	10.800000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24573	32095.799999999999	0	0	0	44.600000000000001	544.20000000000005	1079.4000000000001	1667.5999999999999	3956.4000000000001	6311.1999999999998	7266.8000000000002	4843.3999999999996	6330.6000000000004	48.799999999999997	2.7999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
24574	17776.400000000001	0	0	0	10.800000000000001	238.19999999999999	663	1077.2	2566.4000000000001	4964.6000000000004	4321.8000000000002	1592	2327.1999999999998	15.199999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24575	815.60000000000002	0	0	0	0	49.399999999999999	140.59999999999999	211.80000000000001	214.40000000000001	59.200000000000003	33.200000000000003	24.800000000000001	80.599999999999994	1.3999999999999999	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24570	90.599999999999994	0	0	0	62.299999999999997	8.0999999999999996	4.2999999999999998	3.3999999999999999	3.1000000000000001	3	2.2000000000000002	4	0.20000000000000001	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24569	10335.120000000001	0	0	0	139.03	617.29999999999995	486.62	624.60000000000002	1051	1630	2217	1730	1824	14.529999999999999	1.04	\N	\N	\N	\N	\N	\N	\N	0	\N
24568	7431.1300000000001	0	0	0	0	314.14999999999998	338.33999999999997	307.81999999999999	578	1044	1519	1356	1950	23.449999999999999	0.37	\N	\N	\N	\N	\N	\N	\N	0	\N
24567	10365.5	0	0	0	174.69999999999999	334.31999999999999	679	1143	2381	2166	756	650	2069	11.960000000000001	0.52000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
24566	1755.4000000000001	0	0	0	58.700000000000003	300.89999999999998	400.19999999999999	247.5	277.10000000000002	112.7	92.599999999999994	82.599999999999994	180.5	2.6000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24565	21511.889999999999	0	0	0	255.13	1392	1676	1369	1884	4134	5958	3246	1587	10.76	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24564	21263.25	0	0	0	233.41	921.89999999999998	1040	1260	2289	4306	4249	3357	3577	29.84	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24563	18341.490000000002	0	0	0	1049	1816	1739	2025	2986	3484	2138	1298	1794	12.49	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24562	31284.220000000001	0	0	0	363.81	1311	2222	3985	8698	8565	3867	1154	1109	9.4100000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24561	1024	0	0	0	40.299999999999997	165.19999999999999	214.80000000000001	179.90000000000001	179.5	133	56.399999999999999	22.699999999999999	31.5	0.69999999999999996	0	\N	\N	\N	\N	\N	\N	\N	0	\N
23990	448.80000000000001	0	0	0	0	9.5999999999999996	2.3999999999999999	7.5	32.899999999999999	109.7	141.59999999999999	90.099999999999994	54.299999999999997	0.40000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
23989	388.69999999999999	0	0	0	0	23.300000000000001	11.800000000000001	11.800000000000001	17.199999999999999	56.100000000000001	100.7	104.59999999999999	62.600000000000001	0.5	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
23988	370.30000000000001	0	0	0	0	0	3.3999999999999999	8.0999999999999996	14.800000000000001	47.700000000000003	73.700000000000003	61.5	159.09999999999999	1.8999999999999999	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
23987	388.69999999999999	0	0	0	0	0	3.2000000000000002	8	38.700000000000003	133.59999999999999	128.69999999999999	48.5	27.5	0.20000000000000001	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
23986	205.5	0	0	0	0	18.699999999999999	41.200000000000003	50.600000000000001	43.600000000000001	25.5	9.8000000000000007	6	9.8000000000000007	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24145	319.64999999999998	0	0	0	0	5	4.0999999999999996	2.8500000000000001	10.9	63	111.09999999999999	90	32.600000000000001	0.070000000000000007	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24144	460.30000000000001	0	0	0	0	1.5	14.9	20	57.049999999999997	130.65000000000001	111	73.400000000000006	51.299999999999997	0.47999999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24143	346.35000000000002	0	0	0	0	6.5	2.7999999999999998	11.9	25.600000000000001	52.5	76.349999999999994	57	111.3	2.3799999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24142	375.69999999999999	0	0	0	0	0	3.5	9	13.5	56	154.69999999999999	75.799999999999997	62.200000000000003	0.90000000000000002	0.080000000000000002	\N	\N	\N	\N	\N	\N	\N	0.02	\N
24141	526.95000000000005	0	0	0	0	30.399999999999999	76.75	159.09999999999999	118.59999999999999	60.700000000000003	17.199999999999999	12.199999999999999	51	0.96999999999999997	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23985	652	0	0	0	66.099999999999994	61.899999999999999	57.399999999999999	71.200000000000003	125.3	104	79.400000000000006	49.700000000000003	36.200000000000003	0.78000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23984	432.89999999999998	0	0	0	0	5.8499999999999996	11.949999999999999	27.800000000000001	48.75	86.099999999999994	109.2	102.90000000000001	39.899999999999999	0.40000000000000002	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23983	330.89999999999998	0	0	0	0	4.4500000000000002	20.600000000000001	32.200000000000003	64.299999999999997	73.5	52.700000000000003	42.450000000000003	39.799999999999997	0.84999999999999998	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23982	373.14999999999998	0	0	0	0	3.6000000000000001	6.5	28	63.600000000000001	108.3	79.5	38.25	45.100000000000001	0.25	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23981	528.25	0	0	0	4.4000000000000004	92.849999999999994	59	80.049999999999997	74	48.700000000000003	34.5	42.399999999999999	90.900000000000006	1.3999999999999999	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
26285	292.69999999999999	0	0	0	0	1.3	1.5	6.0999999999999996	18.5	41.600000000000001	66.099999999999994	83.700000000000003	73.400000000000006	0.46999999999999997	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
26284	258	0	0	0	0	2.2999999999999998	4.0999999999999996	5.4000000000000004	9.3000000000000007	21.699999999999999	41.799999999999997	74.150000000000006	98.099999999999994	1.1000000000000001	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
26283	273	0	0	0	0	0	2.8999999999999999	4.0999999999999996	5	12.800000000000001	47.5	70.599999999999994	128.30000000000001	1.7	0.080000000000000002	\N	\N	\N	\N	\N	\N	\N	0.02	\N
26282	439.5	0	0	0	0	0	5.7999999999999998	15.5	28.600000000000001	155.80000000000001	124.90000000000001	62.399999999999999	45.399999999999999	1.05	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
26281	38.549999999999997	0	0	0	0	6.75	5.5999999999999996	11.5	5.0999999999999996	2.2000000000000002	1.7	1.5	4.0999999999999996	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23336	407.44999999999999	0	0	0	0	0	1.6000000000000001	5.2999999999999998	17.600000000000001	71.75	119.8	89.650000000000006	101.09999999999999	0.59999999999999998	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23335	452.64999999999998	0	0	0	0	3.1000000000000001	6.5	17.300000000000001	35.5	120.59999999999999	113.40000000000001	65.799999999999997	89.349999999999994	1	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23334	340.25	0	0	0	0	1.6000000000000001	4.75	4	4.9000000000000004	25.199999999999999	96.299999999999997	95.400000000000006	106.5	1.5	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23333	613.14999999999998	0	0	0	0	14.25	23.600000000000001	61.899999999999999	150	175.84999999999999	62.600000000000001	42.5	81.299999999999997	0.90000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23332	240.75	0	0	0	5.25	24.5	28.899999999999999	53.649999999999999	41.299999999999997	20.399999999999999	12.5	19.699999999999999	34.049999999999997	0.40000000000000002	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23331	598.79999999999995	0	0	0	13.65	60.299999999999997	22.800000000000001	13.300000000000001	20.800000000000001	122.59999999999999	204.55000000000001	111.45	29.25	0.089999999999999997	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23330	722.25	0	0	0	0	10.4	51.5	108.15000000000001	165.30000000000001	154.90000000000001	95.299999999999997	79.299999999999997	56.600000000000001	0.69999999999999996	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23329	164.94999999999999	0	0	0	0	0	5.0999999999999996	13.15	24.550000000000001	37.600000000000001	31.199999999999999	25.649999999999999	27.300000000000001	0.40000000000000002	0	\N	\N	\N	\N	\N	\N	\N	0	\N
23328	690.20000000000005	0	0	0	20.800000000000001	58	49.700000000000003	61	54.100000000000001	56.299999999999997	55.799999999999997	115	219	0.47999999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23327	30.149999999999999	0	0	0	0	0	0	1.1499999999999999	2.7000000000000002	4.5499999999999998	4.75	4.5	12.4	0.089999999999999997	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23326	1763.8	0	0	73.400000000000006	370.89999999999998	208.69999999999999	125.09999999999999	139.09999999999999	158.69999999999999	180.30000000000001	204.5	179.59999999999999	120.8	2.5	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
23325	1627.5999999999999	0	0	0	216.80000000000001	219.09999999999999	123.2	176.19999999999999	208.09999999999999	188	141.69999999999999	158.40000000000001	193	2.8999999999999999	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
23324	1939.9000000000001	0	0	0	244.55000000000001	255.80000000000001	191.69999999999999	296	334.80000000000001	236.94999999999999	124.09999999999999	110.2	142.90000000000001	2.7000000000000002	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
23323	1733.0999999999999	0	0	0	190.90000000000001	202.59999999999999	222.44999999999999	291.69999999999999	348.44999999999999	253.40000000000001	116	93.700000000000003	11.9	1.8	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
23322	1532.3499999999999	0	0	0	387.60000000000002	329.89999999999998	211.90000000000001	216.80000000000001	190.80000000000001	77.799999999999997	18.800000000000001	30.25	67.599999999999994	0.69999999999999996	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
23321	1262.05	0	0	0	94.25	169.90000000000001	189.40000000000001	211.09999999999999	218	172.30000000000001	79.099999999999994	53.5	73.299999999999997	1	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
23405	426.05000000000001	0	0	0	0	3.5	6.5999999999999996	10.199999999999999	30.5	98.299999999999997	123.34999999999999	77.099999999999994	76.049999999999997	0.42999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23404	572.04999999999995	0	0	0	0	6.2999999999999998	28.600000000000001	72	122	133.40000000000001	69.599999999999994	45.299999999999997	93.5	1.3200000000000001	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
13299	426.05000000000001	0	0	0	0	3.5	6.5999999999999996	10.199999999999999	30.5	98.299999999999997	123.34999999999999	77.099999999999994	76.049999999999997	0.42999999999999999	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
23403	409.64999999999998	0	0	0	0	0	0	8.3000000000000007	24.5	71.599999999999994	101.5	86.799999999999997	115.8	1.1000000000000001	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
13300	572.04999999999995	0	0	0	0	6.2999999999999998	28.600000000000001	72	122	133.40000000000001	69.599999999999994	45.299999999999997	93.5	1.3200000000000001	0.02	0.01	\N	\N	\N	\N	\N	\N	0	\N
23402	381	0	0	0	0	0	0.69999999999999996	4.0999999999999996	14.300000000000001	95.950000000000003	136.59999999999999	84.5	44.5	0.33000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
13301	409.64999999999998	0	0	0	0	0	0	8.3000000000000007	24.5	71.599999999999994	101.5	86.799999999999997	115.8	1.1000000000000001	0.040000000000000001	0.01	\N	\N	\N	\N	\N	\N	0	\N
23401	79.400000000000006	0	0	0	0	17	9.9000000000000004	15.300000000000001	11.4	4.2000000000000002	3.1000000000000001	4.7000000000000002	13.6	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
13302	381	0	0	0	0	0	0.69999999999999996	4.0999999999999996	14.300000000000001	95.950000000000003	136.59999999999999	84.5	44.5	0.33000000000000002	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
13303	79.400000000000006	0	0	0	0	17	9.9000000000000004	15.300000000000001	11.4	4.2000000000000002	3.1000000000000001	4.7000000000000002	13.6	0.17999999999999999	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
23385	477.94999999999999	0	0	0	11.5	19.350000000000001	12.300000000000001	9.6999999999999993	26.600000000000001	90.75	178.69999999999999	94.150000000000006	34.600000000000001	0.28000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
13304	477.94999999999999	0	0	0	11.5	19.350000000000001	12.300000000000001	9.6999999999999993	26.600000000000001	90.75	178.69999999999999	94.150000000000006	34.600000000000001	0.28000000000000003	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
23384	881.75	0	0	0	43.100000000000001	97.299999999999997	62.700000000000003	76.299999999999997	119.5	146.40000000000001	117.2	91.700000000000003	126.8	0.72999999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
13305	881.75	0	0	0	43.100000000000001	97.299999999999997	62.700000000000003	76.299999999999997	119.5	146.40000000000001	117.2	91.700000000000003	126.8	0.72999999999999998	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
23383	420.60000000000002	0	0	0	12.25	25.800000000000001	24.600000000000001	35.149999999999999	68.450000000000003	83.099999999999994	40.600000000000001	37.130000000000003	93.099999999999994	0.40000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
13306	420.60000000000002	0	0	0	12.25	25.800000000000001	24.600000000000001	35.149999999999999	68.450000000000003	83.099999999999994	40.600000000000001	37.130000000000003	93.099999999999994	0.40000000000000002	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
23382	967.64999999999998	0	0	0	66.799999999999997	117.7	158.55000000000001	233.5	215.59999999999999	82	31.100000000000001	22.800000000000001	39.299999999999997	0.25	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
13307	967.64999999999998	0	0	0	66.799999999999997	117.7	158.55000000000001	233.5	215.59999999999999	82	31.100000000000001	22.800000000000001	39.299999999999997	0.25	0.029999999999999999	0.02	\N	\N	\N	\N	\N	\N	0	\N
23381	537.35000000000002	0	0	0	30.350000000000001	36.799999999999997	31.199999999999999	39	51.75	55.5	70.200000000000003	63.299999999999997	156.69999999999999	2.3999999999999999	0.13	\N	\N	\N	\N	\N	\N	\N	0.02	\N
13308	537.35000000000002	0	0	0	30.350000000000001	36.799999999999997	31.199999999999999	39	51.75	55.5	70.200000000000003	63.299999999999997	156.69999999999999	2.3999999999999999	0.13	0.02	\N	\N	\N	\N	\N	\N	0	\N
23365	628.99000000000001	0	0	0	52.350000000000001	86.25	24.699999999999999	34.399999999999999	48.399999999999999	53.600000000000001	54.649999999999999	84.200000000000003	189.84999999999999	0.55000000000000004	0.02	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23364	613.39999999999998	0	0	0	10.4	24.199999999999999	26.949999999999999	53.700000000000003	94.799999999999997	95.799999999999997	77.700000000000003	80.150000000000006	149.34999999999999	0.33000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
13309	628.99000000000001	0	0	0	52.350000000000001	86.25	24.699999999999999	34.399999999999999	48.399999999999999	53.600000000000001	54.649999999999999	84.200000000000003	189.84999999999999	0.55000000000000004	0.02	0.02	\N	\N	\N	\N	\N	\N	0	\N
23363	699.25	0	0	0	7.2999999999999998	41.700000000000003	34	44.5	75.599999999999994	132.09999999999999	132.30000000000001	86.900000000000006	144.5	0.33000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
13310	613.39999999999998	0	0	0	10.4	24.199999999999999	26.949999999999999	53.700000000000003	94.799999999999997	95.799999999999997	77.700000000000003	80.150000000000006	149.34999999999999	0.33000000000000002	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
23362	471.75	0	0	0	20.699999999999999	2.5	9.5	13.300000000000001	59.299999999999997	137.09999999999999	89	41.100000000000001	99	0.23000000000000001	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
13311	699.25	0	0	0	7.2999999999999998	41.700000000000003	34	44.5	75.599999999999994	132.09999999999999	132.30000000000001	86.900000000000006	144.5	0.33000000000000002	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
23361	275.35000000000002	0	0	0	0	14.6	31.699999999999999	51.950000000000003	95.400000000000006	51.399999999999999	7.2000000000000002	4.9000000000000004	18	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
13312	471.75	0	0	0	20.699999999999999	2.5	9.5	13.300000000000001	59.299999999999997	137.09999999999999	89	41.100000000000001	99	0.23000000000000001	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
13313	275.35000000000002	0	0	0	0	14.6	31.699999999999999	51.950000000000003	95.400000000000006	51.399999999999999	7.2000000000000002	4.9000000000000004	18	0.17999999999999999	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
13016	321.26999999999998	0	0	0	0	8.25	6	8.0999999999999996	21.449999999999999	79.299999999999997	116.84999999999999	48.75	31.850000000000001	0.65000000000000002	0.050000000000000003	0.02	\N	\N	\N	\N	\N	\N	0	\N
13017	360.89999999999998	0	0	0	0	15.5	18.699999999999999	26	28	16.300000000000001	17.399999999999999	31.800000000000001	204	3.1000000000000001	0.070000000000000007	0.029999999999999999	\N	\N	\N	\N	\N	\N	0	\N
13018	224.59999999999999	0	0	0	0	3.25	0.5	2.6000000000000001	4.7000000000000002	7.5999999999999996	15.15	26.300000000000001	162.69999999999999	1.75	0.025000000000000001	0.025000000000000001	\N	\N	\N	\N	\N	\N	0	\N
13019	284.55000000000001	0	0	0	0	6.2999999999999998	7.4000000000000004	8.4000000000000004	8.9000000000000004	10.4	11.199999999999999	19.350000000000001	208.90000000000001	3.6000000000000001	0.089999999999999997	0.01	\N	\N	\N	\N	\N	\N	0	\N
13020	40.549999999999997	0	0	0	5.7000000000000002	2.5	7	2.6000000000000001	3.8500000000000001	4.0999999999999996	3.3199999999999998	3.25	8	0.20000000000000001	0.02	0.01	\N	\N	\N	\N	\N	\N	0	\N
13011	462.39999999999998	0	0	0	21.399999999999999	20.850000000000001	23.350000000000001	22	65	228.55000000000001	65.400000000000006	6.7999999999999998	8.3000000000000007	0.69999999999999996	0.029999999999999999	0.02	\N	\N	\N	\N	\N	\N	0	\N
13012	510.89999999999998	0	0	0	13.949999999999999	24.699999999999999	18	24.050000000000001	46	122.2	125.84999999999999	51.75	81.799999999999997	2.5	0.050000000000000003	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
13013	350.39999999999998	0	0	0	0	120.95	3.2999999999999998	5.5999999999999996	2.5499999999999998	6.7000000000000002	21	44.049999999999997	144.19999999999999	2	0.029999999999999999	0.02	\N	\N	\N	\N	\N	\N	0	\N
13014	599.95000000000005	0	0	0	18.600000000000001	49.200000000000003	35.350000000000001	67.5	116.3	117.8	68.299999999999997	50.799999999999997	75.349999999999994	0.71999999999999997	0.02	0.01	\N	\N	\N	\N	\N	\N	0	\N
13015	210.94999999999999	0	0	0	6.2999999999999998	4.3499999999999996	4.9000000000000004	4.0499999999999998	8.5999999999999996	17.100000000000001	25.399999999999999	37.75	101.2	1.28	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
10764	1001	0	0	0	0	19	34	60	349	444	80	11	4	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10765	1648	0	0	0	34	103	180	369	528	348	77	7	2	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10766	1821	0	0	0	235	362	460	408	260	79	8	4	5	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10767	1776	0	0	0	638	671	261	105	55	32	11	2	1	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10768	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10754	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10755	8	0	0	0	0	0	0	0	0	2	1	2	3	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10756	6	0	0	0	0	0	0	0	1	2	1	0	2	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10757	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10758	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10749	339	0	0	0	0	3	6	6	13	79	139	78	15	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10750	665	0	0	0	0	11	17	36	102	237	122	75	65	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10751	253	0	0	0	0	5	2	9	42	76	34	34	50	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10752	732	0	0	0	0	2	5	12	74	566	67	4	2	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10753	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10744	1080	0	0	0	0	145	70	73	169	244	161	93	56	68	1	0	0	\N	\N	\N	\N	\N	0	\N
10745	1343	0	0	0	0	114	43	35	86	157	328	223	161	196	0	0	0	\N	\N	\N	\N	\N	0	\N
10746	42	0	0	0	0	0	4	3	5	10	13	4	2	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10747	392	0	0	0	0	3	0	2	17	25	116	163	49	17	0	0	0	\N	\N	\N	\N	\N	0	\N
10748	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10740	651	0	0	0	43	106	30	36	82	150	93	30	29	51	1	0	0	\N	\N	\N	\N	\N	0	\N
10741	1738	0	0	0	270	241	50	59	132	259	362	192	104	68	1	0	0	\N	\N	\N	\N	\N	0	\N
10742	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10743	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10735	1000	0	0	0	0	15	22	30	105	326	399	98	4	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10736	2245	0	0	0	20	261	155	157	353	451	402	351	73	22	0	0	0	\N	\N	\N	\N	\N	0	\N
10737	1000	0	0	0	0	32	28	33	79	128	257	372	61	10	0	0	0	\N	\N	\N	\N	\N	0	\N
10738	94	0	0	0	0	20	11	9	18	11	6	4	6	9	0	0	0	\N	\N	\N	\N	\N	0	\N
10739	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10731	2299	0	0	0	51	320	84	52	99	115	281	375	342	574	6	0	0	\N	\N	\N	\N	\N	0	\N
10732	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10733	1000	0	0	0	0	28	17	13	43	159	436	211	60	32	1	0	0	\N	\N	\N	\N	\N	0	\N
10734	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10727	1000	0	0	0	0	11	4	10	22	71	224	318	230	108	2	0	0	\N	\N	\N	\N	\N	0	\N
10728	873	0	0	0	0	21	23	20	82	98	163	157	121	185	3	0	0	\N	\N	\N	\N	\N	0	\N
10729	11	0	0	0	0	1	0	1	1	2	4	1	0	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10730	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10722	1000	0	0	0	0	11	4	10	22	71	224	318	230	108	2	0	0	\N	\N	\N	\N	\N	0	\N
10723	1000	0	0	0	0	27	25	23	65	66	90	122	147	428	6	1	0	\N	\N	\N	\N	\N	0	\N
10724	208	0	0	0	0	21	11	7	32	42	43	27	12	12	1	0	0	\N	\N	\N	\N	\N	0	\N
10725	101	0	0	0	0	29	7	7	20	19	13	4	1	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10726	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10717	2300	0	0	0	14	153	101	82	147	268	538	792	170	33	2	0	0	\N	\N	\N	\N	\N	0	\N
10718	1000	0	0	0	0	82	70	50	79	75	63	125	230	224	2	0	0	\N	\N	\N	\N	\N	0	\N
10719	357	0	0	0	0	49	43	42	81	117	23	1	1	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10720	18	0	0	0	0	6	0	5	3	3	1	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10721	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10713	2300	0	0	0	19	43	23	27	55	193	724	918	232	65	1	0	0	\N	\N	\N	\N	\N	0	\N
10714	2447	0	0	0	163	169	179	177	349	510	488	188	105	118	1	0	0	\N	\N	\N	\N	\N	0	\N
10715	356	0	0	0	25	80	22	25	61	80	57	4	1	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10716	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10708	401	0	0	0	20	92	16	15	28	32	27	24	48	97	2	0	0	\N	\N	\N	\N	\N	0	\N
10709	2300	0	0	0	33	239	114	83	133	206	619	454	239	179	1	0	0	\N	\N	\N	\N	\N	0	\N
10710	227	0	0	0	12	39	20	20	29	34	40	19	8	6	0	0	0	\N	\N	\N	\N	\N	0	\N
10711	196	0	0	0	27	55	17	13	18	26	30	8	1	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10712	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10699	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10700	2472	0	0	0	116	269	121	121	234	474	739	269	83	45	1	0	0	\N	\N	\N	\N	\N	0	\N
10701	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10702	2300	0	0	0	25	636	246	245	412	276	154	52	80	173	1	0	0	\N	\N	\N	\N	\N	0	\N
10703	263	0	0	0	0	112	51	29	47	21	3	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10704	203	0	0	0	37	72	29	16	26	16	6	1	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10705	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10706	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10707	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10693	101	0	0	0	0	0	1	2	2	3	21	40	17	14	1	0	0	\N	\N	\N	\N	\N	0	\N
10694	1000	0	0	0	0	21	5	20	45	102	121	194	269	222	1	0	0	\N	\N	\N	\N	\N	0	\N
10695	1000	0	0	0	0	113	77	38	49	67	116	167	166	206	1	0	0	\N	\N	\N	\N	\N	0	\N
10696	1000	0	0	0	0	11	14	8	17	50	405	379	83	32	1	0	0	\N	\N	\N	\N	\N	0	\N
10697	22	0	0	0	0	7	1	4	4	2	2	1	1	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10698	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10688	2299	0	0	0	31	119	37	41	156	814	841	159	50	49	2	0	0	\N	\N	\N	\N	\N	0	\N
10689	2414	0	0	0	117	523	248	189	342	283	261	246	106	97	2	0	0	\N	\N	\N	\N	\N	0	\N
10690	2299	0	0	0	275	749	222	165	236	223	189	136	57	46	1	0	0	\N	\N	\N	\N	\N	0	\N
10691	2299	0	0	0	380	886	243	173	208	148	116	72	37	35	1	0	0	\N	\N	\N	\N	\N	0	\N
10692	38	0	0	0	0	0	0	0	0.5	4.9000000000000004	15.800000000000001	10.6	3.5	2.7000000000000002	0	0	0	\N	\N	\N	\N	\N	0	\N
10684	396	0	0	0	0	50	18	17	45	63	83	89	23	8	0	0	0	\N	\N	\N	\N	\N	0	\N
10685	5	0	0	0	0	0	0	0	0	0.69999999999999996	1.3999999999999999	1.2	1	0.69999999999999996	0	0	0	\N	\N	\N	\N	\N	0	\N
10686	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10687	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10678	570	0	0	0	0	52	40	38	50	88	114	91	57	39	1	0	0	\N	\N	\N	\N	\N	0	\N
10679	2299	0	0	0	26	297	117	112	144	111	98	230	622	540	2	0	0	\N	\N	\N	\N	\N	0	\N
10680	160	0	0	0	0	0	2	3	7	44	66	24	7	7	0	0	0	\N	\N	\N	\N	\N	0	\N
10681	2299	0	0	0	66	213	106	102	327	732	639	66	24	23	1	0	0	\N	\N	\N	\N	\N	0	\N
10682	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10683	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10673	25	0	0	0	0	0	0	0	0.29999999999999999	3.2999999999999998	5.5	5.5999999999999996	4.0999999999999996	6.2000000000000002	0	0	0	\N	\N	\N	\N	\N	0	\N
10674	2299	0	0	0	22	282	169	177	330	242	134	175	322	445	1	0	0	\N	\N	\N	\N	\N	0	\N
10675	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10676	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10677	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10668	159	0	0	0	0	41	24	20	26	25	13	5	2	3	0	0	0	\N	\N	\N	\N	\N	0	\N
10669	2299	0	0	0	26	379	125	100	141	126	228	658	340	175	1	0	0	\N	\N	\N	\N	\N	0	\N
10670	2299	0	0	0	280	680	302	289	408	253	80	5	1	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10671	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10672	166	0	0	0	0	68	40	28	26	4	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10662	2299	0	0	0	19	166	68	59	150	535	988	249	54	11	0	0	0	\N	\N	\N	\N	\N	0	\N
10663	2299	0	0	0	66	138	95	81	211	551	822	266	49	20	0	0	0	\N	\N	\N	\N	\N	0	\N
10664	2300	0	0	0	83	407	187	249	639	662	72	1	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10665	135	0	0	0	16	44	11	17	29	16	2	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10666	173	0	0	0	27.699999999999999	87.200000000000003	14.699999999999999	9.5	19.899999999999999	12	1.8999999999999999	0.10000000000000001	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10667	11	0	0	0	0	3	0	0.80000000000000004	0.40000000000000002	3.5	3.2000000000000002	0.10000000000000001	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10657	85.299999999999997	0	0	0	0	17.300000000000001	4.7000000000000002	7.5999999999999996	13.800000000000001	14.300000000000001	19.800000000000001	4.9000000000000004	1.3999999999999999	1.5	0	0	0	\N	\N	\N	\N	\N	0	\N
10658	18.399999999999999	0	0	0	0	0	0	0.69999999999999996	0.59999999999999998	3.8999999999999999	4.4000000000000004	1.7	2	5.0999999999999996	0	0	0	\N	\N	\N	\N	\N	0	\N
10659	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10660	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10661	184	0	0	0	0	77	33	25	26	15	4	2	1	1	0	0	0	\N	\N	\N	\N	\N	0	\N
34824	3859.4000000000001	0	0	0	350.60000000000002	414.80000000000001	548	519.20000000000005	916.79999999999995	908.20000000000005	179.59999999999999	18	3.6000000000000001	0.59999999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34825	29338.400000000001	0	0	0	508.60000000000002	1448.2	2946.5999999999999	4236.3999999999996	8183	8501.6000000000004	2670.5999999999999	560.60000000000002	278	4.5999999999999996	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34826	37016	0	0	0	1263.4000000000001	2356.8000000000002	3516.1999999999998	4678.8000000000002	6856.1999999999998	6430.8000000000002	7327.1999999999998	2616.6999999999998	1948.4000000000001	21.199999999999999	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
34827	9246	0	0	0	285.19999999999999	799.39999999999998	1251.8	1678.4000000000001	1873	877.39999999999998	809	732.79999999999995	932.39999999999998	6.4000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34828	4566.1999999999998	0	0	0	355.39999999999998	793.39999999999998	917.29999999999995	891.20000000000005	663.20000000000005	181.30000000000001	123.40000000000001	207.19999999999999	429.80000000000001	3.7999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34819	11145.700000000001	0	0	0	138.80000000000001	948.20000000000005	2124.8000000000002	2816.4000000000001	3426	1608.8	70	7.4000000000000004	4	0.29999999999999999	1	\N	\N	\N	\N	\N	\N	\N	0	\N
34820	12089.4	0	0	0	978	1832.5999999999999	1667.4000000000001	1255	2316	2474.8000000000002	991	394.60000000000002	175.59999999999999	3.6000000000000001	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0	\N
34821	13681.700000000001	0	0	0	741	1267.2	1961	2607.8000000000002	2978.8000000000002	2084	1129.4000000000001	479.39999999999998	422.80000000000001	9.5999999999999996	0.69999999999999996	\N	\N	\N	\N	\N	\N	\N	0	\N
34822	4265.3999999999996	0	0	0	270.60000000000002	617.39999999999998	820.79999999999995	809	663	237.80000000000001	211	323.19999999999999	309.19999999999999	3	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
34823	4294.6000000000004	0	0	0	152.80000000000001	760.79999999999995	972.79999999999995	666.20000000000005	410.60000000000002	140.40000000000001	79.400000000000006	273.60000000000002	831	6.4000000000000004	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
34736	4117.6000000000004	0	0	0	0	145.40000000000001	386.80000000000001	432	735.20000000000005	1092.8	1059.4000000000001	216.40000000000001	48.799999999999997	0.59999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
10987	980	0	0	0	0	0	4	11	13	37	90	144	194	200	286	1	0	0	0	\N	\N	\N	0	\N
10988	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10975	246	0	0	0	0	0	0	0	1	0	4	28	89	61	62	1	0	0	0	\N	\N	\N	0	\N
10976	46	0	0	0	0	0	0	0	0	0.10000000000000001	3.5	5.7999999999999998	7.0999999999999996	7.7999999999999998	21.300000000000001	0.40000000000000002	0	0	0	\N	\N	\N	0	\N
10977	1335	0	0	0	0	0	2	9	8	33	132	350	377	203	218	3	0	0	0	\N	\N	\N	0	\N
10978	731	0	0	0	0	0	0	1	3	12	50	179	229	130	126	1	0	0	0	\N	\N	\N	0	\N
10979	7	0	0	0	0	0	0	0	0.40000000000000002	0	0.90000000000000002	0.69999999999999996	1	1.2	2.7000000000000002	0.10000000000000001	0	0	0	\N	\N	\N	0	\N
10980	169.90000000000001	0	0	0	0	0	0	0	0	1.3	6.7999999999999998	14.300000000000001	31.899999999999999	49.200000000000003	65.099999999999994	1.3	0	0	0	\N	\N	\N	0	\N
10981	19	0	0	0	0	0	0	0	0	0	1.3	0.80000000000000004	0.59999999999999998	2.7999999999999998	13.199999999999999	0.29999999999999999	0	0	0	\N	\N	\N	0	\N
10968	948	0	0	0	0	0	0	7	4	12	29	141	419	234	101	1	0	0	0	\N	\N	\N	0	\N
10969	873	0	0	0	0	0	2	7	22	96	190	251	163	141	1	0	0	0	0	\N	\N	\N	0	\N
10970	1706	0	0	0	0	0	0	7	5	21	785	168	280	224	215	1	0	0	0	\N	\N	\N	0	\N
10971	999	0	0	0	0	0	37	20	24	89	189	260	203	99	78	0	0	0	0	\N	\N	\N	0	\N
10972	2299	0	0	0	0	12	66	71	75	280	544	502	342	219	187	1	0	0	0	\N	\N	\N	0	\N
10973	999	0	0	0	0	0	4	8	13	57	128	201	256	197	134	1	0	0	0	\N	\N	\N	0	\N
10974	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10963	967	0	0	0	0	0	8	7	12	27	93	247	285	162	125	1	0	0	0	\N	\N	\N	0	\N
10964	999	0	0	0	0	0	69	24	25	68	169	257	184	108	94	1	0	0	0	\N	\N	\N	0	\N
10965	999	0	0	0	0	0	0	3	7	16	44	159	342	238	189	1	0	0	0	\N	\N	\N	0	\N
10966	999	0	0	0	0	0	15	9	11	36	172	278	186	135	156	1	0	0	0	\N	\N	\N	0	\N
10967	999	0	0	0	0	0	0	2	7	44	101	103	152	283	305	2	0	0	0	\N	\N	\N	0	\N
10955	799	0	0	0	0	0	0	2	1	3	20	175	340	182	76	0	0	0	0	\N	\N	\N	0	\N
10956	999	0	0	0	0	0	4	7	4	10	41	212	398	206	117	0	0	0	0	\N	\N	\N	0	\N
10957	113.7	0	0	0	0	0	2	0	0.69999999999999996	1	4	11	21	25	48	1	0	0	0	\N	\N	\N	0	\N
10958	932	0	0	0	0	0	2	6	11	28	87	209	268	170	150	1	0	0	0	\N	\N	\N	0	\N
10959	999	0	0	0	0	0	2	8	7	37	165	304	234	134	108	0	0	0	0	\N	\N	\N	0	\N
10960	999	0	0	0	0	0	4	7	16	47	122	254	243	166	139	1	0	0	0	\N	\N	\N	0	\N
10961	999	0	0	0	0	0	6	9	12	53	99	115	190	293	221	1	0	0	0	\N	\N	\N	0	\N
10962	254	0	0	0	0	0	9	3	7	19	34	34	21	37	89	1	0	0	0	\N	\N	\N	0	\N
10947	16	0	0	0	0	0	0	0	0	0	0.80000000000000004	1	2.1000000000000001	5	7	0.10000000000000001	0	0	0	\N	\N	\N	0	\N
10948	998.70000000000005	0	0	0	0	0	6	4	11	27	126	292	314	141	77	0.69999999999999996	0	0	0	\N	\N	\N	0	\N
10949	999	0	0	0	0	0	19	17	15	37	104	222	269	174	141	1	0	0	0	\N	\N	\N	0	\N
10950	999	0	0	0	0	0	2	11	7	17	68	247	323	191	132	1	0	0	0	\N	\N	\N	0	\N
10951	999.70000000000005	0	0	0	0	0	26	25	26	119	319	246	114	63	61	0.69999999999999996	0	0	0	\N	\N	\N	0	\N
10952	999.29999999999995	0	0	0	0	0	4	11	8	36	112	328	287	140	73	0.29999999999999999	0	0	0	\N	\N	\N	0	\N
10953	999.5	0	0	0	0	0	8	12	11	29	120	307	303	131	78	0.5	0	0	0	\N	\N	\N	0	\N
10954	3.3999999999999999	0	0	0	0	0	0	0	0	0	0	0.29999999999999999	0.59999999999999998	1	1.5	0	0	0	0	\N	\N	\N	0	\N
10938	999.5	0	0	0	0	0	40	15	12	14	42	198	354	214	110	0.5	0	0	0	\N	\N	\N	0	\N
10939	43.799999999999997	0	0	0	0	0	0	2	0.69999999999999996	1	5	12	10	6	7	0.10000000000000001	0	0	0	\N	\N	\N	0	\N
10940	2299.0999999999999	0	0	0	0	41	103	35	39	76	254	598	609	317	225	2	0.10000000000000001	0	0	\N	\N	\N	0	\N
10941	954.39999999999998	0	0	0	0	0	63	30	28	127	298	278	88	42	0.40000000000000002	0	0	0	0	\N	\N	\N	0	\N
10942	40.299999999999997	0	0	0	0	0	0	0	0	0.20000000000000001	6	13	8	6	7	0.10000000000000001	0	0	0	\N	\N	\N	0	\N
10943	999.10000000000002	0	0	0	0	0	46	13	14	51	151	249	189	133	152	1	0.10000000000000001	0	0	\N	\N	\N	0	\N
10944	111	0	0	0	0	0	0	0	0.80000000000000004	2	15	33	28	15	17	0.20000000000000001	0	0	0	\N	\N	\N	0	\N
10945	1134.5999999999999	0	0	0	0	30	84	47	47	98	157	129	199	226	117	0.5	0.10000000000000001	0	0	\N	\N	\N	0	\N
10946	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
27650	5029.6000000000004	0	0	0	0	29.600000000000001	83.200000000000003	222.19999999999999	1232.4000000000001	1907	718.29999999999995	349	480.19999999999999	7.4000000000000004	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
27649	20040.200000000001	0	0	0	120	536.39999999999998	1168.8	2699.1999999999998	6699.3999999999996	6357.1999999999998	1946.5999999999999	356.80000000000001	152.40000000000001	3	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27648	1644	0	0	0	0	148.09999999999999	323.10000000000002	440.5	560.89999999999998	149.80000000000001	17.100000000000001	2.6000000000000001	1.3999999999999999	0.29999999999999999	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27647	12517.200000000001	0	0	0	0	18.399999999999999	160.59999999999999	342.39999999999998	1082.2	3028.5999999999999	4743.6000000000004	1989.4000000000001	1150.8	1.2	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27646	16954.200000000001	0	0	0	0	130	404.80000000000001	720	1938.2	4883.1999999999998	4872.1999999999998	1985.2	2003.5999999999999	17	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27645	16491.599999999999	0	0	0	15.199999999999999	133.80000000000001	360	1622.5999999999999	2319	3924.8000000000002	5706	1809	591.79999999999995	9.4000000000000004	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27644	12776.799999999999	0	0	0	5.4000000000000004	129	537.20000000000005	2064.4000000000001	4727	3656	1274	223.80000000000001	150.19999999999999	9.5999999999999996	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27643	8285	0	0	0	0	56.799999999999997	315.39999999999998	1423	3910.4000000000001	1920.2	499.80000000000001	111.59999999999999	47.600000000000001	0.20000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27634	13996.799999999999	0	0	0	53.399999999999999	321.19999999999999	679.20000000000005	1137	2785.8000000000002	3588.8000000000002	2929.1999999999998	1287	1206	8.4000000000000004	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0	\N
27635	14043.6	0	0	0	79	261.39999999999998	853.39999999999998	1632.8	3344	4167.6000000000004	2434.5999999999999	727.79999999999995	531.70000000000005	11	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
27636	14271.6	0	0	0	56.799999999999997	447.60000000000002	1011.4	1386.8	2780.5999999999999	4059	2719.4000000000001	988.20000000000005	792.39999999999998	26.199999999999999	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27637	16761.299999999999	0	0	0	113	457.19999999999999	861.60000000000002	1798.5999999999999	4185.6000000000004	4988.8000000000002	2893.1999999999998	846.39999999999998	606.79999999999995	9.5	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
27633	13376.200000000001	0	0	0	43.799999999999997	302.80000000000001	665	1262	5582.8000000000002	4771	614	79.799999999999997	53.799999999999997	0.59999999999999998	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
27632	2174.5	0	0	0	0	10.9	95.5	196.90000000000001	319.10000000000002	202.40000000000001	118.59999999999999	165.19999999999999	1023.2	41.100000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27631	18187.5	0	0	28	116.40000000000001	678.79999999999995	937.5	1309.5999999999999	3198.4000000000001	4615.6000000000004	3170.5999999999999	2102.1999999999998	2017.4000000000001	12	1	\N	\N	\N	\N	\N	\N	\N	0	\N
27630	27933	0	0	0	443.80000000000001	584	649.29999999999995	1118.4000000000001	4384.3999999999996	10281.4	7024.1999999999998	2175.5	1265	6.4000000000000004	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
27629	8172.6999999999998	0	0	0	233	703.60000000000002	847.60000000000002	1698.9000000000001	1747.8	856.79999999999995	605.79999999999995	630	840.79999999999995	7.7999999999999998	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
27628	2145.0999999999999	0	0	0	155.40000000000001	452.30000000000001	428	391.80000000000001	340	205.59999999999999	96.299999999999997	49.5	25.699999999999999	0.40000000000000002	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24761	5878.1999999999998	0	0	0	0	2.7999999999999998	17.399999999999999	53.600000000000001	106.59999999999999	183.40000000000001	355.19999999999999	525.79999999999995	4479	151.80000000000001	2.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24762	36621.800000000003	0	0	0	451.60000000000002	1563.2	2481.5999999999999	3706.5999999999999	7821.3999999999996	9933.6000000000004	6686.3999999999996	2314.4000000000001	1653	8.4000000000000004	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24763	36794.599999999999	0	0	0	534.20000000000005	1196.8	1429.8	1892.4000000000001	5278.3999999999996	10628.200000000001	9934.6000000000004	3579.8000000000002	2314.5999999999999	5.4000000000000004	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
24764	25209	0	0	0	296.39999999999998	894.20000000000005	1754.5999999999999	3696.4000000000001	7434.3999999999996	5048.8000000000002	2810.5999999999999	1498.4000000000001	1768	6.5999999999999996	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
24765	2546.5999999999999	0	0	0	203.19999999999999	458.39999999999998	528.20000000000005	475.39999999999998	532.20000000000005	250.19999999999999	67.799999999999997	18.800000000000001	11.800000000000001	0.40000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24750	8876.0799999999999	0	0	0	0	0	13.390000000000001	45.759999999999998	195.33000000000001	1117	2389	2304	2777	34.600000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24749	7160.96	0	0	0	0	31.579999999999998	37.899999999999999	121.81	408.73000000000002	1219	1735	1426	2125	55.939999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24748	5756.1899999999996	0	0	0	0	9.4100000000000001	20.260000000000002	61.509999999999998	444.31	1857	2067	929.10000000000002	358.92000000000002	8.6799999999999997	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24747	440.69999999999999	0	0	0	0	55	36.200000000000003	90.799999999999997	127.8	53.5	37.100000000000001	27.300000000000001	12.699999999999999	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24746	17	0	0	0	0	1.7	6.0999999999999996	4	3.1000000000000001	0.80000000000000004	0.20000000000000001	0.80000000000000004	0.20000000000000001	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24745	19924.740000000002	0	0	0	0	63.859999999999999	317.31999999999999	630.60000000000002	1676	4193	5694	3780	3550	19.960000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24744	8058.6899999999996	0	0	0	0	15.35	127.68000000000001	158.38999999999999	522.02999999999997	1590	2153	1526	1942	24.239999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24743	19442.529999999999	0	0	0	0	247.41	446.12	818.20000000000005	2733	5776	4892	2264	2221	44.799999999999997	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24742	17655.630000000001	0	0	0	49.810000000000002	403.30000000000001	623.39999999999998	1567	3504	4975	3674	1639	1192	26.510000000000002	1.6100000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24741	23407.279999999999	0	0	0	534.10000000000002	1504	2006	3656	6289	5262	2596	1042	511.80000000000001	5.3200000000000003	1.0600000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24100	452.25	0	0	0	0	3.3500000000000001	8.5	22.399999999999999	61.200000000000003	112.90000000000001	82.700000000000003	65.400000000000006	95.400000000000006	0.38	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24099	503.30000000000001	0	0	0	5.5	13.800000000000001	36.299999999999997	104.7	175.59999999999999	98.400000000000006	33.399999999999999	15.550000000000001	19.800000000000001	0.20000000000000001	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
24098	461	0	0	0	0	0	4.7999999999999998	9.8000000000000007	53.899999999999999	167.5	132.69999999999999	68	24.100000000000001	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24097	647.5	0	0	0	5.7000000000000002	26.300000000000001	63.149999999999999	129.25	194.19999999999999	140.69999999999999	53.899999999999999	22.600000000000001	11.6	0.050000000000000003	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
24096	8.3499999999999996	0	0	0	0	0	4.7999999999999998	1.45	0.55000000000000004	0.80000000000000004	0.5	0.10000000000000001	0.10000000000000001	0.029999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24095	370.19999999999999	0	0	0	0	2.6000000000000001	6.4000000000000004	12.6	39	83.299999999999997	78.700000000000003	48.899999999999999	97.099999999999994	1.5800000000000001	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24094	523.5	0	0	0	0	0	4.7999999999999998	41.799999999999997	164.5	171.90000000000001	67.900000000000006	37.299999999999997	34.799999999999997	0.47999999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24093	613.04999999999995	0	0	0	0	7.0999999999999996	22.800000000000001	92.700000000000003	165	167.5	98.900000000000006	43.299999999999997	15.699999999999999	0.029999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24092	638.70000000000005	0	0	0	0	29.699999999999999	70.400000000000006	144.09999999999999	189.5	140.5	50.049999999999997	10.1	4.2999999999999998	0.029999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24091	736.85000000000002	0	0	0	28.550000000000001	120.09999999999999	168	235.34999999999999	130.69999999999999	44.899999999999999	7.2000000000000002	1.25	0.69999999999999996	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
34874	7759.6000000000004	0	0	0	0	348	709	1372.4000000000001	2654.5999999999999	1791.4000000000001	578.79999999999995	187	116.59999999999999	1.2	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
34875	10537.4	0	0	0	42	413.80000000000001	678.60000000000002	1315.4000000000001	3104	2882	1250.5999999999999	480.19999999999999	364.60000000000002	5.5999999999999996	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
34876	1250.4000000000001	0	0	0	0	51.200000000000003	136.19999999999999	230.19999999999999	370.19999999999999	225.19999999999999	108.40000000000001	56	71	1.6000000000000001	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
34877	6563.6000000000004	0	0	0	67.400000000000006	204	373	594.39999999999998	1481	1812.5999999999999	1190.8	437	396.19999999999999	6.7999999999999998	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
34878	8985.7999999999993	0	0	0	245.40000000000001	252.19999999999999	313	632.79999999999995	2588	3568	1002.2	225	156.19999999999999	2.6000000000000001	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
34869	4840	0	0	0	44.600000000000001	153	255.80000000000001	519.79999999999995	1332	1269	655.39999999999998	370	236	4.2000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34870	26051	0	0	0	86.400000000000006	443.39999999999998	1331	2735	7286.6000000000004	8036.1999999999998	3813	1412.4000000000001	889.20000000000005	16.699999999999999	1.1000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34871	7922.1999999999998	0	0	0	33	227.59999999999999	353.60000000000002	775.79999999999995	2170.1999999999998	2353.4000000000001	1148.2	499.60000000000002	354.39999999999998	6	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
34872	9753.3999999999996	0	0	0	88	264.39999999999998	444	809.60000000000002	2616.1999999999998	3365	1283.4000000000001	497.60000000000002	379.60000000000002	5.4000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34873	5951.1999999999998	0	0	0	74.599999999999994	521.79999999999995	1244.2	1493	1048	368.60000000000002	333.39999999999998	432.80000000000001	430.39999999999998	4.2000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34756	7541.1999999999998	0	0	0	0	258	305.80000000000001	484.5	1100.8	2109	2085.3000000000002	756	440.60000000000002	1	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34757	15935.1	0	0	0	36.799999999999997	313	871	1761.5999999999999	3450	4175.3999999999996	3166.1999999999998	1105.2	1044.5999999999999	11	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
34758	1376.5999999999999	0	0	0	0	8.8000000000000007	30.800000000000001	73.799999999999997	227.19999999999999	411.80000000000001	261.39999999999998	121.8	234.40000000000001	6.4000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34759	20441.299999999999	0	0	0	0	117.2	337.39999999999998	961	3860	7458	4701.6000000000004	2078	910.20000000000005	17.199999999999999	0.69999999999999996	\N	\N	\N	\N	\N	\N	\N	0	\N
34760	2728.1999999999998	0	0	0	0	43	118.40000000000001	322.60000000000002	777.60000000000002	548	307.80000000000001	237.80000000000001	365.39999999999998	7.4000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29956	4925.6999999999998	0	0	0	0	9.1999999999999993	11	49.399999999999999	464.10000000000002	2148.1999999999998	1846.2	324.19999999999999	72.599999999999994	0.59999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29957	2273.5999999999999	0	0	0	0	8	8.8000000000000007	44.399999999999999	267	858.60000000000002	635.20000000000005	208.40000000000001	241.40000000000001	1.6000000000000001	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29958	7273	0	0	0	55	42.600000000000001	112.8	229.59999999999999	850.60000000000002	1741.2	1719.5999999999999	976.79999999999995	1535.2	9	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
29959	3575.4000000000001	0	0	0	4.2000000000000002	11.6	41.200000000000003	120.8	603.20000000000005	1265	828.79999999999995	342.80000000000001	352	4.4000000000000004	1.3999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
29960	3825.0999999999999	0	0	0	0	0	5.4000000000000004	66.200000000000003	211.59999999999999	926	984	797.39999999999998	405.5	423.80000000000001	5.2000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
29950	20097.299999999999	0	0	0	158.40000000000001	611.20000000000005	1039.8	1768.4000000000001	5714.8000000000002	6872.8000000000002	3079.8000000000002	633.20000000000005	215.59999999999999	2.6000000000000001	0.69999999999999996	\N	\N	\N	\N	\N	\N	\N	0	\N
29951	10086.799999999999	0	0	0	39.399999999999999	164.40000000000001	407.19999999999999	855.60000000000002	2082	3006.4000000000001	2235.1999999999998	751	538.60000000000002	6.4000000000000004	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
29952	8007.8999999999996	0	0	0	0	62.200000000000003	237	603.5	1503.5999999999999	2083.1999999999998	1742.8	846	920	9	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
29953	19681	0	0	0	0	157.59999999999999	363.60000000000002	905.20000000000005	2881.1999999999998	5379	4805.5	2666.8000000000002	1767.4000000000001	746.39999999999998	8	\N	\N	\N	\N	\N	\N	\N	0.29999999999999999	\N
29954	14253.9	0	0	0	7.4000000000000004	67.799999999999997	205.40000000000001	518.20000000000005	1262.8	3563.8000000000002	4416.1999999999998	2537	1165.8	503.19999999999999	5.5999999999999996	\N	\N	\N	\N	\N	\N	\N	0.69999999999999996	\N
29955	6973.6999999999998	0	0	0	34.299999999999997	438.69999999999999	1419.4000000000001	1812.7	1572.2	643.70000000000005	327.10000000000002	298.10000000000002	422.39999999999998	4.4000000000000004	0.69999999999999996	\N	\N	\N	\N	\N	\N	\N	0	\N
27726	2249.1999999999998	0	0	0	0	10.199999999999999	80.799999999999997	141.19999999999999	344.60000000000002	571.60000000000002	591	264	245.19999999999999	0.40000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27727	16056.200000000001	0	0	0	0	57.799999999999997	179.40000000000001	456.80000000000001	2020.4000000000001	4861	5096.8000000000002	2039.2	1337.8	6.4000000000000004	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
27728	11957.6	0	0	0	0	12.800000000000001	86	291.80000000000001	1858	4284.1999999999998	3290.4000000000001	1270.8	853.60000000000002	9.4000000000000004	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
27729	4299.6000000000004	0	0	0	0	0	10	37.799999999999997	215.59999999999999	1004.2	1674.4000000000001	823.39999999999998	529.79999999999995	4.2000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27730	10639.299999999999	0	0	0	0	5	113.2	330	1283	2787	3775.8000000000002	1640.4000000000001	701	3.5	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27725	2018.3099999999999	0	0	0	12.4	7.7999999999999998	18.600000000000001	95.799999999999997	442.19999999999999	711.60000000000002	444	145.5	139.59999999999999	0.80000000000000004	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
27724	10825.5	0	0	0	0	10.6	8.5999999999999996	24.199999999999999	199.59999999999999	1787.8	4091.5999999999999	2918	1305.2	477.80000000000001	2.1000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27723	2221.6999999999998	0	0	0	0	0	3.7999999999999998	4	54.600000000000001	259.19999999999999	852.39999999999998	619.20000000000005	427.39999999999998	1	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27722	409.80000000000001	0	0	0	0	0	0	0.59999999999999998	0.5	23	141.30000000000001	144.59999999999999	99.299999999999997	0.40000000000000002	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27721	30.199999999999999	0	0	0	0	0	0	0.10000000000000001	1.6000000000000001	13.6	6.5	2.8999999999999999	2.7000000000000002	1.1000000000000001	1.7	\N	\N	\N	\N	\N	\N	\N	0	\N
27711	17102.700000000001	0	0	0	67.400000000000006	286.80000000000001	698.20000000000005	1421	5890.8000000000002	1188.9000000000001	6139.3999999999996	1074.5999999999999	331.80000000000001	3.2000000000000002	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
27710	10195.200000000001	0	0	0	34.200000000000003	93.799999999999997	103.40000000000001	114	748.79999999999995	3487	3916	1221.5999999999999	473.60000000000002	2.3999999999999999	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27709	37781.5	0	0	0	178	572.79999999999995	1000.2	1755	5791.1999999999998	8290.3999999999996	2411.1999999999998	17771.400000000001	10.6	0.69999999999999996	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27708	10409.4	0	0	0	20	254	406.80000000000001	748.20000000000005	2802	3434	1640.2	738.79999999999995	361.39999999999998	3.7999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27706	14280.18	0	0	0	0	82.299999999999997	468	1208.0799999999999	3771.1999999999998	3966.1999999999998	3393	1049.4000000000001	334.39999999999998	7.5999999999999996	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27705	2070.8000000000002	0	0	0	0	15.199999999999999	25	54	191	405.60000000000002	560.79999999999995	367.80000000000001	450.19999999999999	1.2	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27704	8712	0	0	0	0	70.400000000000006	193	400.60000000000002	1509	2568.4000000000001	2186.1999999999998	1010.4	760	14	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27703	24140	0	0	0	0	241.19999999999999	579.20000000000005	1347.4000000000001	4754	8774.3999999999996	5370	1876	1188.8	9	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27693	3781.4000000000001	0	0	0	0	36	64	156	648	1368	1146	270	92	1.2	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27692	25937.5	0	0	0	132	376	916	1944	5310	8734	5784	1744	992	4	1.5	\N	\N	\N	\N	\N	\N	\N	0	\N
27691	27685.700000000001	0	0	0	78.599999999999994	177.80000000000001	611.79999999999995	1600.4000000000001	5893.8000000000002	8803.3999999999996	6391.3999999999996	2275.4000000000001	1831	21.199999999999999	0.90000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27690	15866	0	0	0	20	198	533	1120	3316	5678	3352	918	720	10	1	\N	\N	\N	\N	\N	\N	\N	0	\N
27689	292.30000000000001	0	0	0	11.4	22.5	53.799999999999997	77	80.200000000000003	22.699999999999999	7.2000000000000002	6.5	10.699999999999999	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24791	7414.6000000000004	0	0	0	24.199999999999999	113.59999999999999	314	769.39999999999998	1857.5999999999999	1953.5999999999999	1349.5999999999999	589	442	1.6000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24792	17357.299999999999	0	0	0	22	107.7	567.89999999999998	1534	4582.6000000000004	4851.1000000000004	2946.6999999999998	1345.3	1387.8	10.800000000000001	1.3999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
24793	22991.200000000001	0	0	0	19.800000000000001	108.59999999999999	346	812.39999999999998	3114.1999999999998	6021.8000000000002	5638.6000000000004	3549.5999999999999	3352.8000000000002	23.600000000000001	3.7999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
37351	3936.6999999999998	0	0	0	0	30.800000000000001	101.8	209.19999999999999	457.80000000000001	1093	1172.8	481.39999999999998	386.89999999999998	2.3999999999999999	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
37348	91.299999999999997	0	0	0	13.4	12.699999999999999	18.399999999999999	15.199999999999999	16.699999999999999	10.5	2.6000000000000001	1.2	0.59999999999999998	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37352	9.3000000000000007	0	0	0	0	0	0	0.29999999999999999	0.69999999999999996	3.3999999999999999	2.7999999999999998	1.2	0.90000000000000002	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37361	22.859999999999999	0	0	0	0	0	0.5	0.089999999999999997	0.10000000000000001	1.6000000000000001	5.0999999999999996	6.2000000000000002	9.0999999999999996	0.089999999999999997	0.080000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
37362	13.98	0	0	0	0	0	0	0.90000000000000002	1.2	4.2000000000000002	3.1000000000000001	1.8	2.7000000000000002	0.080000000000000002	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37349	5.0800000000000001	0	0	0	0	0	0	0.5	0.80000000000000004	1.2	0.59999999999999998	0.5	1.3	0.089999999999999997	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0	\N
37350	7.4800000000000004	0	0	0	0	0	0	0.089999999999999997	0.5	1.5	0.90000000000000002	1.2	3.1000000000000001	0.10000000000000001	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0	\N
37365	62.899999999999999	0	0	0	0	0	1.2	0.40000000000000002	2.3999999999999999	12.699999999999999	18.399999999999999	14.699999999999999	13.1	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37370	36.799999999999997	0	0	0	0.20000000000000001	0.10000000000000001	1.8999999999999999	1.3	2.7000000000000002	12.6	6.2000000000000002	6	5.5999999999999996	0.10000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37359	118.5	0	0	0	0	1.8	9.5	10.300000000000001	26.100000000000001	29.800000000000001	11.699999999999999	8.9000000000000004	20.100000000000001	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37360	612.39999999999998	0	0	0	0	6.5999999999999996	1.6000000000000001	7.7000000000000002	23.5	130.69999999999999	212.09999999999999	128.40000000000001	100.90000000000001	0.69999999999999996	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37369	5.4800000000000004	0	0	0	0	0	0	0.10000000000000001	0.40000000000000002	2.7000000000000002	0.90000000000000002	0.5	0.69999999999999996	0.089999999999999997	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0	\N
37367	5419.3000000000002	0	0	0	259.89999999999998	457.80000000000001	688.39999999999998	981.39999999999998	1520.2	1237.8	183.19999999999999	51.600000000000001	38.399999999999999	0.40000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37366	5362.3999999999996	0	0	0	168.19999999999999	455	866.20000000000005	1065	1268.2	918.20000000000005	280.80000000000001	189.19999999999999	151	0.40000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37376	10.880000000000001	0	0	0	0	0	0	0.29999999999999999	1.2	4.9000000000000004	1.8999999999999999	1.1000000000000001	1.3	0.089999999999999997	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0	\N
37377	6.3799999999999999	0	0	0	0	0	0	0	0.10000000000000001	0.69999999999999996	2.1000000000000001	1.8	1.5	0.089999999999999997	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0	\N
37372	10.289999999999999	0	0	0	0	0	0	0.59999999999999998	3	6.0999999999999996	0.29999999999999999	0.10000000000000001	0.10000000000000001	0.089999999999999997	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37371	119.7	0	0	0	0	12.199999999999999	19.5	15.1	18.800000000000001	30.399999999999999	12.5	5.9000000000000004	5.0999999999999996	0.10000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37378	21.379999999999999	0	0	0	0	0	0	0	0.089999999999999997	1.1000000000000001	8.1999999999999993	7	4.7999999999999998	0.10000000000000001	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0	\N
37380	47.280000000000001	0	0	0	0	0	0	0.089999999999999997	0.48999999999999999	6.8899999999999997	18.75	12.99	7.79	0.19	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0	\N
37388	2423.3000000000002	0	0	0	22.699999999999999	136.09999999999999	128.69999999999999	178.40000000000001	430	1093	368.60000000000002	41.799999999999997	23.399999999999999	0.40000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37374	23.27	0	0	0	0	0	1.1000000000000001	0.59999999999999998	5.2999999999999998	10.9	3	1.1000000000000001	1.1000000000000001	0.089999999999999997	0.080000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
37375	149.59999999999999	0	0	0	0	0	0.20000000000000001	0.69999999999999996	1.2	17.899999999999999	54.600000000000001	43.600000000000001	31	0.29999999999999999	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37391	14201.6	0	0	0	24.600000000000001	169.80000000000001	592.79999999999995	1121.2	2507.8000000000002	3070	4243	1751	711.60000000000002	6.2000000000000002	3.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37383	8.5999999999999996	0	0	0	0	0	0	0.10000000000000001	0.40000000000000002	2.2000000000000002	2.3999999999999999	2	1.3999999999999999	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37382	260.30000000000001	0	0	0	0	0	1.3	1.3999999999999999	12	84.900000000000006	83.299999999999997	43.700000000000003	33.600000000000001	0	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37390	19259.5	0	0	5.4000000000000004	46.399999999999999	78.599999999999994	173.09999999999999	308.10000000000002	2697.5999999999999	7196.8000000000002	3552.4000000000001	3887.8000000000002	1310.2	2.2000000000000002	0.90000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
37386	41.399999999999999	0	0	0	0	9.0999999999999996	8.1999999999999993	6.4000000000000004	5.7999999999999998	7.5	2.7000000000000002	0.69999999999999996	0.80000000000000004	0.10000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37387	4885	0	0	50	260.39999999999998	619.39999999999998	707.60000000000002	708.79999999999995	676.79999999999995	447.19999999999999	258.19999999999999	461.39999999999998	692.79999999999995	2	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
37389	10.960000000000001	0	0	0	0	0	0	0	0.59999999999999998	4.7000000000000002	1.5	2.2000000000000002	1.8	0.080000000000000002	0.080000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
37393	4552.5	0	0	0	226.80000000000001	376.39999999999998	354.80000000000001	348	683.20000000000005	1160.4000000000001	751.39999999999998	417	233	1.3999999999999999	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37392	2144	0	0	10.300000000000001	133.69999999999999	166.5	166.90000000000001	173.5	184.69999999999999	307.89999999999998	444.69999999999999	274.89999999999998	278.5	2.2999999999999998	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
11964	1521	0	0	0	189	367	317	297	240	101	8	1	1	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11965	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11966	7	0	0	0	0	0	0	0	0	0	0	0	5	2	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11957	19	0	0	0	0	7	2	2	5	3	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11958	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11959	1818	0	0	0	245	297	415	464	343	54	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11960	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11961	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11949	2889	0	0	65	890	709	398	275	289	184	45	21	12	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11950	4924	0	0	0	1495	1270	854	576	545	160	13	5	5	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11951	4	0	0	0	0	0	0	0	0	0	1	1	2	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11944	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
11945	42	0	0	0	0	0	0	0	1	2	6	10	8	5	10	0	0	0	0	\N	\N	\N	0	\N
11946	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
11947	34	0	0	0	0	0	5	1	2	6	5	4	2	2	6	1	0	0	0	\N	\N	\N	0	\N
11948	11	0	0	0	0	0	0	0	0	0	0.10000000000000001	3	6	0.90000000000000002	0.5	0.5	0	0	0	\N	\N	\N	0	\N
11939	91	0	0	0	0	0	0	0	1	1	8	29	23	14	15	0	0	0	0	\N	\N	\N	0	\N
11940	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
11941	3	0	0	0	0	0	0	0	0	1	1	0.5	0.20000000000000001	0.20000000000000001	0.10000000000000001	0	0	0	0	\N	\N	\N	0	\N
11942	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
11943	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
11935	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
11936	4	0	0	0	0	0	0	0	0	0	0	1	1	1	1	0	0	0	0	\N	\N	\N	0	\N
11937	936	0	0	0	0	0	29	18	32	135	456	262	3	0	1	0	0	0	0	\N	\N	\N	0	\N
11938	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10587	222	0	0	0	0	0	0	0	0	2	11	44	69	95	1	0	0	\N	\N	\N	\N	\N	0	\N
10588	183	0	0	0	0	0	0	0	1	6	17	23	41	94	1	0	0	\N	\N	\N	\N	\N	0	\N
10589	216	0	0	0	20	20	8	9	11	24	42	34	22	25	1	0	0	\N	\N	\N	\N	\N	0	\N
10590	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10584	43	0	0	0	0	5	1	3	6	9	9	5	3	2	0	0	0	\N	\N	\N	\N	\N	0	\N
10585	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10586	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10579	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10580	576	0	0	0	0	0	0	0	1	8	71	145	149	199	3	0	0	\N	\N	\N	\N	\N	0	\N
10581	581	0	0	0	0	0	1	0	5	15	133	150	98	177	2	0	0	\N	\N	\N	\N	\N	0	\N
10582	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10583	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10574	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10575	1000	0	0	0	0	2	1	6	4	16	96	256	258	358	3	0	0	\N	\N	\N	\N	\N	0	\N
10576	1000	0	0	0	0	0	1	4	9	40	210	232	187	315	2	0	0	\N	\N	\N	\N	\N	0	\N
10577	1000	0	0	0	0	8	2	2	12	42	288	260	189	196	1	0	0	\N	\N	\N	\N	\N	0	\N
10578	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10569	700	0	0	0	0	0	0	1	1	2	13	151	267	264	1	0	0	\N	\N	\N	\N	\N	0	\N
10570	1717	0	0	0	0	0	0	1	8	24	169	543	503	466	3	0	0	\N	\N	\N	\N	\N	0	\N
10571	1000	0	0	0	0	3	4	6	23	94	260	249	177	183	1	0	0	\N	\N	\N	\N	\N	0	\N
10572	700	0	0	0	0	0	0	1	1	15	285	320	64	13	1	0	0	\N	\N	\N	\N	\N	0	\N
10573	1186	0	0	0	178	405	89	75	114	106	95	46	23	45	9	1	0	\N	\N	\N	\N	\N	0	\N
10560	14	0	0	0	0	0	0	0.5	3.2999999999999998	5.7000000000000002	3.3999999999999999	0.59999999999999998	0.29999999999999999	0.20000000000000001	0	0	0	\N	\N	\N	\N	\N	0	\N
10561	2299	0	0	0	353	592	176	124	227	267	345	163	35	16	1	0	0	\N	\N	\N	\N	\N	0	\N
10562	2299	0	0	0	159	465	99	82	194	260	295	152	220	371	2	0	0	\N	\N	\N	\N	\N	0	\N
10563	2299	0	0	0	142	184	74	45	79	84	470	453	332	433	3	0	0	\N	\N	\N	\N	\N	0	\N
10554	999	0	0	0	0	0	2	5	6	29	159	356	264	177	1	0	0	\N	\N	\N	\N	\N	0	\N
10555	999	0	0	0	0	0	7	8	23	45	89	143	194	486	4	0	0	\N	\N	\N	\N	\N	0	\N
10556	780	0	0	0	0	0	0	0	1	3	17	57	127	569	6	0	0	\N	\N	\N	\N	\N	0	\N
10557	357	0	0	0	0	0	0	0	0	3	21	46	69	212	6	0	0	\N	\N	\N	\N	\N	0	\N
10558	692	0	0	0	0	0	0	0	0	1	53	245	170	216	7	0	0	\N	\N	\N	\N	\N	0	\N
10559	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10550	4	0	0	0	0	0	0	0	0	0	0.69999999999999996	1	0.90000000000000002	1.3999999999999999	0	0	0	\N	\N	\N	\N	\N	0	\N
10551	10.9	0	0	0	0	0	0	0	0	0.10000000000000001	0.69999999999999996	1.2	2.5	6.4000000000000004	0	0	0	\N	\N	\N	\N	\N	0	\N
10552	10	0	0	0	0	0	0	0	0	0.10000000000000001	0.80000000000000004	2.1000000000000001	2.5	4.4000000000000004	0.10000000000000001	0	0	\N	\N	\N	\N	\N	0	\N
10553	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10540	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10541	687	0	0	0	0	35	26	28	74	122	98	144	102	58	0	0	0	\N	\N	\N	\N	\N	0	\N
10542	9	0	0	0	0	0	0	0	0.29999999999999999	2.1000000000000001	1.7	0.80000000000000004	1.2	2.7000000000000002	0.20000000000000001	0	0	\N	\N	\N	\N	\N	0	\N
10543	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10544	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10545	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10536	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10537	8	0	0	0	0	0	0	1	0	0.59999999999999998	2.6000000000000001	1.3	1.3	1.2	0	0	0	\N	\N	\N	\N	\N	0	\N
10538	36.899999999999999	0	0	0	0	0	0	0	0.80000000000000004	6.7000000000000002	15.800000000000001	3.6000000000000001	4.0999999999999996	5.9000000000000004	0	0	0	\N	\N	\N	\N	\N	0	\N
10539	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10530	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10531	116	0	0	0	0	35	8	6	17	22	24	2	1	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10532	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10533	511	0	0	0	14	109	47	47	91	97	77	8	7	14	0	0	0	\N	\N	\N	\N	\N	0	\N
10534	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10535	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10525	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10526	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10527	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10528	2299	0	0	0	289	726	245	220	390	309	76	6	6	31	1	0	0	\N	\N	\N	\N	\N	0	\N
10529	2299	0	0	0	0	149	92	129	432	774	554	109	28	31	1	0	0	\N	\N	\N	\N	\N	0	\N
10329	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10330	19	0	0	0	0	17	0	1	0.59999999999999998	0.29999999999999999	0.10000000000000001	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10331	58	0	0	0	0	23	9	10	7	5	2	1	1	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10332	1408	0	0	0	190	863	121	63	69	30	13	7	7	44	1	0	0	\N	\N	\N	\N	\N	0	\N
10333	2299	0	0	0	37	192	116	132	359	618	538	188	66	52	1	0	0	\N	\N	\N	\N	\N	0	\N
10334	135	0	0	0	0	0	0	0	0	4	9	7	6	95	13	1	0	\N	\N	\N	\N	\N	0	\N
10301	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10302	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10303	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10304	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10305	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10306	552	0	0	0	0	0	1	3	6	15	60	130	135	201	1	0	0	\N	\N	\N	\N	\N	0	\N
10307	5.9000000000000004	0	0	0	0	0	0	0	0	0.10000000000000001	0.90000000000000002	0.59999999999999998	1	3.2999999999999998	0	0	0	\N	\N	\N	\N	\N	0	\N
10308	6.9000000000000004	0	0	0	0	0	0	0	0	0.29999999999999999	1.5	1.3	0.90000000000000002	2.7000000000000002	0.20000000000000001	0	0	\N	\N	\N	\N	\N	0	\N
10309	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10310	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10311	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10312	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10295	3.2000000000000002	0	0	0	0	0	0	0	0.29999999999999999	0.69999999999999996	0.59999999999999998	1	0.40000000000000002	0.20000000000000001	0	0	0	\N	\N	\N	\N	\N	0	\N
10296	4.5999999999999996	0	0	0	0	0	0	0	0.10000000000000001	0.69999999999999996	0.90000000000000002	1	0.90000000000000002	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10297	351.5	0	0	0	0	0	0	0	0.10000000000000001	3.2000000000000002	51	137	83	77	0.20000000000000001	0	0	\N	\N	\N	\N	\N	0	\N
10298	17.5	0	0	0	0	0	0.80000000000000004	0	2.5	3.2000000000000002	2	1.8999999999999999	2	5	0.10000000000000001	0	0	\N	\N	\N	\N	\N	0	\N
10299	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10300	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10288	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10289	22.100000000000001	0	0	0	0	0	0	0	1.1000000000000001	4	4	5	4	4	0	0	0	\N	\N	\N	\N	\N	0	\N
10290	1854.4000000000001	0	0	109	0	265	118	106	197	208	220	252	218	161	0.29999999999999999	0.10000000000000001	0	\N	\N	\N	\N	\N	0	\N
10291	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10292	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10293	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10294	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10278	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10279	140.19999999999999	0	0	0	40	81	3	4	7	4	1	0.10000000000000001	0.10000000000000001	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10280	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10281	34.299999999999997	0	0	0	0	26	3	3	1	1.2	0.10000000000000001	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10282	2223.3000000000002	0	0	0	101	800	332	331	452	197	9	1	0.10000000000000001	0.20000000000000001	0	0	0	\N	\N	\N	\N	\N	0	\N
13022	777.14999999999998	0	0	0	39	57.200000000000003	58.299999999999997	112.90000000000001	167.90000000000001	276.89999999999998	52.850000000000001	8.4000000000000004	3.5	0.14999999999999999	0.029999999999999999	0.02	\N	\N	\N	\N	\N	\N	0	\N
13023	246.55000000000001	0	0	0	6.9000000000000004	0.5	4.4000000000000004	2.3999999999999999	3.3999999999999999	8.9000000000000004	21.199999999999999	56	140.75	2	0.050000000000000003	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
13024	264.25	0	0	0	0	13.9	13.300000000000001	13.6	8.1999999999999993	8.6999999999999993	19	37.100000000000001	144.40000000000001	5.9000000000000004	0.10000000000000001	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
13025	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10652	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10653	829	0	0	0	259	262	152	78	52	23	3	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10654	1675	0	0	0	107	306	236	184	277	416	134	11	4	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10655	390	0	0	0	140	56	50	44	37	41	4	4	14	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10656	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10647	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10648	305	0	0	0	97	123	51	24	7	3	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10649	2902	0	0	0	499	351	347	337	665	541	92	37	32	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10650	1795	0	0	0	215	399	327	202	215	168	43	56	169	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10651	795	0	0	0	0	7	9	15	42	153	304	173	91	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10637	1.0800000000000001	0	0	0	0	0	0	0	0	0.83999999999999997	0.14000000000000001	0.040000000000000001	0.059999999999999998	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10638	4521	0	0	275	1051	1178	722	468	568	221	21	6	10	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10639	4521	0	0	60	757	971	895	878	675	206	29	13	35	2	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10640	4861	0	0	0	470	910	901	802	770	535	213	89	166	4	1	\N	\N	\N	\N	\N	\N	\N	0	\N
10641	60	0	0	0	0	23	7	14	10	4	1	1	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10632	1041	0	0	0	28	67	26	23	40	178	337	219	90	32	1	0	0	\N	\N	\N	\N	\N	0	\N
10633	1236	0	0	0	98	67	13	9	38	118	198	228	215	251	1	0	0	\N	\N	\N	\N	\N	0	\N
10634	4	0	0	0	0	0	0	0	0	0.10000000000000001	1	1	0.40000000000000002	1.5	0	0	0	\N	\N	\N	\N	\N	0	\N
10635	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10636	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10623	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10624	895	0	0	0	74	129	61	37	89	135	249	83	25	12	1	0	0	\N	\N	\N	\N	\N	0	\N
10625	2000	0	0	0	214	222	97	88	243	464	460	120	43	49	0	0	0	\N	\N	\N	\N	\N	0	\N
10626	288	0	0	0	15	92	21	22	35	46	37	6	4	10	0	0	0	\N	\N	\N	\N	\N	0	\N
10627	562	0	0	0	0	25	21	23	41	76	170	146	30	29	1	0	0	\N	\N	\N	\N	\N	0	\N
10618	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10619	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10620	190	0	0	0	0	0	0	0	1	3	7	12	27	134	5	1	0	\N	\N	\N	\N	\N	0	\N
10621	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10622	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10613	3	0	0	0	0	0	0	0	0	0.089999999999999997	1.6399999999999999	0.42999999999999999	0.32000000000000001	0.5	0.02	0	0	\N	\N	\N	\N	\N	0	\N
10614	2300	0	0	0	42	249	132	103	169	205	395	531	271	202	1	0	0	\N	\N	\N	\N	\N	0	\N
10615	1000	0	0	0	0	32	11	7	18	54	198	233	167	278	2	0	0	\N	\N	\N	\N	\N	0	\N
10616	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10617	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10607	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10608	588	0	0	0	11	147	76	50	79	77	66	40	22	20	0	0	0	\N	\N	\N	\N	\N	0	\N
10609	1000	0	0	0	0	9	18	13	24	40	117	289	269	220	1	0	0	\N	\N	\N	\N	\N	0	\N
10610	1000	0	0	0	0	0	2	2	6	61	236	203	174	314	2	0	0	\N	\N	\N	\N	\N	0	\N
10611	280	0	0	0	0	0	0	0	0	1	13	34	58	172	2	0	0	\N	\N	\N	\N	\N	0	\N
10612	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10601	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10602	2299	0	0	0	290	821	258	190	290	252	138	31	11	17	1	0	0	\N	\N	\N	\N	\N	0	\N
10603	2299	0	0	0	148	554	186	178	355	418	340	82	20	17	1	0	0	\N	\N	\N	\N	\N	0	\N
10604	4399	0	0	149	623	979	261	212	390	478	367	142	242	551	5	0	0	\N	\N	\N	\N	\N	0	\N
10605	1074	0	0	0	28	148	43	31	34	40	77	54	84	526	9	0	0	\N	\N	\N	\N	\N	0	\N
10606	31	0	0	0	0	0	0	2	4	6	6	4	3	6	0	0	0	\N	\N	\N	\N	\N	0	\N
10628	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10629	2299	0	0	0	61	229	89	88	175	369	516	352	228	191	1	0	0	\N	\N	\N	\N	\N	0	\N
10630	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10631	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10595	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10596	628	0	0	0	0	28	32	30	57	67	198	163	30	23	0	0	0	\N	\N	\N	\N	\N	0	\N
10597	237	0	0	0	0	0	0	0	1	12	60	99	39	26	0	0	0	\N	\N	\N	\N	\N	0	\N
10598	34	0	0	0	0	0	0	0	0.29999999999999999	4.2999999999999998	10.300000000000001	6.7999999999999998	3.7999999999999998	8.5	0	0	0	\N	\N	\N	\N	\N	0	\N
10599	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10600	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10591	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10592	293	0	0	0	0	56	8	17	40	106	64	1	0	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10593	689	0	0	0	0	162	55	49	98	87	84	25	41	88	0	0	0	\N	\N	\N	\N	\N	0	\N
10594	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
34814	13221	0	0	0	873.79999999999995	966.20000000000005	940	889.39999999999998	2345	3981.1999999999998	2147.5999999999999	672.60000000000002	360.80000000000001	43.799999999999997	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
34815	23719.200000000001	0	0	0	506.39999999999998	826.20000000000005	756.20000000000005	915.79999999999995	3004.4000000000001	7486.8000000000002	6378	2277.1999999999998	1539.8	27	1.3999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
34816	34946.800000000003	0	0	0	1035.8	2887	4712	6780.1999999999998	7421	4376	3170	2601.5999999999999	1945.2	16.600000000000001	1.3999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
34817	35235.199999999997	0	0	216.59999999999999	3817.4000000000001	5765	5721	5630.6000000000004	5625	2342	1066.4000000000001	1732.8	3296.8000000000002	19.800000000000001	1.8	\N	\N	\N	\N	\N	\N	\N	0	\N
34818	3120.4000000000001	0	0	0	334	646.79999999999995	658.5	548	530.60000000000002	241.40000000000001	37.899999999999999	27.699999999999999	91.599999999999994	3.3999999999999999	0.5	\N	\N	\N	\N	\N	\N	\N	0	\N
34809	463.39999999999998	0	0	0	120	80.799999999999997	60.700000000000003	31.300000000000001	43.299999999999997	47.600000000000001	32.100000000000001	25.199999999999999	21.800000000000001	0.40000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34810	95.700000000000003	0	0	0	0	0	0	1.3	4.2000000000000002	34.899999999999999	35.5	11.699999999999999	7.7999999999999998	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34811	5399.3999999999996	0	0	0	219.59999999999999	326.80000000000001	447.39999999999998	625	1450.4000000000001	1256.5999999999999	450.80000000000001	273.60000000000002	345.60000000000002	3.2000000000000002	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
34812	1523.3	0	0	0	214.40000000000001	305	451.19999999999999	287.30000000000001	185.69999999999999	53	7.0999999999999996	7	12.300000000000001	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34813	1323.2	0	0	0	120.3	159.30000000000001	229.69999999999999	232.90000000000001	231.09999999999999	131.40000000000001	38	51.899999999999999	127	1.3999999999999999	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34731	8744.2000000000007	0	0	0	11.4	28.600000000000001	31	157.80000000000001	179	2921	4286.6000000000004	919	199.19999999999999	10.4	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34732	2586.3000000000002	0	0	0	0	26.199999999999999	42	84	276.39999999999998	1245	720.60000000000002	123	66.799999999999997	2.1000000000000001	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34733	5811	0	0	0	0	132.40000000000001	511.60000000000002	1071.2	1275.4000000000001	570.60000000000002	603.79999999999995	1296.8	334.80000000000001	14.199999999999999	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34734	1424.9000000000001	0	0	0	63.799999999999997	69.799999999999997	65.799999999999997	101.8	253	470	113	66.400000000000006	215.40000000000001	5.5999999999999996	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
34735	106.8	0	0	0	25.100000000000001	30.199999999999999	20.100000000000001	13.5	5.2000000000000002	2.8999999999999999	3.1000000000000001	6	0.40000000000000002	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29892	7664.6000000000004	0	0	0	19.800000000000001	76	259	418.39999999999998	1032.8	2400.4000000000001	1998.4000000000001	815	639.20000000000005	5.4000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29891	2194.3000000000002	0	0	0	31.600000000000001	92.299999999999997	144.90000000000001	139.19999999999999	344.69999999999999	481.69999999999999	381.80000000000001	250	324.80000000000001	3.2000000000000002	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29890	400.39999999999998	0	0	0	0	21.600000000000001	36.399999999999999	39.299999999999997	69.900000000000006	91.599999999999994	47.899999999999999	20.800000000000001	71.400000000000006	1.5	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29889	1046.4000000000001	0	0	0	28.300000000000001	62.700000000000003	198.59999999999999	202.09999999999999	303.10000000000002	165.09999999999999	19.600000000000001	23.100000000000001	43.200000000000003	0.5	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29883	6983.1999999999998	0	0	0	0	107.59999999999999	213.80000000000001	314.80000000000001	798.60000000000002	1799.4000000000001	2906.4000000000001	678.39999999999998	162.80000000000001	1.2	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29882	7316.3999999999996	0	0	0	4	100.40000000000001	293.80000000000001	336.60000000000002	779	1680.5999999999999	3070.8000000000002	853.20000000000005	197.19999999999999	0.80000000000000004	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29881	5427.1000000000004	0	0	0	8	176	359.80000000000001	442	760.89999999999998	848	1218.5999999999999	1123.2	489.39999999999998	1.2	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29880	14000.799999999999	0	0	0	0	119	375.80000000000001	601.20000000000005	1796.2	2690.8000000000002	4768.1999999999998	2767.8000000000002	880.39999999999998	1	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
29879	1253.3	0	0	0	29.300000000000001	156.5	184.30000000000001	122.59999999999999	123.09999999999999	76.400000000000006	83.5	200.59999999999999	275.19999999999999	1.8	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29878	5371.3999999999996	0	0	392.60000000000002	914.29999999999995	959	432.10000000000002	257.30000000000001	501.80000000000001	959.79999999999995	588.5	219.40000000000001	140.80000000000001	5.2000000000000002	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
29877	7711.8999999999996	0	0	0	685	925.20000000000005	724.79999999999995	783.39999999999998	1688.2	2046.4000000000001	523.39999999999998	179.80000000000001	154	1.2	0.5	\N	\N	\N	\N	\N	\N	\N	0	\N
29876	10059.200000000001	0	0	96.299999999999997	594.89999999999998	730.20000000000005	656.29999999999995	734.39999999999998	1910.4000000000001	3265.8000000000002	1188.5	470.89999999999998	404.5	6.2999999999999998	0.69999999999999996	\N	\N	\N	\N	\N	\N	\N	0	\N
29875	26111.700000000001	0	0	0	1761.2	2018	2592.8000000000002	4485.8000000000002	7498.6000000000004	4866.6000000000004	1472.4000000000001	889	525.39999999999998	1.7	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29874	13775.299999999999	0	0	0	2847	3235.5999999999999	2260	1749.4000000000001	1805.4000000000001	931.39999999999998	362.60000000000002	327	255.40000000000001	1.1000000000000001	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27521	16570.099999999999	0	0	0	19.199999999999999	204	439.19999999999999	429.60000000000002	1179.2	5247.6000000000004	5965.8000000000002	2024.5999999999999	1048.5999999999999	11.800000000000001	0.5	\N	\N	\N	\N	\N	\N	\N	0	\N
27522	10782.700000000001	0	0	0	12.800000000000001	93.099999999999994	199.80000000000001	229.40000000000001	779	3729.6999999999998	3979	1044.7	701	13.5	0.69999999999999996	\N	\N	\N	\N	\N	\N	\N	0	\N
27523	8484.5	0	0	0	15	142.59999999999999	139.80000000000001	75.599999999999994	249.19999999999999	2312.5999999999999	4003.1999999999998	1067.7	470.39999999999998	7.7999999999999998	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
27524	4306.8000000000002	0	0	0	15.800000000000001	151.09999999999999	265	418.10000000000002	1083.0999999999999	1369.8	604.60000000000002	343.80000000000001	45.5	9.6999999999999993	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
27525	1786.78	0	0	0	37.799999999999997	237.90000000000001	343.77999999999997	318.5	390.10000000000002	116.3	41.399999999999999	86	211.19999999999999	3.7000000000000002	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27520	16148.799999999999	0	0	0	772.60000000000002	1950.8	1421.4000000000001	808	1468.8	4623.8000000000002	3914.4000000000001	753	432	3.6000000000000001	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27519	9273.7999999999993	0	0	0	152.19999999999999	577.39999999999998	577.60000000000002	609.39999999999998	1470.2	3080.1999999999998	1940.4000000000001	542.10000000000002	321.39999999999998	2.3999999999999999	0.5	\N	\N	\N	\N	\N	\N	\N	0	\N
27518	9147.2000000000007	0	0	0	327.60000000000002	802.39999999999998	847.60000000000002	969.20000000000005	2046.2	2300.8000000000002	1066	445.60000000000002	340.39999999999998	1	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27517	33919.900000000001	0	0	0	608	1704.4000000000001	3270.4000000000001	5552	5857.3999999999996	2673.5999999999999	2224.4000000000001	6877	5146.3999999999996	5.4000000000000004	0.90000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27516	1272.2	0	0	0	0	40.399999999999999	194.80000000000001	269.80000000000001	235.80000000000001	245.59999999999999	128.59999999999999	54	35.200000000000003	67.599999999999994	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27515	38416.800000000003	0	0	0	1666	1794	974	1906	1974	11704	14662	2844	884	6.7999999999999998	2	\N	\N	\N	\N	\N	\N	\N	0	\N
27514	61176.400000000001	0	0	49.600000000000001	2426	4114.8000000000002	3384.5999999999999	3646.8000000000002	7442	15492	15710	6262.1999999999998	2632.4000000000001	14	2	\N	\N	\N	\N	\N	\N	\N	0	\N
27513	59462.900000000001	0	0	47.600000000000001	655	5831.8999999999996	5227.6000000000004	4391.6000000000004	7925.8999999999996	13217	16650	3027	2471.4000000000001	15.9	2	\N	\N	\N	\N	\N	\N	\N	0	\N
27512	21123.5	0	0	54	566	1406	1758	2016	2268	1536	3764	5712	2040	2.3999999999999999	1.1000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
23687	797.46000000000004	0	0	0	0	64.299999999999997	61.700000000000003	117.55	221.5	255.19999999999999	69.049999999999997	7.4500000000000002	0.59999999999999998	0.050000000000000003	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.029999999999999999	\N
23686	281.64999999999998	0	0	0	0	7.5999999999999996	21.850000000000001	44.5	70.150000000000006	95.25	31.600000000000001	7.7000000000000002	2.7000000000000002	0.20000000000000001	0.059999999999999998	\N	\N	\N	\N	\N	\N	\N	0.040000000000000001	\N
23685	624.73000000000002	0	0	0	9.25	25.300000000000001	38.600000000000001	58.25	114.40000000000001	185.59999999999999	130	48.399999999999999	14.800000000000001	0.10000000000000001	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23684	754.75999999999999	0	0	0	34.700000000000003	22	31.25	56.5	122.3	258.25	122.45	74.599999999999994	32.299999999999997	0.34999999999999998	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.029999999999999999	\N
23683	629.64999999999998	0	0	0	33.649999999999999	111.7	135.5	117.2	80.200000000000003	17.899999999999999	12.699999999999999	27.600000000000001	92.400000000000006	0.78000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23682	322.94999999999999	0	0	0	0	0	1.45	4.5	9.4000000000000004	12.449999999999999	39.149999999999999	88.599999999999994	166.80000000000001	0.58999999999999997	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23681	43.399999999999999	0	0	0	0	0	11.800000000000001	2.5499999999999998	9.0999999999999996	4.0999999999999996	4.2000000000000002	3.5	7.9000000000000004	0.23999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
13007	241.30000000000001	0	0	0	0	0	0.80000000000000004	2.7000000000000002	6.2999999999999998	36.799999999999997	141.19999999999999	49.100000000000001	4.2999999999999998	0.070000000000000007	0.02	0.01	\N	\N	\N	\N	\N	\N	0	\N
13008	412.64999999999998	0	0	0	0	0	4.7000000000000002	17.25	32.200000000000003	124.59999999999999	144.40000000000001	72.200000000000003	16.899999999999999	0.37	0.02	0.01	\N	\N	\N	\N	\N	\N	0	\N
13009	307.89999999999998	0	0	0	0	0	0	2.8999999999999999	10.25	57.600000000000001	133.90000000000001	79.450000000000003	22	1.78	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
13010	268.56	0	0	0	0	0	0	0.14999999999999999	0.40000000000000002	1.3500000000000001	12.800000000000001	69.299999999999997	183.40000000000001	0.90000000000000002	0.25	0.01	\N	\N	\N	\N	\N	\N	0	\N
13002	261.94999999999999	0	0	0	0	0	15.85	36.5	92.049999999999997	98.549999999999997	8.5	2.3999999999999999	7.4000000000000004	0.45000000000000001	0.14999999999999999	0.10000000000000001	\N	\N	\N	\N	\N	\N	0	\N
13003	208.69999999999999	0	0	0	0	10.9	7	14.699999999999999	26.300000000000001	45.700000000000003	34.799999999999997	11.9	55.5	1.7	0.10000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	0	\N
13004	202.94999999999999	0	0	0	0	0	0	1.6000000000000001	4.0999999999999996	14.699999999999999	40.5	33.899999999999999	106.59999999999999	1.45	0.050000000000000003	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
13005	211.65000000000001	0	0	0	0	2.5499999999999998	1.8999999999999999	0.69999999999999996	1.95	8.5	45.5	56.850000000000001	92.400000000000006	1.2	0.050000000000000003	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
13006	35.049999999999997	0	0	0	0	0	0.10000000000000001	0.90000000000000002	0.40000000000000002	0.40000000000000002	1	3	28	1.2	0.029999999999999999	0.02	\N	\N	\N	\N	\N	\N	0	\N
12997	652.29999999999995	0	0	0	37.5	16.199999999999999	44.399999999999999	82.200000000000003	203.40000000000001	258.69999999999999	8.4000000000000004	0.80000000000000004	0.5	0.14999999999999999	0.040000000000000001	0.01	\N	\N	\N	\N	\N	\N	0	\N
12998	757.54999999999995	0	0	0	44.299999999999997	33.899999999999999	57.5	73	97.799999999999997	173	191.69999999999999	62.799999999999997	22.800000000000001	0.69999999999999996	0.040000000000000001	0.01	\N	\N	\N	\N	\N	\N	0	\N
12999	629.10000000000002	0	0	0	8.5	58.5	31.800000000000001	28.399999999999999	30.199999999999999	40.5	61.799999999999997	90.5	276.10000000000002	2.7000000000000002	0.080000000000000002	0.02	\N	\N	\N	\N	\N	\N	0	\N
13000	452.35000000000002	0	0	0	0	0	17.699999999999999	16.300000000000001	16.5	28.5	54.700000000000003	72	224.40000000000001	22.199999999999999	0.040000000000000001	0.01	\N	\N	\N	\N	\N	\N	0	\N
13001	186.50999999999999	0	0	0	0	0	0	0	0.20000000000000001	0.40000000000000002	0.90000000000000002	5	175.69999999999999	4.2000000000000002	0.10000000000000001	0.01	\N	\N	\N	\N	\N	\N	0	\N
10918	1569	0	0	0	13	189	391	625	297	53	1	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10919	1320	0	0	0	30	30	33	106	493	496	118	12	2	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10920	1319	0	0	0	22	49	126	212	495	313	85	12	5	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10921	682	0	0	0	13	65	134	153	132	61	35	40	49	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10922	955	0	0	0	0	45	67	43	22	17	73	330	355	3	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10913	1937	0	0	0	107	283	652	578	293	24	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10914	2554	0	0	0	173	326	420	439	614	417	127	25	12	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10915	1655	0	0	0	25	82	203	431	444	268	131	44	26	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10916	2097	0	0	0	133	234	224	173	143	105	361	450	273	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10917	378	0	0	0	0	0	0	0	0	0	0	6	363	9	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10908	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10909	1581	0	0	0	0	45	159	261	424	427	173	59	33	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10910	60	0	0	0	0	1	4	7	19	19	3	2	5	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10911	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10912	176	0	0	0	0	0	0	0	0	0	0	4	166	6	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10903	1338	0	0	0	102	79	150	234	531	229	11	1	1	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10904	2182	0	0	0	89	303	363	396	611	313	76	23	8	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10905	2238	0	0	0	137	203	375	527	464	277	168	57	30	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10906	2229	0	0	0	0	214	369	550	402	234	220	139	100	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10907	123	0	0	0	0	0	0	0	1	1	4	8	102	7	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10898	17	0	0	0	0	0	2	1	2	3	2	2	2	3	0	0	0	\N	\N	\N	\N	\N	0	\N
10899	263	0	0	0	0	6	7	3	29	38	25	25	42	87	1	0	0	\N	\N	\N	\N	\N	0	\N
10900	86	0	0	0	0	0	0	0	1	3	4	8	20	50	0	0	0	\N	\N	\N	\N	\N	0	\N
10901	52	0	0	0	0	3	3	1	7	4	1	2	6	24	1	0	0	\N	\N	\N	\N	\N	0	\N
10902	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10893	2345	0	0	0	19	415	161	139	269	287	312	407	180	156	0	0	0	\N	\N	\N	\N	\N	0	\N
10894	2247	0	0	0	22	68	56	51	142	280	349	836	221	222	0	0	0	\N	\N	\N	\N	\N	0	\N
10895	1420	0	0	0	0	100	86	73	159	224	166	263	174	171	4	0	0	\N	\N	\N	\N	\N	0	\N
10896	1150	0	0	0	0	42	63	55	114	84	70	228	285	209	0	0	0	\N	\N	\N	\N	\N	0	\N
10897	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10889	2000	0	0	0	22	80	67	108	422	793	401	70	24	12	1	0	0	\N	\N	\N	\N	\N	0	\N
10890	2368	0	0	0	94	331	154	163	401	548	411	169	58	37	2	0	0	\N	\N	\N	\N	\N	0	\N
10891	1419	0	0	0	142	369	136	121	276	169	60	19	40	87	0	0	0	\N	\N	\N	\N	\N	0	\N
10892	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10883	547	0	0	0	34	29	19	32	110	194	110	13	4	2	0	0	0	\N	\N	\N	\N	\N	0	\N
10884	4071	0	0	0	69	356	226	267	580	1838	584	86	38	23	4	0	0	\N	\N	\N	\N	\N	0	\N
10885	2000	0	0	0	57	191	98	102	351	578	220	247	93	62	1	0	0	\N	\N	\N	\N	\N	0	\N
10886	2000	0	0	0	307	454	168	177	331	236	105	45	83	93	1	0	0	\N	\N	\N	\N	\N	0	\N
10887	247	0	0	0	0	0	0	0	5	7	4	3	8	210	9	1	0	\N	\N	\N	\N	\N	0	\N
10888	34	0	0	0	0	1	0	0	1	5	14	2	1	8	2	0	0	\N	\N	\N	\N	\N	0	\N
10878	1000	0	0	0	0	0	3	4	32	108	345	339	115	53	1	0	0	\N	\N	\N	\N	\N	0	\N
10879	1000	0	0	0	0	5	2	7	40	132	454	298	52	10	0	0	0	\N	\N	\N	\N	\N	0	\N
10880	1000	0	0	0	0	1	1	1	19	136	559	262	18	3	0	0	0	\N	\N	\N	\N	\N	0	\N
10881	611	0	0	0	0	0	0	1	6	8	7	34	108	445	2	0	0	\N	\N	\N	\N	\N	0	\N
10882	2	0	0	0	0	0	0	0.53000000000000003	0	0.84999999999999998	0.17000000000000001	0.17999999999999999	0.12	0.14999999999999999	0	0	0	\N	\N	\N	\N	\N	0	\N
10873	1000	0	0	0	0	9	13	14	35	96	258	268	163	143	1	0	0	\N	\N	\N	\N	\N	0	\N
10874	1000	0	0	0	0	5	5	8	45	99	280	337	139	81	1	0	0	\N	\N	\N	\N	\N	0	\N
10875	963	0	0	0	0	2	7	22	102	191	326	248	42	22	1	0	0	\N	\N	\N	\N	\N	0	\N
10876	1000	0	0	0	0	0	5	7	15	10	11	91	218	640	3	0	0	\N	\N	\N	\N	\N	0	\N
10877	22	0	0	0	0	7	6	3	3	1	0.5	0.29999999999999999	0.20000000000000001	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10923	384	0	0	0	0	8	6	12	32	64	85	76	58	42	1	0	0	\N	\N	\N	\N	\N	0	\N
10924	700	0	0	0	0	0	0	5	23	101	342	204	22	3	0	0	0	\N	\N	\N	\N	\N	0	\N
10925	1000	0	0	0	0	12	26	27	89	133	189	402	106	16	0	0	0	\N	\N	\N	\N	\N	0	\N
10926	419	0	0	0	0	23	19	14	21	8	6	11	69	247	1	0	0	\N	\N	\N	\N	\N	0	\N
10927	34	0	0	0	0	2	5	7	12	5	1	0	1	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10868	1000	0	0	0	0	34	42	45	125	197	222	186	90	58	1	0	0	\N	\N	\N	\N	\N	0	\N
10869	1000	0	0	0	0	45	25	18	64	308	388	137	11	3	1	0	0	\N	\N	\N	\N	\N	0	\N
10870	1000	0	0	0	0	50	61	59	138	188	220	199	67	17	1	0	0	\N	\N	\N	\N	\N	0	\N
10871	1000	0	0	0	0	3	13	8	18	5	5	51	329	567	1	0	0	\N	\N	\N	\N	\N	0	\N
10872	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10863	1000	0	0	0	0	105	69	50	116	232	268	92	43	25	0	0	0	\N	\N	\N	\N	\N	0	\N
10864	1000	0	0	0	0	40	46	55	146	300	324	73	11	5	0	0	0	\N	\N	\N	\N	\N	0	\N
10865	1000	0	0	0	0	58	65	69	184	336	193	70	19	6	0	0	0	\N	\N	\N	\N	\N	0	\N
10866	238	0	0	0	0	54	40	27	44	23	7	4	9	29	1	0	0	\N	\N	\N	\N	\N	0	\N
10867	402	0	0	0	0	85	36	32	60	36	9	13	32	96	3	0	0	\N	\N	\N	\N	\N	0	\N
10858	1102	0	0	0	0	135	72	76	181	243	176	124	61	33	1	0	0	\N	\N	\N	\N	\N	0	\N
10859	1000	0	0	0	0	29	20	35	126	321	255	152	36	25	1	0	0	\N	\N	\N	\N	\N	0	\N
10860	1000	0	0	0	0	18	25	41	131	163	130	326	129	36	1	0	0	\N	\N	\N	\N	\N	0	\N
10861	1000	0	0	0	0	14	18	40	104	87	58	140	246	292	1	0	0	\N	\N	\N	\N	\N	0	\N
10862	26	0	0	0	0	5	1	6	8	5	1	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10851	256	0	0	0	0	53	21	34	76	60	10	2	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10852	1120	0	0	0	13	64	43	54	125	276	310	169	41	24	1	0	0	\N	\N	\N	\N	\N	0	\N
10853	1000	0	0	0	0	19	19	35	79	172	290	248	91	46	1	0	0	\N	\N	\N	\N	\N	0	\N
10854	1000	0	0	0	0	21	39	44	98	247	379	158	11	3	0	0	0	\N	\N	\N	\N	\N	0	\N
10855	1000	0	0	0	0	16	17	35	65	42	15	64	276	468	2	0	0	\N	\N	\N	\N	\N	0	\N
10856	971	0	0	0	0	13	15	38	111	112	35	96	243	307	1	0	0	\N	\N	\N	\N	\N	0	\N
10857	22	0	0	0	0	5.9199999999999999	0.78000000000000003	3.3300000000000001	4.0099999999999998	2.6899999999999999	0.56999999999999995	0.51000000000000001	1.1100000000000001	3.02	0.059999999999999998	0	0	\N	\N	\N	\N	\N	0	\N
10846	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10847	700	0	0	0	0	0	0	0	2	29	255	345	52	16	1	0	0	\N	\N	\N	\N	\N	0	\N
10848	245	0	0	0	0	0	0	1	2	18	45	71	38	69	1	0	0	\N	\N	\N	\N	\N	0	\N
10849	999	0	0	0	0	94	44	52	102	114	63	117	186	226	1	0	0	\N	\N	\N	\N	\N	0	\N
10850	177	0	0	0	0	0	0	0	0	1	1	1	3	165	6	0	0	\N	\N	\N	\N	\N	0	\N
10841	8	0	0	0	0	0	0	0	0	2	1.8	2.7000000000000002	1.1000000000000001	0.40000000000000002	0	0	0	\N	\N	\N	\N	\N	0	\N
10842	235	0	0	0	0	0	0	0	2	13	90	102	20	8	0	0	0	\N	\N	\N	\N	\N	0	\N
10843	999	0	0	0	0	0	15	22	34	86	340	391	80	31	0	0	0	\N	\N	\N	\N	\N	0	\N
10844	999	0	0	0	0	0	2	6	9	10	14	96	298	563	1	0	0	\N	\N	\N	\N	\N	0	\N
10845	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10835	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10836	23	0	0	0	0	0	0	0	1	9	10	2	1	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10837	307	0	0	0	0	0	0	1	3	18	130	129	18	8	0	0	0	\N	\N	\N	\N	\N	0	\N
10838	999	0	0	0	0	48	40	35	116	245	350	123	26	16	0	0	0	\N	\N	\N	\N	\N	0	\N
10839	216	0	0	0	0	2	1	1	2	4	34	81	90	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10840	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10830	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10831	2299	0	0	0	0	36	84	77	81	203	582	1014	189	27	6	0	0	\N	\N	\N	\N	\N	0	\N
10832	2299	0	0	0	45	357	181	153	369	493	453	160	51	37	0	0	0	\N	\N	\N	\N	\N	0	\N
10833	2299	0	0	0	0	341	191	192	313	230	98	148	365	420	1	0	0	\N	\N	\N	\N	\N	0	\N
10834	128	0	0	0	0	0	2	1	3	2	1	5	27	86	1	0	0	\N	\N	\N	\N	\N	0	\N
10824	2299	0	0	0	30	204	150	158	490	955	311	1	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10825	2255	0	0	0	28	95	56	101	284	626	788	181	55	40	1	0	0	\N	\N	\N	\N	\N	0	\N
10826	2299	0	0	0	0	48	44	47	198	562	990	327	65	18	0	0	0	\N	\N	\N	\N	\N	0	\N
10827	2299	0	0	0	0	136	82	134	375	676	728	116	27	25	0	0	0	\N	\N	\N	\N	\N	0	\N
10828	1700	0	0	0	0	10	38	33	50	41	44	265	806	412	1	0	0	\N	\N	\N	\N	\N	0	\N
10829	437	0	0	0	28	173	60	54	77	29	4	1	3	8	0	0	0	\N	\N	\N	\N	\N	0	\N
10817	99	0	0	0	0	21	6	5	15	29	19	2	1	1	0	0	0	\N	\N	\N	\N	\N	0	\N
10818	2299	0	0	0	73	195	87	65	148	384	744	399	127	76	1	0	0	\N	\N	\N	\N	\N	0	\N
10819	2299	0	0	0	52	402	143	116	277	541	558	143	36	30	1	0	0	\N	\N	\N	\N	\N	0	\N
10820	2299	0	0	0	88	391	148	135	312	462	424	222	67	49	1	0	0	\N	\N	\N	\N	\N	0	\N
10821	318	0	0	0	27	61	11	11	18	28	37	38	46	41	0	0	0	\N	\N	\N	\N	\N	0	\N
10822	186	0	0	0	0	0	0	0	3	6	4	9	43	120	1	0	0	\N	\N	\N	\N	\N	0	\N
10823	122	0	0	0	0	0	0	0	0	0	1	1	2	112	6	0	0	\N	\N	\N	\N	\N	0	\N
10810	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10811	2299	0	0	0	177	735	177	153	262	276	225	125	89	79	1	0	0	\N	\N	\N	\N	\N	0	\N
10812	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10813	2299	0	0	0	43	304	158	171	356	544	461	162	43	55	2	0	0	\N	\N	\N	\N	\N	0	\N
10814	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10815	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10816	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10798	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10799	999	0	0	0	0	16	3	8	45	269	594	63	1	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10800	193	0	0	0	0	3	2	7	32	69	46	21	8	5	0	0	0	\N	\N	\N	\N	\N	0	\N
10801	999	0	0	0	0	30	21	39	133	311	267	119	52	26	1	0	0	\N	\N	\N	\N	\N	0	\N
10802	103	0	0	0	0	0	0	0	0	6	19	42	21	14	1	0	0	\N	\N	\N	\N	\N	0	\N
10803	999	0	0	0	0	54	47	37	88	176	410	161	21	5	0	0	0	\N	\N	\N	\N	\N	0	\N
10804	202	0	0	0	0	2	1	2	3	40	89	51	10	4	0	0	0	\N	\N	\N	\N	\N	0	\N
10805	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10806	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10807	999	0	0	0	0	23	21	26	120	234	144	166	168	93	4	0	0	\N	\N	\N	\N	\N	0	\N
10808	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10809	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10786	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10787	384	0	0	0	0	8	10	23	91	164	72	11	3	2	0	0	0	\N	\N	\N	\N	\N	0	\N
10788	3.2999999999999998	0	0	0	0	0	0	0	0	1	1	0.5	0.5	0.29999999999999999	0	0	0	\N	\N	\N	\N	\N	0	\N
10789	999	0	0	0	0	16	17	13	43	94	483	290	35	8	0	0	0	\N	\N	\N	\N	\N	0	\N
10790	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10791	999	0	0	0	0	21	18	17	51	187	433	211	44	17	0	0	0	\N	\N	\N	\N	\N	0	\N
10792	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10793	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10794	999	0	0	0	0	29	3	36	165	336	168	140	88	32	2	0	0	\N	\N	\N	\N	\N	0	\N
10795	1021	0	0	0	0	53	61	63	134	132	17	84	138	334	5	0	0	\N	\N	\N	\N	\N	0	\N
10796	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10797	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10778	137.40000000000001	0	0	0	0	16	2	7	13	52	44	3	0.20000000000000001	0.20000000000000001	0	0	0	\N	\N	\N	\N	\N	0	\N
10779	804.29999999999995	0	0	0	0	9	10	25	83	219	296	97	32	33	0.29999999999999999	0	0	\N	\N	\N	\N	\N	0	\N
10780	999.20000000000005	0	0	0	0	28	33	45	95	203	327	186	52	30	0.20000000000000001	0	0	\N	\N	\N	\N	\N	0	\N
10781	999	0	0	0	0	71	31	37	114	314	340	82	8	2	0	0	0	\N	\N	\N	\N	\N	0	\N
10782	999.20000000000005	0	0	0	0	8	7	10	39	130	389	320	72	24	0.20000000000000001	0	0	\N	\N	\N	\N	\N	0	\N
10783	999	0	0	0	0	14	13	22	44	38	37	160	303	367	1	0	0	\N	\N	\N	\N	\N	0	\N
10784	999.5	0	0	0	0	35	45	54	88	54	26	114	302	281	0.5	0	0	\N	\N	\N	\N	\N	0	\N
10785	10.300000000000001	0	0	0	0	0	0.90000000000000002	0	2.6000000000000001	2.8999999999999999	0.59999999999999998	0.29999999999999999	0.80000000000000004	2.2000000000000002	0	0	0	\N	\N	\N	\N	\N	0	\N
10769	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10770	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10771	2299.1999999999998	0	0	0	75	185	75	110	297	808	575	137	27	10	0.20000000000000001	0	0	\N	\N	\N	\N	\N	0	\N
10772	2299.1999999999998	0	0	0	49	139	33	61	246	754	710	247	43	17	0.20000000000000001	0	0	\N	\N	\N	\N	\N	0	\N
10773	69.900000000000006	0	0	0	0	12	0.90000000000000002	3	4	12	16	11	5	6	0	0	0	\N	\N	\N	\N	\N	0	\N
10774	2299.9000000000001	0	0	0	24	341	167	164	337	359	224	271	236	176	0.80000000000000004	0.10000000000000001	0	\N	\N	\N	\N	\N	0	\N
10775	2343.9000000000001	0	0	0	59	382	182	241	344	276	106	134	274	345	0.80000000000000004	0.10000000000000001	0	\N	\N	\N	\N	\N	0	\N
10776	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10777	499.5	0	0	0	0	0	1.3	0	0	0	0.29999999999999999	10	106	381	0.90000000000000002	0	0	\N	\N	\N	\N	\N	0	\N
34844	2355.1999999999998	0	0	0	26.399999999999999	115.8	758.79999999999995	917.60000000000002	456.80000000000001	77.400000000000006	0.59999999999999998	0.10000000000000001	1.3999999999999999	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34845	308.80000000000001	0	0	0	0	9.1999999999999993	16.699999999999999	35.600000000000001	140.80000000000001	91.200000000000003	6.7000000000000002	5	3.5	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34846	6763.3999999999996	0	0	0	143.80000000000001	230.59999999999999	386.60000000000002	694.39999999999998	1827.8	1936.2	866.60000000000002	419.60000000000002	256.39999999999998	1	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
34847	14173	0	0	0	105.40000000000001	289.39999999999998	662.20000000000005	1172	2477.5999999999999	2396.1999999999998	1733.4000000000001	2114.1999999999998	3200.5999999999999	21.199999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0	\N
34848	9595.3999999999996	0	0	0	34.799999999999997	220.59999999999999	529.39999999999998	1200.2	2593.4000000000001	1718.5999999999999	717.39999999999998	678.20000000000005	1881.2	21	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
34839	37847.599999999999	0	0	0	203.59999999999999	1251	3064.4000000000001	6131.3999999999996	10856.6	10499	4348	1051	439.39999999999998	2.7999999999999998	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
34840	7167.1000000000004	0	0	0	14.4	234.19999999999999	584.60000000000002	936.39999999999998	2070.5999999999999	2032.5999999999999	774.60000000000002	321.39999999999998	196.19999999999999	1.8	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
34841	5948.3000000000002	0	0	0	0	95.799999999999997	323.60000000000002	884.60000000000002	1693.5999999999999	1608.5999999999999	715	314.19999999999999	309.60000000000002	3	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
34842	5342.3999999999996	0	0	0	48.399999999999999	121	304.80000000000001	798.20000000000005	1426	1105.4000000000001	494.19999999999999	311.19999999999999	720.60000000000002	11.4	1.2	\N	\N	\N	\N	\N	\N	\N	0	\N
34843	1936	0	0	0	0	0	7.7999999999999998	16.199999999999999	35.399999999999999	98.400000000000006	351.19999999999999	558.79999999999995	862.79999999999995	5.2000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34741	3150.6999999999998	0	0	0	13.4	68.700000000000003	237.69999999999999	536.60000000000002	1035.5999999999999	662.89999999999998	308	186.30000000000001	99.900000000000006	1.3999999999999999	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34742	7879	0	0	0	0	53.200000000000003	193.80000000000001	433.19999999999999	1182	1923.4000000000001	2575.8000000000002	1261.5999999999999	255.19999999999999	0.59999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34743	1657.2	0	0	0	0	0	16	47.600000000000001	112	261.39999999999998	404.19999999999999	357.60000000000002	450.60000000000002	7.5999999999999996	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34744	12488.5	0	0	0	8	97.400000000000006	420.39999999999998	1080.2	2290.5	2469	2090.8000000000002	1768.2	2242.8000000000002	20.199999999999999	1	\N	\N	\N	\N	\N	\N	\N	0	\N
34745	10158.799999999999	0	0	0	0	40.799999999999997	246.59999999999999	803.39999999999998	2346	2288	1697.2	1355	1361.2	20.399999999999999	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29919	3822.5	0	0	0	8.9000000000000004	34.399999999999999	100.2	198.69999999999999	806.60000000000002	1031.5999999999999	924.79999999999995	397.39999999999998	317.5	2.1000000000000001	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
29920	8717.3999999999996	0	0	0	0	18.800000000000001	117.40000000000001	307.39999999999998	693.60000000000002	1064.4000000000001	1915	2582.8000000000002	2009.8	7.5999999999999996	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
29921	3871.8000000000002	0	0	0	0	7.4000000000000004	95.599999999999994	161.09999999999999	291.69999999999999	357.5	430.69999999999999	851.20000000000005	1671.5	4.7999999999999998	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
29922	2379.5999999999999	0	0	0	0	5.4000000000000004	21	61	146.19999999999999	232.40000000000001	245.59999999999999	350.19999999999999	1315.2	2.6000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29923	2400.6999999999998	0	0	0	0	0	1.8999999999999999	7.4000000000000004	39	100.59999999999999	177.69999999999999	350	1716.9000000000001	7.0999999999999996	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29914	7232.3000000000002	0	0	0	26.800000000000001	151.90000000000001	328.30000000000001	1149.2	2499.8000000000002	2137.6999999999998	864.60000000000002	20.100000000000001	53.399999999999999	0.5	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29915	12028.1	0	0	0	12.6	111.8	423.69999999999999	792.89999999999998	2269.5999999999999	3966.1999999999998	2745.5999999999999	1129.8	573.89999999999998	1.7	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
29916	12802.200000000001	0	0	0	33	361.60000000000002	1897.4000000000001	4115.8000000000002	3159	1231.5999999999999	561.39999999999998	479.80000000000001	950.39999999999998	11	1.2	\N	\N	\N	\N	\N	\N	\N	0	\N
29917	21132.400000000001	0	0	0	6.5999999999999996	155.80000000000001	931.79999999999995	3266.5999999999999	6263	4670.8000000000002	2272.8000000000002	1587	1937.5999999999999	38	2.3999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
29918	6291.3999999999996	0	0	0	1.3999999999999999	0.20000000000000001	19.199999999999999	77.599999999999994	401.80000000000001	848.60000000000002	1089.2	1543.2	2296.4000000000001	12.199999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27576	9911.7999999999993	0	0	0	0	42.399999999999999	201.80000000000001	680.79999999999995	2449.4000000000001	3553.4000000000001	1797.8	601	583	1.8	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27577	15990.9	0	0	0	0	53.600000000000001	387	1130	2852.8000000000002	3633.5999999999999	3996.1999999999998	2267.1999999999998	1659.8	9.8000000000000007	0.90000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27578	1441.5999999999999	0	0	0	0	4.4000000000000004	11	27.199999999999999	95.200000000000003	204	273.19999999999999	265.39999999999998	556	4.7999999999999998	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27579	7556.6999999999998	0	0	0	0	6.4000000000000004	70	371	1250.8	1645.5999999999999	1357.2	1024.5999999999999	1806.4000000000001	24.199999999999999	0.5	\N	\N	\N	\N	\N	\N	\N	0	\N
27580	2355	0	0	0	0	0	1.8	19	89.200000000000003	232.19999999999999	463.80000000000001	597	946.39999999999998	5.4000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27575	3207.5	0	0	0	30.199999999999999	144	506	1167.5	1018.6	313.10000000000002	23.199999999999999	2.7999999999999998	1.6000000000000001	0.40000000000000002	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27574	3056.4000000000001	0	0	0	50.399999999999999	169.19999999999999	208.40000000000001	347.80000000000001	697	719.39999999999998	435.39999999999998	206	220.59999999999999	2	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27573	7834.1999999999998	0	0	0	65.200000000000003	144.40000000000001	350.80000000000001	709	1562.0999999999999	1647.4000000000001	1569.5	868	911.60000000000002	6	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27572	1223.4000000000001	0	0	0	0	5.2999999999999998	30.600000000000001	96.700000000000003	342.30000000000001	247.5	158.5	125.7	215.09999999999999	1.5	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27571	13.1	0	0	0	0	0	0	0.40000000000000002	0.40000000000000002	1.5	1.8	1.7	4.2999999999999998	2.8999999999999999	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27910	121	0	0	0	0	8	15.800000000000001	21	38	28.100000000000001	8	1.3	0.59999999999999998	0.20000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27909	42478.400000000001	0	0	0	199.19999999999999	551.60000000000002	1111.4000000000001	1959.4000000000001	7107	16673	12163	2107.4000000000001	600.79999999999995	5.5999999999999996	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27908	17533.200000000001	0	0	0	90.200000000000003	639.20000000000005	1397.2	2368.1999999999998	3074.4000000000001	2636.8000000000002	2724.4000000000001	2278.4000000000001	2287.8000000000002	34.399999999999999	2.2000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27907	38054.199999999997	0	0	0	72.799999999999997	528	1989.8	4995.6000000000004	8348	6173.8000000000002	5223.3999999999996	5439.3999999999996	5217	66.200000000000003	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27906	1768.5999999999999	0	0	0	0	0	1.3999999999999999	2.7999999999999998	21	51.399999999999999	119.40000000000001	130.19999999999999	1372.4000000000001	68	2	\N	\N	\N	\N	\N	\N	\N	0	\N
27560	8366.7999999999993	0	0	0	8.5999999999999996	44.399999999999999	260	670.20000000000005	2833.8000000000002	3224.5999999999999	910.60000000000002	253.19999999999999	160.80000000000001	0.59999999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10380	17	0	0	0	0	0	0	0	0	0	0.80000000000000004	4	3.7000000000000002	3.5	4.9000000000000004	0.10000000000000001	0	0	0	\N	\N	\N	0	\N
10381	11	0	0	0	0	0	0	0	0	0	0.90000000000000002	3.2000000000000002	1.6000000000000001	1.6000000000000001	3.7000000000000002	0	0	0	0	\N	\N	\N	0	\N
10382	33	0	0	0	0	0	0	0	0	0	2.3999999999999999	5.2000000000000002	3.2999999999999998	5.4000000000000004	16.199999999999999	0.5	0	0	0	\N	\N	\N	0	\N
10383	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10371	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10372	32.600000000000001	0	0	0	0	0	1.8999999999999999	1.2	0.29999999999999999	3.2999999999999998	9.3000000000000007	9	4.5	3.1000000000000001	0	0	0	0	0	\N	\N	\N	0	\N
10373	4.7000000000000002	0	0	0	0	0	0	0	0	0	0	0.5	1.1000000000000001	1.3999999999999999	1.7	0	0	0	0	\N	\N	\N	0	\N
10374	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10375	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10376	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10377	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10361	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10362	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10363	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10364	31.399999999999999	0	0	0	0	0	2.7999999999999998	0	2.1000000000000001	6.5	10.6	6.4000000000000004	1.7	0.5	0.69999999999999996	0.10000000000000001	0	0	0	\N	\N	\N	0	\N
10365	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10366	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10367	3	0	0	0	0	0	0	0	0	0	0	0.29999999999999999	0.59999999999999998	0.80000000000000004	1.3	0	0	0	0	\N	\N	\N	0	\N
10368	2.2000000000000002	0	0	0	0	0	0	0	0	0	0	0.40000000000000002	0.40000000000000002	0.5	0.90000000000000002	0	0	0	0	\N	\N	\N	0	\N
10369	6.7000000000000002	0	0	0	0	0	0	0	0	0	0.20000000000000001	1.8	1.8999999999999999	1.3	1.5	0	0	0	0	\N	\N	\N	0	\N
10370	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
34800	43.799999999999997	0	0	0	0	0	2	5	11.300000000000001	20.199999999999999	2.7000000000000002	1.5	1.1000000000000001	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34801	236.40000000000001	0	0	0	50.100000000000001	4.5	9.1999999999999993	7.9000000000000004	25.699999999999999	74.200000000000003	30.600000000000001	15.1	18.800000000000001	0.29999999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34795	17.600000000000001	0	0	0	0	0	0.40000000000000002	4.7000000000000002	5.5999999999999996	5.2000000000000002	1.2	0.20000000000000001	0.29999999999999999	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34796	77.200000000000003	0	0	0	0	2.6000000000000001	2.7999999999999998	14.1	23.5	26	3.1000000000000001	2.8999999999999999	2.1000000000000001	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34716	5559	0	0	0	5.2000000000000002	53	216.59999999999999	541.60000000000002	1660.2	1890.2	764.79999999999995	225.19999999999999	200.19999999999999	2	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34717	11.4	0	0	0	0	0	0	0	1.3999999999999999	3.1000000000000001	2.3999999999999999	1.1000000000000001	3.2000000000000002	0.20000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34718	23.149999999999999	0	0	0	0	0	0	2.2000000000000002	8.5	7.5	1.5	1.2	2	0.25	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34719	6.5	0	0	0	0	0	0	0.29999999999999999	1	1.8	1.2	1.1000000000000001	1.1000000000000001	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29840	1514.5	0	0	0	7.5999999999999996	12.5	31.199999999999999	56.100000000000001	219.5	440.10000000000002	398.30000000000001	230.90000000000001	117.2	1.1000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29841	20.300000000000001	0	0	0	0	0	0	0	0.20000000000000001	1.1000000000000001	4.5999999999999996	6.5999999999999996	7.7000000000000002	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29843	15.699999999999999	0	0	0	0	0	0	0	0	0.20000000000000001	1.5	4.7999999999999998	9	0.20000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29834	6082.6999999999998	0	0	0	35.700000000000003	134.40000000000001	249.59999999999999	363.30000000000001	1226.2	2608.0999999999999	1020.4	278.19999999999999	164.19999999999999	2	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
29835	91	0	0	0	0	2.7000000000000002	9.0999999999999996	11.9	26.800000000000001	24.899999999999999	6.7000000000000002	4.5	4.2999999999999998	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29836	435.80000000000001	0	0	0	0	4.4000000000000004	13.800000000000001	20.100000000000001	53.700000000000003	122.5	117	59.799999999999997	44.399999999999999	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29837	44.5	0	0	0	0	2.2999999999999998	1.8	3.2000000000000002	10.800000000000001	16.899999999999999	4	2.7000000000000002	2.7000000000000002	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29838	5.2000000000000002	0	0	0	0	0	0	0.10000000000000001	0.10000000000000001	0.5	1.3999999999999999	1.6000000000000001	1.5	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29829	854.89999999999998	0	0	0	48.100000000000001	82.299999999999997	109.3	152.59999999999999	281.10000000000002	160.90000000000001	11.6	3.8999999999999999	3.3999999999999999	1.5	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29830	760.5	0	0	0	336.80000000000001	148	45.299999999999997	34.5	71	101	11.300000000000001	6.7999999999999998	5.5	0.29999999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29831	335.10000000000002	0	0	0	42.200000000000003	8.4000000000000004	7.7000000000000002	8.6999999999999993	53.600000000000001	176.09999999999999	26.5	7.2000000000000002	4.5	0.20000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27417	5882.8000000000002	0	0	0	0	18.199999999999999	22.800000000000001	88	548.20000000000005	2266.4000000000001	1763	682.60000000000002	489	4.4000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27418	8	0	0	0	0	0	0	0	0.40000000000000002	2	2	1.6000000000000001	2	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27419	91.700000000000003	0	0	0	0	0	0	0.40000000000000002	3.7000000000000002	24.300000000000001	29.600000000000001	19.100000000000001	14.5	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27420	3.7000000000000002	0	0	0	0	0	0	0	0	0.29999999999999999	0.59999999999999998	0.80000000000000004	1.8999999999999999	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27421	36	0	0	0	0	0	0	0	0	0.29999999999999999	6	10	19.300000000000001	0.29999999999999999	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27416	63.100000000000001	0	0	0	0	10.5	11.6	12.699999999999999	18.199999999999999	8.4000000000000004	0.29999999999999999	0.59999999999999998	0.59999999999999998	0.10000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27414	89.799999999999997	0	0	0	0	0	0	2.7999999999999998	22	55	4	2.5	3.2999999999999998	0.10000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27412	766.60000000000002	0	0	0	72.700000000000003	91.5	28.300000000000001	22.100000000000001	60.600000000000001	127	185.5	123.90000000000001	54.399999999999999	0.5	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27411	281.19999999999999	0	0	70.099999999999994	43.399999999999999	83.099999999999994	41.299999999999997	19.399999999999999	15.300000000000001	5.2999999999999998	1.2	0.80000000000000004	1	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27410	48045.5	0	0	0	139	3566.4000000000001	4687.1999999999998	5830.1999999999998	7226	5857	11392.6	6380.1999999999998	2956.5999999999999	9	1.3	\N	\N	\N	\N	\N	\N	\N	0	\N
27409	4508	0	0	0	237.59999999999999	429.19999999999999	542	638.60000000000002	1235.8	958.79999999999995	250.59999999999999	112	102	1.2	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27407	4.7000000000000002	0	0	0	0	0	0	0	0.90000000000000002	1.2	0.90000000000000002	0.90000000000000002	0.69999999999999996	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27406	2.6000000000000001	0	0	0	0	0	0	0	0	0.10000000000000001	0.40000000000000002	0.59999999999999998	1.3	0.10000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27405	1864.2	0	0	0	21.199999999999999	64.599999999999994	48.799999999999997	82.599999999999994	151.80000000000001	386.60000000000002	641	276.80000000000001	189.40000000000001	1.2	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27404	7714.8000000000002	0	0	0	0	16.600000000000001	101	333.19999999999999	1092.5999999999999	2074	2679.1999999999998	850.20000000000005	563	5	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27403	12985.4	0	0	0	15.199999999999999	13	65.799999999999997	190	804.79999999999995	3598.1999999999998	5111	2006.8	1169.8	10.4	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27402	106.8	0	0	0	19.600000000000001	6.7999999999999998	2.7999999999999998	2.5	3.6000000000000001	9.3000000000000007	20.199999999999999	20.399999999999999	21.300000000000001	0.29999999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24531	5159	0	0	0	0	88.799999999999997	320.80000000000001	436	733.79999999999995	775.79999999999995	1103.8	870.39999999999998	825.60000000000002	4	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24532	6771.6000000000004	0	0	0	5.5999999999999996	8	150.80000000000001	362	1226.4000000000001	1729.5999999999999	1656.8	921.39999999999998	704.39999999999998	6.5999999999999996	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24533	1603.4000000000001	0	0	0	0	20.399999999999999	25.199999999999999	38.600000000000001	125.2	335	406.80000000000001	260	385.60000000000002	6.5999999999999996	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24534	92.200000000000003	0	0	0	13	11	6.4000000000000004	3.6000000000000001	2.6000000000000001	6.4000000000000004	15.800000000000001	14	18.600000000000001	0.80000000000000004	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24525	273.89999999999998	0	0	0	23.600000000000001	72.900000000000006	41.299999999999997	77.099999999999994	28.600000000000001	14.1	7.0999999999999996	9	0.20000000000000001	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24524	2348.0500000000002	0	0	0	16.670000000000002	209.50999999999999	247.03	337.30000000000001	545	345.30000000000001	292.19999999999999	201.5	153	0.54000000000000004	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24523	5178.5699999999997	0	0	0	0	305.67000000000002	282.88	411.10000000000002	901.22000000000003	992.65999999999997	808.74000000000001	789.04999999999995	683.62	3.3700000000000001	0.26000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24522	13.91	0	0	0	0	2.7000000000000002	2.3999999999999999	0.80000000000000004	0.59999999999999998	1.8999999999999999	2.5	1.6699999999999999	1.28	0.059999999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
23970	317.19999999999999	0	0	0	0	3.7999999999999998	15.85	37.950000000000003	69.599999999999994	65.599999999999994	39	41.700000000000003	43.5	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23969	849.95000000000005	0	0	0	0	306.30000000000001	90.700000000000003	71.200000000000003	93.5	101	52	59	75.25	0.94999999999999996	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23968	581.70000000000005	0	0	0	0	74	49	49.700000000000003	60.600000000000001	96.599999999999994	73.5	59.399999999999999	117.5	1.3500000000000001	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23967	31.75	0	0	0	0	0	2.8999999999999999	1.3999999999999999	1.6499999999999999	2.5	4.9000000000000004	6.4000000000000004	11.6	0.34999999999999998	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23966	15.800000000000001	0	0	0	0	0	0	0	0.10000000000000001	0.20000000000000001	0.14999999999999999	1.05	13.4	0.88	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23600	378.05000000000001	0	0	0	0	0	3.8999999999999999	11.6	23	93.099999999999994	134	64.150000000000006	48	0.28000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23599	303.69999999999999	0	0	0	0	1.8	1.1000000000000001	2.5	9.0999999999999996	66.900000000000006	103.09999999999999	69.200000000000003	49.299999999999997	0.55000000000000004	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23598	243.84999999999999	0	0	0	0	0	3.6000000000000001	5.25	11.300000000000001	21.75	37.75	71	92.200000000000003	0.90000000000000002	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23597	3.25	0	0	0	0	0	0	0	0.40000000000000002	0.20000000000000001	0.20000000000000001	0.65000000000000002	1.7	0.070000000000000007	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23595	506.44999999999999	0	0	0	0	29.399999999999999	32.600000000000001	64.700000000000003	109.8	160.09999999999999	58.25	25.5	25.800000000000001	0.28000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23594	427.75	0	0	0	0	9.0999999999999996	11.5	26.199999999999999	67.5	145.40000000000001	97.200000000000003	41.549999999999997	28.899999999999999	0.29999999999999999	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23593	498.19999999999999	0	0	0	0	34.25	11.5	22.800000000000001	56.049999999999997	116	111.59999999999999	90.700000000000003	54.5	0.69999999999999996	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23592	18.449999999999999	0	0	0	0	8.6999999999999993	2.7000000000000002	2.2999999999999998	1.95	1.3999999999999999	0.20000000000000001	0.34999999999999998	0.80000000000000004	0.029999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23590	41	0	0	0	19.199999999999999	16.100000000000001	2.6499999999999999	1	0.69999999999999996	0.75	0.20000000000000001	0.10000000000000001	0.28999999999999998	0.01	0	\N	\N	\N	\N	\N	\N	\N	0	\N
23589	878.29999999999995	0	0	0	25.550000000000001	35.100000000000001	67.25	171.05000000000001	266.19999999999999	159	64.5	41.399999999999999	47.75	0.40000000000000002	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23588	1166.45	0	0	0	24	64.700000000000003	75.200000000000003	148.5	271.69999999999999	253.59999999999999	154.94999999999999	87.75	85.099999999999994	0.90000000000000002	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23584	1444.75	0	0	0	433.10000000000002	442	292.5	175.90000000000001	88.049999999999997	12.5	0.5	0.10000000000000001	0.089999999999999997	0.01	0	\N	\N	\N	\N	\N	\N	\N	0	\N
23583	1251.8499999999999	0	0	0	79	107	91.599999999999994	163.69999999999999	373.30000000000001	301.44999999999999	94	27	14.6	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23582	585.64999999999998	0	0	43.700000000000003	188.30000000000001	49.5	33.399999999999999	30.5	95.049999999999997	138.65000000000001	2.4500000000000002	1.6000000000000001	2.3999999999999999	0.089999999999999997	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23565	296.69999999999999	0	0	0	0	1.8999999999999999	2.3999999999999999	10.800000000000001	32.600000000000001	76.950000000000003	94	44.799999999999997	32.700000000000003	0.52000000000000002	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23564	253.25	0	0	0	0	5.9000000000000004	1.6499999999999999	4.9000000000000004	10.300000000000001	30.850000000000001	66.150000000000006	66.400000000000006	66.200000000000003	0.84999999999999998	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23563	14.1	0	0	0	0	4	0	0.20000000000000001	0.20000000000000001	0.40000000000000002	0.90000000000000002	1.6000000000000001	6.5	0.28999999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23562	12.65	0	0	0	0	0	0	0	0	0.69999999999999996	2.2999999999999998	3.1000000000000001	6.4000000000000004	0.13	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23555	577.85000000000002	0	0	0	0	2.75	7	14.199999999999999	73.75	207.80000000000001	186.59999999999999	69.549999999999997	16.100000000000001	0.089999999999999997	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23554	548.89999999999998	0	0	0	0	1	8.3000000000000007	21.600000000000001	64.099999999999994	137.09999999999999	159.59999999999999	98.5	58.450000000000003	0.22	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23553	550.25	0	0	0	0	4.5999999999999996	12.1	22.600000000000001	64.700000000000003	113.90000000000001	156.15000000000001	107.59999999999999	68.400000000000006	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23545	486.32999999999998	0	0	0	6.0999999999999996	19.600000000000001	42.600000000000001	73.650000000000006	182.59999999999999	142.30000000000001	17.050000000000001	2	0.40000000000000002	0.01	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23544	689.89999999999998	0	0	0	45.100000000000001	57.399999999999999	57.399999999999999	81.700000000000003	135.75	234.40000000000001	60.600000000000001	12.699999999999999	4.7999999999999998	0.02	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23543	1005	0	0	0	154.25	94.799999999999997	59.700000000000003	64.900000000000006	112.5	249.30000000000001	150.90000000000001	73.900000000000006	44.399999999999999	0.29999999999999999	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23525	422.94999999999999	0	0	0	0	31.350000000000001	35	44.25	82	137.09999999999999	73.700000000000003	15.199999999999999	4.25	0.089999999999999997	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23524	378.58999999999997	0	0	0	0	7.4000000000000004	24.800000000000001	26.899999999999999	61	112.59999999999999	97.950000000000003	35.649999999999999	12.1	0.14999999999999999	0.02	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23523	345.89999999999998	0	0	0	0	0	1.8	5.2000000000000002	13.949999999999999	70.549999999999997	149.40000000000001	77.299999999999997	27.5	0.14999999999999999	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
13036	48.060000000000002	0	0	0	0	0	0	1.95	4	12.6	8.5500000000000007	5.9000000000000004	14.5	0.5	0.029999999999999999	0.029999999999999999	\N	\N	\N	\N	\N	\N	0	\N
13037	353.94999999999999	0	0	0	0	0	3	3	4.5999999999999996	27.300000000000001	68.700000000000003	89.510000000000005	157.09999999999999	0.69999999999999996	0.02	0.02	\N	\N	\N	\N	\N	\N	0	\N
13038	361.25	0	0	0	0	7.5	10	6.5999999999999996	9.5	32.100000000000001	60	77.299999999999997	157	1.2	0.029999999999999999	0.02	\N	\N	\N	\N	\N	\N	0	\N
13039	5.4800000000000004	0	0	0	0	0	0	0	0.10000000000000001	0.10000000000000001	0.14999999999999999	0.40000000000000002	4.2000000000000002	0.5	0.02	0.01	\N	\N	\N	\N	\N	\N	0	\N
13040	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
13031	203.34999999999999	0	0	0	0	0	10.65	29.149999999999999	61.799999999999997	75.200000000000003	9.5	3.2999999999999998	12.300000000000001	1.3500000000000001	0.080000000000000002	0.02	\N	\N	\N	\N	\N	\N	0	\N
13032	104.34999999999999	0	0	0	0	0	0	1.3999999999999999	2	3.6000000000000001	5.9000000000000004	12.25	76.200000000000003	2.8999999999999999	0.050000000000000003	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
13033	470	0	0	0	0	26.399999999999999	8.6999999999999993	20.399999999999999	40.700000000000003	105.3	81.700000000000003	48.600000000000001	136.44999999999999	1.6499999999999999	0.080000000000000002	0.02	\N	\N	\N	\N	\N	\N	0	\N
13034	82.650000000000006	0	0	0	0	0	0	0	0.10000000000000001	0.55000000000000004	1.8500000000000001	5.7000000000000002	70.700000000000003	3.6000000000000001	0.10000000000000001	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
13035	4.2999999999999998	0	0	0	0	0	0	0	0	0.14999999999999999	0.10000000000000001	0.10000000000000001	2.7000000000000002	1.2	0.040000000000000001	0.01	\N	\N	\N	\N	\N	\N	0	\N
11962	3	0	0	0	0	0	0	0	0	0	0	0	2	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11963	1203	0	0	205	426	271	94	79	67	47	8	3	3	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10283	4039.1999999999998	0	301	0	216	678	278	363	730	965	457	45	4	2	0.10000000000000001	0.10000000000000001	0	\N	\N	\N	\N	\N	0	\N
10284	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10285	6597.6000000000004	0	0	79	516	1122	397	558	1145	1702	944	109	14.5	10.4	0.59999999999999998	0.10000000000000001	0	\N	\N	\N	\N	\N	0	\N
10286	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10287	2682	0	0	0	43	92	73	110	272	631	715	314	285	145	1	1	0	\N	\N	\N	\N	\N	0	\N
10273	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10274	176.80000000000001	0	0	0	0	0	33.899999999999999	15.9	19.800000000000001	38.100000000000001	35.5	22.5	4.9000000000000004	2.7999999999999998	2.7000000000000002	0.29999999999999999	0.40000000000000002	0	0	\N	\N	\N	0	\N
10275	296.60000000000002	0	0	0	0	0	8.4000000000000004	0	5	11.699999999999999	38.100000000000001	63.200000000000003	26	47	90.299999999999997	3.1000000000000001	2.3999999999999999	1.3999999999999999	0	\N	\N	\N	0	\N
10276	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10277	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
34807	502	0	0	0	161	107.8	80.099999999999994	47.399999999999999	55.700000000000003	41.100000000000001	3.2999999999999998	1.2	3.8999999999999999	0.29999999999999999	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34806	12592.200000000001	0	0	161.80000000000001	2882.8000000000002	2111	1516.2	1355.5999999999999	1461.2	913.20000000000005	665.39999999999998	662.60000000000002	847.39999999999998	14.199999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0	\N
34805	22008.599999999999	0	0	1436.4000000000001	2292	2482	2789.1999999999998	3159.1999999999998	2676	3227.5999999999999	1952.2	1965.2	27.600000000000001	1.2	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34804	629.20000000000005	0	0	0	139.59999999999999	157.5	79	56.399999999999999	52.200000000000003	56.899999999999999	24.899999999999999	17.5	44	1.1000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34724	2096.1999999999998	0	0	51	182.40000000000001	436.80000000000001	490.80000000000001	429.80000000000001	385.60000000000002	111.40000000000001	4.5	1.3999999999999999	1.3999999999999999	0.20000000000000001	0.90000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
34723	12199.6	0	0	0	108	198.80000000000001	239.19999999999999	599.79999999999995	3184	5985.1999999999998	1570.8	159.40000000000001	150.40000000000001	3.6000000000000001	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
34722	8172.6000000000004	0	0	0	6.2000000000000002	171.80000000000001	312.39999999999998	593.20000000000005	1928	4249.1999999999998	753.79999999999995	101.2	53.600000000000001	2.6000000000000001	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
34721	414.30000000000001	0	0	0	42	35.100000000000001	53.799999999999997	55	42.399999999999999	38.700000000000003	45.799999999999997	39.5	60.899999999999999	1	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34727	11491.66	0	0	0	109.8	269.60000000000002	533	555	1284.5999999999999	3454.4000000000001	3818.0599999999999	1152	314.19999999999999	0.90000000000000002	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34728	12402.299999999999	0	0	0	22.199999999999999	105.2	181.19999999999999	261.19999999999999	1193.2	4094.8000000000002	4258.8000000000002	1580	701.79999999999995	3.6000000000000001	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
34729	9693.3999999999996	0	0	0	0	126.40000000000001	199	182.40000000000001	380	2510	4003.5999999999999	1380	897.79999999999995	14	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34730	41.899999999999999	0	0	0	0	11.199999999999999	8.0999999999999996	3.7000000000000002	3.1000000000000001	2.6000000000000001	2	2.3999999999999999	8.4000000000000004	0.29999999999999999	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29864	1568.3	0	0	0	0	11	53.200000000000003	87.099999999999994	146.69999999999999	222.40000000000001	445.30000000000001	418	182.69999999999999	1.3	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
29863	5686	0	0	0	0	12.6	58.600000000000001	148.19999999999999	430.60000000000002	1076	1280	1220	1452	7	1	\N	\N	\N	\N	\N	\N	\N	0	\N
29862	4010.1999999999998	0	0	0	0	0	20	52	185.59999999999999	983.60000000000002	1286	777.20000000000005	697.39999999999998	8.1999999999999993	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29861	2955	0	0	0	0	6	2.6000000000000001	2.6000000000000001	9.4000000000000004	147.80000000000001	1404.5999999999999	846.79999999999995	531.20000000000005	4	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29854	2.2000000000000002	0	0	0	0	0	0	0.29999999999999999	0.29999999999999999	0.90000000000000002	0.20000000000000001	0.20000000000000001	0.29999999999999999	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29852	361.89999999999998	0	0	0	7.9000000000000004	14.5	19.300000000000001	20.699999999999999	48.299999999999997	92.400000000000006	71.099999999999994	46.799999999999997	39.899999999999999	0.80000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29851	8127.3999999999996	0	0	0	11.6	19.199999999999999	141	280.19999999999999	834.39999999999998	2636.4000000000001	2274.5999999999999	1236.4000000000001	669.79999999999995	23	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0	\N
29850	14151	0	0	0	0	56.200000000000003	135	366.60000000000002	3775.5999999999999	6221.6000000000004	2323.5999999999999	877	378.60000000000002	16.600000000000001	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29849	4.5	0	0	0	0	0	0	0	0.29999999999999999	0.59999999999999998	0.90000000000000002	1.1000000000000001	1.5	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27476	3959.5999999999999	0	0	0	125	192.59999999999999	191.19999999999999	232	421.80000000000001	877.20000000000005	1340.2	438.19999999999999	139.59999999999999	1.6000000000000001	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27477	3602	0	0	0	0	15.4	38.799999999999997	136.59999999999999	1007.6	856.39999999999998	468.60000000000002	424.60000000000002	641.20000000000005	12.6	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27478	4122	0	0	0	0	9.5999999999999996	28.600000000000001	82	424.19999999999999	1941.5999999999999	1127.5999999999999	289.60000000000002	213.59999999999999	5	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27479	923	0	0	0	0	5.0999999999999996	3.7999999999999998	8.0999999999999996	43	356	369.69999999999999	88.299999999999997	48.200000000000003	0.69999999999999996	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27480	3.2000000000000002	0	0	0	0	0	0	0	0	0.40000000000000002	0.5	0.69999999999999996	0.80000000000000004	0.69999999999999996	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27469	359.5	0	0	0	154	95.599999999999994	50.200000000000003	21.800000000000001	26.199999999999999	10	0.80000000000000004	0.29999999999999999	0.40000000000000002	0.10000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27468	2112.3000000000002	0	0	44.399999999999999	92	130.59999999999999	205	204.59999999999999	318.19999999999999	511.30000000000001	322.80000000000001	152	130.80000000000001	0.40000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27467	6516.8999999999996	0	0	0	40.799999999999997	90	191.40000000000001	641.39999999999998	3643.5999999999999	1760	130.19999999999999	5.7999999999999998	13.4	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27464	7185.6000000000004	0	0	64.200000000000003	1114.4000000000001	1368.4000000000001	841.20000000000005	566.79999999999995	658	880.20000000000005	763.20000000000005	439	487.19999999999999	3	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27463	34669.199999999997	0	0	0	277.19999999999999	1340.4000000000001	2264.8000000000002	3065.8000000000002	4147.6000000000004	6783.8000000000002	11268.799999999999	3637.4000000000001	1877	6.4000000000000004	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27462	12751.200000000001	0	0	75.099999999999994	370.80000000000001	482.10000000000002	739.70000000000005	1135.8	2665.3000000000002	3238.0999999999999	2329.9000000000001	1136.3	574.89999999999998	2.6000000000000001	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
27461	732.39999999999998	0	0	0	0	13.6	12	12.699999999999999	15.800000000000001	44.5	335.30000000000001	286.30000000000001	11.699999999999999	0.5	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27460	25.300000000000001	0	0	0	0	0	0	0.90000000000000002	2.7000000000000002	8.9000000000000004	8.3000000000000007	2.5	0.90000000000000002	0.5	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
27459	13023.700000000001	0	0	0	684.39999999999998	1120	928.60000000000002	808.60000000000002	1743.5999999999999	3201.6999999999998	2919.1999999999998	1076.8	531.60000000000002	6.7999999999999998	2.3999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
27458	2421	0	0	0	326	207.19999999999999	237.40000000000001	248.19999999999999	350.60000000000002	431.19999999999999	335	143.40000000000001	140.40000000000001	1.6000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27457	12845	0	0	0	219.80000000000001	246.80000000000001	405.39999999999998	1130.4000000000001	3780.4000000000001	4722.3999999999996	1880.8	260	195.40000000000001	3.6000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27456	268	0	0	0	0	0	0	0.40000000000000002	4.2999999999999998	30.899999999999999	65.5	67.700000000000003	98.5	0.69999999999999996	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24552	13748	0	0	0	43.799999999999997	205.19999999999999	413.60000000000002	708	1829.8	3285.8000000000002	5242	1518.5999999999999	499.19999999999999	1.8	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24553	10579.4	0	0	0	0	48.799999999999997	172.80000000000001	344.39999999999998	970	2569	2702.5999999999999	1754.4000000000001	2003.4000000000001	13.4	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
24554	11128	0	0	0	38.399999999999999	81.799999999999997	200.80000000000001	601.79999999999995	2864.1999999999998	3738	1611.4000000000001	791.39999999999998	1183.4000000000001	16.800000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24555	49.299999999999997	0	0	0	0	5	9.5999999999999996	6.5999999999999996	7.5999999999999996	6.5	5	3.3999999999999999	5.4000000000000004	0.20000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24549	1895.0999999999999	0	0	0	297	420.30000000000001	285.69999999999999	187.40000000000001	265.19999999999999	190.69999999999999	91.400000000000006	56.600000000000001	99.799999999999997	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24548	16486.540000000001	0	0	0	0	251.47999999999999	594.5	938.29999999999995	1821	4512	5086	1700	1575	8.2599999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24547	5393.8699999999999	0	0	270.19	143.87	117.15000000000001	66.400000000000006	194.34	1243	1988	414.60000000000002	494.49000000000001	455.62	6.21	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24546	151.80000000000001	0	0	0	0	3.7000000000000002	3.5	3.2999999999999998	4.4000000000000004	14.5	30.300000000000001	30.899999999999999	60.600000000000001	0.59999999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24544	10562.129999999999	0	0	0	580.89999999999998	1095	743	767	1059	1641	1979	1838	855	3.7000000000000002	0.53000000000000003	\N	\N	\N	\N	\N	\N	\N	0	\N
24543	9518.8099999999995	0	0	0	122.84	465.05000000000001	563	741.5	1646	2449	2061	931	536.70000000000005	2.27	0.45000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24542	21241.509999999998	0	0	0	159.34999999999999	390.93000000000001	480.17000000000002	1484.0999999999999	3372	8912	5097	905.10000000000002	432.36000000000001	7.4400000000000004	1.0600000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24541	185.30000000000001	0	0	0	20.5	37.200000000000003	33.700000000000003	19.699999999999999	17.199999999999999	10	10.699999999999999	12.5	23.100000000000001	0.69999999999999996	0	\N	\N	\N	\N	\N	\N	\N	0	\N
23980	362.19999999999999	0	0	0	0	3	19.199999999999999	25.5	77.700000000000003	109.59999999999999	71.400000000000006	44.399999999999999	11.300000000000001	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
23979	325.94999999999999	0	0	0	0	17.800000000000001	11.9	14.9	21.699999999999999	40	65.900000000000006	69.299999999999997	84	0.40000000000000002	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0	\N
23978	542.10000000000002	0	0	0	0	17.899999999999999	12.199999999999999	17.100000000000001	25.899999999999999	51.5	105.2	169.5	141.90000000000001	0.69999999999999996	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
23977	417.80000000000001	0	0	0	0	0	2.3999999999999999	5.4000000000000004	24.699999999999999	110.59999999999999	109.5	114.2	50.700000000000003	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
23976	11.25	0	0	0	0	4.4000000000000004	0.5	1.3999999999999999	0.59999999999999998	1.2	0.69999999999999996	0.59999999999999998	1.8	0.050000000000000003	0	\N	\N	\N	\N	\N	\N	\N	0	\N
23975	236.55000000000001	0	0	0	0	0	4.7999999999999998	1.7	3.2999999999999998	10.1	41.5	81.25	93.5	0.38	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23974	294.75	0	0	0	0	0	2.3999999999999999	10.25	17.5	32.950000000000003	51.549999999999997	61.700000000000003	118.3	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23973	274.85000000000002	0	0	0	0	0	0.5	1.7	5.2999999999999998	32.600000000000001	76.799999999999997	72.200000000000003	84.299999999999997	1.3999999999999999	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23972	261.60000000000002	0	0	0	0	0	0	0.20000000000000001	3.8999999999999999	52.600000000000001	98.599999999999994	55.700000000000003	50.299999999999997	0.28000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23495	496.5	0	0	0	0	19.199999999999999	25.699999999999999	64.599999999999994	133.59999999999999	149.19999999999999	53.299999999999997	23.399999999999999	27.199999999999999	0.20000000000000001	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23494	209.30000000000001	0	0	0	0	0	0	4.7999999999999998	9.8000000000000007	14.800000000000001	29.600000000000001	46.299999999999997	102.8	1.05	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23493	317.14999999999998	0	0	0	0	0	0	3	17.199999999999999	63.950000000000003	100.8	85.5	45.299999999999997	1.2	0.14999999999999999	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23492	247.65000000000001	0	0	0	0	0	0	1.1000000000000001	13.300000000000001	71.700000000000003	94.200000000000003	55.100000000000001	12.1	0.11	0.02	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23489	589.75	0	0	0	0	30	13.300000000000001	28.699999999999999	56.899999999999999	163.40000000000001	163.30000000000001	89.299999999999997	44.549999999999997	0.27000000000000002	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23488	499.30000000000001	0	0	0	0	0	7.4000000000000004	17.399999999999999	52	113.59999999999999	131.69999999999999	93.150000000000006	81.099999999999994	2.7999999999999998	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23487	374.75	0	0	0	0	0	8.5	12.15	43.899999999999999	160.09999999999999	96.900000000000006	38.5	13.9	0.69999999999999996	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23469	1470.5999999999999	0	0	0	111.8	245.05000000000001	283.10000000000002	373.10000000000002	311.39999999999998	128.69999999999999	11.4	2.8999999999999999	2.7999999999999998	0.31	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23468	1592.2	0	0	113.7	908.70000000000005	284.69999999999999	94.900000000000006	57	43.799999999999997	28.300000000000001	15.300000000000001	18.600000000000001	26.5	0.65000000000000002	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23467	1326.8	0	0	0	95.299999999999997	160	164.90000000000001	216.5	217.80000000000001	149.80000000000001	89.549999999999997	94.049999999999997	136.25	2.5499999999999998	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23466	10.550000000000001	0	0	0	0	0	2.25	1.2	2.1000000000000001	2.7999999999999998	0.59999999999999998	0.40000000000000002	1	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23465	491.80000000000001	0	0	0	12.6	13.5	21.100000000000001	49.5	102.09999999999999	102.55	87.799999999999997	64.099999999999994	38.5	0.029999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23464	384.05000000000001	0	0	0	0	0	4.4000000000000004	12.449999999999999	33	51.899999999999999	69	93.400000000000006	119.59999999999999	0.28000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23463	371.64999999999998	0	0	0	0	0	1.8999999999999999	9	29.300000000000001	47.149999999999999	77.450000000000003	92	114.3	0.53000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23462	251.09999999999999	0	0	0	0	0	0	1.2	2.6000000000000001	17.399999999999999	49.100000000000001	68	112.25	0.5	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23461	216.25	0	0	0	0	5.7999999999999998	18.5	22.300000000000001	19.300000000000001	16.5	22.5	27.100000000000001	80.799999999999997	3.2999999999999998	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23445	13.9	0	0	0	0	2.7999999999999998	3.7000000000000002	1.75	3.0499999999999998	1.95	0.40000000000000002	0.20000000000000001	0.02	0.01	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23444	1353.55	0	0	0	177.40000000000001	380	292.30000000000001	267.64999999999998	180.09999999999999	49.049999999999997	5	1.2	0.80000000000000004	0.029999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23443	927.45000000000005	0	0	0	91.599999999999994	86.5	66.299999999999997	78.400000000000006	95.299999999999997	92.599999999999994	89	135.80000000000001	191.05000000000001	0.84999999999999998	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23442	885.45000000000005	0	0	0	128.44999999999999	84.700000000000003	49.850000000000001	53.75	120.40000000000001	197.55000000000001	132	73.299999999999997	44.649999999999999	0.59999999999999998	0.17999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23441	359.95999999999998	0	0	0	8.9000000000000004	13.800000000000001	16.100000000000001	19.350000000000001	24.600000000000001	24.199999999999999	37.100000000000001	49.299999999999997	162.15000000000001	4.4000000000000004	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.029999999999999999	\N
23425	886	0	0	0	38.899999999999999	56.100000000000001	48.700000000000003	65.099999999999994	80.200000000000003	133.40000000000001	193.05000000000001	141.15000000000001	129.09999999999999	0.28999999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23424	642.54999999999995	0	0	0	0	32.549999999999997	33.700000000000003	46.200000000000003	76.049999999999997	118.15000000000001	145.30000000000001	88.700000000000003	101.59999999999999	0.28999999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23423	611.14999999999998	0	0	0	0	21.399999999999999	15.6	32.899999999999999	76	182	163.30000000000001	68.25	51.5	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23422	635.70000000000005	0	0	0	39.5	19.899999999999999	8.1999999999999993	13.199999999999999	76.200000000000003	233.90000000000001	142.84999999999999	59.850000000000001	41.5	0.40000000000000002	0.14999999999999999	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23421	51.210000000000001	0	0	0	29.350000000000001	4.7999999999999998	4.75	1.45	1.3	1.05	3.2000000000000002	4.5	0.70999999999999996	0.089999999999999997	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
13026	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
13027	136.59999999999999	0	0	0	0	0	0	0.55000000000000004	0.80000000000000004	1.8	10.050000000000001	39.649999999999999	82.230000000000004	1.5	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
13028	209.65000000000001	0	0	0	0	0	0	0.080000000000000002	0.80000000000000004	3.02	6.7999999999999998	20.629999999999999	175.59999999999999	2.7000000000000002	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
13029	206.18000000000001	0	0	0	0	0	0	0.59999999999999998	4	6.7000000000000002	10	18.149999999999999	164.09999999999999	2.6000000000000001	0.02	0.01	\N	\N	\N	\N	\N	\N	0	\N
13030	19.649999999999999	0	0	0	0	0	0	0	0.10000000000000001	0.65000000000000002	0.59999999999999998	1.05	16.100000000000001	1.1000000000000001	0.040000000000000001	0.01	\N	\N	\N	\N	\N	\N	0	\N
13021	32.82	0	0	0	0	0	4.0999999999999996	3.7000000000000002	4.5	8.6999999999999993	7.2000000000000002	1.8	1.6000000000000001	1.2	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
12972	7.0199999999999996	0	0	0	0	0	0	0	0.45000000000000001	1.25	1.6000000000000001	1.1000000000000001	2.5	0.10000000000000001	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
12973	110.22	0	0	0	0	0	0	0.14999999999999999	0.59999999999999998	4.1500000000000004	12.4	23.649999999999999	67.450000000000003	1.8	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
12974	335.64999999999998	0	0	0	0	0	3.1000000000000001	5.5	24.199999999999999	60.399999999999999	82.049999999999997	70.980000000000004	88.5	0.90000000000000002	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
12975	167.62	0	0	0	0	0	0.5	0.29999999999999999	6.0499999999999998	19.350000000000001	37.5	35.5	67.099999999999994	1.3	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
12976	240.75	0	0	0	0	4.7000000000000002	7.0999999999999996	16.149999999999999	15.300000000000001	12	23.899999999999999	55.549999999999997	105.5	0.5	0.029999999999999999	0.02	\N	\N	\N	\N	\N	\N	0	\N
12966	134.69999999999999	0	0	0	0	0	0	0.5	1.7	4.5	8.3000000000000007	19.649999999999999	99.200000000000003	0.80000000000000004	0.040000000000000001	0.01	\N	\N	\N	\N	\N	\N	0	\N
12967	389.25	0	0	0	0	10.300000000000001	10.199999999999999	10.699999999999999	21.449999999999999	43.5	50.700000000000003	50.100000000000001	190.90000000000001	1.3	0.059999999999999998	0.040000000000000001	\N	\N	\N	\N	\N	\N	0	\N
12968	482	0	0	0	0	0	0	4	8.5999999999999996	33.25	62.299999999999997	66.099999999999994	69.900000000000006	236.69999999999999	1.1000000000000001	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
12969	273.75	0	0	0	0	0	0	3.7999999999999998	7.2999999999999998	19.5	25	33.600000000000001	182.5	2	0.029999999999999999	0.02	\N	\N	\N	\N	\N	\N	0	\N
12970	359.05000000000001	0	0	0	0	0	3	6.0999999999999996	19.399999999999999	39.299999999999997	46.799999999999997	60.899999999999999	182.69999999999999	0.80000000000000004	0.040000000000000001	0.01	\N	\N	\N	\N	\N	\N	0	\N
12971	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11079	1057	0	0	0	0	13	28	53	333	409	176	36	9	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11080	1116	0	0	0	0	13	28	52	170	321	258	148	125	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11081	1992	0	0	0	41	71	190	356	670	314	155	79	114	2	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11082	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11083	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11074	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11075	1567	0	0	0	26	98	233	264	511	296	108	21	10	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11076	1556	0	0	0	0	72	101	178	616	373	137	45	33	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11077	4795	0	0	45	166	299	358	544	1226	1151	604	219	181	2	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11078	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11069	20	0	0	0	0	0	0	1	1	3	7	5	3	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11070	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11071	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11072	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11073	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11064	1657	0	0	0	0	4	21	62	477	829	232	28	4	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11065	2571	0	0	0	0	28	121	195	835	826	432	104	29	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11066	2225	0	0	0	0	15	32	130	1170	590	187	63	37	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11067	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11068	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11059	1466	0	0	0	0	0	1	6	5	28	113	317	506	324	166	0	0	0	0	\N	\N	\N	0	\N
11060	1617	0	0	0	0	0	24	22	17	66	206	418	422	283	159	0	0	0	0	\N	\N	\N	0	\N
11061	1348	0	0	0	0	0	3	5	8	50	190	352	297	238	204	1	0	0	0	\N	\N	\N	0	\N
11062	1366	0	0	0	0	0	0	2	7	31	78	215	355	365	312	1	0	0	0	\N	\N	\N	0	\N
11063	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
11054	740	0	0	0	0	0	10	7	11	41	259	298	96	14	4	0	0	0	0	\N	\N	\N	0	\N
11055	725	0	0	0	0	0	0	3	9	32	277	260	102	31	11	0	0	0	0	\N	\N	\N	0	\N
11056	2000	0	0	0	0	0	60	41	46	238	839	497	175	55	48	1	0	0	0	\N	\N	\N	0	\N
11057	4000	0	0	0	0	70	164	81	116	400	1704	930	402	79	51	2	1	0	0	\N	\N	\N	0	\N
11058	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
11049	1000	0	0	0	0	0	0	1	6	29	124	238	248	172	180	2	0	0	0	\N	\N	\N	0	\N
11050	1000	0	0	0	0	0	0	12	17	59	211	316	211	101	72	1	0	0	0	\N	\N	\N	0	\N
11051	703	0	0	0	0	0	2	2	2	9	81	272	168	94	72	1	0	0	0	\N	\N	\N	0	\N
11052	1000	0	0	0	0	0	8	6	10	39	145	290	273	150	78	1	0	0	0	\N	\N	\N	0	\N
11053	126	0	0	0	0	0	0	1	3	24	63	21	4	4	6	0	0	0	0	\N	\N	\N	0	\N
11043	1000	0	0	0	0	0	0	1	2	5	28	154	337	260	212	1	0	0	0	\N	\N	\N	0	\N
11044	1000	0	0	0	0	0	2	6	5	11	45	186	296	229	219	1	0	0	0	\N	\N	\N	0	\N
11045	1000	0	0	0	0	0	0	7	7	24	80	253	281	180	167	1	0	0	0	\N	\N	\N	0	\N
11046	1000	0	0	0	0	0	9	7	15	25	104	252	274	157	156	1	0	0	0	\N	\N	\N	0	\N
11047	1000	0	0	0	0	0	2	4	6	17	66	228	274	189	213	1	0	0	0	\N	\N	\N	0	\N
11048	248	0	0	0	0	0	0	0	0	0	1	2	12	44	172	17	0	0	0	\N	\N	\N	0	\N
11038	2485	0	0	0	0	50	77	59	68	204	580	1002	337	82	25	1	0	0	0	\N	\N	\N	0	\N
11039	1000	0	0	0	0	0	70	30	20	45	121	350	245	89	29	1	0	0	0	\N	\N	\N	0	\N
11040	2300	0	0	0	0	52	130	117	90	272	485	610	298	149	96	1	0	0	0	\N	\N	\N	0	\N
11041	2300	0	0	0	0	49	126	32	30	107	348	781	490	211	125	1	0	0	0	\N	\N	\N	0	\N
11042	11	0	0	0	0	0	0	0	0	0.14000000000000001	0.92000000000000004	2.29	0.78000000000000003	0.28999999999999998	5.2999999999999998	1.25	0.029999999999999999	0	0	\N	\N	\N	0	\N
11031	1000	0	0	0	0	0	56	28	35	133	280	272	127	47	21	1	0	0	0	\N	\N	\N	0	\N
11032	1000	0	0	0	0	0	51	40	21	54	201	375	187	54	17	0	0	0	0	\N	\N	\N	0	\N
11033	1000	0	0	0	0	0	13	11	11	30	91	259	267	176	141	1	0	0	0	\N	\N	\N	0	\N
11034	844	0	0	0	0	0	23	10	13	52	145	225	139	105	131	1	0	0	0	\N	\N	\N	0	\N
11035	2300	0	0	0	0	11	33	24	25	61	164	542	666	429	344	1	0	0	0	\N	\N	\N	0	\N
11036	1000	0	0	0	0	0	64	76	56	109	215	177	104	107	91	1	0	0	0	\N	\N	\N	0	\N
11037	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
11024	697	0	0	0	0	0	0	1	5	8	52	194	244	116	76	1	0	0	0	\N	\N	\N	0	\N
11025	627	0	0	0	0	0	2	1	1	20	103	246	157	47	49	1	0	0	0	\N	\N	\N	0	\N
11026	396	0	0	0	0	0	5	13	14	63	128	86	40	46	1	0	0	0	0	\N	\N	\N	0	\N
11027	1072	0	0	0	0	0	0	2	8	33	100	224	309	199	196	1	0	0	0	\N	\N	\N	0	\N
11028	900	0	0	0	0	0	5	16	19	64	152	176	210	118	139	1	0	0	0	\N	\N	\N	0	\N
11029	1000	0	0	0	0	0	2	6	14	59	312	387	156	63	1	0	0	0	0	\N	\N	\N	0	\N
11030	1000	0	0	0	0	0	0	7	5	61	259	242	161	139	125	1	0	0	0	\N	\N	\N	0	\N
11019	1000	0	0	0	0	0	4	9	18	60	197	356	228	78	49	1	0	0	0	\N	\N	\N	0	\N
11020	1000	0	0	0	0	0	13	15	5	21	82	293	313	142	114	2	0	0	0	\N	\N	\N	0	\N
11021	1000	0	0	0	0	0	61	48	27	84	194	315	161	58	51	1	0	0	0	\N	\N	\N	0	\N
11022	1000	0	0	0	0	0	30	17	24	82	211	271	176	91	97	1	0	0	0	\N	\N	\N	0	\N
11023	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
11015	1000	0	0	0	0	0	0	7	6	45	130	246	292	161	112	1	0	0	0	\N	\N	\N	0	\N
11016	1000	0	0	0	0	0	0	12	15	67	185	256	201	124	139	1	0	0	0	\N	\N	\N	0	\N
11017	1000	0	0	0	0	0	6	7	8	35	103	293	321	152	74	1	0	0	0	\N	\N	\N	0	\N
11018	700	0	0	0	0	0	0	1	1	18	114	206	155	110	94	1	0	0	0	\N	\N	\N	0	\N
11010	1000	0	0	0	0	0	2	3	7	34	126	241	268	204	114	1	0	0	0	\N	\N	\N	0	\N
11011	1000	0	0	0	0	0	70	55	46	108	221	238	126	70	65	1	0	0	0	\N	\N	\N	0	\N
11012	1000	0	0	0	0	0	15	13	11	38	139	287	254	151	91	1	0	0	0	\N	\N	\N	0	\N
11013	1000	0	0	0	0	0	9	18	13	32	93	257	301	168	108	1	0	0	0	\N	\N	\N	0	\N
11014	1000	0	0	0	0	0	0	9	5	25	143	372	295	107	43	1	0	0	0	\N	\N	\N	0	\N
11004	1000	0	0	0	0	0	20	21	19	35	128	428	243	75	31	0	0	0	0	\N	\N	\N	0	\N
11005	1000	0	0	0	0	0	29	51	31	54	109	277	255	115	78	1	0	0	0	\N	\N	\N	0	\N
11006	1000	0	0	0	0	0	4	9	9	32	83	212	299	181	168	3	0	0	0	\N	\N	\N	0	\N
11007	1000	0	0	0	0	0	12	9	12	33	115	268	275	151	124	1	0	0	0	\N	\N	\N	0	\N
11008	1000	0	0	0	0	0	29	17	15	78	221	268	160	104	106	2	0	0	0	\N	\N	\N	0	\N
11009	1000	0	0	0	0	0	9	6	12	70	190	194	115	175	226	3	0	0	0	\N	\N	\N	0	\N
10995	1000	0	0	0	0	0	2	11	9	15	63	275	382	166	76	1	0	0	0	\N	\N	\N	0	\N
10996	1000	0	0	0	0	0	51	32	22	44	128	266	240	124	92	1	0	0	0	\N	\N	\N	0	\N
10997	1000	0	0	0	0	0	20	16	13	35	100	276	307	145	87	1	0	0	0	\N	\N	\N	0	\N
10998	1000	0	0	0	0	0	42	52	26	44	106	228	227	144	129	2	0	0	0	\N	\N	\N	0	\N
10999	1000	0	0	0	0	0	30	38	37	107	222	230	155	91	89	1	0	0	0	\N	\N	\N	0	\N
11000	1000	0	0	0	0	0	35	40	28	58	198	288	169	94	89	1	0	0	0	\N	\N	\N	0	\N
11001	700	0	0	0	0	0	0	9	6	19	66	180	204	132	82	2	0	0	0	\N	\N	\N	0	\N
11002	700	0	0	0	0	0	0	1	1	5	25	81	167	210	208	2	0	0	0	\N	\N	\N	0	\N
11003	1000	0	0	0	0	0	6	9	14	43	109	114	131	246	326	2	0	0	0	\N	\N	\N	0	\N
10989	1317	0	0	0	0	0	31	7	10	36	79	210	425	298	219	2	0	0	0	\N	\N	\N	0	\N
10990	999	0	0	0	0	0	24	26	28	90	167	198	215	142	108	1	0	0	0	\N	\N	\N	0	\N
10991	999	0	0	0	0	0	65	55	26	41	112	256	224	126	93	1	0	0	0	\N	\N	\N	0	\N
10992	1000	0	0	0	0	0	39	19	24	69	208	350	172	68	50	1	0	0	0	\N	\N	\N	0	\N
10993	1000	0	0	0	0	0	133	30	35	110	240	220	125	61	45	1	0	0	0	\N	\N	\N	0	\N
10994	999	0	0	0	0	0	10	20	30	87	77	44	88	256	386	1	0	0	0	\N	\N	\N	0	\N
10982	464	0	0	0	0	0	0	0	0	0	5	39	201	143	76	0	0	0	0	\N	\N	\N	0	\N
10983	999	0	0	0	0	0	13	12	4	12	69	267	333	179	110	0	0	0	0	\N	\N	\N	0	\N
10984	1000	0	0	0	0	0	43	15	14	58	203	308	177	82	99	1	0	0	0	\N	\N	\N	0	\N
10985	999	0	0	0	0	0	22	17	19	60	190	295	210	107	78	1	0	0	0	\N	\N	\N	0	\N
10986	615	0	0	0	0	0	1	7	7	23	108	149	141	90	88	1	0	0	0	\N	\N	\N	0	\N
10314	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10315	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10316	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10317	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10318	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10319	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10320	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
10456	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10454	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10455	1000	0	0	0	0	0	21	10	9	15	34	170	353	233	153	2	0	0	0	\N	\N	\N	0	\N
24794	4682.1999999999998	0	0	0	0	11.4	42.600000000000001	68.200000000000003	277	925.79999999999995	1764.8	1022.6	565.60000000000002	4.2000000000000002	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24790	14539.77	0	0	0	0	0	148.06	301.60000000000002	1082	2687	3807	3012	3482	20.109999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24789	13302.67	0	0	0	0	28.309999999999999	73.280000000000001	391.41000000000003	1251	4136	4027	2112	1282	1.6699999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24788	12281.99	0	0	0	0	64.549999999999997	252.06999999999999	621	1543	2714	2473	1706	2893	15.369999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24787	12974.209999999999	0	0	0	0	0	23.870000000000001	73.769999999999996	568.39999999999998	3387	4736	2417	1766	2.1699999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24786	136.90000000000001	0	0	0	0	2.2999999999999998	4.4000000000000004	6.5999999999999996	6.4000000000000004	6.2999999999999998	21.899999999999999	43.200000000000003	45.700000000000003	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27688	2524.1900000000001	0	0	0	0	49.960000000000001	72.790000000000006	184.12	467.66000000000003	907.20000000000005	614.70000000000005	163.59999999999999	64.159999999999997	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27687	9798.4500000000007	0	0	0	0	84.379999999999995	127.55	127.5	504.31999999999999	2525	3675	1656	1083	15.699999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27686	13138.15	0	0	0	0	324.94	357.85000000000002	724.70000000000005	1867	4843	3104	989.60000000000002	913.89999999999998	13.16	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27685	22479.369999999999	0	0	0	313.95999999999998	517.5	593.10000000000002	1079	3819	8636	5122	1551	842.70000000000005	5.1100000000000003	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24785	2524.1900000000001	0	0	0	0	49.960000000000001	72.790000000000006	184.12	467.66000000000003	907.20000000000005	614.70000000000005	163.59999999999999	64.159999999999997	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24784	9798.4500000000007	0	0	0	0	84.379999999999995	127.55	127.5	504.31999999999999	2525	3675	1656	1083	15.699999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24783	13138.15	0	0	0	0	324.94	357.85000000000002	724.70000000000005	1867	4843	3104	989.60000000000002	913.89999999999998	13.16	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24782	22479.369999999999	0	0	0	313.95999999999998	517.5	593.10000000000002	1079	3819	8636	5122	1551	842.70000000000005	5.1100000000000003	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24070	334.35000000000002	0	0	0	0	0	1.3	17.300000000000001	60	118.7	72.400000000000006	37.100000000000001	27.300000000000001	0.20000000000000001	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0	\N
24069	377.10000000000002	0	0	0	0	0	3.2999999999999998	17.5	46.600000000000001	100.3	111.09999999999999	64.299999999999997	33.299999999999997	0.40000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
24068	281.5	0	0	0	0	0	3.6000000000000001	9.0999999999999996	16.300000000000001	57.899999999999999	110.09999999999999	54.200000000000003	29.800000000000001	0.20000000000000001	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
24067	288.89999999999998	0	0	0	0	6	4.4000000000000004	31.399999999999999	49.899999999999999	74.700000000000003	65.099999999999994	34.899999999999999	22.300000000000001	0.20000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24185	391.14999999999998	0	0	0	0	0	4.5	4.5499999999999998	23.899999999999999	98.900000000000006	146.40000000000001	86.5	26.199999999999999	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24184	499.14999999999998	0	0	0	0	0	20.800000000000001	31.800000000000001	74.5	128.94999999999999	108.84999999999999	80.200000000000003	53.549999999999997	0.47999999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24183	295.39999999999998	0	0	0	0	0	0	4.5	15.300000000000001	63.5	95.849999999999994	65.450000000000003	50.600000000000001	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24182	479.80000000000001	0	0	0	0	0	18.399999999999999	32.100000000000001	57.899999999999999	143.30000000000001	135	61.299999999999997	31.699999999999999	0.070000000000000007	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24061	332.64999999999998	0	0	0	0	1.8	8.1999999999999993	26.5	56.350000000000001	109.40000000000001	79.799999999999997	33.399999999999999	17.100000000000001	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24060	266.64999999999998	0	0	0	0	0	4.7000000000000002	15.4	43.850000000000001	62.600000000000001	48	43.299999999999997	48.399999999999999	0.38	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24059	335.14999999999998	0	0	0	0	3.8999999999999999	1.8	9	46.399999999999999	94.299999999999997	80.700000000000003	65.599999999999994	33.100000000000001	0.33000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24058	356.69999999999999	0	0	0	0	3.3999999999999999	8	19.25	57.299999999999997	108.5	74.650000000000006	54.5	30.899999999999999	0.17000000000000001	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24057	329	0	0	0	0	3.5	6.4000000000000004	7.5999999999999996	28.699999999999999	64.799999999999997	65.5	66.200000000000003	86.049999999999997	0.23000000000000001	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24056	3.5	0	0	0	0	0	0	0	0.050000000000000003	1.5	0.34999999999999998	0.20000000000000001	1.2	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24055	397.85000000000002	0	0	0	0	1.8	3.2999999999999998	4.75	28	78.299999999999997	120	82	79.400000000000006	0.28000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24054	450.69999999999999	0	0	0	0	0	6.2999999999999998	17.899999999999999	61.350000000000001	101.84999999999999	103.8	89.700000000000003	69.150000000000006	0.59999999999999998	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
24053	363.85000000000002	0	0	0	0	0	2	3.7999999999999998	13.65	40.799999999999997	76.299999999999997	96.700000000000003	129.59999999999999	0.94999999999999996	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
24052	250	0	0	0	0	0	1.3	8.6999999999999993	34.100000000000001	84.099999999999994	46.100000000000001	24	50.299999999999997	1.2	0.17999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
24051	29.449999999999999	0	0	0	0	0	0	0	0.050000000000000003	0.34999999999999998	2.1499999999999999	7.2999999999999998	19.199999999999999	0.34999999999999998	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23920	396.80000000000001	0	0	0	0	0	24.399999999999999	62.399999999999999	112.59999999999999	88.900000000000006	44.799999999999997	30.600000000000001	31.600000000000001	1.3999999999999999	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23919	317.30000000000001	0	0	0	0	2	1.7	6	24.199999999999999	91.400000000000006	114.2	49.25	28.300000000000001	0.20000000000000001	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23918	273.05000000000001	0	0	0	0	0	2.6499999999999999	7.2000000000000002	23.300000000000001	47.899999999999999	78.599999999999994	57.399999999999999	55.299999999999997	0.59999999999999998	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23917	309.64999999999998	0	0	0	0	0	3.7999999999999998	2.8500000000000001	14.5	53	105.09999999999999	95.900000000000006	34.350000000000001	0.11	0.02	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23916	256.55000000000001	0	0	0	0	0	8	31.399999999999999	61	37.100000000000001	17.100000000000001	36.299999999999997	64.799999999999997	0.80000000000000004	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23915	466.60000000000002	0	0	0	0	0	5	18.649999999999999	64.900000000000006	136.34999999999999	146.69999999999999	73.400000000000006	21.199999999999999	0.38	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23914	420.35000000000002	0	0	0	0	1.7	6.0999999999999996	8.1500000000000004	25.800000000000001	100.7	145.59999999999999	79.299999999999997	52.399999999999999	0.56999999999999995	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23913	517.89999999999998	0	0	0	10.300000000000001	13.5	23.800000000000001	32.899999999999999	70.5	119.3	125.3	66.5	54.899999999999999	0.80000000000000004	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23912	487	0	0	0	0	9.3000000000000007	8.6999999999999993	14.4	54	125.09999999999999	127.2	102.8	44.700000000000003	0.78000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23911	395.85000000000002	0	0	0	0	0	2.2999999999999998	13.199999999999999	79.599999999999994	148.09999999999999	78.700000000000003	56.700000000000003	17.100000000000001	0.10000000000000001	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23910	609.5	0	0	0	0	9.6999999999999993	14.800000000000001	41.899999999999999	94.799999999999997	170.30000000000001	148.90000000000001	81.700000000000003	47.25	0.10000000000000001	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23909	742	0	0	0	0	28.5	38.200000000000003	70.049999999999997	148.09999999999999	163.30000000000001	110.40000000000001	70.549999999999997	112.40000000000001	0.45000000000000001	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23908	589.79999999999995	0	0	0	0	8.1500000000000004	8.3000000000000007	20.199999999999999	76.099999999999994	158.44999999999999	149	85.400000000000006	83.700000000000003	0.40000000000000002	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23907	161.80000000000001	0	0	0	0	0	0	0.5	0.80000000000000004	8.3000000000000007	37.600000000000001	49.200000000000003	65.099999999999994	0.28999999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23906	3.7000000000000002	0	0	0	0	0	0	0.29999999999999999	1.55	1.55	0.10000000000000001	0.050000000000000003	0.050000000000000003	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23905	428.60000000000002	0	0	0	0	11	10	31.850000000000001	94.25	185.69999999999999	85.5	9	1.25	0.029999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23904	563.5	0	0	0	0	15.6	14.85	51.600000000000001	131	184	108.2	35.850000000000001	22	0.38	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23903	845.45000000000005	0	0	0	0	24.350000000000001	24	59.950000000000003	173.40000000000001	260.55000000000001	152.59999999999999	63.5	86.299999999999997	0.75	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23902	890.29999999999995	0	0	0	0	24.550000000000001	30.800000000000001	71.049999999999997	183.19999999999999	309.10000000000002	154.30000000000001	62.700000000000003	54.200000000000003	0.38	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23890	370.14999999999998	0	0	0	0	5.0999999999999996	10.5	22.699999999999999	42.149999999999999	148.09999999999999	103.15000000000001	27.100000000000001	11.300000000000001	0.029999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23889	438.25	0	0	0	0	3.6000000000000001	5	23.100000000000001	55.149999999999999	111.3	123.90000000000001	64.900000000000006	50.399999999999999	0.88	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23888	432.05000000000001	0	0	0	0	0	4.4000000000000004	15.300000000000001	62.899999999999999	122.8	114.5	62.5	48.899999999999999	0.69999999999999996	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23887	399.89999999999998	0	0	0	0	1.5	1.5	8.9000000000000004	38.299999999999997	90.049999999999997	126	77.700000000000003	55.399999999999999	0.53000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23886	304.85000000000002	0	0	0	0	0	12.4	47.100000000000001	92	74.799999999999997	27.100000000000001	17.800000000000001	32.700000000000003	0.93000000000000005	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23875	566.60000000000002	0	0	0	0	7.4500000000000002	21.449999999999999	61.100000000000001	146.69999999999999	170.25	94.900000000000006	43.299999999999997	21.399999999999999	0.040000000000000001	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23874	385.94999999999999	0	0	0	0	0	0	3.4500000000000002	19.600000000000001	74.099999999999994	114.2	92.299999999999997	82.099999999999994	0.19	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23873	513.39999999999998	0	0	0	0	2.4500000000000002	19	49.799999999999997	124.84999999999999	145.09999999999999	76.200000000000003	45.5	50.200000000000003	0.28999999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23872	371.64999999999998	0	0	0	0	4.0999999999999996	2.3999999999999999	9.0500000000000007	37.549999999999997	112.5	95.450000000000003	62.700000000000003	47.799999999999997	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23871	457.69999999999999	0	0	0	0	2.1000000000000001	5.9000000000000004	20.949999999999999	35.649999999999999	53.399999999999999	81.200000000000003	121.7	136.59999999999999	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23870	526.99000000000001	0	0	0	0	0	11.6	31.399999999999999	119	186.69999999999999	116.8	43.5	17.800000000000001	0.14999999999999999	0.02	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23869	588.12	0	0	0	0	15	18.649999999999999	53.799999999999997	142.65000000000001	192.30000000000001	100.2	41.299999999999997	24.100000000000001	0.10000000000000001	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23868	492.37	0	0	0	0	10.9	9.3000000000000007	24	87.450000000000003	171.34999999999999	93.200000000000003	45.5	50.100000000000001	0.55000000000000004	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23867	573.91999999999996	0	0	0	0	27.649999999999999	25.699999999999999	66	149.75	180.19999999999999	73	27.399999999999999	24	0.20000000000000001	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23866	686.75	0	0	0	17.699999999999999	36.600000000000001	62.75	115.09999999999999	163.40000000000001	99.799999999999997	67.200000000000003	62.399999999999999	61.5	0.20000000000000001	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23865	323.68000000000001	0	0	0	0	4.0499999999999998	7.3499999999999996	20.350000000000001	54.149999999999999	79.099999999999994	78.599999999999994	47.950000000000003	31.649999999999999	0.28000000000000003	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
23864	490.63999999999999	0	0	0	0	18.850000000000001	4.2000000000000002	5.9000000000000004	34.200000000000003	152.19999999999999	159.09999999999999	76.700000000000003	39.200000000000003	0.25	0.02	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23863	506	0	0	0	0	19.5	23.100000000000001	54.700000000000003	137.05000000000001	137	71.799999999999997	35.100000000000001	27.600000000000001	0.13	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23862	435.89999999999998	0	0	0	0	3.8500000000000001	14.5	25.75	78.599999999999994	124.40000000000001	88.400000000000006	53.200000000000003	46.899999999999999	0.28000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23861	471.64999999999998	0	0	0	0	5.7000000000000002	17.5	31	59.799999999999997	80.200000000000003	109.40000000000001	101.8	66.099999999999994	0.10000000000000001	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
12977	635.70000000000005	0	0	0	0	0	11.050000000000001	47.549999999999997	142.59999999999999	232.19999999999999	106.3	53.200000000000003	42.100000000000001	0.59999999999999998	0.050000000000000003	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
12978	370.42000000000002	0	0	0	0	0	2.3500000000000001	10	50.399999999999999	159.09999999999999	85.099999999999994	35.5	27.899999999999999	0.035000000000000003	0.025000000000000001	0.01	\N	\N	\N	\N	\N	\N	0	\N
12979	692.39999999999998	0	0	0	0	5.9500000000000002	28.699999999999999	59.299999999999997	136.25	175.5	145.69999999999999	86.099999999999994	54.399999999999999	0.47999999999999998	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
12980	429.35000000000002	0	0	0	0	4.4500000000000002	7.5999999999999996	15.1	39.649999999999999	100.90000000000001	119.7	85.25	55.100000000000001	1.5800000000000001	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
12981	1.2	0	0	0	0	0	0	0	0	0.10000000000000001	0.10000000000000001	0.10000000000000001	0.69999999999999996	0.17999999999999999	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
27559	8183.8000000000002	0	0	0	0	76.599999999999994	142	267.39999999999998	853.20000000000005	2625	3127.1999999999998	796.39999999999998	295	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27558	20887.900000000001	0	0	0	181.19999999999999	966.60000000000002	2078.8000000000002	3629.1999999999998	4367	3809.4000000000001	2492	1510.2	1830.8	22.300000000000001	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27557	19104.200000000001	0	0	0	75.200000000000003	322.80000000000001	885.60000000000002	2063.4000000000001	3875.4000000000001	4315.8000000000002	3450.5999999999999	1767.4000000000001	2313.4000000000001	33.399999999999999	1.2	\N	\N	\N	\N	\N	\N	\N	0	\N
27556	16608	0	0	0	14.6	50.600000000000001	208.40000000000001	847.79999999999995	2850.1999999999998	3765.8000000000002	4228.3999999999996	2274.8000000000002	2332.1999999999998	34.799999999999997	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
24661	25843.599999999999	0	0	0	6.5999999999999996	123.2	430.19999999999999	702.60000000000002	2503.1999999999998	8021	10308	2962.5999999999999	785.60000000000002	0.59999999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24662	16834.799999999999	0	0	0	18.600000000000001	161	636.60000000000002	1228.5999999999999	2881.8000000000002	4203.8000000000002	3771.4000000000001	1859	2061.1999999999998	12.800000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24663	3483.1999999999998	0	0	0	0	17.399999999999999	105.2	325	651.20000000000005	661	578.79999999999995	412.19999999999999	720	12.4	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24664	17066.400000000001	0	0	0	0	77.200000000000003	365.19999999999999	870	2646.8000000000002	3191	4164.6000000000004	3545.1999999999998	2188.1999999999998	18	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24665	11169.200000000001	0	0	0	7	14.4	74	137.80000000000001	608.20000000000005	1847.2	3556.4000000000001	2423	2489	12.199999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24650	16033.059999999999	0	0	0	0	128.28	198.43000000000001	779.70000000000005	1852	4036	4587	2840.1999999999998	1543.3	68.150000000000006	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24649	3915.73	0	0	0	0	36.229999999999997	74.900000000000006	120.92	275.13	542.89999999999998	833.70000000000005	1031.8	960.5	39.649999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24648	2737.25	0	0	0	0	0	26.989999999999998	86.849999999999994	180.74000000000001	381.43000000000001	454.19999999999999	470.19999999999999	1120.8	14.869999999999999	1.1699999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
24647	12474	0	0	0	0	42.770000000000003	133.65000000000001	311.85000000000002	769.79999999999995	1612.7	2459.8000000000002	3342.4000000000001	3685.1999999999998	114.05	1.78	\N	\N	\N	\N	\N	\N	\N	0	\N
24646	4112.9399999999996	0	0	0	0	0	8.2300000000000004	63.770000000000003	112.45	403.87	825.79999999999995	973.29999999999995	1716.5999999999999	8.2300000000000004	0.68999999999999995	\N	\N	\N	\N	\N	\N	\N	0	\N
24645	947	0	0	0	90.400000000000006	312.89999999999998	353.69999999999999	92.700000000000003	54.5	23	8.9000000000000004	3.3999999999999999	5.2999999999999998	2	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24644	25424.950000000001	0	0	0	302.87	1019.36	994.5	2217	7297	8023	3603	1263	700.70000000000005	4.5199999999999996	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24643	15789.299999999999	0	0	0	90.930000000000007	375.58999999999997	674.70000000000005	1141	2197	4164	2934	1456	2706	50.079999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24642	25794.369999999999	0	0	0	332.92000000000002	1119	2530	3733	5011	4825	3110	1634	3493	6.4500000000000002	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24641	4063.7199999999998	0	0	0	0	8.6400000000000006	48.259999999999998	104.65000000000001	255.02000000000001	504.89999999999998	867.70000000000005	690.39999999999998	1543	39.119999999999997	2.0299999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
24050	297.5	0	0	0	0	1.5	10	27.899999999999999	51.399999999999999	71.700000000000003	58.100000000000001	38.200000000000003	38.299999999999997	0.40000000000000002	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24049	299.19999999999999	0	0	0	0	2.6000000000000001	3.1000000000000001	19.300000000000001	38.200000000000003	53.700000000000003	55	65.5	61	0.69999999999999996	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24048	262.39999999999998	0	0	0	0	4.5999999999999996	3.2000000000000002	23.5	42.200000000000003	66.400000000000006	45.299999999999997	27.699999999999999	45.399999999999999	3.7999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
24047	283	0	0	0	0	0	8.1999999999999993	32.200000000000003	47.299999999999997	47.799999999999997	41.700000000000003	29.100000000000001	70.200000000000003	6.4000000000000004	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24046	384.69999999999999	0	0	0	0	0	0	4.4000000000000004	12.199999999999999	55.200000000000003	99.400000000000006	75.799999999999997	135.5	2	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
24165	473.30000000000001	0	0	0	0	0	22.5	58.399999999999999	109.5	125.7	88.700000000000003	44.799999999999997	23.600000000000001	0.070000000000000007	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24164	405.05000000000001	0	0	0	0	0	10.9	24.399999999999999	62.649999999999999	122	87.299999999999997	57.299999999999997	40.200000000000003	0.28000000000000003	0.02	\N	\N	\N	\N	\N	\N	\N	0	\N
24163	250.30000000000001	0	0	0	0	0	1.6000000000000001	2.1000000000000001	10.4	56.299999999999997	93.099999999999994	45.700000000000003	40.600000000000001	0.47999999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24162	251	0	0	0	0	0	0.90000000000000002	6.2000000000000002	7.7000000000000002	23.399999999999999	45.399999999999999	42.600000000000001	122.40000000000001	2.2999999999999998	0.080000000000000002	\N	\N	\N	\N	\N	\N	\N	0.02	\N
24161	250.90000000000001	0	0	0	0	0	0.84999999999999998	2	6.7000000000000002	15	43.649999999999999	49.600000000000001	129.5	3.5800000000000001	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24045	559.10000000000002	0	0	0	0	17.300000000000001	16.5	36.200000000000003	106	157.90000000000001	114.59999999999999	58.200000000000003	52.200000000000003	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24044	403.89999999999998	0	0	0	0	8.5999999999999996	13	21.100000000000001	62.5	91.200000000000003	72.5	84.599999999999994	50.100000000000001	0.27000000000000002	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24043	411.35000000000002	0	0	0	0	18.149999999999999	18.800000000000001	27.899999999999999	49.100000000000001	94	87.700000000000003	57.700000000000003	57.100000000000001	0.84999999999999998	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
24042	314.25	0	0	0	0	2.2000000000000002	4	17.5	51.100000000000001	69.099999999999994	65.700000000000003	35.350000000000001	66.5	2.7799999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24041	290.05000000000001	0	0	0	0	0	0.55000000000000004	3	14.9	43.899999999999999	80.799999999999997	62.600000000000001	82.700000000000003	1.5	0.080000000000000002	\N	\N	\N	\N	\N	\N	\N	0.02	\N
25913	516.89999999999998	0	0	0	0	5.2000000000000002	26	65.099999999999994	105.09999999999999	108.7	95.400000000000006	56.5	54.700000000000003	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
25912	398.25	0	0	0	0	0	2.2999999999999998	10.699999999999999	33.299999999999997	98	113.25	76.099999999999994	64.299999999999997	0.28000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
25911	340.19999999999999	0	0	0	0	0	1.6000000000000001	9.3000000000000007	21.449999999999999	64.400000000000006	90.549999999999997	70	82.099999999999994	0.76000000000000001	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.01	\N
25910	25.850000000000001	0	0	0	0	0	0	2.6000000000000001	5.9000000000000004	7.7999999999999998	5.0999999999999996	2.0499999999999998	2.2999999999999998	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23845	337.5	0	0	0	0	0	6	6.7999999999999998	11.699999999999999	37.100000000000001	105.40000000000001	118	52.299999999999997	0.14999999999999999	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23844	330.25	0	0	0	0	0	9.8000000000000007	33	40.850000000000001	52.399999999999999	55.700000000000003	51.799999999999997	83.099999999999994	3.5	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23843	401.19999999999999	0	0	0	0	10	22.399999999999999	71.099999999999994	61.700000000000003	68.599999999999994	64.5	39.200000000000003	62	1.55	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23842	266.5	0	0	0	0	0	1.3999999999999999	5.4000000000000004	18.800000000000001	83.599999999999994	86.200000000000003	34.600000000000001	35.399999999999999	0.90000000000000002	0.14999999999999999	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23835	492.14999999999998	0	0	0	0	2.5499999999999998	21.899999999999999	82.5	179.80000000000001	135.59999999999999	45.149999999999999	16	8.5	0.10000000000000001	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23834	593.10000000000002	0	0	0	8.1999999999999993	9.3000000000000007	12.6	27.050000000000001	53	186.80000000000001	201.75	66.799999999999997	27.399999999999999	0.14999999999999999	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23833	417.39999999999998	0	0	0	0	39.899999999999999	50.149999999999999	49.950000000000003	62.799999999999997	60.100000000000001	49.799999999999997	36.5	66.900000000000006	1.2	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23832	470.19999999999999	0	0	0	0	3.8999999999999999	8.3000000000000007	42.700000000000003	96.5	98.099999999999994	70.799999999999997	71.099999999999994	77.400000000000006	1.1000000000000001	0.25	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23831	489.69999999999999	0	0	0	0	0	8.8000000000000007	27.600000000000001	53.200000000000003	82.900000000000006	81.099999999999994	92.299999999999997	142.09999999999999	1.6000000000000001	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23830	596.09000000000003	0	0	0	12.1	22.699999999999999	29.399999999999999	13.300000000000001	248.55000000000001	187.69999999999999	10.890000000000001	51.299999999999997	20	0.13	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23829	728	0	0	0	0	0	41.700000000000003	95.900000000000006	166.19999999999999	215	132.19999999999999	49	27.600000000000001	0.37	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23828	208.94999999999999	0	0	0	16.800000000000001	1.5	17.800000000000001	29.800000000000001	36.5	21.300000000000001	13.699999999999999	12.949999999999999	56.899999999999999	1.6499999999999999	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23827	631.54999999999995	0	0	0	0	16.399999999999999	29.600000000000001	84.700000000000003	124.3	87.099999999999994	62.649999999999999	56.700000000000003	166.09999999999999	3.8500000000000001	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
23826	478.60000000000002	0	0	0	0	6.2999999999999998	32.399999999999999	73.150000000000006	107.90000000000001	66.299999999999997	43.899999999999999	35	110	3.6000000000000001	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23805	492.39999999999998	0	0	0	0	1.8999999999999999	10.300000000000001	42.850000000000001	84.400000000000006	120.59999999999999	111.25	65.700000000000003	55.200000000000003	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23804	273.30000000000001	0	0	0	0	1.8500000000000001	0.40000000000000002	3.1000000000000001	14.1	42.399999999999999	51	47.200000000000003	112.3	0.93000000000000005	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23803	404	0	0	0	0	0	19.699999999999999	71.900000000000006	130.5	80.5	27.800000000000001	19.699999999999999	53	0.88	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23802	365.80000000000001	0	0	0	0	0	1.1000000000000001	5.5	24.199999999999999	59	51.299999999999997	46.5	174.09999999999999	4.0800000000000001	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23801	347.39999999999998	0	0	0	0	0	3.3999999999999999	20.75	51	68.799999999999997	60.200000000000003	47.25	94.299999999999997	1.6799999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23790	599.89999999999998	0	0	0	0	1.3	13.300000000000001	29.899999999999999	85.700000000000003	174	168.40000000000001	85.400000000000006	41.700000000000003	0.17999999999999999	0.02	\N	\N	\N	\N	\N	\N	\N	0	\N
23789	384.39999999999998	0	0	0	0	0	3.1000000000000001	5.9000000000000004	20.300000000000001	77.700000000000003	114.59999999999999	92.599999999999994	70	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23788	559.70000000000005	0	0	0	0	9.1999999999999993	10.300000000000001	37.5	86.299999999999997	109.09999999999999	102.8	88.400000000000006	114.3	1.78	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23787	571.29999999999995	0	0	0	0	2.7000000000000002	32.5	111.5	110.09999999999999	66.299999999999997	62.399999999999999	64.599999999999994	119.5	1.6799999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23786	532.89999999999998	0	0	0	0	0	12.1	72.400000000000006	172.5	116.8	54.700000000000003	36.799999999999997	67.099999999999994	0.47999999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23770	900.5	0	0	0	22.399999999999999	88.299999999999997	104.09999999999999	271.39999999999998	298.80000000000001	99.099999999999994	12.449999999999999	2.7999999999999998	1	0.10000000000000001	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23769	677.64999999999998	0	0	0	0	25.600000000000001	31.100000000000001	83.5	223.19999999999999	222.19999999999999	65.900000000000006	17.699999999999999	8.4000000000000004	0.029999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23768	708.70000000000005	0	0	0	28.800000000000001	32.549999999999997	51	103.09999999999999	150.59999999999999	138.90000000000001	82.75	48.399999999999999	71.900000000000006	0.59999999999999998	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23767	538.95000000000005	0	0	0	0	19.600000000000001	12.050000000000001	20.899999999999999	61.049999999999997	134.09999999999999	115.8	74.450000000000003	100.2	0.69999999999999996	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23766	397.75999999999999	0	0	0	0	0	7.3499999999999996	26.600000000000001	75.900000000000006	92.299999999999997	68.099999999999994	55.549999999999997	71.5	0.40000000000000002	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.029999999999999999	\N
23785	475.10000000000002	0	0	0	0	0	4.5999999999999996	16	35.399999999999999	110.45	144.15000000000001	95.400000000000006	69	0.089999999999999997	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23784	613.55999999999995	0	0	0	0	15.25	32.600000000000001	90.200000000000003	125	115.84999999999999	103.40000000000001	67.950000000000003	62.899999999999999	0.39000000000000001	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23783	507.64999999999998	0	0	0	0	6.1500000000000004	21.600000000000001	55.75	84.099999999999994	92.650000000000006	74	56.200000000000003	116	1.1799999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23782	409.5	0	0	0	0	6.5999999999999996	5.7999999999999998	14.449999999999999	22.699999999999999	50.799999999999997	66.799999999999997	68.549999999999997	172.80000000000001	0.97999999999999998	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23781	358.39999999999998	0	0	0	0	0	1.8999999999999999	19.649999999999999	54.700000000000003	70.200000000000003	63.5	50.5	97.299999999999997	0.62	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
12992	556.79999999999995	0	0	0	0	7.9000000000000004	4.2999999999999998	22.399999999999999	48.450000000000003	131.19999999999999	159.59999999999999	110	72.900000000000006	0.029999999999999999	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
12993	323.47000000000003	0	0	0	0	0	2.75	6.0999999999999996	15.800000000000001	45.799999999999997	90.75	83.75	77.599999999999994	0.90000000000000002	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
12994	445.39999999999998	0	0	0	0	5.7000000000000002	15.4	25.100000000000001	53.649999999999999	85.900000000000006	82.900000000000006	71.400000000000006	104	1.3	0.029999999999999999	0.02	\N	\N	\N	\N	\N	\N	0	\N
12995	225.55000000000001	0	0	0	0	5	4.4000000000000004	12.5	22.949999999999999	22	12.800000000000001	16.600000000000001	121.90000000000001	7.0999999999999996	0.28000000000000003	0.02	\N	\N	\N	\N	\N	\N	0	\N
12996	165.84999999999999	0	0	0	0	0	4.4000000000000004	2.5	8.5999999999999996	16.800000000000001	16.600000000000001	18.600000000000001	92.299999999999997	5.2000000000000002	0.80000000000000004	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
12987	331.44999999999999	0	0	0	0	0	8.75	10.800000000000001	36.899999999999999	91.700000000000003	82.099999999999994	49.799999999999997	51	0.34999999999999998	0.029999999999999999	0.02	\N	\N	\N	\N	\N	\N	0	\N
12988	142.05000000000001	0	0	0	0	0	0	0.90000000000000002	1.7	5.7000000000000002	12.550000000000001	20.100000000000001	98.599999999999994	2.3999999999999999	0.050000000000000003	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
12989	159.94999999999999	0	0	0	0	0	0	0	0.84999999999999998	2.7000000000000002	9.6999999999999993	17.199999999999999	124.84999999999999	4.5499999999999998	0.050000000000000003	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
12990	407.35000000000002	0	0	0	0	9.6500000000000004	10.5	17.850000000000001	29.100000000000001	40.450000000000003	58.600000000000001	74.799999999999997	164.09999999999999	2.2000000000000002	0.050000000000000003	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
12991	52.590000000000003	0	0	0	0	0	0	1.1000000000000001	1.3	2.5	4.7000000000000002	8.9000000000000004	33.200000000000003	0.87	0.02	\N	\N	\N	\N	\N	\N	\N	0	\N
12982	701.25	0	0	0	24	28.199999999999999	44.5	83.099999999999994	179.80000000000001	205.40000000000001	73.5	31.100000000000001	31.100000000000001	0.40000000000000002	0.10000000000000001	0.050000000000000003	\N	\N	\N	\N	\N	\N	0	\N
12983	668.35000000000002	0	0	0	0	8.4000000000000004	19.800000000000001	44.399999999999999	79.799999999999997	153.80000000000001	125.5	90.299999999999997	143.90000000000001	2.3999999999999999	0.029999999999999999	0.02	\N	\N	\N	\N	\N	\N	0	\N
12984	280.12	0	0	0	0	8.0999999999999996	0.59999999999999998	3.2999999999999998	6.2000000000000002	15.699999999999999	52	71.799999999999997	119.5	2.8999999999999999	0.01	0.01	\N	\N	\N	\N	\N	\N	0	\N
12985	581.95000000000005	0	0	0	0	11.9	10.5	38.700000000000003	80.299999999999997	83.099999999999994	68	75.5	210.5	3.3999999999999999	0.029999999999999999	0.02	\N	\N	\N	\N	\N	\N	0	\N
12986	326.66000000000003	0	0	0	0	0	3.1499999999999999	7.4000000000000004	16.25	25.600000000000001	40.600000000000001	57.700000000000003	173.09999999999999	2.7999999999999998	0.029999999999999999	0.029999999999999999	\N	\N	\N	\N	\N	\N	0	\N
10933	1352	0	0	0	0	10	44	177	627	275	130	43	45	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10934	1569	0	0	0	0	27	157	426	431	188	116	80	141	3	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10935	920	0	0	0	0	9	24	73	134	94	74	114	394	4	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10936	586	0	0	0	0	0	3	11	44	76	110	151	190	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10937	525	0	0	0	0	0	0	2	21	94	105	116	185	2	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10928	1691	0	0	0	183	449	501	303	205	47	2	1	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10929	2076	0	0	0	8	51	150	438	839	450	116	20	4	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10930	1280	0	0	0	28	45	66	179	552	270	85	35	20	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10931	1958	0	0	0	29	115	307	823	446	115	41	33	48	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
10932	739	0	0	0	0	0	0	4	37	122	148	182	245	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34854	151.80000000000001	0	0	0	0	0	0	0.20000000000000001	1.3999999999999999	12.5	35.899999999999999	31.100000000000001	70	0.69999999999999996	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34855	1686.4000000000001	0	0	0	24	27.600000000000001	11.800000000000001	14.199999999999999	34.600000000000001	167.59999999999999	409	356.39999999999998	636.79999999999995	4.4000000000000004	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34856	1901.2	0	0	0	40.600000000000001	17.600000000000001	30.600000000000001	78.799999999999997	331.80000000000001	645.60000000000002	381	201.40000000000001	172.80000000000001	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34857	9191.3999999999996	0	0	0	99.200000000000003	119.59999999999999	423	1196.4000000000001	3666.1999999999998	2782	701.20000000000005	154.40000000000001	48.200000000000003	1.2	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34737	1358.2	0	0	0	0	33.399999999999999	104.8	95.200000000000003	147.59999999999999	354.80000000000001	349.60000000000002	147.80000000000001	123.59999999999999	1.2	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34738	9943.7000000000007	0	0	0	0	70.599999999999994	288.39999999999998	755	1768.5999999999999	1599	2402.5999999999999	1994	1054.8	10.199999999999999	0.5	\N	\N	\N	\N	\N	\N	\N	0	\N
34739	7052.8000000000002	0	0	0	0	101	364	590.79999999999995	1013.2	645	1381.5999999999999	1791.2	1159.2	6.5999999999999996	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34740	7838	0	0	0	0	93	331.19999999999999	621.39999999999998	878.39999999999998	436.60000000000002	675.79999999999995	1926.4000000000001	2861.4000000000001	13.199999999999999	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
29908	6695	0	0	0	0	3	31.399999999999999	132	435	1910.8	2727.5999999999999	992	462.39999999999998	0.59999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29907	2583.8000000000002	0	0	0	0	5.2000000000000002	16.199999999999999	27.800000000000001	47.200000000000003	222.40000000000001	1441.2	636.39999999999998	186.80000000000001	0.40000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29906	9117.2000000000007	0	0	0	0	1.8	37.399999999999999	90.200000000000003	190.59999999999999	653.20000000000005	3879.8000000000002	3305.1999999999998	958	0.80000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29905	1128.2	0	0	0	0	3.2000000000000002	9.4000000000000004	49.399999999999999	89	59	114.2	313.60000000000002	488.80000000000001	1.3999999999999999	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29904	358.80000000000001	0	0	0	9.4000000000000004	33.799999999999997	113	63.799999999999997	36.399999999999999	9.4000000000000004	6.7999999999999998	11.6	73.200000000000003	1.3999999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29899	8637.7999999999993	0	0	0	0	66.599999999999994	173.80000000000001	227.59999999999999	663.79999999999995	2122.4000000000001	3938.4000000000001	1127.5999999999999	316.19999999999999	1.3999999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29900	2446.1999999999998	0	0	0	0	82.700000000000003	201.09999999999999	212.19999999999999	308	468.19999999999999	627.39999999999998	367.89999999999998	177.19999999999999	1.1000000000000001	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
29901	11194.6	0	0	0	40.799999999999997	351.39999999999998	931.60000000000002	1145.5999999999999	1318	1423.5999999999999	2541.5999999999999	2464	975	3	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29902	16303.200000000001	0	0	0	51.200000000000003	232.59999999999999	813.79999999999995	1029.8	951.39999999999998	823.39999999999998	2329.5999999999999	6550.1999999999998	3517.1999999999998	4	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29903	749.60000000000002	0	0	0	16.199999999999999	15	38.5	43.399999999999999	38.600000000000001	28.699999999999999	63.600000000000001	195	309.60000000000002	1	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29894	27151	0	0	0	595.20000000000005	1702.0999999999999	1585	1360.0999999999999	2536.8000000000002	4802.8999999999996	10520.299999999999	3476.0999999999999	558.10000000000002	13.800000000000001	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
29895	39409	0	0	0	2013.4000000000001	3180	3291	3361.5999999999999	6557.3999999999996	10245	7686.6000000000004	2192.8000000000002	862.39999999999998	17.800000000000001	1	\N	\N	\N	\N	\N	\N	\N	0	\N
29896	5763.3999999999996	0	0	0	157	222.59999999999999	455.30000000000001	555.5	805.70000000000005	1183.5	1392.5	583.5	399.39999999999998	8	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
29897	2836.5999999999999	0	0	0	274.89999999999998	349.69999999999999	391.89999999999998	500.19999999999999	305.39999999999998	289.89999999999998	275.10000000000002	277.19999999999999	171.90000000000001	0.29999999999999999	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29898	22340.400000000001	0	0	0	557.20000000000005	1380.5999999999999	2206.8000000000002	2878	3990	2211.1999999999998	2656.5999999999999	4232	2201	26.800000000000001	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27551	2036	0	0	0	0	17.199999999999999	78.200000000000003	119.2	317.19999999999999	589.39999999999998	522.79999999999995	206	184.19999999999999	1.6000000000000001	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27552	4499	0	0	0	0	19.199999999999999	132.59999999999999	283	725	1641.8	1162.4000000000001	256.39999999999998	275.39999999999998	3	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27553	11467.5	0	0	0	0	44.200000000000003	157.80000000000001	470.19999999999999	1883	3409.8000000000002	3157	1454.9000000000001	878	12.199999999999999	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27554	5571.6000000000004	0	0	0	0	5.4000000000000004	74.599999999999994	132.40000000000001	146.19999999999999	107.2	662.60000000000002	2676.4000000000001	1756.4000000000001	10.199999999999999	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27555	162.80000000000001	0	0	0	0	55.600000000000001	34.299999999999997	19.300000000000001	14	4.0999999999999996	3.2999999999999998	8.5	23.100000000000001	0.5	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27961	1652.8	0	0	0	0	9.4000000000000004	50.399999999999999	71.599999999999994	236.59999999999999	391.60000000000002	479.19999999999999	182.59999999999999	228.80000000000001	2.2000000000000002	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27962	1680	0	0	0	0	0	8.5999999999999996	22.199999999999999	66.799999999999997	308.19999999999999	910	266	96.799999999999997	1.1000000000000001	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
27963	7589.1999999999998	0	0	0	0	5.2000000000000002	66	232.40000000000001	1066.5999999999999	1536.8	2560	1430.4000000000001	685.60000000000002	6	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27964	5975.1999999999998	0	0	0	0	5.4000000000000004	55.799999999999997	174	242.19999999999999	224.40000000000001	882.20000000000005	2805.8000000000002	1582.2	3	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27965	82.700000000000003	0	0	0	0	19	18.399999999999999	15.9	11.6	2.6000000000000001	1.2	3.6000000000000001	10.199999999999999	0.10000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27545	2890.1999999999998	0	0	0	19	241.40000000000001	436.39999999999998	522.60000000000002	871.60000000000002	727.20000000000005	66.200000000000003	3	2.3999999999999999	0.20000000000000001	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27544	3744.1999999999998	0	0	0	160.40000000000001	221.59999999999999	472.39999999999998	551	924.39999999999998	790.20000000000005	383	129.80000000000001	110.40000000000001	0.80000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27543	11645.9	0	0	0	158	665.79999999999995	1373.4000000000001	1904.5999999999999	2101	1505.2	2225.5999999999999	1084	625.60000000000002	2.3999999999999999	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
27542	2956.5	0	0	0	20.199999999999999	215.59999999999999	180.59999999999999	378.80000000000001	460.89999999999998	280.80000000000001	414	537.60000000000002	466.60000000000002	1.2	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27541	169.90000000000001	0	0	0	0	0	0	0.29999999999999999	0.10000000000000001	0.20000000000000001	0.10000000000000001	1.2	163.90000000000001	4	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27905	14004	0	0	0	226.40000000000001	893.20000000000005	2269	3313	4073	2874	319.19999999999999	26.800000000000001	9	0.40000000000000002	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27904	24492.099999999999	0	0	0	755.79999999999995	2570.4000000000001	4270.3999999999996	4108.1999999999998	4370	4878	2948.4000000000001	470.5	110.2	10.199999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27903	38602.800000000003	0	0	0	1105.4000000000001	1941.8	3488	4798.8000000000002	6895	6846.1999999999998	9155.6000000000004	3620	722.79999999999995	29.199999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27902	10704	0	0	132.19999999999999	212.80000000000001	784	951.60000000000002	1128.4000000000001	1287	1106.5999999999999	2975	1738	380	8	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27901	6163	0	0	0	74.599999999999994	407.80000000000001	597	478.60000000000002	328	116.2	337	2275	1539	9.5999999999999996	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27535	10165.299999999999	0	0	0	109.2	559.60000000000002	1169.2	1335.5999999999999	2347.5999999999999	2435.8000000000002	1672.0999999999999	435	99.400000000000006	1.3999999999999999	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27534	40212.5	0	0	47.600000000000001	1432.4000000000001	3293.5999999999999	3888.6999999999998	4305.8999999999996	7245	10590.4	6349.3999999999996	1871	1177.9000000000001	8.4000000000000004	2.2000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27533	9520.3999999999996	0	0	0	83.200000000000003	357.60000000000002	416.39999999999998	620.60000000000002	1191.8	1469.5	2141.8000000000002	1855.3	1371.4000000000001	10.800000000000001	2	\N	\N	\N	\N	\N	\N	\N	0	\N
27532	11477.4	0	0	0	54	310	895.20000000000005	1581.5999999999999	2280.8000000000002	743.39999999999998	384.19999999999999	1176.8	4036.8000000000002	14.6	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27531	4632	0	0	0	0	0	3.2000000000000002	1.6000000000000001	2	3.3999999999999999	13.4	645.39999999999998	3950.8000000000002	12.199999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24621	14571.799999999999	0	0	0	3.3999999999999999	81.200000000000003	415.80000000000001	762.79999999999995	1771.2	3178.8000000000002	5267	2135.4000000000001	951.39999999999998	4.4000000000000004	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
24622	7777	0	0	0	0	82.799999999999997	197.40000000000001	238.59999999999999	620.20000000000005	2176.1999999999998	3322.1999999999998	776.20000000000005	360.80000000000001	2.3999999999999999	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24623	1696	0	0	0	0	23	110	147.80000000000001	293.19999999999999	420.19999999999999	314	202.59999999999999	183.80000000000001	1.3999999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24624	17891.400000000001	0	0	0	5.7999999999999998	191.59999999999999	603.20000000000005	1104.5999999999999	2264.4000000000001	1733.8	1781.8	5533.8000000000002	4660.1999999999998	12	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24625	1292.8	0	0	0	16.600000000000001	123.8	209.80000000000001	180	114	28.800000000000001	19.199999999999999	53.399999999999999	542.20000000000005	5	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24610	8805.1000000000004	0	0	0	90.840000000000003	170.11000000000001	211.40000000000001	286.26999999999998	1039	3993	2775	209.75	28.079999999999998	1.6499999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24609	785.60000000000002	0	0	0	0	20.699999999999999	50.100000000000001	67.099999999999994	85.200000000000003	101.2	223.40000000000001	171.40000000000001	66.400000000000006	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24608	6386.9700000000003	0	0	0	0	489.38	354.49000000000001	272.33999999999997	412.02999999999997	942.29999999999995	1750	1148	1013	5.1100000000000003	0.32000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24607	17511.400000000001	0	0	0	0	1596	2102	1867	2514	1566	1461	2233	4154	17.52	0.88	\N	\N	\N	\N	\N	\N	\N	0	\N
24606	1518.8	0	0	0	0	0	2.79	1.52	3.5499999999999998	4.5599999999999996	31.649999999999999	228.91999999999999	1241	4.5599999999999996	0.25	\N	\N	\N	\N	\N	\N	\N	0	\N
24604	14476.129999999999	0	0	0	395.14999999999998	1185	1676	2220	4018	3627	1180	145.43000000000001	28.390000000000001	1.1599999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24605	41332.269999999997	0	0	0	880	1810	2767	4135	8102	13530	7892	1644	564	8.2699999999999996	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24603	30485.439999999999	0	0	0	375.66000000000003	1154	1206	1473	3696	9858	8856	2612	1248	6.7800000000000002	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24602	13909.83	0	0	0	202.88999999999999	431.14999999999998	734.20000000000005	931.60000000000002	1731	2617	3296	2238	1715	12.99	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24601	8107.6899999999996	0	0	0	0	106.55	52.770000000000003	43.640000000000001	11.16	3.04	31.460000000000001	390.69	7442	26.379999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
25905	570.79999999999995	0	0	0	0	0	2	6.7000000000000002	24.800000000000001	152.09999999999999	259.80000000000001	102.8	22.5	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
25904	693.79999999999995	0	0	0	0	2.2999999999999998	9.1999999999999993	54.200000000000003	169.90000000000001	235.59999999999999	122.7	69.400000000000006	29.899999999999999	0.5	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
25903	644.75	0	0	0	29.399999999999999	123.3	66.700000000000003	45.100000000000001	31.699999999999999	26.5	45.799999999999997	127.7	146.09999999999999	1.6000000000000001	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
25902	428.19999999999999	0	0	0	0	3.3999999999999999	4.2999999999999998	4	4.2999999999999998	6.2999999999999998	20.199999999999999	99.799999999999997	282.69999999999999	2.2000000000000002	0.90000000000000002	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
25901	54.700000000000003	0	0	0	0	0	3.3999999999999999	3.7000000000000002	1.7	2	3.2999999999999998	3.7999999999999998	33.799999999999997	2.7999999999999998	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.10000000000000001	\N
24030	305.60000000000002	0	0	0	0	0	0.69999999999999996	1.5	2.6000000000000001	23.199999999999999	154.59999999999999	108.90000000000001	14	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24029	379.85000000000002	0	0	0	0	0	10.800000000000001	19.5	58.600000000000001	116.90000000000001	88	49.049999999999997	36.700000000000003	0.27000000000000002	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24028	354	0	0	0	0	0	12.1	15.800000000000001	15.9	24.600000000000001	100.09999999999999	107.2	77.700000000000003	0.57999999999999996	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24027	289.39999999999998	0	0	0	0	0	5.5	3.5	2.3999999999999999	4.4000000000000004	21	62.200000000000003	185.90000000000001	4.4500000000000002	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
24026	195.09999999999999	0	0	0	0	0	64	29.899999999999999	8.5999999999999996	3.6000000000000001	3.2000000000000002	7.4000000000000004	76.599999999999994	1.78	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24005	398.75	0	0	0	0	1.8	7.7999999999999998	33	92.650000000000006	130.80000000000001	104.09999999999999	24.800000000000001	3.7000000000000002	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24004	463.94999999999999	0	0	0	0	0	5.9000000000000004	17.350000000000001	42.600000000000001	101	131.5	121.09999999999999	44.200000000000003	0.27000000000000002	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24003	322.44999999999999	0	0	0	0	0	2.2999999999999998	5.4500000000000002	8.4499999999999993	16.899999999999999	66	133.30000000000001	89.5	0.5	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24002	514.54999999999995	0	0	0	0	59	31.300000000000001	48.5	33.700000000000003	21.800000000000001	32.200000000000003	62.649999999999999	223.69999999999999	1.6799999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24001	4.8200000000000003	0	0	0	0	0	0	0.40000000000000002	0.20000000000000001	0.20000000000000001	0.29999999999999999	0.29999999999999999	3.1499999999999999	0.22	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
25909	248.59999999999999	0	0	0	0	0	1.3999999999999999	2	6.2000000000000002	36.5	94.099999999999994	68.799999999999997	39.399999999999999	0.17000000000000001	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
25908	244.40000000000001	0	0	0	0	0	0.90000000000000002	4.9000000000000004	12.9	82.400000000000006	107	32.200000000000003	4	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
25907	339.80000000000001	0	0	0	0	2.3999999999999999	8.6999999999999993	26.300000000000001	37.299999999999997	91.299999999999997	116.59999999999999	36.299999999999997	20.399999999999999	0.40000000000000002	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
25906	242.59999999999999	0	0	0	0	0	1.7	7.4000000000000004	7.7999999999999998	4.2999999999999998	15.6	61.399999999999999	143.30000000000001	1.05	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23745	777.14999999999998	0	0	0	0	3.2999999999999998	22.800000000000001	102.5	222.59999999999999	194.30000000000001	112	72.200000000000003	47.399999999999999	0.029999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23744	474.82999999999998	0	0	0	0	23.300000000000001	17.699999999999999	48.700000000000003	80.200000000000003	122.5	126.09999999999999	40.799999999999997	12.800000000000001	2.7000000000000002	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23743	428.89999999999998	0	0	0	0	5	18.699999999999999	30.100000000000001	67.5	68	71.299999999999997	85	81.5	1.75	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23742	192	0	0	0	0	2.5	2.2000000000000002	4.7999999999999998	11.1	7	10.050000000000001	50	102.40000000000001	1.8999999999999999	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23741	27.899999999999999	0	0	0	0	0	0	0	2.3999999999999999	0.94999999999999996	21.399999999999999	1.1499999999999999	0.94999999999999996	1	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23725	717.20000000000005	0	0	0	0	42.25	49.5	106.84999999999999	205.30000000000001	237.30000000000001	68	6.5	1.45	0.040000000000000001	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23724	774.75	0	0	0	15.6	35.399999999999999	33.600000000000001	43.700000000000003	115.65000000000001	340.5	168.90000000000001	17.800000000000001	3.5	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23723	629.10000000000002	0	0	0	9	21.100000000000001	32.299999999999997	42.600000000000001	94.400000000000006	170	154.69999999999999	49.600000000000001	54.799999999999997	0.56999999999999995	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23722	749.60000000000002	0	0	0	17.199999999999999	30.699999999999999	33.200000000000003	41.299999999999997	66.400000000000006	111.3	177.90000000000001	115.8	154.80000000000001	0.96999999999999997	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23721	302.5	0	0	0	0	51.600000000000001	35.5	33.399999999999999	15.1	9.8000000000000007	23.100000000000001	38.399999999999999	95.150000000000006	0.42999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23945	1010.3	0	0	0	53.200000000000003	168.84999999999999	229.09999999999999	276.30000000000001	203.40000000000001	68.549999999999997	9.25	1.3500000000000001	0.25	0.029999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23944	1352.2	0	0	0	54.700000000000003	83	112.40000000000001	181.30000000000001	258.30000000000001	364.35000000000002	211.84999999999999	64.299999999999997	21.300000000000001	0.59999999999999998	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23943	1134.55	0	0	0	54.399999999999999	41.600000000000001	56.049999999999997	114	192.19999999999999	220.40000000000001	203.19999999999999	108.40000000000001	142.90000000000001	1.3	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23942	931.64999999999998	0	0	0	59.799999999999997	83.599999999999994	143.19999999999999	207.65000000000001	157.80000000000001	44.700000000000003	33	48.5	151.40000000000001	1.8999999999999999	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23941	284.10000000000002	0	0	0	0	0	5.9000000000000004	14.6	18.600000000000001	13.85	2.8999999999999999	2.8500000000000001	214.5	10.75	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23705	509.10000000000002	0	0	0	0	5.7000000000000002	23.949999999999999	57.299999999999997	77.799999999999997	150.80000000000001	134.44999999999999	42.5	16.5	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23704	461.89999999999998	0	0	0	0	10.9	10.300000000000001	28.800000000000001	57.799999999999997	80.400000000000006	83.099999999999994	109.8	80.299999999999997	0.40000000000000002	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23703	442.75	0	0	0	0	0	8.0999999999999996	33.100000000000001	66.599999999999994	71.799999999999997	75.049999999999997	111.40000000000001	75.799999999999997	0.88	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23702	417.44999999999999	0	0	0	0	0	4.9000000000000004	17.899999999999999	19.5	13.15	26.649999999999999	71.349999999999994	261.10000000000002	2.8799999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23701	31.050000000000001	0	0	0	0	1.8500000000000001	2.9500000000000002	4.4000000000000004	2.75	1.1000000000000001	1.1000000000000001	1.8999999999999999	14.6	0.38	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
37396	2318.4000000000001	0	0	0	8	12	56.600000000000001	137.80000000000001	161.59999999999999	459.39999999999998	467.19999999999999	442	567.39999999999998	5.5999999999999996	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0	\N
37395	3444	0	0	0	0	0	0.80000000000000004	1.2	39.200000000000003	1259.5999999999999	1603	387.60000000000002	151.59999999999999	0.59999999999999998	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
37398	113.18000000000001	0	0	0	0	3.2999999999999998	3.7000000000000002	9.5999999999999996	24.5	37.799999999999997	19.399999999999999	9.3000000000000007	5.4000000000000004	0.10000000000000001	0.080000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
37397	4555.1000000000004	0	0	0	1.6000000000000001	24.899999999999999	77.200000000000003	248.19999999999999	636.39999999999998	1046.5999999999999	1088.8	674	753.20000000000005	3.7999999999999998	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
37394	18.399999999999999	0	0	0	2.5	1.8999999999999999	3.5	5.0999999999999996	2.5	1.3	0.59999999999999998	0.40000000000000002	0.5	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37401	4141.6000000000004	0	0	0	0	6.7999999999999998	40.799999999999997	118.59999999999999	764.79999999999995	1624.4000000000001	787.79999999999995	369.89999999999998	423.89999999999998	4.4000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37400	2784.9000000000001	0	0	0	0	28.300000000000001	18.199999999999999	31.100000000000001	399.39999999999998	1405.7	603	216.69999999999999	81.799999999999997	0.59999999999999998	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37399	0.96999999999999997	0	0	0	0	0	0	0.089999999999999997	0.14999999999999999	0.20000000000000001	0.20000000000000001	0.089999999999999997	0.14999999999999999	0.089999999999999997	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37403	4884.6000000000004	0	0	0	20.600000000000001	163.40000000000001	157.90000000000001	202.59999999999999	568.20000000000005	1566.8	1315	514.39999999999998	374.39999999999998	1.2	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37402	4196.6000000000004	0	0	0	18.199999999999999	28	55.799999999999997	85.599999999999994	261.80000000000001	1037	1068.2	713.79999999999995	920.20000000000005	7.5999999999999996	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
37410	471.60000000000002	0	0	0	51.5	174	124.40000000000001	62	39.100000000000001	13.4	2.2999999999999998	1.7	2.5	0.5	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37409	979	0	0	0	0	30.300000000000001	91.099999999999994	96.799999999999997	157	248.69999999999999	127	84.299999999999997	140	3.6000000000000001	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37416	1988.9000000000001	0	0	0	67.599999999999994	197	278.19999999999999	260	304.39999999999998	287.19999999999999	377.19999999999999	136.59999999999999	78.400000000000006	2.2999999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37415	1544.9000000000001	0	0	0	71.299999999999997	135.09999999999999	167.5	337.19999999999999	181.90000000000001	142.80000000000001	195.69999999999999	306.30000000000001	2.1000000000000001	0.40000000000000002	4.5999999999999996	\N	\N	\N	\N	\N	\N	\N	0	\N
37412	13848.6	0	0	227.19999999999999	2253	1858.7	1457.7	1657	2457.0999999999999	1998.3	958.39999999999998	490.19999999999999	473.80000000000001	15.800000000000001	1.3999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
37411	3081.6999999999998	0	267.30000000000001	94.5	279.69999999999999	350	307.69999999999999	447	726	394.10000000000002	116.3	57.299999999999997	40.5	1.3	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37418	7528.1000000000004	0	0	0	9.4000000000000004	106.59999999999999	155.80000000000001	325	1677.2	4056.5	1113	68.799999999999997	13.800000000000001	1.6000000000000001	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
37417	6064.5	0	0	67.400000000000006	275.60000000000002	387.80000000000001	531.39999999999998	1106.8	1731.5999999999999	1619.8	257.39999999999998	83.400000000000006	3	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37421	4242	0	0	0	8	82	170.80000000000001	450.80000000000001	988.39999999999998	623.60000000000002	988.39999999999998	658	268.19999999999999	3.7999999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37420	284.30000000000001	0	0	0	4.0999999999999996	30.100000000000001	33.299999999999997	41.700000000000003	55.700000000000003	31.399999999999999	6.5	12.199999999999999	69	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37419	279.19999999999999	0	0	0	76	78.599999999999994	49.600000000000001	27.100000000000001	23	13.9	4.7999999999999998	2.1000000000000001	4.0999999999999996	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37426	1508.9000000000001	0	0	0	0	7.7000000000000002	17.199999999999999	48.100000000000001	64.099999999999994	119.59999999999999	226.30000000000001	339	671.39999999999998	14.300000000000001	1.2	\N	\N	\N	\N	\N	\N	\N	0	\N
37425	1133.5	0	0	0	0	0	5.5	13	56.200000000000003	318.80000000000001	578.39999999999998	83.900000000000006	61.600000000000001	14.699999999999999	1.3999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
37423	10186.6	0	0	0	20	46.799999999999997	114.59999999999999	296.19999999999999	1842.8	6474.8000000000002	1275.2	90.799999999999997	22.600000000000001	2.6000000000000001	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37422	1823.5	0	0	0	0	47.299999999999997	60.299999999999997	94.099999999999994	253.5	885	420.60000000000002	44.899999999999999	17.100000000000001	0.69999999999999996	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37424	141	0	0	0	0	30.399999999999999	36.299999999999997	34.399999999999999	27.100000000000001	9.9000000000000004	0.90000000000000002	0.29999999999999999	0.69999999999999996	0.59999999999999998	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
37428	3168.8000000000002	0	0	0	0	49	16.399999999999999	53.399999999999999	306	1009.1	899.10000000000002	475.80000000000001	340.69999999999999	16.699999999999999	2.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37427	1910.5999999999999	0	0	0	0	13.1	41.399999999999999	148.30000000000001	278.5	422.19999999999999	394.39999999999998	374.19999999999999	217	11	10.5	\N	\N	\N	\N	\N	\N	\N	0	\N
37431	4891.6999999999998	0	0	11.800000000000001	686	729.89999999999998	745.39999999999998	745.89999999999998	799.10000000000002	466	134	128.80000000000001	437	7.4000000000000004	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
37430	5785.1000000000004	0	0	0	380.19999999999999	1045.2	1139.8	1015.2	941.79999999999995	708.39999999999998	308.89999999999998	72.599999999999994	169.40000000000001	3.3999999999999999	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
37429	165.90000000000001	0	0	0	0	19.399999999999999	87.700000000000003	23	21.300000000000001	10.5	1.8	0.69999999999999996	1.3999999999999999	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
37433	6655.6000000000004	0	0	0	750.60000000000002	505	469.80000000000001	494.60000000000002	1343	1657.5999999999999	650.79999999999995	332	445.19999999999999	6.4000000000000004	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
37432	1545.8	0	0	65.400000000000006	62.200000000000003	214.40000000000001	224.19999999999999	211.19999999999999	293.80000000000001	239.59999999999999	74	48.799999999999997	110	2	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34858	583.60000000000002	0	0	0	106.09999999999999	189.30000000000001	181.90000000000001	67.5	27.5	9.6999999999999993	1	0.29999999999999999	0.29999999999999999	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34853	3724.5	0	0	0	0	5	19.199999999999999	18	111.2	845.60000000000002	1446.2	624.79999999999995	645.60000000000002	8.5999999999999996	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
34852	11724.9	0	0	0	176	555	469.60000000000002	293	666.5	3150.8000000000002	3384.8000000000002	1673.2	1347.8	7.5999999999999996	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
34851	14163	0	0	0	110.2	257	580.79999999999995	1570.8	4049	3563.5999999999999	1799	1032.2	1192.2	7.4000000000000004	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0	\N
34850	16960.799999999999	0	0	0	102	366	723.39999999999998	1383.5999999999999	3753.8000000000002	6225.3999999999996	3064.1999999999998	886.79999999999995	450	5	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
34746	11326.299999999999	0	0	0	0	22.199999999999999	145.59999999999999	530	1973.9000000000001	3048	2555	1456.8	1567.4000000000001	26.600000000000001	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0	\N
34747	3106.8000000000002	0	0	0	0	4.2999999999999998	15	26.399999999999999	114.09999999999999	654.29999999999995	1024	698.29999999999995	565.10000000000002	4.2000000000000002	1.1000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34748	5502.5	0	0	0	0	17	157	499.39999999999998	1289.5	1696.7	941.60000000000002	529	362.89999999999998	9	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
34749	8925.6000000000004	0	0	0	0	17.800000000000001	131.40000000000001	328.60000000000002	1444.8	3547.8000000000002	2252.5999999999999	834.39999999999998	360.19999999999999	7.7999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34750	707.10000000000002	0	0	0	18.899999999999999	115.5	199.09999999999999	265.30000000000001	95.299999999999997	2.2000000000000002	1.1000000000000001	2.8999999999999999	6.7000000000000002	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29929	7853.3999999999996	0	0	0	0	7.4000000000000004	19.199999999999999	63.600000000000001	335.60000000000002	1514.8	2410.8000000000002	1824.2	1667.2	10.199999999999999	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
29930	9309.6000000000004	0	0	0	0	49.399999999999999	92.799999999999997	112.40000000000001	266.80000000000001	1154	2864.1999999999998	2280.8000000000002	2466.1999999999998	22	1	\N	\N	\N	\N	\N	\N	\N	0	\N
29931	6993.5	0	0	0	0	9.4000000000000004	51.399999999999999	133.80000000000001	583.60000000000002	1881.4000000000001	2493.5999999999999	950.39999999999998	878	11.800000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29932	18278.799999999999	0	0	0	72.400000000000006	303	1034.8	3494.5999999999999	6364.1999999999998	5198.1999999999998	1588.2	174.80000000000001	46.399999999999999	1.8	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
29933	4806.8000000000002	0	0	0	181.80000000000001	783	1230.8	1271.4000000000001	977.79999999999995	335.39999999999998	24.800000000000001	1	0.59999999999999998	0.10000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29924	2657.9000000000001	0	0	0	0	4.4000000000000004	0	4	10.199999999999999	148.5	715.39999999999998	755.60000000000002	1007.8	11.4	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
29925	8826.2000000000007	0	0	0	0	40.200000000000003	97.400000000000006	268.10000000000002	1440.7	3104	2165	945.10000000000002	751.10000000000002	13.4	1.2	\N	\N	\N	\N	\N	\N	\N	0	\N
29926	31939	0	0	0	2.6000000000000001	84.799999999999997	353.39999999999998	824.10000000000002	4789	11727.4	8406.6000000000004	3099.4000000000001	2619	30	2.7000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
29927	3514.8000000000002	0	0	0	16	31.800000000000001	89	220.40000000000001	709	1008.1	679.10000000000002	323.80000000000001	435.69999999999999	1.6000000000000001	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
29928	6326.1999999999998	0	0	0	0	82.799999999999997	409	1090.2	2534.8000000000002	1603.9000000000001	318.60000000000002	142.59999999999999	143.59999999999999	0.69999999999999996	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27612	4594.8000000000002	0	0	0	0	0	0	7.2000000000000002	77.799999999999997	749.39999999999998	1868	1019.4	865.60000000000002	7.2000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27613	5265	0	0	0	0	6.2000000000000002	29.600000000000001	110.8	693.39999999999998	1872.4000000000001	1506	572.20000000000005	470.39999999999998	3.7999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27614	7522.3999999999996	0	0	0	0	17	87	260.39999999999998	1369.5999999999999	2588.4000000000001	1879.5999999999999	704.39999999999998	609.20000000000005	6.4000000000000004	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27615	8663.8999999999996	0	0	0	9.4000000000000004	12.199999999999999	105.40000000000001	337.39999999999998	1615	2989.5999999999999	2077.5999999999999	872.39999999999998	638.60000000000002	6	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
34406	8914.1000000000004	0	0	0	0	0	15	20.600000000000001	154.80000000000001	1013.4	2376	2464.1999999999998	2858.5999999999999	11.199999999999999	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
34405	7406.1000000000004	0	0	0	0	40.200000000000003	51.200000000000003	79.200000000000003	391.80000000000001	1606	2462.5	1457.4000000000001	1305.8	11.800000000000001	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34404	9435	0	0	0	0	48	84.799999999999997	271.60000000000002	1505	3327.5999999999999	2728.8000000000002	988.20000000000005	476.60000000000002	4.2000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34403	15682.9	0	0	0	21.199999999999999	253	838.60000000000002	1918.5999999999999	6123.3999999999996	5310.6000000000004	1053.4000000000001	126.8	34.799999999999997	2	0.5	\N	\N	\N	\N	\N	\N	\N	0	\N
34402	58.299999999999997	0	0	0	15.9	20.399999999999999	12.1	3.1000000000000001	3.1000000000000001	1.1000000000000001	0.29999999999999999	0.20000000000000001	1.3	0.59999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27606	13383.299999999999	0	0	0	0	0	37.399999999999999	43.299999999999997	116.8	645.79999999999995	2903.8000000000002	4168	5429	37	2.2000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27604	32625.299999999999	0	0	0	56	126.8	327	1638	7286.6000000000004	11161	7677.6000000000004	3411.5999999999999	930.79999999999995	9.9000000000000004	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27603	49255.800000000003	0	0	0	6	161	327.19999999999999	767	4461.1999999999998	17072.799999999999	16960	5875.6000000000004	3572.8000000000002	52.200000000000003	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27602	20914.400000000001	0	0	0	48.399999999999999	205.19999999999999	585.39999999999998	2001	7403.8000000000002	7363	2603.8000000000002	387.19999999999999	313.80000000000001	2.7999999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27601	5240	0	0	0	690.39999999999998	1782	1375	889	444.19999999999999	48	2.2000000000000002	0.20000000000000001	7	2	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27595	12617.6	0	0	0	0	5.5999999999999996	15.6	27.600000000000001	222.19999999999999	2255.4000000000001	5863.1999999999998	2496.8000000000002	1698.2	33	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27594	13179.4	0	0	0	0	7	46.399999999999999	54	310.19999999999999	2617	6312	2331.4000000000001	1460.2	41.200000000000003	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27593	10535.5	0	0	0	0	9.1999999999999993	78.200000000000003	143	748.79999999999995	2867.1999999999998	3571.4000000000001	1644.0999999999999	1452.2	21.399999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27592	31151.200000000001	0	0	0	58.200000000000003	129.59999999999999	686.39999999999998	2287.1999999999998	9177.2000000000007	11728.200000000001	4791.3999999999996	1392.4000000000001	896.60000000000002	3.2000000000000002	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0	\N
27590	1959.3	0	0	0	0	0	0	11.6	118.7	722.60000000000002	663.20000000000005	307	133.30000000000001	2.7999999999999998	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27587	12488.4	0	0	0	0	15.800000000000001	59.600000000000001	81.799999999999997	526	4068	4995	1642.8	1088.2	11	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27589	8929.7999999999993	0	0	0	0	4	38	139	727.79999999999995	2507	3574.1999999999998	1154	764.60000000000002	20.800000000000001	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27588	9646.5	0	0	0	12.199999999999999	8.8000000000000007	65.799999999999997	283.89999999999998	1730	4026.5999999999999	2234.4000000000001	739.39999999999998	540.60000000000002	4.4000000000000004	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
24721	13423.200000000001	0	0	0	0	0	6	8	106.59999999999999	2115	5826.6000000000004	3066.8000000000002	2285.5999999999999	8.1999999999999993	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
24722	1037	0	0	0	0	2.6000000000000001	2.7999999999999998	3.7999999999999998	51.200000000000003	236.40000000000001	347.39999999999998	160	228.80000000000001	3.7999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24724	768.79999999999995	0	0	0	0	0	2.6000000000000001	8.1999999999999993	55.200000000000003	102.2	150.19999999999999	145	298.39999999999998	7	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24725	7217.1999999999998	0	0	0	0	18.600000000000001	132.80000000000001	403.80000000000001	1556.5999999999999	2134.1999999999998	1616	766.39999999999998	588.79999999999995	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24705	13686.92	0	0	0	0	0	32.509999999999998	51.32	213.84999999999999	1442	3882	3846	4197	20.530000000000001	1.71	\N	\N	\N	\N	\N	\N	\N	0	\N
24704	4970	0	0	0	0	0	26.219999999999999	63.670000000000002	297.11000000000001	1002	1454	1172	939.39999999999998	14.98	0.62	\N	\N	\N	\N	\N	\N	\N	0	\N
24703	14125.459999999999	0	0	0	0	0	83.290000000000006	315.44999999999999	1161	3621	5136	2462	1329	15.949999999999999	1.77	\N	\N	\N	\N	\N	\N	\N	0	\N
24702	13906.82	0	0	0	0	0	55.630000000000003	227.72999999999999	2197	7446	3525	365.06	86.920000000000002	3.48	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24701	58.200000000000003	0	0	0	28.100000000000001	8.5999999999999996	8.6999999999999993	4.4000000000000004	6.7000000000000002	1.3	0	0	0.40000000000000002	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24685	10583.48	0	0	0	0	0	42.5	29.219999999999999	88.980000000000004	669.29999999999995	2636	2857	4214	46.479999999999997	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24684	19851.52	0	0	0	0	21.859999999999999	155	176.84999999999999	741.20000000000005	3561	5882	4292	4962	59.609999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24683	7540.3299999999999	0	0	0	0	17.399999999999999	74.129999999999995	165.65000000000001	618.70000000000005	1554	1909	1529	1649	22.690000000000001	0.76000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24682	21409.75	0	0	0	95.319999999999993	283.37	672.39999999999998	1553	5932	8276	3502	857.79999999999995	233.56999999999999	4.29	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24090	286.05000000000001	0	0	0	0	0	0.55000000000000004	5.5	35.399999999999999	77.700000000000003	74	37.600000000000001	55.200000000000003	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24089	266.30000000000001	0	0	0	0	0	2.7000000000000002	3.2000000000000002	15.9	42	58.299999999999997	71.599999999999994	72.200000000000003	0.38	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24088	546.29999999999995	0	0	0	0	23.600000000000001	17.199999999999999	57.399999999999999	143.90000000000001	158.19999999999999	78.799999999999997	37.200000000000003	29.699999999999999	0.27000000000000002	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24087	465.64999999999998	0	0	0	0	8.3000000000000007	37.600000000000001	91	158.19999999999999	134.80000000000001	29.800000000000001	4.7999999999999998	1.1200000000000001	0.01	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24086	2.8999999999999999	0	0	0	0	0	0	0	0.20000000000000001	1.5	0.5	0.29999999999999999	0.29999999999999999	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24085	418.10000000000002	0	0	0	0	0	3.75	18.949999999999999	75.700000000000003	118.09999999999999	87.099999999999994	47.600000000000001	66.299999999999997	0.56999999999999995	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24084	310.30000000000001	0	0	0	0	0	3.2000000000000002	8.8000000000000007	25.100000000000001	52.100000000000001	69.599999999999994	77.200000000000003	74.099999999999994	0.17000000000000001	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
24083	497.10000000000002	0	0	0	0	1.5	19.850000000000001	57.799999999999997	154.55000000000001	140.19999999999999	57.600000000000001	33.100000000000001	32	0.40000000000000002	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
24082	546.20000000000005	0	0	0	0	22	36.399999999999999	84.700000000000003	136.59999999999999	152.30000000000001	83.400000000000006	21.800000000000001	8.6999999999999993	0.14999999999999999	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
24081	194.94999999999999	0	0	0	24.25	87	33.350000000000001	37.75	11.6	0.5	0.10000000000000001	0.050000000000000003	0.10000000000000001	0.10000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
34864	6210.8999999999996	0	0	0	10.6	3.7999999999999998	49.399999999999999	211.40000000000001	1074	2090.3000000000002	1606.2	678.10000000000002	483.30000000000001	3.2000000000000002	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
34865	888.10000000000002	0	0	0	0	5.7999999999999998	11.9	15.5	31	239.69999999999999	270.5	218.80000000000001	94.099999999999994	0.80000000000000004	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34866	8079	0	0	0	70	159.09999999999999	194.09999999999999	361.89999999999998	1519.2	3271.3000000000002	1459.4000000000001	530.29999999999995	509.69999999999999	3.7999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34867	32374.400000000001	0	0	0	274	703.60000000000002	1429.8	3441.5999999999999	9179.3999999999996	10312.799999999999	4462	1434	1129	7.5999999999999996	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
34868	8101.3999999999996	0	0	0	111	542.39999999999998	1017.6	1514	2318.8000000000002	1657.5999999999999	576.60000000000002	227.40000000000001	134.19999999999999	1.8	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34859	11889.799999999999	0	0	0	0	96.599999999999994	181.80000000000001	443.60000000000002	1641.5999999999999	2954.8000000000002	3096	2273.5999999999999	1195.8	5.5999999999999996	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
34860	2814.1999999999998	0	0	0	37.600000000000001	86.200000000000003	155	270	444.60000000000002	682	559.20000000000005	310.19999999999999	266.39999999999998	2.7999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34861	22711.700000000001	0	0	0	18.399999999999999	278.80000000000001	630.79999999999995	1520	5454.1999999999998	7004.8000000000002	3996.8000000000002	1832.5999999999999	1948	25.399999999999999	1.8999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
34862	298.5	0	0	0	0	0	5.4000000000000004	13.6	40.799999999999997	72	46.200000000000003	37	82.400000000000006	1	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34863	25925.299999999999	0	0	0	407.39999999999998	942.79999999999995	1799.4000000000001	3850	6427	5024.8000000000002	2428.4000000000001	2473.4000000000001	2561.8000000000002	9.4000000000000004	0.90000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
34751	12559.6	0	0	0	0	30.300000000000001	176.19999999999999	545.20000000000005	2295.4000000000001	3699.8000000000002	2774	1364.2	1636.4000000000001	37.399999999999999	0.69999999999999996	\N	\N	\N	\N	\N	\N	\N	0	\N
34752	13829.5	0	0	0	0	115.40000000000001	549.20000000000005	1247.2	2778	3131.4000000000001	3318	1903.8	781.79999999999995	4.5999999999999996	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34753	18329.400000000001	0	0	0	40.399999999999999	116.2	381.30000000000001	1121.8	4583.6000000000004	6708.6000000000004	3399.5999999999999	1225.8	742.79999999999995	8.8000000000000007	0.5	\N	\N	\N	\N	\N	\N	\N	0	\N
34754	11756.5	0	0	0	0	332	897.20000000000005	2345.8000000000002	3561.1999999999998	2644.4000000000001	1081.4000000000001	497.60000000000002	390.80000000000001	5.5999999999999996	0.5	\N	\N	\N	\N	\N	\N	\N	0	\N
34755	10498.700000000001	0	0	0	118.59999999999999	892.29999999999995	1717	2353.1999999999998	1496.4000000000001	773.60000000000002	698	1418.4000000000001	1027.5999999999999	3	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
29939	7401.5	0	0	0	0	10.300000000000001	9.5999999999999996	69.200000000000003	217.80000000000001	717.39999999999998	1581.5999999999999	2142.5999999999999	1427.5999999999999	1219.2	6.2000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
29940	6278	0	0	0	0	48.399999999999999	219.80000000000001	418.19999999999999	1085	1730.8	1299.5999999999999	585.39999999999998	881.20000000000005	9.1999999999999993	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
29941	1296	0	0	0	0	2.6000000000000001	13	47	277.80000000000001	443.60000000000002	227.30000000000001	127.09999999999999	154.59999999999999	2.7000000000000002	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
29942	516.20000000000005	0	0	0	0	66.799999999999997	49.600000000000001	39.100000000000001	91	111	79.5	45.799999999999997	32.700000000000003	0.5	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29943	349.30000000000001	0	0	0	0	17.300000000000001	40.600000000000001	61.600000000000001	123.90000000000001	77	20.5	5.7000000000000002	2.2000000000000002	0.40000000000000002	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29934	9846	0	0	0	0	46	121.2	229.80000000000001	559	1221	1817	2391	3400.8000000000002	58.600000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29935	4622.6000000000004	0	0	0	0	37	131	288.60000000000002	688	1226	1115.4000000000001	636.79999999999995	357.39999999999998	141.80000000000001	0.59999999999999998	\N	\N	\N	\N	\N	\N	\N	0	\N
29936	11592.799999999999	0	0	0	0	56.200000000000003	140.19999999999999	404.80000000000001	2377.1999999999998	4801.1999999999998	2262.4000000000001	890.79999999999995	634	24	2	\N	\N	\N	\N	\N	\N	\N	0	\N
29937	14973.299999999999	0	0	0	47	377.19999999999999	866.20000000000005	2007.5999999999999	4299.6000000000004	4205.6000000000004	1628.5999999999999	735.39999999999998	778.60000000000002	26.600000000000001	0.90000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
29938	7672	0	0	0	201.19999999999999	773.5	1301.2	1772.2	1992	894	205	140	383.19999999999999	7.5	2.2000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27658	10415.1	0	0	0	0	38	154	600.79999999999995	2186	2870.5999999999999	2253.1999999999998	1077	1224.2	10.800000000000001	0.5	\N	\N	\N	\N	\N	\N	\N	0	\N
27659	6406	0	0	0	0	34.600000000000001	105	247	1012	1987	1548	762.20000000000005	702.20000000000005	7.7999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27660	13821.6	0	0	0	10.4	34.399999999999999	174.19999999999999	564.79999999999995	2788	4141.6000000000004	3310	1306	1471.5999999999999	19.800000000000001	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0	\N
27661	12747.799999999999	0	0	0	11.800000000000001	347.39999999999998	767.79999999999995	1420	3175.5	3743.4000000000001	1964	637.20000000000005	669.60000000000002	10.6	0.5	\N	\N	\N	\N	\N	\N	\N	0	\N
27662	164.5	0	0	0	0	16.399999999999999	30.300000000000001	43.100000000000001	37	21.800000000000001	7.4000000000000004	3.7000000000000002	4.5999999999999996	0.10000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27652	3731.4000000000001	0	0	0	0	40.799999999999997	120.8	203.59999999999999	381.39999999999998	700.20000000000005	646.79999999999995	403	1178.2	56.200000000000003	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0	\N
27651	7293.8000000000002	0	0	0	26.800000000000001	113	121.59999999999999	188	741.20000000000005	1869.2	2283	1113.5999999999999	836	1.2	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34790	222.19999999999999	0	0	0	48.799999999999997	45.5	34.700000000000003	24.100000000000001	33.600000000000001	29.800000000000001	2.3999999999999999	1.2	2	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34791	7641.1999999999998	0	0	67.400000000000006	264.89999999999998	248.30000000000001	309.19999999999999	439.19999999999999	1755.2	2939.4000000000001	952.60000000000002	387.39999999999998	274.39999999999998	3	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34792	110	0	0	0	0	9.1999999999999993	1.3999999999999999	8.0999999999999996	23	64.299999999999997	1.2	0.40000000000000002	2.3999999999999999	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34784	11.199999999999999	0	0	0	0	0	0	0.69999999999999996	2.1000000000000001	2.2000000000000002	1.8999999999999999	0.90000000000000002	2.2999999999999998	1.1000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34785	61.399999999999999	0	0	0	0	0	7.0999999999999996	15.300000000000001	9.3000000000000007	9.3000000000000007	12.1	4.5	1.8999999999999999	1.7	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34786	59.5	0	0	0	0	1	5.7000000000000002	5.4000000000000004	9.3000000000000007	17.699999999999999	7	5.7000000000000002	7.5999999999999996	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34713	1822.4000000000001	0	0	0	0	13.6	37.200000000000003	74	255	599.20000000000005	371.39999999999998	232.40000000000001	238	1.3999999999999999	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34714	41.600000000000001	0	0	0	0	4.0999999999999996	4.2999999999999998	2.7999999999999998	11	11.6	1.3999999999999999	1.3	3.1000000000000001	1.8	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
34715	16.199999999999999	0	0	0	0	0	1.3	1.7	3.6000000000000001	6.7000000000000002	0.80000000000000004	0.59999999999999998	1	0.29999999999999999	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
29825	472.19999999999999	0	0	0	9.8000000000000007	10.4	15.199999999999999	22.800000000000001	84.900000000000006	207.90000000000001	79.400000000000006	22.899999999999999	18.800000000000001	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29826	665.89999999999998	0	0	0	0	0	5.5	22.300000000000001	117.59999999999999	281.89999999999998	142.90000000000001	58.200000000000003	37.299999999999997	0.20000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29827	51.299999999999997	0	0	0	0	0	3	3.6000000000000001	14.300000000000001	23.100000000000001	4.7000000000000002	1.5	1	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29820	718.70000000000005	0	0	0	0	27.199999999999999	39.5	47.100000000000001	96.200000000000003	164.69999999999999	159.40000000000001	106.40000000000001	77.900000000000006	0.29999999999999999	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29821	3102.8000000000002	0	0	0	0	0	22	45.899999999999999	511.80000000000001	2027.2	382.5	68.5	43.600000000000001	1	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
29814	13.699999999999999	0	0	0	0	0	4.0999999999999996	1.3	4.2000000000000002	3.2000000000000002	0.29999999999999999	0.10000000000000001	0.29999999999999999	0.20000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29815	644.89999999999998	0	0	0	358.39999999999998	99.900000000000006	65	37.100000000000001	37.600000000000001	34.600000000000001	7.4000000000000004	2.7999999999999998	2	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29816	506.69999999999999	0	0	0	50.200000000000003	30.300000000000001	34.200000000000003	33.399999999999999	96.799999999999997	135.40000000000001	59.100000000000001	37.799999999999997	28.899999999999999	0.59999999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
29817	214.19999999999999	0	0	0	121	13.199999999999999	22.100000000000001	10.4	20.399999999999999	21.800000000000001	1.5	1	2.7000000000000002	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27388	50.299999999999997	0	0	0	0	0	0	0.40000000000000002	1.3999999999999999	6.7999999999999998	10.800000000000001	10.300000000000001	20.199999999999999	0.29999999999999999	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27389	164.19999999999999	0	0	0	0	0	4.9000000000000004	7	35.299999999999997	52.5	34.200000000000003	18.300000000000001	11.699999999999999	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27390	5.5999999999999996	0	0	0	0	0	0	0	0.59999999999999998	1.7	1.1000000000000001	1	1	0.10000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27383	42.700000000000003	0	0	0	0	0	0	0	0.5	2.7999999999999998	13.199999999999999	14.199999999999999	11.699999999999999	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27384	15.199999999999999	0	0	0	0	0	0	0	0.20000000000000001	1.3999999999999999	4	4.0999999999999996	5.2999999999999998	0.20000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27380	110.3	0	0	56.899999999999999	0.20000000000000001	7.4000000000000004	14	10.300000000000001	13.300000000000001	6.4000000000000004	0.59999999999999998	0.40000000000000002	0.5	0.20000000000000001	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27378	1053.8	0	0	0	14.5	5	26.800000000000001	79.900000000000006	349.89999999999998	376.5	95.400000000000006	54.700000000000003	50.100000000000001	0.90000000000000002	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27377	13062.1	0	0	0	441.60000000000002	794.79999999999995	984.60000000000002	1325.4000000000001	3121.5999999999999	3387.5999999999999	1809.4000000000001	706.79999999999995	489	1	0.29999999999999999	\N	\N	\N	\N	\N	\N	\N	0	\N
27375	21.699999999999999	0	0	0	0	0	5.7000000000000002	3.6000000000000001	7	3.7000000000000002	0.59999999999999998	0.40000000000000002	0.59999999999999998	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27374	348	0	0	0	42.799999999999997	52.299999999999997	39.799999999999997	44.399999999999999	72.900000000000006	64.299999999999997	12	7.2999999999999998	11.5	0.5	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27373	1255.7	0	0	0	15.199999999999999	25.399999999999999	68.099999999999994	99	261.5	360.69999999999999	175.09999999999999	132.5	117.5	0.59999999999999998	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27372	80.200000000000003	0	0	0	0	25	5.5	13.6	16.100000000000001	14.5	1.6000000000000001	1.5	2	0.29999999999999999	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27371	2	0	0	0	0	0	0	0	0	0	0	0	0.40000000000000002	1.5	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
27369	9	0	0	0	0	0	0	0	1.1000000000000001	3.7000000000000002	2.5	1	0.69999999999999996	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27368	57.899999999999999	0	0	0	0	0	0	1.1000000000000001	2.5	10.199999999999999	11.9	14.1	18	0.10000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27367	3622.1999999999998	0	0	0	0	11.800000000000001	36	90.599999999999994	248.59999999999999	789.20000000000005	1518.2	540.60000000000002	384.39999999999998	2.7999999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
27366	48.5	0	0	0	23.100000000000001	3.2000000000000002	10.1	3.7000000000000002	4.9000000000000004	3.1000000000000001	0.20000000000000001	0.10000000000000001	0.10000000000000001	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24481	80.799999999999997	0	0	0	11.6	4.5999999999999996	6	3.6000000000000001	9.4000000000000004	16.399999999999999	14.6	6.7999999999999998	7.2000000000000002	0.40000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	\N	\N	0	\N
24482	258.60000000000002	0	0	0	0	0	2	6.2000000000000002	41.200000000000003	89.599999999999994	61.600000000000001	27.600000000000001	29.800000000000001	0.59999999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
24483	359.39999999999998	0	0	0	0	4	4.2000000000000002	7.4000000000000004	16.800000000000001	32.799999999999997	97.400000000000006	85.599999999999994	111.2	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34400	6326	0	0	0	58.600000000000001	177.30000000000001	225.09999999999999	263.69999999999999	811.29999999999995	2014.3	1789.0999999999999	645.10000000000002	337.69999999999999	3.7999999999999998	0	\N	\N	\N	\N	\N	\N	\N	0	\N
34401	358.30000000000001	0	0	0	0	3	5.0999999999999996	6.7000000000000002	14.699999999999999	42.700000000000003	80.099999999999994	88	116.90000000000001	1.1000000000000001	0	\N	\N	\N	\N	\N	\N	\N	0	\N
23965	18.5	0	0	0	0	0	0	0.34999999999999998	0.80000000000000004	2.5	5.2999999999999998	3.8999999999999999	5.5499999999999998	0.070000000000000007	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23964	21.5	0	0	0	0	0	2	4.2000000000000002	3.7999999999999998	4.4000000000000004	3.2999999999999998	1.8999999999999999	1.8	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23963	14.050000000000001	0	0	0	0	0	0	0	0.59999999999999998	1.7	2	2.7999999999999998	6.9000000000000004	0.040000000000000001	0.01	\N	\N	\N	\N	\N	\N	\N	0	\N
23962	135.05000000000001	0	0	0	0	0	0	0.34999999999999998	2.3500000000000001	15.199999999999999	35.299999999999997	44.75	36.799999999999997	0.28000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23638	149.80000000000001	0	0	0	0	0	2.7000000000000002	3.5	15.300000000000001	33.950000000000003	28	27	38.399999999999999	0.90000000000000002	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23634	134.55000000000001	0	0	0	0	0	1.1000000000000001	3.3999999999999999	10.4	42.950000000000003	40.299999999999997	18.600000000000001	17	0.59999999999999998	0.14999999999999999	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23633	418.75	0	0	0	0	14.800000000000001	7	16	66.900000000000006	160.75	88.5	42.049999999999997	22.100000000000001	0.59999999999999998	0.029999999999999999	\N	\N	\N	\N	\N	\N	\N	0.02	\N
23630	120.09999999999999	0	0	0	0	0	3.2999999999999998	11.199999999999999	64.549999999999997	39.799999999999997	0.5	0.25	0.45000000000000001	0.02	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23629	849.95000000000005	0	0	0	7.9000000000000004	57	76.900000000000006	167.69999999999999	331.30000000000001	155.40000000000001	21.100000000000001	14.4	18.199999999999999	0.02	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23628	1120.0999999999999	0	0	53.100000000000001	188.5	122	81.099999999999994	121.09999999999999	134.80000000000001	149.09999999999999	132.80000000000001	75.75	61.299999999999997	0.40000000000000002	0.10000000000000001	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23625	347.85000000000002	0	0	0	126.2	107.90000000000001	29.699999999999999	20.899999999999999	28.300000000000001	31.199999999999999	1.8	0.75	1	0.080000000000000002	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23624	741.39999999999998	0	0	0	100.09999999999999	123.40000000000001	125.5	170.59999999999999	155.40000000000001	63.549999999999997	1.8	0.55000000000000004	0.45000000000000001	0.029999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23623	1301.4000000000001	0	0	0	272.30000000000001	222.5	140.80000000000001	181.75	197.40000000000001	164.15000000000001	50.600000000000001	33.399999999999999	38.200000000000003	0.28000000000000003	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23622	585	0	0	0	306.19999999999999	88.200000000000003	58.299999999999997	49.600000000000001	53.799999999999997	27.100000000000001	0.40000000000000002	0.25	1.1100000000000001	0.02	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23615	215.19999999999999	0	0	0	0	1.55	1.45	5.5	11.5	32.299999999999997	46.299999999999997	42	70.799999999999997	3.7000000000000002	0.089999999999999997	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23614	378.39999999999998	0	0	0	0	0	2.8999999999999999	3	19.699999999999999	84	110.90000000000001	78.549999999999997	77.900000000000006	1.3999999999999999	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23613	140.75	0	0	0	0	0	0	0	0.5	5.7000000000000002	25.199999999999999	48.100000000000001	59.799999999999997	1.4299999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23612	197.34999999999999	0	0	0	0	34.299999999999997	15.5	17	24.300000000000001	49.350000000000001	32.299999999999997	15.1	9.3000000000000007	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23610	20.449999999999999	0	0	0	0	0	0	0	0.80000000000000004	3.7999999999999998	4.7999999999999998	3.7999999999999998	6.7999999999999998	0.41999999999999998	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23609	17.699999999999999	0	0	0	0	0	0	0	0.14999999999999999	1.1000000000000001	2.2000000000000002	2.7999999999999998	10.300000000000001	1.1000000000000001	0.040000000000000001	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23608	307.52999999999997	0	0	0	0	0	1	7.0999999999999996	29.800000000000001	79.299999999999997	79.799999999999997	55	54.299999999999997	1.2	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23607	258.35000000000002	0	0	0	0	2	2.7999999999999998	5.7999999999999998	19.399999999999999	49.399999999999999	71.799999999999997	56.700000000000003	49.799999999999997	0.62	0.02	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23606	84.549999999999997	0	0	0	14.1	8.9000000000000004	8.6999999999999993	10	13.6	13.699999999999999	7	4.1500000000000004	4.2000000000000002	0.17999999999999999	0.01	\N	\N	\N	\N	\N	\N	\N	0.01	\N
23605	773.54999999999995	0	0	0	217.09999999999999	185.59999999999999	109.3	109.7	95.75	50.399999999999999	2.3999999999999999	1	2	0.20000000000000001	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23604	1071.9000000000001	0	0	0	252.65000000000001	214.40000000000001	155.15000000000001	139.69999999999999	175.40000000000001	107.90000000000001	11.199999999999999	4.9000000000000004	9.8499999999999996	0.65000000000000002	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
23603	838.39999999999998	0	0	0	124	161.5	60.600000000000001	62.600000000000001	112.7	167.5	63.850000000000001	34.899999999999999	50	0.65000000000000002	0.050000000000000003	\N	\N	\N	\N	\N	\N	\N	0.050000000000000003	\N
13041	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
13042	153.90000000000001	0	0	0	0	0	0	0.20000000000000001	1.5	9	10.300000000000001	28.699999999999999	102.95	1.2	0.029999999999999999	0.02	\N	\N	\N	\N	\N	\N	0	\N
13043	257.60000000000002	0	0	0	0	3.1000000000000001	4.5	4.0999999999999996	7.75	23.300000000000001	61	69.650000000000006	82.150000000000006	2	0.040000000000000001	0.01	\N	\N	\N	\N	\N	\N	0	\N
13044	349.64999999999998	0	0	0	0	9.1500000000000004	3.2999999999999998	8.4000000000000004	11.800000000000001	34	81.049999999999997	100	100.90000000000001	1	0.040000000000000001	0.01	\N	\N	\N	\N	\N	\N	0	\N
13045	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	0	\N
11930	374	0	0	162	58	41	27	42	41	2	0	1	0	0	\N	\N	\N	\N	\N	\N	\N	\N	0	\N
11931	578	0	85	256	78	53	38	38	25	3	1	1	0	0	\N	\N	\N	\N	\N	\N	\N	\N	0	\N
11932	1010	0	0	139	79	75	115	268	259	34	21	20	0	0	\N	\N	\N	\N	\N	\N	\N	\N	0	\N
11933	771	0	226	203	91	65	50	74	53	2	2	5	0	0	\N	\N	\N	\N	\N	\N	\N	\N	0	\N
11934	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	\N	\N	\N	0	\N
11920	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
11921	18	0	0	0	0	0	0	0	1	5	5	3	2	2	0	0	0	\N	\N	\N	\N	\N	0	\N
11922	1.6799999999999999	0	0	0	0	0	0	0	0	0.46000000000000002	0.16	0.19	0.27000000000000002	0.56999999999999995	0.029999999999999999	0	0	\N	\N	\N	\N	\N	0	\N
11923	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
11924	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	\N	\N	0	\N
11917	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
11918	53	0	0	0	0	0	0	0	0	0	2	7	15	13	15	1	0	0	0	\N	\N	\N	0	\N
11919	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10457	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10458	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10459	481	0	0	0	0	0	0	0	0	1	4	22	76	117	255	6	0	0	0	\N	\N	\N	0	\N
10460	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10461	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10443	88	0	0	0	0	0	10	3	1	5	14	28	12	6	8	1	0	0	0	\N	\N	\N	0	\N
10444	1000	0	0	0	0	0	4	0	5	15	82	376	297	130	90	1	0	0	0	\N	\N	\N	0	\N
10445	370	0	0	0	0	0	4	5	4	30	82	163	50	20	12	0	0	0	0	\N	\N	\N	0	\N
10446	12	0	0	0	0	0	0	0	0	0	4	7	1	0	0	0	0	0	0	\N	\N	\N	0	\N
10447	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10448	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10449	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10450	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10451	79	0	0	0	0	0	0	0	0	0	3	12	16	20	27	1	0	0	0	\N	\N	\N	0	\N
10452	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10453	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10437	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10438	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10439	228	0	0	0	0	36	0	0	0	1	2	17	49	58	64	1	0	0	0	\N	\N	\N	0	\N
10440	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10441	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10442	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10431	2	0	0	0	0	0	0	0	0	0.17000000000000001	0.12	0.68999999999999995	0.44	0.20000000000000001	0.38	0	0	0	0	\N	\N	\N	0	\N
10432	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10433	15	0	0	0	0	0	0	0	0	0.32000000000000001	1.3100000000000001	3.6200000000000001	3.1000000000000001	2.98	3.6699999999999999	0	0	0	0	\N	\N	\N	0	\N
10434	8	0	0	0	0	0	0	0	0	0	0.16	1.5900000000000001	1.8799999999999999	1.8999999999999999	2.4700000000000002	0	0	0	0	\N	\N	\N	0	\N
10435	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10436	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10425	8.2639999999999993	0	0	0	0	0	0	1.1799999999999999	0.5	1.1499999999999999	1.1200000000000001	1.49	0.85999999999999999	0.56999999999999995	1.304	0.089999999999999997	0	0	0	\N	\N	\N	0	\N
10426	14	0	0	0	0	0	0	3.6800000000000002	0	0.31	2.7599999999999998	3.48	1.8400000000000001	0.93999999999999995	0.94999999999999996	0.040000000000000001	0	0	0	\N	\N	\N	0	\N
10427	107	0	0	0	0	0	7	0	2	3	10	16	18	19	31	1	0	0	0	\N	\N	\N	0	\N
10428	286	0	0	0	0	0	2	4	4	9	42	109	60	29	26	1	0	0	0	\N	\N	\N	0	\N
10429	5	0	0	0	0	0	0	0	0	0.28000000000000003	1.5600000000000001	2.54	0.17000000000000001	0.17999999999999999	0.27000000000000002	0	0	0	0	\N	\N	\N	0	\N
10430	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10421	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10422	60	0	0	0	0	0	0	0	0	0	5	13	10	12	20	0	0	0	0	\N	\N	\N	0	\N
10423	266	0	0	0	0	0	0	0	0	2	13	50	48	66	86	1	0	0	0	\N	\N	\N	0	\N
10424	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10416	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10417	7	0	0	0	0	0	0	0	0	0.10000000000000001	1.7	1.8999999999999999	1.3	0.59999999999999998	1.3999999999999999	0	0	0	0	\N	\N	\N	0	\N
10418	32	0	0	0	0	0	0	0	0	0	3.6000000000000001	9.9000000000000004	5.4000000000000004	4.9000000000000004	8.1999999999999993	0	0	0	0	\N	\N	\N	0	\N
10419	176	0	0	0	0	0	0	0	0	1	5	37	38	42	53	0	0	0	0	\N	\N	\N	0	\N
10420	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10413	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10414	14	0	0	0	0	0	0	0	0	0	2	4	1	2	5	0	0	0	0	\N	\N	\N	0	\N
10415	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10408	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10409	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10410	56	0	0	0	0	0	0	0	0	0	1.6000000000000001	11.4	15.1	11.9	15.800000000000001	0.20000000000000001	0	0	0	\N	\N	\N	0	\N
10411	699	0	0	0	0	0	0	0	1	3	16	78	228	194	177	2	0	0	0	\N	\N	\N	0	\N
10412	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10404	4	0	0	0	0	0	0	0	0	0	0.10000000000000001	0.80000000000000004	1	0.90000000000000002	1.2	0	0	0	0	\N	\N	\N	0	\N
10405	37	0	0	0	0	0	0	0	0	0	0.29999999999999999	4.7000000000000002	11.800000000000001	10.1	10.1	0	0	0	0	\N	\N	\N	0	\N
10406	11	0	0	0	0	0	0	0	0	0.10000000000000001	0.40000000000000002	2.1000000000000001	3.2000000000000002	2.6000000000000001	2.6000000000000001	0	0	0	0	\N	\N	\N	0	\N
10407	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10399	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10400	6	0	0	0	0	0	0	0	0	0	0.5	2.1000000000000001	1.3	0.69999999999999996	1.3999999999999999	0	0	0	0	\N	\N	\N	0	\N
10401	298.69999999999999	0	0	0	0	0	1.3	0.69999999999999996	2.3999999999999999	7.7999999999999998	49	166.09999999999999	27.699999999999999	22.100000000000001	21.199999999999999	0.40000000000000002	0	0	0	\N	\N	\N	0	\N
10402	107.59999999999999	0	0	0	0	0	3.8999999999999999	4.0999999999999996	1.6000000000000001	8.5999999999999996	19.800000000000001	46.299999999999997	6.5999999999999996	6.7999999999999998	9.8000000000000007	0.10000000000000001	0	0	0	\N	\N	\N	0	\N
10403	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10395	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10396	541	0	0	0	0	0	97	41	39	79	123	115	24	12	11	0	0	0	0	\N	\N	\N	0	\N
10397	7	0	0	0	0	0	0	0	0	0	0	2.5	0.80000000000000004	1.2	2.5	0	0	0	0	\N	\N	\N	0	\N
10398	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10390	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10391	7	0	0	0	0	0	0	0	0	0	1.8	4.0999999999999996	0.59999999999999998	0.29999999999999999	0.20000000000000001	0	0	0	0	\N	\N	\N	0	\N
10392	123	0	0	0	0	0	13	7	8	8	17	44	11	7	8	0	0	0	0	\N	\N	\N	0	\N
10393	1122	0	0	0	0	0	10	2	8	28	140	636	32	175	91	0	0	0	0	\N	\N	\N	0	\N
10394	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10384	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10385	6	0	0	0	0	0	0	0	0	0	0.80000000000000004	2.3999999999999999	1.3	0.80000000000000004	0.69999999999999996	0	0	0	0	\N	\N	\N	0	\N
10386	177	0	0	0	0	0	50	12.5	8.5	17.300000000000001	29.899999999999999	42	7.7000000000000002	4.7000000000000002	4.2000000000000002	0.20000000000000001	0	0	0	\N	\N	\N	0	\N
10387	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10388	13	0	0	0	0	0	2.2999999999999998	0.80000000000000004	0	0.5	2.8999999999999999	4.5	0.80000000000000004	0.29999999999999999	0.90000000000000002	0	0	0	0	\N	\N	\N	0	\N
10389	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10378	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	\N	\N	\N	0	\N
10379	7	0	0	0	0	0	0	0	0	0	0.5	1.5	1.5	1.3	2.2000000000000002	0	0	0	0	\N	\N	\N	0	\N
\.


--
-- Data for Name: hpeilpunkt; Type: TABLE DATA; Schema: public; Owner: -
--

COPY hpeilpunkt (hpeilungid, punktnr, y, z) FROM stdin;
185	70	529.35699999999997	59.972000000000001
185	71	583.423	59.994
185	72	583.423	65
186	1	-122.432	55.341999999999999
186	2	-117.032	54.238999999999997
186	3	-111.63200000000001	53.982999999999997
186	4	-10.416	54.588999999999999
186	5	-1.7290000000000001	54.171999999999997
186	6	0	54.088999999999999
186	7	8.3369999999999997	53.726999999999997
186	8	15.843999999999999	50.006999999999998
186	9	17.172000000000001	50.009
186	10	18.870999999999999	49.651000000000003
186	11	22.198	49.808
186	12	23.690000000000001	49.581000000000003
186	13	24.786000000000001	49.658000000000001
186	14	27.363	49.509999999999998
186	15	31.163	49.630000000000003
186	16	35.649999999999999	49.343000000000004
186	17	36.622	49.524000000000001
186	18	41.177	49.320999999999998
186	19	41.555999999999997	49.579999999999998
186	20	42.640000000000001	49.5
186	21	43.213999999999999	49.658999999999999
186	22	44.433999999999997	49.659999999999997
186	23	46.276000000000003	49.439999999999998
186	24	49.003	49.628999999999998
186	25	52.229999999999997	49.578000000000003
186	26	54.447000000000003	49.219999999999999
186	27	56.904000000000003	49.340000000000003
186	28	57.542999999999999	49.240000000000002
186	29	59.759	49.399000000000001
186	30	61.780000000000001	49.158000000000001
186	31	62.484999999999999	49.338999999999999
186	32	67.575999999999993	49.576999999999998
186	33	68.471000000000004	49.456000000000003
186	34	69.378	49.536999999999999
186	35	70.073999999999998	49.316000000000003
186	36	71.287999999999997	49.177
186	37	76.921000000000006	49.216999999999999
186	38	78.061000000000007	49.115000000000002
186	39	79.063000000000002	49.256999999999998
186	40	80.058999999999997	49.136000000000003
186	41	88.974000000000004	49.311999999999998
186	42	96.064999999999998	49.090000000000003
186	43	98.546999999999997	49.130000000000003
186	44	99.915999999999997	49.366999999999997
186	45	116.90600000000001	49.466000000000001
186	46	118.43899999999999	49.581000000000003
186	47	119.89100000000001	49.426000000000002
186	48	123.074	49.527999999999999
186	49	125.86199999999999	49.448999999999998
186	50	126.705	49.548999999999999
186	51	147.13	49.533999999999999
186	52	149.60499999999999	49.771999999999998
186	53	150.452	50.088000000000001
186	54	154.226	49.543999999999997
186	55	156.328	49.564
186	56	157.749	49.384
186	57	161.71600000000001	49.484000000000002
186	58	162.69800000000001	49.743000000000002
186	59	163.80699999999999	49.780000000000001
186	60	164.619	50.084000000000003
186	61	164.964	49.985999999999997
186	62	165.34399999999999	50.267000000000003
186	63	166.03200000000001	50.213999999999999
186	64	169.16800000000001	50.701000000000001
186	65	174.56800000000001	51.003
186	66	296.06900000000002	52.923999999999999
186	67	333.86900000000003	53.256999999999998
186	68	393.26900000000001	53.067999999999998
186	69	398.66899999999998	53.359000000000002
186	70	404.01999999999998	54.171999999999997
186	71	409.46899999999999	55
186	72	944.07100000000003	55.104999999999997
186	73	965.66999999999996	56.604999999999997
186	74	971.07000000000005	56.408999999999999
186	75	981.87	55.383000000000003
186	76	987.26999999999998	55.085999999999999
186	77	1440.8620000000001	54.962000000000003
186	78	1878.2539999999999	53.75
186	79	2007.8510000000001	53.643000000000001
186	80	2029.451	52.904000000000003
186	81	2034.8510000000001	53.002000000000002
186	82	2045.6510000000001	53.415999999999997
186	83	2094.25	53.713999999999999
186	84	2148.2489999999998	53.686
186	85	2515.442	52.511000000000003
186	86	2591.0410000000002	53.960000000000001
186	87	2596.4409999999998	54.222999999999999
186	88	2601.8409999999999	54.743000000000002
186	89	2634.2399999999998	59.421999999999997
182	1	-40	89.986999999999995
182	2	-8.1839999999999993	89.918999999999997
182	3	-5.6600000000000001	89.640000000000001
182	4	0.23899999999999999	86.262
182	5	1.4930000000000001	85.183999999999997
182	6	2.7759999999999998	84.954999999999998
182	7	8.8719999999999999	83.296000000000006
182	8	30.053999999999998	82.849999999999994
182	9	32.838999999999999	82.900000000000006
182	10	32.93	83
182	11	33.076000000000001	82.760000000000005
182	12	34.857999999999997	82.700000000000003
182	13	37.036999999999999	82.849999999999994
182	14	38.034999999999997	82.700000000000003
182	15	38.075000000000003	82.810000000000002
182	16	39.075000000000003	82.609999999999999
182	17	39.152999999999999	82.75
182	18	39.868000000000002	82.549999999999997
182	19	41.027999999999999	82.75
182	20	43.308999999999997	82.549999999999997
182	21	48.871000000000002	82.549999999999997
182	22	49.869	82.5
182	23	50.085000000000001	82.359999999999999
182	24	51.314999999999998	82.5
182	25	53.404000000000003	82.299999999999997
182	26	54.106999999999999	82.459999999999994
182	27	54.192999999999998	82.349999999999994
182	28	55.399999999999999	82.400000000000006
182	29	56.106000000000002	82.159999999999997
182	30	56.189	82.349999999999994
182	31	57.015999999999998	82.25
182	32	58.012	82.400000000000006
182	33	58.470999999999997	82.150000000000006
182	34	58.939	82.450000000000003
182	35	59.390999999999998	82.049999999999997
182	36	60.203000000000003	82.150000000000006
182	37	60.363	82.349999999999994
182	38	61.387	82.25
182	39	61.488999999999997	82.099999999999994
182	40	63.000999999999998	82.049999999999997
182	41	63.103000000000002	82.209999999999994
182	42	63.472999999999999	82
182	43	64.102999999999994	82.209999999999994
182	44	66.188000000000002	81.959999999999994
182	45	66.332999999999998	82.209999999999994
182	46	68.144000000000005	81.810000000000002
182	47	68.366	81.959999999999994
182	48	71.358999999999995	81.959999999999994
182	49	72.361999999999995	81.760000000000005
182	50	73.349000000000004	81.810000000000002
182	51	74.325000000000003	81.659999999999997
182	52	78.350999999999999	81.760000000000005
182	53	80.367999999999995	81.609999999999999
182	54	82.356999999999999	81.859999999999999
182	55	83.370000000000005	81.709999999999994
182	56	84.382999999999996	81.810000000000002
182	57	85.375	81.659999999999997
182	58	88.356999999999999	81.659999999999997
182	59	89.364999999999995	81.359999999999999
182	60	90.325000000000003	81.659999999999997
182	61	90.361000000000004	81.510000000000005
182	62	92.361000000000004	81.659999999999997
182	63	93.358000000000004	81.510000000000005
182	64	94.366	81.810000000000002
182	65	97.356999999999999	82.060000000000002
182	66	98.344999999999999	81.959999999999994
182	67	99.341999999999999	82.159999999999997
182	68	99.373000000000005	82.060000000000002
182	69	100.34399999999999	82.359999999999999
182	70	100.378	82.227000000000004
182	71	101.354	82.659999999999997
182	72	102.026	82.606999999999999
182	73	105.608	84.186000000000007
182	74	108.339	84.950000000000003
182	75	110.97499999999999	85.918999999999997
182	76	111.28	86.251999999999995
182	77	115.676	88.840999999999994
182	78	119.44	89.992999999999995
182	79	122.84	91.408000000000001
182	80	141.179	90.159999999999997
182	81	163.47200000000001	89.852999999999994
182	82	196.19200000000001	89.926000000000002
182	83	217.37200000000001	89.707999999999998
178	1	-44	83.390000000000001
178	2	-30.663	83.390000000000001
178	3	-17.244	80.879999999999995
178	4	2.633	78.849999999999994
178	5	4.4630000000000001	78.670000000000002
178	6	7.5529999999999999	77.769999999999996
178	7	7.8600000000000003	77.665000000000006
178	8	11.943	76.260000000000005
178	9	13.362	75.540000000000006
178	10	17.271999999999998	74.099999999999994
178	11	21.041	73.629999999999995
178	12	21.282	73.349999999999994
178	13	21.751000000000001	73.439999999999998
178	14	22.271999999999998	73.269999999999996
178	15	22.751000000000001	73.409999999999997
178	16	23.751999999999999	73.390000000000001
178	17	24.751000000000001	73.510000000000005
178	18	25.341000000000001	73.450000000000003
178	19	27.731000000000002	73.609999999999999
178	20	29.321000000000002	73.560000000000002
178	21	31.309999999999999	73.650000000000006
178	22	32.710000000000001	73.540000000000006
178	23	33.302	73.680000000000007
178	24	35.340000000000003	73.680000000000007
178	25	35.710000000000001	73.609999999999999
178	26	36.340000000000003	73.680000000000007
178	27	36.710000000000001	73.629999999999995
178	28	38.709000000000003	73.700000000000003
178	29	41.32	73.540000000000006
178	30	45.749000000000002	73.519999999999996
178	31	46.317999999999998	73.430000000000007
178	32	46.749000000000002	73.489999999999995
178	33	49.347999999999999	73.430000000000007
178	34	49.908999999999999	73.340000000000003
178	35	50.389000000000003	73.409999999999997
178	36	52.868000000000002	73.209999999999994
178	37	56.347999999999999	73.189999999999998
178	38	56.868000000000002	73.109999999999999
178	39	57.828000000000003	73.209999999999994
178	40	57.868000000000002	73.030000000000001
178	41	58.817	73.150000000000006
178	42	58.857999999999997	73.010000000000005
178	43	59.817999999999998	73.120000000000005
178	44	59.857999999999997	72.950000000000003
178	45	60.357999999999997	73.090000000000003
178	46	60.857999999999997	72.950000000000003
178	47	62.837000000000003	73.079999999999998
178	48	63.057000000000002	73.010000000000005
178	49	65.828000000000003	73.030000000000001
178	50	65.917000000000002	72.969999999999999
178	51	68.846999999999994	72.989999999999995
178	52	69.844999999999999	72.909999999999997
178	53	69.936999999999998	72.959999999999994
178	54	70.835999999999999	72.909999999999997
178	55	71.287000000000006	72.959999999999994
178	56	72.266999999999996	72.840000000000003
178	57	72.406000000000006	72.909999999999997
178	58	73.236000000000004	72.819999999999993
178	59	75.796999999999997	72.829999999999998
178	60	76.275999999999996	72.959999999999994
178	61	80.795000000000002	72.799999999999997
178	62	80.873999999999995	72.920000000000002
178	63	81.775000000000006	72.780000000000001
178	64	81.864999999999995	72.879999999999995
178	65	83.724999999999994	72.810000000000002
178	66	83.924999999999997	72.890000000000001
178	67	84.584999999999994	72.849999999999994
178	68	87.123000000000005	72.939999999999998
178	69	92.185000000000002	74.379999999999995
178	70	95.043999999999997	75.590000000000003
178	71	97.284000000000006	76.310000000000002
178	72	103.026	77.664000000000001
178	73	110.923	79.549999999999997
178	74	113.29600000000001	79.810000000000002
178	75	117.322	79.859999999999999
178	76	153.90799999999999	79.75
178	77	187.125	80.349999999999994
178	78	211.46299999999999	79.950000000000003
178	79	231.81999999999999	79.340000000000003
178	80	259.03699999999998	79.340000000000003
178	81	309.54300000000001	83.379999999999995
178	82	321.50299999999999	85.299999999999997
180	1	-956.78599999999994	81.569999999999993
180	2	-940.27200000000005	78.695999999999998
180	3	-925.34100000000001	77.381
180	4	-909.95399999999995	77.099999999999994
180	5	-878.17899999999997	77.094999999999999
180	6	-866.95799999999997	76.623000000000005
180	7	-843.36300000000006	76.396000000000001
180	8	-813.15800000000002	76.622
180	9	-778.83199999999999	76.655000000000001
180	10	-774.98699999999997	76.298000000000002
180	11	-767.28800000000001	76.194999999999993
180	12	-705.10400000000004	76.049999999999997
180	13	-697.78599999999994	76.281000000000006
180	14	-695.01499999999999	76.281999999999996
180	15	-683.41899999999998	77.417000000000002
180	16	-621.85900000000004	77.159000000000006
180	17	-603.90099999999995	77.400000000000006
180	18	-591.44399999999996	77.159000000000006
180	19	-569.78399999999999	77.277000000000001
180	20	-541.04600000000005	77.846000000000004
180	21	-508.25099999999998	77.929000000000002
180	22	-495.21199999999999	77.662000000000006
180	23	-488.30500000000001	77.394999999999996
180	24	-478.71199999999999	77.665999999999997
180	25	-453.51999999999998	77.745999999999995
180	26	-440.01600000000002	77.254000000000005
180	27	-408.85300000000001	77.087000000000003
180	28	-388.34399999999999	77.087999999999994
180	29	-378.226	75.968999999999994
180	30	-367.44999999999999	76.031000000000006
180	31	-364.45699999999999	76.456999999999994
180	32	-340.04300000000001	77.411000000000001
180	33	-307.61900000000003	77.531000000000006
180	34	-239.328	77.408000000000001
180	35	-220.96700000000001	77.081999999999994
180	36	-206.94499999999999	76.614999999999995
180	37	-180.68000000000001	76.876999999999995
180	38	-171.72499999999999	77.233000000000004
180	39	-121.431	77.391000000000005
180	40	-100.96599999999999	76.980999999999995
180	41	-30.896999999999998	77.569999999999993
180	42	0	76.885999999999996
180	43	20.518999999999998	76.885999999999996
180	44	45.142000000000003	76.659000000000006
180	45	62.734999999999999	73.033000000000001
180	46	64.230999999999995	72.879999999999995
180	47	65.807000000000002	72.579999999999998
180	48	68.343000000000004	72.689999999999998
180	49	69.427999999999997	72.530000000000001
180	50	72.066999999999993	72.379999999999995
180	51	75.998000000000005	71.129999999999995
180	52	82.652000000000001	70.829999999999998
180	53	87.200999999999993	69.730000000000004
180	54	97.846000000000004	69.930000000000007
180	55	122.251	70.079999999999998
180	56	136.732	70.379999999999995
180	57	143.81899999999999	71.030000000000001
180	58	148.04599999999999	71.730000000000004
180	59	156.33500000000001	71.480000000000004
180	60	165.01300000000001	70.480000000000004
180	61	168.06999999999999	70.430000000000007
180	62	170.79499999999999	70.980000000000004
180	63	172.53700000000001	72.030000000000001
180	64	174.393	71.680000000000007
180	65	176.36799999999999	72.665999999999997
180	66	178.79599999999999	74.094999999999999
180	67	187.07300000000001	77.135000000000005
180	68	193.48099999999999	78.176000000000002
180	69	200	78.173000000000002
180	70	210.37299999999999	78.168000000000006
180	71	224.208	77.986999999999995
180	72	238.37799999999999	78.087999999999994
180	73	246.48400000000001	78.320999999999998
180	74	251.374	78.311999999999998
180	75	264.44799999999998	77.983000000000004
180	76	277.98399999999998	77.933000000000007
180	77	295.71899999999999	77.584999999999994
180	78	304.28100000000001	77.662000000000006
180	79	315.61900000000003	77.495000000000005
180	80	318.46600000000001	77.600999999999999
180	81	324.10899999999998	78.453000000000003
180	82	332.73200000000003	81.191999999999993
181	1	-341.03800000000001	73.230999999999995
181	2	-297.99099999999999	72.962000000000003
181	3	-277.83300000000003	72.643000000000001
181	4	-270.649	73.387
181	5	-267.40300000000002	73.331000000000003
181	6	-257.08800000000002	73.927999999999997
181	7	-245.21000000000001	73.590999999999994
181	8	-236.44499999999999	73.878
181	9	-208.10300000000001	73.724000000000004
181	10	-182.59999999999999	74.018000000000001
181	11	-178.03200000000001	73.123999999999995
181	12	-169.17699999999999	73.969999999999999
181	13	-158.715	74.180000000000007
181	14	-145.53399999999999	73.186999999999998
181	15	-121.398	73.052000000000007
181	16	-97.457999999999998	73.158000000000001
181	17	-66.718999999999994	74.284000000000006
181	18	-24.152000000000001	74.302000000000007
181	19	-8.2219999999999995	73.614000000000004
181	20	0	72.981999999999999
181	21	1.2210000000000001	72.888000000000005
181	22	8.9440000000000008	72.573999999999998
181	23	20.295999999999999	72.397000000000006
181	24	24.495000000000001	70.677999999999997
181	25	26.552	70.349999999999994
181	26	31.542999999999999	70.177000000000007
181	27	34.054000000000002	72.159000000000006
181	28	44.149000000000001	72.590000000000003
181	29	53.616	69.995000000000005
181	30	59.845999999999997	68.819999999999993
181	31	64.316999999999993	67.769999999999996
181	32	73.296000000000006	66.670000000000002
181	33	90.019000000000005	67.170000000000002
181	34	102.57899999999999	67.170000000000002
181	35	106.69799999999999	66.969999999999999
181	36	108.32299999999999	67.170000000000002
181	37	118.432	67.469999999999999
181	38	120.995	67.269999999999996
181	39	124.318	67.219999999999999
181	40	126.751	67.420000000000002
181	41	138.59	69.120000000000005
181	42	145.72499999999999	69.319999999999993
181	43	188.762	71.725999999999999
181	44	200.001	72.001000000000005
181	45	230.798	72.756
181	46	242.09399999999999	73.789000000000001
181	47	255.08500000000001	73.634
181	48	260.90899999999999	73.254999999999995
181	49	272.36900000000003	73.361000000000004
181	50	282.125	72.622
181	51	294.892	73.293999999999997
181	52	306.68700000000001	72.338999999999999
181	53	322.887	73.501000000000005
181	54	359.97800000000001	73.652000000000001
181	55	381.49299999999999	73.932000000000002
181	56	389.11799999999999	74.814999999999998
181	57	395.82299999999998	76.915000000000006
184	1	-96.480000000000004	67.283000000000001
184	2	-91.043000000000006	67.021000000000001
184	3	-66.841999999999999	66.777000000000001
184	4	-33.841000000000001	66.852000000000004
184	5	-2.145	67.144000000000005
184	6	0	67.099999999999994
184	7	33.677999999999997	66.769000000000005
184	8	37.409999999999997	66.713999999999999
184	9	40.594000000000001	66.343000000000004
184	10	41.914999999999999	66.188000000000002
184	11	48.289999999999999	64.849999999999994
184	12	49.590000000000003	64.599999999999994
184	13	51.430999999999997	64.25
184	14	52.625999999999998	64.064999999999998
184	15	53.399000000000001	63.649999999999999
184	16	54.436	62.938000000000002
184	17	54.68	62.899999999999999
184	18	56.539999999999999	62.049999999999997
184	19	58.546999999999997	61.399999999999999
184	20	60.109999999999999	61.450000000000003
184	21	61.834000000000003	61.399999999999999
184	22	63.713000000000001	61.200000000000003
184	23	66.051000000000002	61.100000000000001
184	24	68.037999999999997	61.25
184	25	70.182000000000002	61.350000000000001
184	26	73.111000000000004	61.450000000000003
184	27	75.400000000000006	61.450000000000003
184	28	78.272000000000006	61.450000000000003
184	29	81.058999999999997	61.450000000000003
184	30	83.549000000000007	61.399999999999999
184	31	87.078999999999994	61.450000000000003
184	32	88.421000000000006	61.350000000000001
184	33	92.620000000000005	61.350000000000001
184	34	95.132999999999996	61.25
184	35	97.656000000000006	61.200000000000003
184	36	101.73999999999999	61.350000000000001
184	37	105.495	61.299999999999997
184	38	108.91200000000001	61.350000000000001
184	39	112.151	61.5
184	40	115.25700000000001	61.5
184	41	118.22799999999999	61.5
184	42	121.642	61.450000000000003
184	43	124.343	61.5
184	44	126.86799999999999	61.399999999999999
184	45	129.44900000000001	61.200000000000003
184	46	132.34100000000001	60.950000000000003
184	47	134.76499999999999	61.049999999999997
184	48	136.78800000000001	61.100000000000001
184	49	137.97499999999999	61.200000000000003
184	50	139.608	61.5
184	51	140.81700000000001	62.200000000000003
184	52	141.48599999999999	63.137
184	53	142.20500000000001	63.450000000000003
184	54	143.535	63.649999999999999
184	55	144.55699999999999	63.75
184	56	145.364	63.966000000000001
184	57	146.55600000000001	64.049999999999997
184	58	147.60300000000001	64.200000000000003
184	59	148.79400000000001	64.349999999999994
184	60	158.73099999999999	65.242000000000004
184	61	176.94499999999999	65.397000000000006
184	62	193.43000000000001	65.849000000000004
184	63	200	66.099999999999994
184	64	206.94499999999999	66.393000000000001
184	65	207.22399999999999	66.427000000000007
184	66	210.68100000000001	66.387
184	67	217.87899999999999	66.494
184	68	226.029	66.376000000000005
184	69	236.523	66.305000000000007
184	70	250.74600000000001	66.521000000000001
184	71	276.81	66.543000000000006
184	72	314.85000000000002	66.456000000000003
184	73	350.721	66.918000000000006
184	74	395.81900000000002	66.981999999999999
184	75	447.26299999999998	67.259
185	1	20.198	65
185	2	20.097999999999999	63.020000000000003
185	3	20.097999999999999	63.020000000000003
185	4	23.716000000000001	62.899000000000001
185	5	35.829999999999998	59.972000000000001
185	6	38.906999999999996	59.406999999999996
185	7	42.432000000000002	58.978000000000002
185	8	45.265000000000001	58.052
185	9	48.570999999999998	57.195999999999998
185	10	49.960000000000001	56.759999999999998
185	11	50.945999999999998	56.57
185	12	52.002000000000002	55.990000000000002
185	13	52.984000000000002	55.210000000000001
185	14	53.978999999999999	54.590000000000003
185	15	55.405000000000001	54.359999999999999
185	16	60.359000000000002	54.600000000000001
185	17	63.509	54.869999999999997
185	18	65.978999999999999	54.840000000000003
185	19	67.974999999999994	54.93
185	20	68.974999999999994	55.079999999999998
185	21	72.969999999999999	54.93
185	22	75.388999999999996	55.100000000000001
185	23	79.971000000000004	55.030000000000001
185	24	81.977999999999994	55.159999999999997
185	25	83.504999999999995	55.149999999999999
185	26	84.504999999999995	55.259999999999998
185	27	90.478999999999999	55.170000000000002
185	28	91.537000000000006	55.259999999999998
185	29	107.501	55.439999999999998
185	30	111.218	55.689999999999998
185	31	116.414	55.789999999999999
185	32	122.465	56.079999999999998
185	33	126.47199999999999	55.960000000000001
185	34	132.41399999999999	56.509999999999998
185	35	133.429	56.399999999999999
185	36	135.41399999999999	56.579999999999998
185	37	136.87299999999999	56.560000000000002
185	38	138.87299999999999	56.689999999999998
185	39	142.071	56.670000000000002
185	40	146.52600000000001	56.810000000000002
185	41	148.46000000000001	56.659999999999997
185	42	149.47200000000001	56.810000000000002
185	43	152.46600000000001	56.729999999999997
185	44	152.501	56.82
185	45	171.54400000000001	56.832999999999998
185	46	183.44200000000001	57.423999999999999
185	47	188.88800000000001	57.920000000000002
185	48	197.28999999999999	58.293999999999997
185	49	197.28999999999999	58.295000000000002
185	50	200	58.310000000000002
185	51	203.316	58.329000000000001
185	52	205.99799999999999	58.798000000000002
185	53	210.83199999999999	59.326000000000001
185	54	218.48599999999999	60.591000000000001
185	55	223.351	62.048000000000002
185	56	238.18299999999999	61.381
185	57	272.54199999999997	61.493000000000002
185	58	313.09199999999998	61.292000000000002
185	59	340.125	61.064
185	60	380.67500000000001	60.533000000000001
185	61	394.19099999999997	60.103000000000002
185	62	407.70800000000003	59.862000000000002
185	63	421.22399999999999	59.222000000000001
185	64	434.74099999999999	59.109999999999999
185	65	448.25700000000001	59.863
185	66	461.774	60.744999999999997
185	67	475.29000000000002	61.802
185	68	488.80700000000002	61.866999999999997
185	69	502.32400000000001	61.124000000000002
501	1	-51.807000000000002	86.281000000000006
501	2	-45.616	84.617999999999995
501	3	-35.289000000000001	84.033000000000001
501	4	-30.213000000000001	83.296999999999997
501	5	-22.486000000000001	82.795000000000002
501	6	-15.576000000000001	83.046000000000006
501	7	-4.9740000000000002	83.081999999999994
501	8	0	83.201999999999998
501	9	3.351	83.091999999999999
501	10	9.7080000000000002	81.358999999999995
501	11	10.98	80.811000000000007
501	12	37.771999999999998	80.537000000000006
501	13	57.289999999999999	77.534000000000006
501	14	60.421999999999997	77.329999999999998
501	15	75.722999999999999	77.25
501	16	78.923000000000002	77.109999999999999
501	17	82.822999999999993	77.180000000000007
501	18	91.222999999999999	76.989999999999995
501	19	93.722999999999999	77.060000000000002
501	20	97.423000000000002	76.959999999999994
501	21	103.72199999999999	77.010000000000005
501	22	105.623	76.900000000000006
501	23	107.82299999999999	76.969999999999999
501	24	108.623	76.900000000000006
501	25	111.622	76.939999999999998
501	26	116.523	76.870000000000005
501	27	120.45099999999999	77.043000000000006
501	28	137.946	80.472999999999999
501	29	152.86600000000001	82.337999999999994
501	30	153.785	82.721000000000004
501	31	157.184	83.183999999999997
501	32	162.45699999999999	83.537000000000006
501	33	168.31100000000001	83.763999999999996
501	34	169.28	83.811999999999998
501	35	174.386	83.558999999999997
501	36	180.40899999999999	83.159000000000006
501	37	188.59700000000001	83.030000000000001
501	38	195.059	84.256
501	39	200.64400000000001	85.481999999999999
501	40	201.76599999999999	85.591999999999999
501	41	206.81399999999999	85.662999999999997
502	1	-45.009999999999998	87.019000000000005
502	2	-41.203000000000003	86.861000000000004
502	3	-29.187000000000001	84.096999999999994
502	4	-22.785	83.415000000000006
502	5	-16.507000000000001	82.869
502	6	-10.167	82.462000000000003
502	7	-3.8210000000000002	82.686000000000007
502	8	0	82.798000000000002
502	9	4.5430000000000001	82.706999999999994
502	10	8.093	82.403000000000006
502	11	14.054	81.123999999999995
502	12	17.452000000000002	80.719999999999999
502	13	39.805999999999997	80.254000000000005
502	14	77.215000000000003	76.971999999999994
502	15	79.715000000000003	76.909999999999997
502	16	81.215000000000003	76.780000000000001
502	17	94.441000000000003	76.748000000000005
502	18	100.41500000000001	76.530000000000001
502	19	106.089	76.635999999999996
502	20	107.715	76.599999999999994
502	21	114.655	76.670000000000002
502	22	117.155	76.819999999999993
502	23	118.55500000000001	77.049999999999997
502	24	119.806	77.156000000000006
502	25	122.05500000000001	77.75
502	26	124.517	78.012
502	27	138.43299999999999	80.852000000000004
502	28	149.15700000000001	81.197999999999993
502	29	151.06200000000001	81.786000000000001
502	30	155.89599999999999	82.269999999999996
502	31	159.714	83.212999999999994
502	32	163.94800000000001	83.686999999999998
502	33	164.44499999999999	83.655000000000001
502	34	169.88399999999999	83.596000000000004
502	35	176.19300000000001	83.245000000000005
502	36	182.02500000000001	83.025000000000006
502	37	187.13300000000001	83.363
502	38	208.161	84.153000000000006
502	39	210.995	84.722999999999999
502	40	222.51300000000001	84.790000000000006
502	41	236.178	88.855999999999995
503	1	-50.188000000000002	84.439999999999998
503	2	-34.622	83.334999999999994
503	3	-23.303000000000001	83.447000000000003
503	4	-17.619	83.682000000000002
503	5	-5.7999999999999998	83.384
503	6	0	83.436999999999998
503	7	1.9830000000000001	83.393000000000001
503	8	8.3659999999999997	83.352999999999994
503	9	9.7089999999999996	82.299000000000007
503	10	14.956	81.128
503	11	18.445	80.459000000000003
503	12	37.158999999999999	80.194999999999993
503	13	54.805	77.960999999999999
503	14	62.817	77.579999999999998
503	15	73.216999999999999	77.230000000000004
503	16	78.816999999999993	76.980000000000004
503	17	83.896000000000001	76.909999999999997
503	18	88.195999999999998	76.709999999999994
503	19	107.39700000000001	76.319999999999993
503	20	112.89700000000001	76.030000000000001
503	21	118.06	75.980000000000004
503	22	122.59699999999999	76.269999999999996
503	23	127.639	77.361000000000004
503	24	133.35900000000001	79.366
503	25	137.946	80.771000000000001
503	26	142.79599999999999	81.215000000000003
503	27	148.08199999999999	81.450000000000003
503	28	161.25	81.576999999999998
503	29	167.37299999999999	81.837999999999994
503	30	172.952	82.364000000000004
503	31	178.79599999999999	82.742000000000004
503	32	185.48500000000001	83.459999999999994
503	33	185.887	83.507999999999996
503	34	200.36699999999999	84.436999999999998
504	1	-58.908000000000001	83.524000000000001
504	2	-37.866	84.021000000000001
504	3	-21.780000000000001	83.504000000000005
504	4	-10.592000000000001	83.078000000000003
504	5	-5.1779999999999999	83.049000000000007
504	6	0	83.131
504	7	2.847	83.114999999999995
504	8	5.5199999999999996	83.126000000000005
504	9	11.188000000000001	82.638999999999996
504	10	14.625	82.058999999999997
504	11	18.901	80.682000000000002
504	12	25.321999999999999	78.783000000000001
504	13	30.521999999999998	76.929000000000002
504	14	33.509	76.231999999999999
504	15	36.938000000000002	76.070999999999998
504	16	57.402999999999999	76.531999999999996
504	17	71.694000000000003	76.608999999999995
504	18	81.754000000000005	76.489999999999995
504	19	92.153000000000006	76.569999999999993
504	20	96.953000000000003	76.769999999999996
504	21	101.554	77.25
504	22	104.85299999999999	77.939999999999998
504	23	108.669	79.230000000000004
504	24	115.68600000000001	80.561999999999998
504	25	127.45399999999999	80.778000000000006
504	26	134.15700000000001	80.793000000000006
504	27	140.27000000000001	80.689999999999998
504	28	146.38900000000001	80.944000000000003
504	29	152.60300000000001	81.772000000000006
504	30	159.30000000000001	81.941999999999993
504	31	166.02699999999999	82.781999999999996
504	32	173.22300000000001	83.525999999999996
504	33	176.77500000000001	83.578000000000003
504	34	191.48500000000001	83.359999999999999
504	35	201.154	82.863
504	36	226.37100000000001	83.522999999999996
505	1	-31.751000000000001	84.721999999999994
505	2	-25.222999999999999	83.189999999999998
505	3	-19.974	82.835999999999999
505	4	-8.4960000000000004	82.878
505	5	-3.8250000000000002	82.831000000000003
505	6	0	82.769999999999996
505	7	2.996	82.635000000000005
505	8	5.4370000000000003	82.513999999999996
505	9	9.8770000000000007	81.984999999999999
505	10	15.861000000000001	80.253
505	11	20.184000000000001	79.206999999999994
505	12	22.757999999999999	78.742000000000004
505	13	23.765999999999998	78.358000000000004
505	14	26.757999999999999	77.530000000000001
505	15	29.859000000000002	76.519999999999996
505	16	33.950000000000003	76.022000000000006
505	17	38.143000000000001	75.802000000000007
505	18	44.258000000000003	76.180000000000007
505	19	59.457999999999998	76.370000000000005
505	20	73.567999999999998	76.799999999999997
505	21	78.837000000000003	76.677000000000007
505	22	84.268000000000001	77.230000000000004
505	23	95.069000000000003	77.560000000000002
505	24	100.04900000000001	77.567999999999998
505	25	110.56699999999999	77.897000000000006
505	26	121.604	80.525000000000006
505	27	165.78200000000001	81.688000000000002
505	28	170.49199999999999	82.953000000000003
505	29	176.089	83.680999999999997
505	30	182.05000000000001	83.793000000000006
505	31	185.68199999999999	83.837999999999994
505	32	210.68000000000001	83.483999999999995
505	33	215.16300000000001	83.150000000000006
505	34	221.12200000000001	83.426000000000002
506	1	-2.194	84.863
506	2	0	84.894999999999996
506	3	3.343	84.944000000000003
506	4	9.1989999999999998	84.963999999999999
506	5	15.128	84.725999999999999
506	6	17.061	84.322999999999993
506	7	22.047999999999998	82.382999999999996
506	8	26.108000000000001	80.930000000000007
506	9	27.789999999999999	80.671999999999997
506	10	34.878999999999998	78.447999999999993
506	11	40.158999999999999	75.659999999999997
506	12	43.628	75.710999999999999
506	13	57.741	75.616
506	14	76.186999999999998	75.692999999999998
506	15	88.912999999999997	75.861000000000004
506	16	98.719999999999999	75.719999999999999
506	17	103.15300000000001	75.578000000000003
506	18	128.63	80.296000000000006
506	19	144.95099999999999	80.433000000000007
506	20	149.53	80.602000000000004
506	21	153.99100000000001	81.239999999999995
506	22	155.08799999999999	81.397000000000006
506	23	159.858	82.566000000000003
506	24	163.47499999999999	83.210999999999999
506	25	173.52500000000001	83.591999999999999
506	26	195.339	83.451999999999998
506	27	195.339	83.695999999999998
506	28	210.53299999999999	83.516999999999996
506	29	223.08500000000001	84.323999999999998
507	1	-26.515999999999998	84.183999999999997
507	2	-22.91	84.477999999999994
507	3	-22.91	84.156999999999996
507	4	-17.417999999999999	84.555000000000007
507	5	-11.539	84.477000000000004
507	6	-6.1050000000000004	84.280000000000001
507	7	-0.48199999999999998	84.313999999999993
507	8	0	84.322999999999993
507	9	5.1479999999999997	84.418999999999997
507	10	9.4260000000000002	84.448999999999998
507	11	15.634	83.629999999999995
507	12	20.431999999999999	82.900000000000006
507	13	24.449999999999999	82.494
507	14	29.574999999999999	80.641999999999996
507	15	35.93	78.411000000000001
507	16	40.871000000000002	76.200000000000003
507	17	45.469999999999999	76.024000000000001
507	18	49.072000000000003	76.090000000000003
507	19	54.572000000000003	76.030000000000001
507	20	65.072000000000003	75.510000000000005
507	21	74.051000000000002	74.861000000000004
507	22	78.271000000000001	74.620999999999995
507	23	86.820999999999998	74.359999999999999
507	24	97.064999999999998	74.539000000000001
507	25	101.52200000000001	74.810000000000002
507	26	104.20999999999999	75.581999999999994
507	27	108.122	76
507	28	118.021	76.620000000000005
507	29	122.29600000000001	77.176000000000002
507	30	126.592	79.171000000000006
507	31	129.83199999999999	80.772000000000006
507	32	132.69300000000001	81.492000000000004
507	33	137.25800000000001	83.420000000000002
507	34	138	83.736000000000004
507	35	138.49299999999999	83.659999999999997
507	36	144.91499999999999	84.076999999999998
507	37	151.154	84.084999999999994
507	38	162.71600000000001	83.814999999999998
507	39	174.58000000000001	83.757000000000005
507	40	186.965	83.825999999999993
508	1	-25.834	84.183000000000007
508	2	-9.2699999999999996	84.224000000000004
508	3	-4.0110000000000001	83.938000000000002
508	4	0	83.795000000000002
508	5	0.373	83.781999999999996
508	6	5.6390000000000002	82.619
508	7	11.057	82.021000000000001
508	8	16.527999999999999	81.802999999999997
508	9	22.199999999999999	81.881
508	10	27.917000000000002	81.378
508	11	35.113999999999997	79.376000000000005
508	12	38.134	78.724999999999994
508	13	40.262999999999998	78.105999999999995
508	14	41.302	77.662999999999997
508	15	45.529000000000003	76.819999999999993
508	16	52.628999999999998	75.620000000000005
508	17	56.856999999999999	75.375
508	18	65.728999999999999	75.379999999999995
508	19	70.929000000000002	75.670000000000002
508	20	86.828999999999994	75.909999999999997
508	21	102.959	76.239999999999995
508	22	108.27200000000001	76.533000000000001
508	23	113.65900000000001	76.700000000000003
508	24	117.44199999999999	76.713999999999999
508	25	133.58099999999999	79.545000000000002
508	26	192.82900000000001	80.549000000000007
508	27	194.30699999999999	80.834999999999994
508	28	196.464	81.897999999999996
508	29	197.75299999999999	82.340000000000003
508	30	201.559	83.644999999999996
508	31	204.87299999999999	84.323999999999998
508	32	223.869	82.724000000000004
508	33	223.869	84.228999999999999
509	1	-55.978999999999999	82.198999999999998
509	2	-34.844999999999999	82.477999999999994
509	3	-26.895	82.451999999999998
509	4	-21.937000000000001	82.655000000000001
509	5	-21.937000000000001	82.087999999999994
509	6	-17.114999999999998	82.456999999999994
509	7	-12.367000000000001	82.066999999999993
509	8	-0.35099999999999998	81.481999999999999
509	9	0	81.471999999999994
509	10	5.0259999999999998	81.334999999999994
509	11	10.305999999999999	81.299999999999997
509	12	16.047999999999998	81.063999999999993
509	13	20.632999999999999	79.852999999999994
509	14	24.555	79.227000000000004
509	15	47.481999999999999	78.081000000000003
509	16	55.316000000000003	76.301000000000002
509	17	78.271000000000001	75.349999999999994
509	18	83.731999999999999	74.962999999999994
509	19	88.756	75.019999999999996
509	20	113.61	74.530000000000001
509	21	124.11	74.950000000000003
509	22	129.82599999999999	75.141999999999996
509	23	147.702	79.114000000000004
509	24	155.381	79.727999999999994
509	25	161.93299999999999	79.992999999999995
509	26	167.47999999999999	80.622
509	27	173.101	80.783000000000001
509	28	177.22499999999999	81.105999999999995
509	29	178.73699999999999	81.224000000000004
509	30	184.19	82.602999999999994
509	31	184.19	82.691999999999993
509	32	206.97800000000001	82.623000000000005
509	33	209.535	82.837000000000003
509	34	212.43199999999999	83.512
510	1	-47.206000000000003	82.661000000000001
510	2	-43.677	82.897000000000006
510	3	-36.703000000000003	81.432000000000002
510	4	-31.151	81.325999999999993
510	5	-10.045	82.075999999999993
510	6	-4.1299999999999999	82.207999999999998
510	7	0	82.444000000000003
510	8	4.6920000000000002	82.323999999999998
510	9	13.397	80.522999999999996
510	10	16.881	80.021000000000001
510	11	18.297000000000001	79.418000000000006
510	12	38.753	79.076999999999998
510	13	67.644000000000005	74.209999999999994
510	14	102.504	74.189999999999998
510	15	119.184	74.060000000000002
510	16	141.25800000000001	79.076999999999998
510	17	157.93299999999999	80.745000000000005
510	18	158.94200000000001	81.177000000000007
510	19	164.76400000000001	82.311000000000007
510	20	171.31700000000001	83.329999999999998
510	21	173.506	83.394000000000005
510	22	198.99600000000001	83.543999999999997
511	1	-33.609999999999999	82.421000000000006
511	2	-12.968999999999999	82.887
511	3	-1.9390000000000001	82.998000000000005
511	4	0	83.015000000000001
511	5	4.4279999999999999	82.968999999999994
511	6	9.3200000000000003	82.731999999999999
511	7	18.073	81.481999999999999
511	8	22.975999999999999	79.850999999999999
511	9	23.483000000000001	79.739000000000004
511	10	47.366	78.744
511	11	72.456000000000003	73.516999999999996
511	12	89.936000000000007	73.290000000000006
511	13	94.936000000000007	73.150000000000006
511	14	114.23699999999999	72.909999999999997
511	15	119.20699999999999	72.682000000000002
511	16	145.63800000000001	78.305999999999997
511	17	171.571	78.858000000000004
511	18	180.22200000000001	80.549000000000007
511	19	197.23400000000001	80.986000000000004
511	20	199.97999999999999	81.088999999999999
511	21	203.09200000000001	81.117000000000004
511	22	209.65199999999999	81.010000000000005
511	23	216.012	80.748000000000005
511	24	235.96199999999999	80.859999999999999
511	25	248.619	81.507999999999996
577	155	82.430999999999997	73.120000000000005
577	156	82.805999999999997	73.099999999999994
577	157	83.311999999999998	73.079999999999998
577	158	83.817999999999998	73.069999999999993
577	159	84.516000000000005	73.079999999999998
577	160	84.831000000000003	73.079999999999998
577	161	85.063000000000002	73.090000000000003
577	162	85.841999999999999	73.120000000000005
577	163	85.933000000000007	73.140000000000001
577	164	86.531000000000006	73.230000000000004
577	165	86.813999999999993	73.280000000000001
577	166	86.853999999999999	73.280000000000001
577	167	87.683999999999997	73.530000000000001
577	168	87.867000000000004	73.590000000000003
577	169	88.555000000000007	73.799999999999997
577	170	88.879000000000005	73.909999999999997
577	171	89.435000000000002	74.049999999999997
577	172	89.891000000000005	74.209999999999994
577	173	95.043999999999997	75.590000000000003
577	174	97.284000000000006	76.310000000000002
577	175	103.026	77.664000000000001
577	176	110.923	79.549999999999997
577	177	113.29600000000001	79.810000000000002
577	178	117.322	79.859999999999999
577	179	153.90799999999999	79.75
577	180	187.125	80.349999999999994
577	181	211.46299999999999	79.950000000000003
577	182	231.81999999999999	79.340000000000003
577	183	259.03699999999998	79.340000000000003
577	184	309.54300000000001	83.379999999999995
577	185	321.50299999999999	85.299999999999997
578	1	-1152.3320000000001	81.688999999999993
578	2	-1132.444	78.311000000000007
578	3	-1095.9280000000001	77.320999999999998
578	4	-1057.6600000000001	77.385999999999996
578	5	-1044.145	76.391999999999996
578	6	-1019.33	75.813999999999993
578	7	-979.34900000000005	76.043999999999997
578	8	-938.00800000000004	75.853999999999999
578	9	-933.37699999999995	75.114999999999995
578	10	-924.10500000000002	74.856999999999999
578	11	-837.06200000000001	74.605000000000004
578	12	-823.09500000000003	76.819999999999993
578	13	-799.58699999999999	76.525999999999996
578	14	-729.09400000000005	76.727999999999994
578	15	-686.23500000000001	76.707999999999998
578	16	-651.62400000000002	77.661000000000001
578	17	-636.37300000000005	77.716999999999999
578	18	-596.42399999999998	77.664000000000001
578	19	-588.10400000000004	77.185000000000002
578	20	-576.54999999999995	77.804000000000002
578	21	-546.20899999999995	78.165999999999997
578	22	-529.94600000000003	77.278000000000006
578	23	-492.41300000000001	77.037999999999997
578	24	-370.48899999999998	77.277000000000001
578	25	-328.714	77.25
578	26	-288.24099999999999	77.361999999999995
578	27	-271.86900000000003	76.903999999999996
578	28	-241.94399999999999	76.731999999999999
578	29	-201.27099999999999	76.649000000000001
578	30	-160.48099999999999	77.004999999999995
578	31	-77.850999999999999	77.433999999999997
578	32	-37.212000000000003	77.832999999999998
578	33	0	78.152000000000001
578	34	4.8860000000000001	78.194000000000003
578	35	20.048999999999999	76.981999999999999
578	36	26.515999999999998	75.277000000000001
578	37	53.630000000000003	72.989999999999995
578	38	56.353999999999999	72.290000000000006
578	39	60.182000000000002	72.439999999999998
578	40	61.962000000000003	72.090000000000003
578	41	65	71.819999999999993
578	42	65.382999999999996	71.75
578	43	66.162999999999997	71.659999999999997
578	44	66.620999999999995	71.640000000000001
578	45	67.832999999999998	71.689999999999998
578	46	67.858000000000004	71.689999999999998
578	47	67.870000000000005	71.700000000000003
578	48	68.575000000000003	71.75
578	49	69.094999999999999	71.819999999999993
578	50	69.564999999999998	71.829999999999998
578	51	70.331999999999994	71.819999999999993
578	52	71.272000000000006	71.650000000000006
578	53	71.569000000000003	71.579999999999998
578	54	72.385000000000005	71.310000000000002
578	55	72.805999999999997	71.170000000000002
578	56	72.966999999999999	71.120000000000005
578	57	74.043000000000006	70.799999999999997
578	58	74.662000000000006	70.659999999999997
578	59	75.280000000000001	70.530000000000001
578	60	76.369	70.349999999999994
578	61	76.516999999999996	70.319999999999993
578	62	76.938000000000002	70.269999999999996
578	63	77.754000000000005	70.170000000000002
578	64	78.063999999999993	70.140000000000001
578	65	78.596000000000004	70.079999999999998
578	66	78.991	70.040000000000006
578	67	79.313000000000002	70.019999999999996
578	68	79.757999999999996	69.989999999999995
578	69	80.031000000000006	69.969999999999999
578	70	80.227999999999994	69.959999999999994
578	71	80.748000000000005	69.939999999999998
578	72	81.465999999999994	69.930000000000007
578	73	81.465999999999994	69.930000000000007
578	74	81.465999999999994	69.930000000000007
578	75	81.477999999999994	69.930000000000007
578	76	82.703000000000003	69.950000000000003
578	77	83.159999999999997	69.969999999999999
578	78	83.939999999999998	69.989999999999995
578	79	84.322999999999993	70
578	80	84.855000000000004	70.030000000000001
578	81	85.040999999999997	70.040000000000006
578	82	85.177000000000007	70.049999999999997
578	83	85.757999999999996	70.090000000000003
578	84	86.414000000000001	70.129999999999995
578	85	86.475999999999999	70.140000000000001
578	86	86.561999999999998	70.140000000000001
578	87	87.650999999999996	70.180000000000007
578	88	88.257000000000005	70.200000000000003
578	89	88.888000000000005	70.219999999999999
578	90	89.951999999999998	70.25
578	91	90.125	70.25
578	92	90.582999999999998	70.269999999999996
578	93	91.361999999999995	70.290000000000006
578	94	91.486000000000004	70.290000000000006
578	95	91.659000000000006	70.299999999999997
578	96	92.599000000000004	70.329999999999998
578	97	93.353999999999999	70.349999999999994
578	98	93.835999999999999	70.359999999999999
578	99	95.049000000000007	70.359999999999999
578	100	95.072999999999993	70.359999999999999
578	101	95.135000000000005	70.359999999999999
578	102	96.311000000000007	70.370000000000005
578	103	96.756	70.379999999999995
578	104	97.548000000000002	70.400000000000006
578	105	97.930999999999997	70.409999999999997
578	106	98.450999999999993	70.430000000000007
578	107	98.649000000000001	70.439999999999998
578	108	98.784999999999997	70.450000000000003
578	109	99.674999999999997	70.459999999999994
578	110	100.02200000000001	70.469999999999999
578	111	100.071	70.469999999999999
578	112	100.146	70.469999999999999
578	113	100.789	70.489999999999995
578	114	101.259	70.5
578	115	101.506	70.5
578	116	101.85299999999999	70.5
578	117	102.496	70.5
578	118	103.548	70.5
578	119	103.65900000000001	70.489999999999995
578	120	103.733	70.489999999999995
578	121	104.22799999999999	70.489999999999995
578	122	104.97	70.480000000000004
578	123	105.242	70.480000000000004
578	124	106.20699999999999	70.480000000000004
578	125	106.949	70.480000000000004
578	126	107.444	70.489999999999995
578	127	107.952	70.510000000000005
578	128	108.64400000000001	70.530000000000001
578	129	108.669	70.530000000000001
578	130	108.681	70.530000000000001
578	131	108.78	70.530000000000001
578	132	109.91800000000001	70.560000000000002
578	133	110.339	70.569999999999993
578	134	111.15600000000001	70.579999999999998
578	135	112.04600000000001	70.579999999999998
578	136	112.393	70.579999999999998
578	137	113.333	70.579999999999998
578	138	113.63	70.579999999999998
578	139	113.741	70.579999999999998
578	140	114.867	70.579999999999998
578	141	115.43600000000001	70.590000000000003
578	142	116.104	70.599999999999994
578	143	117.143	70.620000000000005
578	144	117.34099999999999	70.620000000000005
578	145	117.88500000000001	70.629999999999995
576	3	-8.5199999999999996	89.640000000000001
576	4	-2.621	86.262
576	5	-1.367	85.183999999999997
576	6	-0.084000000000000005	84.954999999999998
576	7	6.0119999999999996	83.296000000000006
576	8	18	82.980000000000004
576	9	18.571999999999999	82.980000000000004
576	10	19.003	82.969999999999999
576	11	19.664999999999999	82.959999999999994
576	12	20.006	82.950000000000003
576	13	20.748000000000001	82.920000000000002
576	14	21.009	82.909999999999997
576	15	21.831	82.870000000000005
576	16	22.012	82.870000000000005
576	17	22.914000000000001	82.840000000000003
576	18	23.013999999999999	82.840000000000003
576	19	24.007000000000001	82.799999999999997
576	20	24.016999999999999	82.799999999999997
576	21	24.027000000000001	82.799999999999997
576	22	24.187999999999999	82.790000000000006
576	23	24.960000000000001	82.75
576	24	25.02	82.75
576	25	25.893000000000001	82.709999999999994
576	26	26.023	82.709999999999994
576	27	26.824999999999999	82.689999999999998
576	28	27.026	82.689999999999998
576	29	27.257000000000001	82.680000000000007
576	30	28.029	82.670000000000002
576	31	28.690999999999999	82.650000000000006
576	32	29.032	82.650000000000006
576	33	29.433	82.640000000000001
576	34	30.035	82.620000000000005
576	35	30.515999999999998	82.609999999999999
576	36	31.038	82.599999999999994
576	37	31.599	82.590000000000003
576	38	32.039999999999999	82.590000000000003
576	39	32.421999999999997	82.579999999999998
576	40	33.042999999999999	82.569999999999993
576	41	33.353999999999999	82.560000000000002
576	42	34.045999999999999	82.530000000000001
576	43	34.277000000000001	82.519999999999996
576	44	35.048999999999999	82.5
576	45	35.210000000000001	82.489999999999995
576	46	36.052	82.489999999999995
576	47	36.142000000000003	82.489999999999995
576	48	37.055	82.489999999999995
576	49	37.075000000000003	82.489999999999995
576	50	37.375999999999998	82.480000000000004
576	51	38.008000000000003	82.469999999999999
576	52	38.058	82.469999999999999
576	53	38.939999999999998	82.459999999999994
576	54	39.061	82.450000000000003
576	55	39.872999999999998	82.439999999999998
576	56	40.064	82.430000000000007
576	57	40.805999999999997	82.409999999999997
576	58	41.066000000000003	82.400000000000006
576	59	41.738	82.379999999999995
576	60	42.069000000000003	82.370000000000005
576	61	42.670999999999999	82.349999999999994
576	62	43.072000000000003	82.329999999999998
576	63	43.603999999999999	82.310000000000002
576	64	44.075000000000003	82.299999999999997
576	65	44.536000000000001	82.290000000000006
576	66	45.078000000000003	82.290000000000006
576	67	45.469000000000001	82.280000000000001
576	68	46.081000000000003	82.269999999999996
576	69	46.402000000000001	82.260000000000005
576	70	47.084000000000003	82.230000000000004
576	71	47.334000000000003	82.219999999999999
576	72	48.087000000000003	82.180000000000007
576	73	48.256999999999998	82.180000000000007
576	74	49.090000000000003	82.150000000000006
576	75	49.189999999999998	82.150000000000006
576	76	50.091999999999999	82.120000000000005
576	77	50.122	82.120000000000005
576	78	50.554000000000002	82.120000000000005
576	79	51.094999999999999	82.109999999999999
576	80	51.988	82.120000000000005
576	81	52.097999999999999	82.120000000000005
576	82	52.920999999999999	82.129999999999995
576	83	53.100999999999999	82.129999999999995
576	84	53.311999999999998	82.129999999999995
576	85	54.103999999999999	82.129999999999995
576	86	54.786000000000001	82.109999999999999
576	87	55.106999999999999	82.090000000000003
576	88	55.719000000000001	82.040000000000006
576	89	56.109999999999999	82.010000000000005
576	90	56.651000000000003	81.980000000000004
576	91	57.113	81.959999999999994
576	92	57.584000000000003	81.950000000000003
576	93	58.116	81.950000000000003
576	94	58.517000000000003	81.939999999999998
576	95	59.118000000000002	81.930000000000007
576	96	59.82	81.909999999999997
576	97	60.121000000000002	81.900000000000006
576	98	60.914000000000001	81.879999999999995
576	99	61.124000000000002	81.870000000000005
576	100	61.997	81.829999999999998
576	101	62.127000000000002	81.819999999999993
576	102	63.079999999999998	81.780000000000001
576	103	63.130000000000003	81.780000000000001
576	104	63.741999999999997	81.75
576	105	64.132999999999996	81.730000000000004
576	106	64.162999999999997	81.730000000000004
576	107	65.135999999999996	81.670000000000002
576	108	65.245999999999995	81.670000000000002
576	109	66.138999999999996	81.640000000000001
576	110	66.338999999999999	81.640000000000001
576	111	67.141000000000005	81.620000000000005
576	112	67.421999999999997	81.599999999999994
576	113	68.144000000000005	81.569999999999993
576	114	68.504999999999995	81.549999999999997
576	115	69.147000000000006	81.530000000000001
576	116	69.588999999999999	81.510000000000005
576	117	70.150000000000006	81.5
576	118	70.682000000000002	81.480000000000004
576	119	71.153000000000006	81.459999999999994
576	120	71.765000000000001	81.439999999999998
576	121	72.156000000000006	81.430000000000007
576	122	72.847999999999999	81.430000000000007
576	123	73.159000000000006	81.430000000000007
576	124	73.420000000000002	81.430000000000007
576	125	74.162000000000006	81.430000000000007
576	126	75.024000000000001	81.420000000000002
576	127	75.165000000000006	81.420000000000002
576	128	76.106999999999999	81.390000000000001
576	129	76.167000000000002	81.390000000000001
576	130	76.930000000000007	81.359999999999999
576	131	77.150000000000006	81.359999999999999
576	132	77.170000000000002	81.359999999999999
576	133	77.189999999999998	81.359999999999999
576	134	78.173000000000002	81.340000000000003
576	135	79.016000000000005	81.359999999999999
576	136	79.176000000000002	81.359999999999999
576	137	79.947999999999993	81.390000000000001
576	138	80.179000000000002	81.390000000000001
576	139	80.450000000000003	81.400000000000006
576	140	81.182000000000002	81.439999999999998
576	141	81.813999999999993	81.469999999999999
576	142	82.185000000000002	81.5
576	143	82.745999999999995	81.510000000000005
576	144	83.188000000000002	81.530000000000001
576	145	83.698999999999998	81.530000000000001
576	146	84.191000000000003	81.530000000000001
576	147	84.792000000000002	81.5
576	148	85.192999999999998	81.5
576	149	85.543999999999997	81.5
576	150	86.195999999999998	81.459999999999994
576	151	86.477000000000004	81.439999999999998
576	152	87.198999999999998	81.400000000000006
576	153	87.409999999999997	81.379999999999995
576	154	88.201999999999998	81.340000000000003
576	155	89.135000000000005	81.299999999999997
576	156	89.204999999999998	81.290000000000006
576	157	90.108000000000004	81.260000000000005
576	158	90.207999999999998	81.25
576	159	91.131	81.260000000000005
576	160	91.210999999999999	81.260000000000005
576	161	92.063000000000002	81.310000000000002
576	162	92.213999999999999	81.319999999999993
576	163	92.995999999999995	81.370000000000005
576	164	93.216999999999999	81.390000000000001
576	165	93.929000000000002	81.439999999999998
576	166	94.218999999999994	81.459999999999994
576	167	94.861000000000004	81.519999999999996
576	168	95.221999999999994	81.549999999999997
576	169	95.793999999999997	81.670000000000002
576	170	96.224999999999994	81.739999999999995
576	171	96.727000000000004	81.909999999999997
576	172	97.227999999999994	82.069999999999993
576	173	97.659000000000006	82.219999999999999
576	174	98.230999999999995	82.420000000000002
576	175	98.591999999999999	82.519999999999996
576	176	99.233999999999995	82.689999999999998
576	177	102.748	84.186000000000007
576	178	105.479	84.950000000000003
576	179	108.11499999999999	85.918999999999997
576	180	108.42	86.251999999999995
576	181	112.816	88.840999999999994
576	182	116.58	89.992999999999995
576	183	119.98	91.408000000000001
576	184	138.31899999999999	90.159999999999997
576	185	160.61199999999999	89.852999999999994
577	1	-44	83.390000000000001
577	2	-30.663	83.390000000000001
577	3	-17.244	80.879999999999995
577	4	2.633	78.849999999999994
577	5	4.4630000000000001	78.670000000000002
577	6	7.5529999999999999	77.769999999999996
577	7	7.8600000000000003	77.665000000000006
576	1	-42.859999999999999	89.986999999999995
576	2	-11.044	89.918999999999997
577	8	11.943	76.260000000000005
577	9	13.362	75.540000000000006
577	10	16	74.450000000000003
577	11	16.800000000000001	74.159999999999997
577	12	17.012	74.079999999999998
577	13	17.681000000000001	73.840000000000003
577	14	18.024000000000001	73.709999999999994
577	15	18.550999999999998	73.5
577	16	19.036999999999999	73.290000000000006
577	17	19.431000000000001	73.129999999999995
577	18	20.048999999999999	72.859999999999999
577	19	20.302	72.780000000000001
577	20	21.061	72.540000000000006
577	21	21.181999999999999	72.510000000000005
577	22	21.931999999999999	72.390000000000001
577	23	22.053000000000001	72.370000000000005
577	24	22.073	72.359999999999999
577	25	22.934000000000001	72.329999999999998
577	26	23.085000000000001	72.319999999999993
577	27	23.803999999999998	72.340000000000003
577	28	24.097999999999999	72.349999999999994
577	29	24.675000000000001	72.390000000000001
577	30	25.111000000000001	72.420000000000002
577	31	25.555	72.439999999999998
577	32	26.122	72.459999999999994
577	33	26.425999999999998	72.469999999999999
577	34	27.134	72.489999999999995
577	35	27.306000000000001	72.5
577	36	28.146000000000001	72.519999999999996
577	37	28.177	72.519999999999996
577	38	28.388999999999999	72.519999999999996
577	39	29.056999999999999	72.530000000000001
577	40	29.158999999999999	72.530000000000001
577	41	29.928000000000001	72.540000000000006
577	42	30.170999999999999	72.540000000000006
577	43	30.809000000000001	72.549999999999997
577	44	31.183	72.560000000000002
577	45	31.678999999999998	72.599999999999994
577	46	32.195	72.640000000000001
577	47	32.561	72.689999999999998
577	48	33.207000000000001	72.769999999999996
577	49	33.430999999999997	72.790000000000006
577	50	34.220999999999997	72.879999999999995
577	51	34.301000000000002	72.890000000000001
577	52	34.847000000000001	72.930000000000007
577	53	35.180999999999997	72.950000000000003
577	54	35.231999999999999	72.959999999999994
577	55	36.052	73
577	56	36.244	73
577	57	36.932000000000002	73.040000000000006
577	58	37.256	73.060000000000002
577	59	37.802999999999997	73.090000000000003
577	60	38.268999999999998	73.120000000000005
577	61	38.683999999999997	73.150000000000006
577	62	39.280999999999999	73.189999999999998
577	63	39.554000000000002	73.209999999999994
577	64	40.292999999999999	73.239999999999995
577	65	41.305	73.239999999999995
577	66	41.305	73.239999999999995
577	67	41.305	73.239999999999995
577	68	41.305	73.239999999999995
577	69	42.186	73.230000000000004
577	70	42.317	73.230000000000004
577	71	43.055999999999997	73.239999999999995
577	72	43.331000000000003	73.239999999999995
577	73	43.704000000000001	73.239999999999995
577	74	44.341999999999999	73.25
577	75	44.807000000000002	73.239999999999995
577	76	45.353999999999999	73.230000000000004
577	77	45.677999999999997	73.209999999999994
577	78	46.366	73.159999999999997
577	79	46.558	73.150000000000006
577	80	47.378	73.079999999999998
577	81	47.429000000000002	73.079999999999998
577	82	47.762999999999998	73.060000000000002
577	83	48.311	73.030000000000001
577	84	48.390999999999998	73.030000000000001
577	85	49.180999999999997	73
577	86	49.402999999999999	72.989999999999995
577	87	50.061	72.980000000000004
577	88	50.414999999999999	72.980000000000004
577	89	50.930999999999997	72.969999999999999
577	90	51.427	72.959999999999994
577	91	51.811999999999998	72.950000000000003
577	92	52.439	72.939999999999998
577	93	52.682000000000002	72.930000000000007
577	94	53.451999999999998	72.909999999999997
577	95	53.552999999999997	72.909999999999997
577	96	54.220999999999997	72.900000000000006
577	97	54.433	72.900000000000006
577	98	54.463999999999999	72.900000000000006
577	99	54.503999999999998	72.900000000000006
577	100	55.475999999999999	72.909999999999997
577	101	55.709000000000003	72.909999999999997
577	102	56.488	72.920000000000002
577	103	56.912999999999997	72.920000000000002
577	104	57.500999999999998	72.920000000000002
577	105	58.107999999999997	72.930000000000007
577	106	58.512999999999998	72.930000000000007
577	107	59.311999999999998	72.930000000000007
577	108	59.524999999999999	72.939999999999998
577	109	60.506999999999998	72.950000000000003
577	110	60.536999999999999	72.950000000000003
577	111	60.689	72.950000000000003
577	112	61.548999999999999	72.959999999999994
577	113	61.710999999999999	72.959999999999994
577	114	62.561	72.980000000000004
577	115	62.905999999999999	72.989999999999995
577	116	63.573999999999998	73.010000000000005
577	117	64.111000000000004	73.019999999999996
577	118	64.585999999999999	73.040000000000006
577	119	65.314999999999998	73.069999999999993
577	120	65.597999999999999	73.079999999999998
577	121	66.509	73.109999999999999
577	122	66.611000000000004	73.120000000000005
577	123	67.147000000000006	73.140000000000001
577	124	67.622	73.150000000000006
577	125	67.713999999999999	73.150000000000006
577	126	68.635000000000005	73.170000000000002
577	127	68.908000000000001	73.180000000000007
577	128	69.647000000000006	73.189999999999998
577	129	70.111999999999995	73.200000000000003
577	130	70.659000000000006	73.209999999999994
577	131	71.307000000000002	73.209999999999994
577	132	71.671000000000006	73.209999999999994
577	133	71.933999999999997	73.209999999999994
577	134	72.683000000000007	73.209999999999994
577	135	72.805000000000007	73.209999999999994
577	136	73.605000000000004	73.209999999999994
577	137	73.695999999999998	73.209999999999994
577	138	73.715999999999994	73.209999999999994
577	139	74.707999999999998	73.209999999999994
577	140	74.909999999999997	73.219999999999999
577	141	75.721000000000004	73.219999999999999
577	142	76.307000000000002	73.219999999999999
577	143	76.731999999999999	73.219999999999999
577	144	77.308999999999997	73.209999999999994
577	145	77.745000000000005	73.209999999999994
577	146	78.513999999999996	73.209999999999994
577	147	78.757000000000005	73.219999999999999
577	148	79.718000000000004	73.230000000000004
577	149	79.769000000000005	73.230000000000004
577	150	80.061999999999998	73.219999999999999
577	151	80.680999999999997	73.209999999999994
577	152	80.781000000000006	73.209999999999994
577	153	81.561000000000007	73.170000000000002
577	154	81.793000000000006	73.159999999999997
578	146	118.578	70.650000000000006
578	147	118.83799999999999	70.650000000000006
578	148	119.815	70.640000000000001
578	149	120.124	70.629999999999995
578	150	120.533	70.609999999999999
578	151	120.842	70.609999999999999
578	152	121.05200000000001	70.599999999999994
578	153	121.547	70.579999999999998
578	154	122.23999999999999	70.569999999999993
578	155	122.289	70.569999999999993
578	156	122.982	70.549999999999997
578	157	123.526	70.530000000000001
578	158	123.7	70.519999999999996
578	159	123.935	70.510000000000005
578	160	124.417	70.489999999999995
578	161	124.76300000000001	70.469999999999999
578	162	125.13500000000001	70.450000000000003
578	163	125.629	70.439999999999998
578	164	125.852	70.430000000000007
578	165	126.001	70.430000000000007
578	166	126.557	70.420000000000002
578	167	127.238	70.430000000000007
578	168	127.27500000000001	70.430000000000007
578	169	127.337	70.439999999999998
578	170	127.992	70.480000000000004
578	171	128.47499999999999	70.530000000000001
578	172	128.71000000000001	70.549999999999997
578	173	129.03100000000001	70.599999999999994
578	174	129.42699999999999	70.640000000000001
578	175	129.71199999999999	70.680000000000007
578	176	130.14500000000001	70.730000000000004
578	177	130.739	70.780000000000001
578	178	130.86199999999999	70.790000000000006
578	179	130.94900000000001	70.799999999999997
578	180	131.58000000000001	70.849999999999994
578	181	132.18600000000001	70.909999999999997
578	182	132.285	70.920000000000002
578	183	132.43299999999999	70.950000000000003
578	184	133.00200000000001	71.079999999999998
578	185	133.423	71.209999999999994
578	186	133.72	71.310000000000002
578	187	134.12799999999999	71.469999999999999
578	188	134.43700000000001	71.579999999999998
578	189	134.66	71.670000000000002
578	190	135.155	71.859999999999999
578	191	135.83500000000001	72.159999999999997
578	192	135.87200000000001	72.180000000000007
578	193	135.89699999999999	72.189999999999998
578	194	136.59	72.480000000000004
578	195	137.13399999999999	72.680000000000007
578	196	137.29499999999999	72.739999999999995
578	197	139.203	73.090000000000003
578	198	180.05500000000001	72.777000000000001
578	199	185.30099999999999	73.585999999999999
578	200	198.65799999999999	78.113
578	201	200	78.141999999999996
578	202	206.399	78.281000000000006
578	203	218.52099999999999	77.840000000000003
578	204	228.27500000000001	78.382999999999996
578	205	238.61199999999999	78.436000000000007
578	206	248.43799999999999	77.876000000000005
578	207	271.94099999999997	77.881
578	208	278.37599999999998	78.165999999999997
578	209	289.03699999999998	77.962999999999994
578	210	299.75900000000001	81.275000000000006
579	1	4.8860000000000001	78.194000000000003
579	2	20.048999999999999	76.981999999999999
579	3	26.515999999999998	75.277000000000001
579	4	53.630000000000003	72.989999999999995
579	5	56.353999999999999	72.290000000000006
579	6	60.182000000000002	72.439999999999998
579	7	61.962000000000003	72.090000000000003
579	8	65	71.819999999999993
579	9	65.382999999999996	71.75
579	10	66.162999999999997	71.659999999999997
579	11	66.620999999999995	71.640000000000001
579	12	67.832999999999998	71.689999999999998
579	13	67.858000000000004	71.689999999999998
579	14	67.870000000000005	71.700000000000003
579	15	68.575000000000003	71.75
579	16	69.094999999999999	71.819999999999993
579	17	69.564999999999998	71.829999999999998
579	18	70.331999999999994	71.819999999999993
579	19	71.272000000000006	71.650000000000006
579	20	71.569000000000003	71.579999999999998
579	21	72.385000000000005	71.310000000000002
579	22	72.805999999999997	71.170000000000002
579	23	72.966999999999999	71.120000000000005
579	24	74.043000000000006	70.799999999999997
579	25	74.662000000000006	70.659999999999997
579	26	75.280000000000001	70.530000000000001
579	27	76.369	70.349999999999994
579	28	76.516999999999996	70.319999999999993
579	29	76.938000000000002	70.269999999999996
579	30	77.754000000000005	70.170000000000002
579	31	78.063999999999993	70.140000000000001
579	32	78.596000000000004	70.079999999999998
579	33	78.991	70.040000000000006
579	34	79.313000000000002	70.019999999999996
579	35	79.757999999999996	69.989999999999995
579	36	80.031000000000006	69.969999999999999
579	37	80.227999999999994	69.959999999999994
579	38	80.748000000000005	69.939999999999998
579	39	81.465999999999994	69.930000000000007
579	40	81.465999999999994	69.930000000000007
579	41	81.465999999999994	69.930000000000007
579	42	81.477999999999994	69.930000000000007
579	43	82.703000000000003	69.950000000000003
579	44	83.159999999999997	69.969999999999999
579	45	83.939999999999998	69.989999999999995
579	46	84.322999999999993	70
579	47	84.855000000000004	70.030000000000001
579	48	85.040999999999997	70.040000000000006
579	49	85.177000000000007	70.049999999999997
579	50	85.757999999999996	70.090000000000003
579	51	86.414000000000001	70.129999999999995
579	52	86.475999999999999	70.140000000000001
579	53	86.561999999999998	70.140000000000001
579	54	87.650999999999996	70.180000000000007
579	55	88.257000000000005	70.200000000000003
579	56	88.888000000000005	70.219999999999999
579	57	89.951999999999998	70.25
579	58	90.125	70.25
579	59	90.582999999999998	70.269999999999996
579	60	91.361999999999995	70.290000000000006
579	61	91.486000000000004	70.290000000000006
579	62	91.659000000000006	70.299999999999997
579	63	92.599000000000004	70.329999999999998
579	64	93.353999999999999	70.349999999999994
579	65	93.835999999999999	70.359999999999999
579	66	95.049000000000007	70.359999999999999
579	67	95.072999999999993	70.359999999999999
579	68	95.135000000000005	70.359999999999999
579	69	96.311000000000007	70.370000000000005
579	70	96.756	70.379999999999995
579	71	97.548000000000002	70.400000000000006
579	72	97.930999999999997	70.409999999999997
579	73	98.450999999999993	70.430000000000007
579	74	98.649000000000001	70.439999999999998
579	75	98.784999999999997	70.450000000000003
579	76	99.674999999999997	70.459999999999994
579	77	100.02200000000001	70.469999999999999
579	78	100.071	70.469999999999999
579	79	100.146	70.469999999999999
579	80	100.789	70.489999999999995
579	81	101.259	70.5
579	82	101.506	70.5
579	83	101.85299999999999	70.5
579	84	102.496	70.5
579	85	103.548	70.5
579	86	103.65900000000001	70.489999999999995
579	87	103.733	70.489999999999995
579	88	104.22799999999999	70.489999999999995
579	89	104.97	70.480000000000004
579	90	105.242	70.480000000000004
579	91	106.20699999999999	70.480000000000004
579	92	106.949	70.480000000000004
579	93	107.444	70.489999999999995
579	94	107.952	70.510000000000005
579	95	108.64400000000001	70.530000000000001
579	96	108.669	70.530000000000001
579	97	108.681	70.530000000000001
579	98	108.78	70.530000000000001
579	99	109.91800000000001	70.560000000000002
579	100	110.339	70.569999999999993
579	101	111.15600000000001	70.579999999999998
579	102	112.04600000000001	70.579999999999998
579	103	112.393	70.579999999999998
579	104	113.333	70.579999999999998
579	105	113.63	70.579999999999998
579	106	113.741	70.579999999999998
579	107	114.867	70.579999999999998
579	108	115.43600000000001	70.590000000000003
579	109	116.104	70.599999999999994
579	110	117.143	70.620000000000005
579	111	117.34099999999999	70.620000000000005
579	112	117.88500000000001	70.629999999999995
579	113	118.578	70.650000000000006
579	114	118.83799999999999	70.650000000000006
579	115	119.815	70.640000000000001
579	116	120.124	70.629999999999995
579	117	120.533	70.609999999999999
579	118	120.842	70.609999999999999
579	119	121.05200000000001	70.599999999999994
579	120	121.547	70.579999999999998
579	121	122.23999999999999	70.569999999999993
579	122	122.289	70.569999999999993
579	123	122.982	70.549999999999997
579	124	123.526	70.530000000000001
579	125	123.7	70.519999999999996
579	126	123.935	70.510000000000005
579	127	124.417	70.489999999999995
579	128	124.76300000000001	70.469999999999999
579	129	125.13500000000001	70.450000000000003
579	130	125.629	70.439999999999998
579	131	125.852	70.430000000000007
579	132	126.001	70.430000000000007
579	133	126.557	70.420000000000002
579	134	127.238	70.430000000000007
579	135	127.27500000000001	70.430000000000007
579	136	127.337	70.439999999999998
579	137	127.992	70.480000000000004
579	138	128.47499999999999	70.530000000000001
579	139	128.71000000000001	70.549999999999997
579	140	129.03100000000001	70.599999999999994
579	141	129.42699999999999	70.640000000000001
579	142	129.71199999999999	70.680000000000007
579	143	130.14500000000001	70.730000000000004
579	144	130.739	70.780000000000001
579	145	130.86199999999999	70.790000000000006
579	146	130.94900000000001	70.799999999999997
579	147	131.58000000000001	70.849999999999994
579	148	132.18600000000001	70.909999999999997
579	149	132.285	70.920000000000002
579	150	132.43299999999999	70.950000000000003
579	151	133.00200000000001	71.079999999999998
579	152	133.423	71.209999999999994
579	153	133.72	71.310000000000002
579	154	134.12799999999999	71.469999999999999
579	155	134.43700000000001	71.579999999999998
579	156	134.66	71.670000000000002
579	157	135.155	71.859999999999999
579	158	135.83500000000001	72.159999999999997
579	159	135.87200000000001	72.180000000000007
579	160	135.89699999999999	72.189999999999998
579	161	136.59	72.480000000000004
579	162	137.13399999999999	72.680000000000007
579	163	137.29499999999999	72.739999999999995
579	164	139.203	73.090000000000003
579	165	180.05500000000001	72.777000000000001
579	166	185.30099999999999	73.585999999999999
579	167	198.65799999999999	78.113
579	168	200	78.141999999999996
579	169	206.399	78.281000000000006
594	1	-345	77
594	2	-341.03800000000001	73.230999999999995
594	3	-297.99099999999999	72.962000000000003
594	4	-277.83300000000003	72.643000000000001
594	5	-270.649	73.387
594	6	-267.40300000000002	73.331000000000003
594	7	-257.08800000000002	73.927999999999997
594	8	-245.21000000000001	73.590999999999994
594	9	-236.44499999999999	73.878
594	10	-208.10300000000001	73.724000000000004
594	11	-182.59999999999999	74.018000000000001
594	12	-178.03200000000001	73.123999999999995
594	13	-169.17699999999999	73.969999999999999
594	14	-158.715	74.180000000000007
594	15	-145.53399999999999	73.186999999999998
594	16	-121.398	73.052000000000007
594	17	-97.457999999999998	73.158000000000001
594	18	-66.718999999999994	74.284000000000006
594	19	-24.152000000000001	74.302000000000007
594	20	-8.2219999999999995	73.614000000000004
594	21	0	72.981999999999999
594	22	1.2210000000000001	72.888000000000005
594	23	8.9440000000000008	72.573999999999998
594	24	20.295999999999999	72.397000000000006
594	25	24.495000000000001	70.677999999999997
594	26	26.552	70.349999999999994
594	27	31.542999999999999	70.177000000000007
594	28	34.054000000000002	72.159000000000006
594	29	44.149000000000001	72.590000000000003
594	30	53.616	69.995000000000005
594	31	59.845999999999997	68.819999999999993
594	32	64	67.680000000000007
594	33	64.343999999999994	67.569999999999993
594	34	64.968000000000004	67.349999999999994
594	35	65.075999999999993	67.310000000000002
594	36	65.140000000000001	67.290000000000006
594	37	65.807000000000002	67.030000000000001
594	38	66.259	66.879999999999995
594	39	66.560000000000002	66.799999999999997
594	40	67.120000000000005	66.680000000000007
594	41	67.292000000000002	66.640000000000001
594	42	67.399000000000001	66.629999999999995
594	43	68.045000000000002	66.590000000000003
594	44	68.518000000000001	66.579999999999998
594	45	68.775999999999996	66.579999999999998
594	46	69.271000000000001	66.590000000000003
594	47	69.528999999999996	66.599999999999994
594	48	69.658000000000001	66.599999999999994
594	49	70.260999999999996	66.609999999999999
594	50	70.777000000000001	66.620000000000005
594	51	71.421999999999997	66.620000000000005
594	52	71.745000000000005	66.620000000000005
594	53	71.917000000000002	66.629999999999995
594	54	72.454999999999998	66.620000000000005
594	55	73.036000000000001	66.620000000000005
594	56	73.573999999999998	66.609999999999999
594	57	74.176000000000002	66.609999999999999
594	58	74.822000000000003	66.620000000000005
594	59	75.295000000000002	66.629999999999995
594	60	75.724999999999994	66.629999999999995
594	61	76.435000000000002	66.629999999999995
594	62	77.209999999999994	66.640000000000001
594	63	77.554000000000002	66.640000000000001
594	64	77.661000000000001	66.650000000000006
594	65	77.876999999999995	66.659999999999997
594	66	78.694000000000003	66.680000000000007
594	67	79.575999999999993	66.670000000000002
594	68	79.813000000000002	66.670000000000002
594	69	79.899000000000001	66.670000000000002
594	70	80.028000000000006	66.670000000000002
594	71	80.629999999999995	66.670000000000002
594	72	80.953000000000003	66.689999999999998
594	73	81.963999999999999	66.680000000000007
594	74	82.072000000000003	66.680000000000007
594	75	82.179000000000002	66.680000000000007
594	76	83.212000000000003	66.689999999999998
594	77	84.331000000000003	66.689999999999998
594	78	84.331000000000003	66.689999999999998
594	79	85.084000000000003	66.730000000000004
594	80	85.471000000000004	66.75
594	81	85.814999999999998	66.790000000000006
594	82	86.481999999999999	66.819999999999993
594	83	86.546999999999997	66.829999999999998
594	84	86.590000000000003	66.829999999999998
594	85	86.718999999999994	66.840000000000003
594	86	87.730000000000004	66.900000000000006
594	87	88.634	66.870000000000005
594	88	88.849000000000004	66.870000000000005
594	89	89.084999999999994	66.859999999999999
594	90	89.989000000000004	66.840000000000003
594	91	90.784999999999997	66.819999999999993
594	92	91.108000000000004	66.819999999999993
594	93	91.474000000000004	66.819999999999993
594	94	92.248000000000005	66.829999999999998
594	95	92.936000000000007	66.840000000000003
594	96	93.367000000000004	66.859999999999999
594	97	93.840000000000003	66.870000000000005
594	98	94.507000000000005	66.890000000000001
594	99	95.087999999999994	66.900000000000006
594	100	95.432000000000002	66.920000000000002
594	101	95.626000000000005	66.920000000000002
594	102	96.185000000000002	66.939999999999998
594	103	96.766000000000005	66.959999999999994
594	104	96.917000000000002	66.969999999999999
594	105	97.239000000000004	66.969999999999999
594	106	97.885000000000005	66.989999999999995
594	107	98.400999999999996	66.989999999999995
594	108	99.025000000000006	67
594	109	99.153999999999996	67
594	110	99.391000000000005	67.010000000000005
594	111	99.885999999999996	67.019999999999996
594	112	100.14400000000001	67.019999999999996
594	113	100.983	67.030000000000001
594	114	101.28400000000001	67.040000000000006
594	115	101.542	67.040000000000006
594	116	102.40300000000001	67.060000000000002
594	117	103.349	67.079999999999998
594	118	103.54300000000001	67.079999999999998
594	119	103.694	67.079999999999998
594	120	104.66200000000001	67.109999999999999
594	121	105.73699999999999	67.129999999999995
594	122	105.78	67.129999999999995
594	123	105.845	67.129999999999995
594	124	106.92100000000001	67.120000000000005
594	125	107.996	67.099999999999994
594	126	108.039	67.090000000000003
594	127	108.039	67.090000000000003
594	128	108.104	67.090000000000003
594	129	109.18000000000001	67.060000000000002
594	130	110.148	67.030000000000001
594	131	110.255	67.019999999999996
594	132	110.298	67.019999999999996
594	133	110.98699999999999	66.980000000000004
594	134	111.43899999999999	66.950000000000003
594	135	112.29900000000001	66.890000000000001
594	136	112.471	66.870000000000005
594	137	112.557	66.859999999999999
594	138	113.224	66.810000000000002
594	139	113.69799999999999	66.760000000000005
594	140	113.956	66.75
594	141	114.45099999999999	66.719999999999999
594	142	114.687	66.709999999999994
594	143	114.816	66.709999999999994
594	144	115.44	66.689999999999998
594	145	115.95699999999999	66.680000000000007
594	146	116.602	66.670000000000002
594	147	117.075	66.670000000000002
594	148	117.613	66.689999999999998
594	149	118.21599999999999	66.700000000000003
594	150	118.753	66.730000000000004
594	151	119.334	66.769999999999996
594	152	119.872	66.799999999999997
594	153	120.47499999999999	66.849999999999994
594	154	120.625	66.859999999999999
594	155	120.905	66.870000000000005
594	156	121.593	66.909999999999997
594	157	122.36799999999999	66.930000000000007
594	158	122.73399999999999	66.939999999999998
594	159	123.056	66.930000000000007
594	160	123.852	66.930000000000007
594	161	124.32599999999999	66.909999999999997
594	162	124.99299999999999	66.890000000000001
594	163	125.057	66.890000000000001
594	164	125.208	66.879999999999995
594	165	125.81	66.879999999999995
594	166	126.111	66.909999999999997
594	167	126.542	66.939999999999998
594	168	127.251	67
594	169	127.35899999999999	67.010000000000005
594	170	128.37	67.090000000000003
594	171	129.50999999999999	67.040000000000006
594	172	129.50999999999999	67.040000000000006
594	173	129.50999999999999	67.040000000000006
594	174	130.62899999999999	66.969999999999999
594	175	131.66200000000001	66.939999999999998
594	176	131.76900000000001	66.939999999999998
594	177	131.87700000000001	66.920000000000002
594	178	132.88800000000001	66.790000000000006
594	179	133.21100000000001	66.780000000000001
594	180	138.59	69.120000000000005
594	181	145.72499999999999	69.319999999999993
594	182	188.762	71.725999999999999
594	183	200.001	72.001000000000005
594	184	230.798	72.756
594	185	242.09399999999999	73.789000000000001
594	186	255.08500000000001	73.634
594	187	260.90899999999999	73.254999999999995
594	188	272.36900000000003	73.361000000000004
594	189	282.125	72.622
594	190	294.892	73.293999999999997
594	191	306.68700000000001	72.338999999999999
594	192	322.887	73.501000000000005
594	193	359.97800000000001	73.652000000000001
594	194	381.49299999999999	73.932000000000002
594	195	389.11799999999999	74.814999999999998
594	196	395.82299999999998	76.915000000000006
598	3	0	72.981999999999999
598	4	1.2210000000000001	72.888000000000005
598	5	8.9440000000000008	72.573999999999998
598	6	20.295999999999999	72.397000000000006
598	7	24.495000000000001	70.677999999999997
598	8	26.552	70.349999999999994
598	9	31.542999999999999	70.177000000000007
598	10	34.054000000000002	72.159000000000006
598	11	44.149000000000001	72.590000000000003
598	12	53.616	69.995000000000005
598	13	59.845999999999997	68.819999999999993
598	14	64	67.680000000000007
598	15	64.343999999999994	67.569999999999993
598	16	64.968000000000004	67.349999999999994
598	17	65.075999999999993	67.310000000000002
598	18	65.140000000000001	67.290000000000006
598	19	65.807000000000002	67.030000000000001
598	20	66.259	66.879999999999995
598	21	66.560000000000002	66.799999999999997
598	22	67.120000000000005	66.680000000000007
598	23	67.292000000000002	66.640000000000001
598	24	67.399000000000001	66.629999999999995
598	25	68.045000000000002	66.590000000000003
598	26	68.518000000000001	66.579999999999998
598	27	68.775999999999996	66.579999999999998
598	28	69.271000000000001	66.590000000000003
598	29	69.528999999999996	66.599999999999994
598	30	69.658000000000001	66.599999999999994
598	31	70.260999999999996	66.609999999999999
598	32	70.777000000000001	66.620000000000005
598	33	71.421999999999997	66.620000000000005
598	34	71.745000000000005	66.620000000000005
598	35	71.917000000000002	66.629999999999995
598	36	72.454999999999998	66.620000000000005
598	37	73.036000000000001	66.620000000000005
598	38	73.573999999999998	66.609999999999999
598	39	74.176000000000002	66.609999999999999
598	40	74.822000000000003	66.620000000000005
598	41	75.295000000000002	66.629999999999995
598	42	75.724999999999994	66.629999999999995
598	43	76.435000000000002	66.629999999999995
598	44	77.209999999999994	66.640000000000001
598	45	77.554000000000002	66.640000000000001
598	46	77.661000000000001	66.650000000000006
598	47	77.876999999999995	66.659999999999997
598	48	78.694000000000003	66.680000000000007
598	49	79.575999999999993	66.670000000000002
598	50	79.813000000000002	66.670000000000002
598	51	79.899000000000001	66.670000000000002
598	52	80.028000000000006	66.670000000000002
598	53	80.629999999999995	66.670000000000002
598	54	80.953000000000003	66.689999999999998
598	55	81.963999999999999	66.680000000000007
598	56	82.072000000000003	66.680000000000007
598	57	82.179000000000002	66.680000000000007
598	58	83.212000000000003	66.689999999999998
598	59	84.331000000000003	66.689999999999998
598	60	84.331000000000003	66.689999999999998
598	61	85.084000000000003	66.730000000000004
598	62	85.471000000000004	66.75
598	63	85.814999999999998	66.790000000000006
598	64	86.481999999999999	66.819999999999993
598	65	86.546999999999997	66.829999999999998
598	66	86.590000000000003	66.829999999999998
598	67	86.718999999999994	66.840000000000003
598	68	87.730000000000004	66.900000000000006
598	69	88.634	66.870000000000005
598	70	88.849000000000004	66.870000000000005
598	71	89.084999999999994	66.859999999999999
598	72	89.989000000000004	66.840000000000003
598	73	90.784999999999997	66.819999999999993
598	74	91.108000000000004	66.819999999999993
598	75	91.474000000000004	66.819999999999993
598	76	92.248000000000005	66.829999999999998
598	77	92.936000000000007	66.840000000000003
598	78	93.367000000000004	66.859999999999999
598	79	93.840000000000003	66.870000000000005
598	80	94.507000000000005	66.890000000000001
598	81	95.087999999999994	66.900000000000006
598	82	95.432000000000002	66.920000000000002
598	83	95.626000000000005	66.920000000000002
598	84	96.185000000000002	66.939999999999998
598	85	96.766000000000005	66.959999999999994
598	86	96.917000000000002	66.969999999999999
598	87	97.239000000000004	66.969999999999999
598	88	97.885000000000005	66.989999999999995
598	89	98.400999999999996	66.989999999999995
598	90	99.025000000000006	67
598	91	99.153999999999996	67
598	92	99.391000000000005	67.010000000000005
598	93	99.885999999999996	67.019999999999996
598	94	100.14400000000001	67.019999999999996
598	95	100.983	67.030000000000001
598	96	101.28400000000001	67.040000000000006
598	97	101.542	67.040000000000006
598	98	102.40300000000001	67.060000000000002
598	99	103.349	67.079999999999998
598	100	103.54300000000001	67.079999999999998
598	101	103.694	67.079999999999998
598	102	104.66200000000001	67.109999999999999
598	103	105.73699999999999	67.129999999999995
598	104	105.78	67.129999999999995
598	105	105.845	67.129999999999995
598	106	106.92100000000001	67.120000000000005
598	107	107.996	67.099999999999994
598	108	108.039	67.090000000000003
598	109	108.039	67.090000000000003
598	110	108.104	67.090000000000003
598	111	109.18000000000001	67.060000000000002
598	112	110.148	67.030000000000001
598	113	110.255	67.019999999999996
598	114	110.298	67.019999999999996
598	115	110.98699999999999	66.980000000000004
598	116	111.43899999999999	66.950000000000003
598	117	112.29900000000001	66.890000000000001
598	118	112.471	66.870000000000005
598	119	112.557	66.859999999999999
598	120	113.224	66.810000000000002
598	121	113.69799999999999	66.760000000000005
598	122	113.956	66.75
598	123	114.45099999999999	66.719999999999999
598	124	114.687	66.709999999999994
598	125	114.816	66.709999999999994
598	126	115.44	66.689999999999998
598	127	115.95699999999999	66.680000000000007
598	128	116.602	66.670000000000002
598	129	117.075	66.670000000000002
598	130	117.613	66.689999999999998
598	131	118.21599999999999	66.700000000000003
598	132	118.753	66.730000000000004
598	133	119.334	66.769999999999996
598	134	119.872	66.799999999999997
598	135	120.47499999999999	66.849999999999994
598	136	120.625	66.859999999999999
598	137	120.905	66.870000000000005
598	138	121.593	66.909999999999997
598	139	122.36799999999999	66.930000000000007
598	140	122.73399999999999	66.939999999999998
598	141	123.056	66.930000000000007
598	142	123.852	66.930000000000007
598	143	124.32599999999999	66.909999999999997
598	144	124.99299999999999	66.890000000000001
598	145	125.057	66.890000000000001
598	146	125.208	66.879999999999995
598	147	125.81	66.879999999999995
598	148	126.111	66.909999999999997
598	149	126.542	66.939999999999998
598	150	127.251	67
598	151	127.35899999999999	67.010000000000005
598	152	128.37	67.090000000000003
598	153	129.50999999999999	67.040000000000006
598	154	129.50999999999999	67.040000000000006
598	155	129.50999999999999	67.040000000000006
598	156	130.62899999999999	66.969999999999999
598	157	131.66200000000001	66.939999999999998
598	158	131.76900000000001	66.939999999999998
598	159	131.87700000000001	66.920000000000002
598	160	132.88800000000001	66.790000000000006
598	161	133.21100000000001	66.780000000000001
598	162	138.59	69.120000000000005
598	163	145.72499999999999	69.319999999999993
598	164	188.762	71.725999999999999
598	165	200.001	72.001000000000005
598	166	230.798	72.756
598	1	-24.152000000000001	74.302000000000007
598	2	-8.2219999999999995	73.614000000000004
598	167	242.09399999999999	73.789000000000001
599	1	-96.480000000000004	67.283000000000001
599	2	-91.043000000000006	67.021000000000001
599	3	-66.841999999999999	66.777000000000001
599	4	-33.841000000000001	66.852000000000004
599	5	-2.145	67.144000000000005
599	6	0	67.099999999999994
599	7	33.677999999999997	66.769000000000005
599	8	37.409999999999997	66.713999999999999
599	9	40.594000000000001	66.343000000000004
599	10	41.914999999999999	66.188000000000002
599	11	48.289999999999999	64.849999999999994
599	12	49.590000000000003	64.599999999999994
599	13	51.430999999999997	64.25
599	14	52.625999999999998	64.064999999999998
599	15	53.399000000000001	63.649999999999999
599	16	54.436	62.938000000000002
599	17	54.68	62.899999999999999
599	18	56	62.25
599	19	56.377000000000002	62.119999999999997
599	20	56.829999999999998	61.920000000000002
599	21	57.395000000000003	61.68
599	22	57.621000000000002	61.600000000000001
599	23	58.451000000000001	61.399999999999999
599	24	58.451000000000001	61.399999999999999
599	25	58.451000000000001	61.399999999999999
599	26	59.243000000000002	61.329999999999998
599	27	59.469000000000001	61.32
599	28	60.072000000000003	61.310000000000002
599	29	60.524999999999999	61.299999999999997
599	30	61.279000000000003	61.310000000000002
599	31	61.542999999999999	61.310000000000002
599	32	61.694000000000003	61.32
599	33	62.222000000000001	61.329999999999998
599	34	62.598999999999997	61.340000000000003
599	35	63.314999999999998	61.369999999999997
599	36	63.616999999999997	61.390000000000001
599	37	64.144999999999996	61.409999999999997
599	38	64.673000000000002	61.439999999999998
599	39	64.936999999999998	61.450000000000003
599	40	65.691000000000003	61.469999999999999
599	41	65.766000000000005	61.479999999999997
599	42	65.992999999999995	61.490000000000002
599	43	66.747	61.509999999999998
599	44	67.388000000000005	61.520000000000003
599	45	67.765000000000001	61.530000000000001
599	46	68.216999999999999	61.530000000000001
599	47	68.820999999999998	61.539999999999999
599	48	69.009	61.539999999999999
599	49	69.763000000000005	61.539999999999999
599	50	69.838999999999999	61.539999999999999
599	51	70.631	61.539999999999999
599	52	70.894999999999996	61.539999999999999
599	53	71.459999999999994	61.530000000000001
599	54	71.912999999999997	61.520000000000003
599	55	72.251999999999995	61.520000000000003
599	56	72.968000000000004	61.5
599	57	73.081999999999994	61.5
599	58	73.534000000000006	61.479999999999997
599	59	73.911000000000001	61.469999999999999
599	60	73.986999999999995	61.469999999999999
599	61	74.703000000000003	61.450000000000003
599	62	75.042000000000002	61.439999999999998
599	63	75.533000000000001	61.439999999999998
599	64	76.061000000000007	61.43
599	65	77.040999999999997	61.439999999999998
599	66	77.116	61.439999999999998
599	67	77.153999999999996	61.439999999999998
599	68	77.305000000000007	61.439999999999998
599	69	78.134	61.439999999999998
599	70	78.436000000000007	61.450000000000003
599	71	79.189999999999998	61.450000000000003
599	72	79.869	61.469999999999999
599	73	80.207999999999998	61.469999999999999
599	74	80.397000000000006	61.479999999999997
599	75	81.075999999999993	61.5
599	76	81.227000000000004	61.5
599	77	81.263999999999996	61.5
599	78	82.018000000000001	61.520000000000003
599	79	82.281999999999996	61.530000000000001
599	80	82.847999999999999	61.549999999999997
599	81	83.337999999999994	61.560000000000002
599	82	83.640000000000001	61.57
599	83	84.355999999999995	61.579999999999998
599	84	84.846000000000004	61.590000000000003
599	85	85.412000000000006	61.600000000000001
599	86	85.600999999999999	61.609999999999999
599	87	86.430000000000007	61.630000000000003
599	88	87.033000000000001	61.649999999999999
599	89	87.486000000000004	61.659999999999997
599	90	88.465999999999994	61.68
599	91	88.504000000000005	61.68
599	92	88.617000000000004	61.68
599	93	89.560000000000002	61.689999999999998
599	94	89.899000000000001	61.689999999999998
599	95	90.578000000000003	61.689999999999998
599	96	91.331999999999994	61.689999999999998
599	97	91.634	61.689999999999998
599	98	92.388000000000005	61.689999999999998
599	99	92.652000000000001	61.689999999999998
599	100	93.406000000000006	61.68
599	101	93.707999999999998	61.670000000000002
599	102	94.236000000000004	61.659999999999997
599	103	94.725999999999999	61.649999999999999
599	104	95.028000000000006	61.640000000000001
599	105	95.781999999999996	61.640000000000001
599	106	95.856999999999999	61.640000000000001
599	107	96.159000000000006	61.640000000000001
599	108	96.799999999999997	61.640000000000001
599	109	97.063999999999993	61.640000000000001
599	110	97.855999999999995	61.640000000000001
599	111	98.308000000000007	61.640000000000001
599	112	98.873999999999995	61.640000000000001
599	113	99.099999999999994	61.630000000000003
599	114	99.930000000000007	61.640000000000001
599	115	99.930000000000007	61.640000000000001
599	116	100.94799999999999	61.640000000000001
599	117	101.325	61.640000000000001
599	118	102.003	61.640000000000001
599	119	102.343	61.640000000000001
599	120	103.02200000000001	61.630000000000003
599	121	103.172	61.619999999999997
599	122	103.7	61.609999999999999
599	123	104.077	61.600000000000001
599	124	104.794	61.57
599	125	105.096	61.549999999999997
599	126	105.623	61.539999999999999
599	127	106.114	61.5
599	128	106.41500000000001	61.5
599	129	107.169	61.460000000000001
599	130	107.245	61.460000000000001
599	131	107.471	61.460000000000001
599	132	108.03700000000001	61.450000000000003
599	133	108.22499999999999	61.450000000000003
599	134	108.866	61.439999999999998
599	135	109.24299999999999	61.439999999999998
599	136	109.696	61.420000000000002
599	137	110.29900000000001	61.409999999999997
599	138	110.488	61.399999999999999
599	139	111.242	61.369999999999997
599	140	111.31699999999999	61.369999999999997
599	141	111.355	61.369999999999997
599	142	112.373	61.350000000000001
599	143	112.788	61.340000000000003
599	144	113.39100000000001	61.329999999999998
599	145	113.73099999999999	61.329999999999998
599	146	114.447	61.299999999999997
599	147	114.56	61.299999999999997
599	148	115.01300000000001	61.289999999999999
599	149	115.352	61.280000000000001
599	150	115.465	61.280000000000001
599	151	116.182	61.240000000000002
599	152	116.483	61.240000000000002
599	153	117.011	61.189999999999998
599	154	117.539	61.159999999999997
599	155	117.803	61.130000000000003
599	156	118.595	61.07
599	157	118.633	61.07
599	158	118.783	61.060000000000002
599	159	119.613	61
599	160	119.91500000000001	60.990000000000002
599	161	120.669	60.939999999999998
599	162	121.348	60.880000000000003
599	163	121.687	60.850000000000001
599	164	122.554	60.799999999999997
599	165	122.74299999999999	60.789999999999999
599	166	122.78	60.789999999999999
599	167	123.761	60.770000000000003
599	168	124.21299999999999	60.740000000000002
599	169	124.81699999999999	60.719999999999999
599	170	125.646	60.640000000000001
599	171	125.83499999999999	60.630000000000003
599	172	125.94799999999999	60.619999999999997
599	173	126.325	60.590000000000003
599	174	126.85299999999999	60.560000000000002
599	175	127.569	60.57
599	176	127.90900000000001	60.579999999999998
599	177	128.512	60.579999999999998
599	178	128.965	60.590000000000003
599	179	129.94499999999999	60.600000000000001
599	180	129.983	60.600000000000001
599	181	130.096	60.609999999999999
599	182	131.03800000000001	60.630000000000003
599	183	131.37799999999999	60.640000000000001
599	184	132.05699999999999	60.659999999999997
599	185	132.434	60.670000000000002
599	186	133.11199999999999	60.710000000000001
599	187	133.26300000000001	60.729999999999997
599	188	133.86699999999999	60.82
599	189	134.09299999999999	60.859999999999999
599	190	134.131	60.869999999999997
599	191	134.88499999999999	61.060000000000002
599	192	135.18600000000001	61.149999999999999
599	193	135.714	61.289999999999999
599	194	136.20400000000001	61.479999999999997
599	195	136.506	61.57
599	196	137.22300000000001	61.829999999999998
599	197	137.33600000000001	61.859999999999999
599	198	137.637	61.990000000000002
599	199	138.12799999999999	62.189999999999998
599	200	138.27799999999999	62.25
599	201	138.95699999999999	62.509999999999998
599	202	139.334	62.649999999999999
599	203	139.78700000000001	62.789999999999999
599	204	140.352	62.969999999999999
599	205	140.57900000000001	63.030000000000001
599	206	141.40799999999999	63.259999999999998
599	207	142.20500000000001	63.450000000000003
599	208	143.535	63.649999999999999
599	209	144.55699999999999	63.75
599	210	145.364	63.966000000000001
599	211	146.55600000000001	64.049999999999997
599	212	147.60300000000001	64.200000000000003
599	213	148.79400000000001	64.349999999999994
599	214	158.73099999999999	65.242000000000004
599	215	176.94499999999999	65.397000000000006
599	216	193.43000000000001	65.849000000000004
599	217	200	66.099999999999994
599	218	206.94499999999999	66.393000000000001
599	219	207.22399999999999	66.427000000000007
599	220	210.68100000000001	66.387
599	221	217.87899999999999	66.494
599	222	226.029	66.376000000000005
599	223	236.523	66.305000000000007
599	224	250.74600000000001	66.521000000000001
599	225	276.81	66.543000000000006
599	226	314.85000000000002	66.456000000000003
599	227	350.721	66.918000000000006
599	228	395.81900000000002	66.981999999999999
599	229	447.26299999999998	67.259
600	1	33.677999999999997	66.769000000000005
600	2	37.409999999999997	66.713999999999999
600	3	40.594000000000001	66.343000000000004
600	4	41.914999999999999	66.188000000000002
600	5	48.289999999999999	64.849999999999994
600	6	49.590000000000003	64.599999999999994
600	7	51.430999999999997	64.25
600	8	52.625999999999998	64.064999999999998
600	9	53.399000000000001	63.649999999999999
600	10	54.436	62.938000000000002
600	11	54.68	62.899999999999999
600	12	56	62.25
600	13	56.377000000000002	62.119999999999997
600	14	56.829999999999998	61.920000000000002
600	15	57.395000000000003	61.68
600	16	57.621000000000002	61.600000000000001
600	17	58.451000000000001	61.399999999999999
600	18	58.451000000000001	61.399999999999999
600	19	58.451000000000001	61.399999999999999
600	20	59.243000000000002	61.329999999999998
600	21	59.469000000000001	61.32
600	22	60.072000000000003	61.310000000000002
600	23	60.524999999999999	61.299999999999997
600	24	61.279000000000003	61.310000000000002
600	25	61.542999999999999	61.310000000000002
600	26	61.694000000000003	61.32
600	27	62.222000000000001	61.329999999999998
600	28	62.598999999999997	61.340000000000003
600	29	63.314999999999998	61.369999999999997
600	30	63.616999999999997	61.390000000000001
600	31	64.144999999999996	61.409999999999997
600	32	64.673000000000002	61.439999999999998
600	33	64.936999999999998	61.450000000000003
600	34	65.691000000000003	61.469999999999999
600	35	65.766000000000005	61.479999999999997
600	36	65.992999999999995	61.490000000000002
600	37	66.747	61.509999999999998
600	38	67.388000000000005	61.520000000000003
600	39	67.765000000000001	61.530000000000001
600	40	68.216999999999999	61.530000000000001
600	41	68.820999999999998	61.539999999999999
600	42	69.009	61.539999999999999
600	43	69.763000000000005	61.539999999999999
600	44	69.838999999999999	61.539999999999999
600	45	70.631	61.539999999999999
600	46	70.894999999999996	61.539999999999999
600	47	71.459999999999994	61.530000000000001
600	48	71.912999999999997	61.520000000000003
600	49	72.251999999999995	61.520000000000003
600	50	72.968000000000004	61.5
600	51	73.081999999999994	61.5
600	52	73.534000000000006	61.479999999999997
600	53	73.911000000000001	61.469999999999999
600	54	73.986999999999995	61.469999999999999
600	55	74.703000000000003	61.450000000000003
600	56	75.042000000000002	61.439999999999998
600	57	75.533000000000001	61.439999999999998
600	58	76.061000000000007	61.43
600	59	77.040999999999997	61.439999999999998
600	60	77.116	61.439999999999998
600	61	77.153999999999996	61.439999999999998
600	62	77.305000000000007	61.439999999999998
600	63	78.134	61.439999999999998
600	64	78.436000000000007	61.450000000000003
600	65	79.189999999999998	61.450000000000003
600	66	79.869	61.469999999999999
600	67	80.207999999999998	61.469999999999999
600	68	80.397000000000006	61.479999999999997
600	69	81.075999999999993	61.5
600	70	81.227000000000004	61.5
600	71	81.263999999999996	61.5
600	72	82.018000000000001	61.520000000000003
600	73	82.281999999999996	61.530000000000001
600	74	82.847999999999999	61.549999999999997
600	75	83.337999999999994	61.560000000000002
600	76	83.640000000000001	61.57
600	77	84.355999999999995	61.579999999999998
600	78	84.846000000000004	61.590000000000003
600	79	85.412000000000006	61.600000000000001
600	80	85.600999999999999	61.609999999999999
600	81	86.430000000000007	61.630000000000003
600	82	87.033000000000001	61.649999999999999
600	83	87.486000000000004	61.659999999999997
600	84	88.465999999999994	61.68
600	85	88.504000000000005	61.68
600	86	88.617000000000004	61.68
600	87	89.560000000000002	61.689999999999998
600	88	89.899000000000001	61.689999999999998
600	89	90.578000000000003	61.689999999999998
600	90	91.331999999999994	61.689999999999998
600	91	91.634	61.689999999999998
600	92	92.388000000000005	61.689999999999998
600	93	92.652000000000001	61.689999999999998
600	94	93.406000000000006	61.68
600	95	93.707999999999998	61.670000000000002
600	96	94.236000000000004	61.659999999999997
600	97	94.725999999999999	61.649999999999999
600	98	95.028000000000006	61.640000000000001
600	99	95.781999999999996	61.640000000000001
600	100	95.856999999999999	61.640000000000001
600	101	96.159000000000006	61.640000000000001
600	102	96.799999999999997	61.640000000000001
600	103	97.063999999999993	61.640000000000001
600	104	97.855999999999995	61.640000000000001
600	105	98.308000000000007	61.640000000000001
600	106	98.873999999999995	61.640000000000001
600	107	99.099999999999994	61.630000000000003
600	108	99.930000000000007	61.640000000000001
600	109	99.930000000000007	61.640000000000001
600	110	100.94799999999999	61.640000000000001
600	111	101.325	61.640000000000001
600	112	102.003	61.640000000000001
600	113	102.343	61.640000000000001
600	114	103.02200000000001	61.630000000000003
600	115	103.172	61.619999999999997
600	116	103.7	61.609999999999999
600	117	104.077	61.600000000000001
600	118	104.794	61.57
600	119	105.096	61.549999999999997
600	120	105.623	61.539999999999999
600	121	106.114	61.5
600	122	106.41500000000001	61.5
600	123	107.169	61.460000000000001
600	124	107.245	61.460000000000001
600	125	107.471	61.460000000000001
600	126	108.03700000000001	61.450000000000003
600	127	108.22499999999999	61.450000000000003
600	128	108.866	61.439999999999998
600	129	109.24299999999999	61.439999999999998
600	130	109.696	61.420000000000002
600	131	110.29900000000001	61.409999999999997
600	132	110.488	61.399999999999999
600	133	111.242	61.369999999999997
600	134	111.31699999999999	61.369999999999997
600	135	111.355	61.369999999999997
600	136	112.373	61.350000000000001
600	137	112.788	61.340000000000003
600	138	113.39100000000001	61.329999999999998
600	139	113.73099999999999	61.329999999999998
600	140	114.447	61.299999999999997
600	141	114.56	61.299999999999997
600	142	115.01300000000001	61.289999999999999
600	143	115.352	61.280000000000001
600	144	115.465	61.280000000000001
600	145	116.182	61.240000000000002
600	146	116.483	61.240000000000002
600	147	117.011	61.189999999999998
600	148	117.539	61.159999999999997
600	149	117.803	61.130000000000003
600	150	118.595	61.07
600	151	118.633	61.07
600	152	118.783	61.060000000000002
600	153	119.613	61
600	154	119.91500000000001	60.990000000000002
600	155	120.669	60.939999999999998
600	156	121.348	60.880000000000003
600	157	121.687	60.850000000000001
600	158	122.554	60.799999999999997
600	159	122.74299999999999	60.789999999999999
600	160	122.78	60.789999999999999
600	161	123.761	60.770000000000003
600	162	124.21299999999999	60.740000000000002
600	163	124.81699999999999	60.719999999999999
600	164	125.646	60.640000000000001
600	165	125.83499999999999	60.630000000000003
600	166	125.94799999999999	60.619999999999997
600	167	126.325	60.590000000000003
600	168	126.85299999999999	60.560000000000002
600	169	127.569	60.57
600	170	127.90900000000001	60.579999999999998
600	171	128.512	60.579999999999998
600	172	128.965	60.590000000000003
600	173	129.94499999999999	60.600000000000001
600	174	129.983	60.600000000000001
600	175	130.096	60.609999999999999
600	176	131.03800000000001	60.630000000000003
600	177	131.37799999999999	60.640000000000001
600	178	132.05699999999999	60.659999999999997
600	179	132.434	60.670000000000002
600	180	133.11199999999999	60.710000000000001
600	181	133.26300000000001	60.729999999999997
600	182	133.86699999999999	60.82
600	183	134.09299999999999	60.859999999999999
600	184	134.131	60.869999999999997
600	185	134.88499999999999	61.060000000000002
600	186	135.18600000000001	61.149999999999999
600	187	135.714	61.289999999999999
600	188	136.20400000000001	61.479999999999997
600	189	136.506	61.57
600	190	137.22300000000001	61.829999999999998
600	191	137.33600000000001	61.859999999999999
600	192	137.637	61.990000000000002
600	193	138.12799999999999	62.189999999999998
600	194	138.27799999999999	62.25
600	195	138.95699999999999	62.509999999999998
600	196	139.334	62.649999999999999
600	197	139.78700000000001	62.789999999999999
600	198	140.352	62.969999999999999
600	199	140.57900000000001	63.030000000000001
600	200	141.40799999999999	63.259999999999998
600	201	142.20500000000001	63.450000000000003
600	202	143.535	63.649999999999999
600	203	144.55699999999999	63.75
600	204	145.364	63.966000000000001
600	205	146.55600000000001	64.049999999999997
600	206	147.60300000000001	64.200000000000003
600	207	148.79400000000001	64.349999999999994
600	208	158.73099999999999	65.242000000000004
600	209	176.94499999999999	65.397000000000006
600	210	193.43000000000001	65.849000000000004
600	211	200	66.099999999999994
600	212	206.94499999999999	66.393000000000001
600	213	207.22399999999999	66.427000000000007
600	214	210.68100000000001	66.387
600	215	217.87899999999999	66.494
614	1	20.198	65
614	2	20.097999999999999	63.020000000000003
614	3	20.097999999999999	63.020000000000003
614	4	23.716000000000001	62.899000000000001
614	5	35.829999999999998	59.972000000000001
614	6	38.906999999999996	59.406999999999996
614	7	42.432000000000002	58.978000000000002
614	8	45.265000000000001	58.052
614	9	48.570999999999998	57.195999999999998
614	10	49.960000000000001	56.759999999999998
614	11	50.945999999999998	56.57
614	12	52	56.140000000000001
614	13	52.088999999999999	56.140000000000001
614	14	52.277999999999999	56.140000000000001
614	15	53.110999999999997	56.109999999999999
614	16	53.588999999999999	56.100000000000001
614	17	54.222000000000001	56.060000000000002
614	18	54.332999999999998	56.060000000000002
614	19	54.578000000000003	56.060000000000002
614	20	55.088999999999999	56.039999999999999
614	21	55.332999999999998	56.030000000000001
614	22	55.832999999999998	55.990000000000002
614	23	56.444000000000003	55.939999999999998
614	24	56.588999999999999	55.920000000000002
614	25	56.866	55.880000000000003
614	26	57.332999999999998	55.799999999999997
614	27	57.555	55.759999999999998
614	28	58.076999999999998	55.670000000000002
614	29	58.665999999999997	55.579999999999998
614	30	58.832999999999998	55.549999999999997
614	31	59.165999999999997	55.520000000000003
614	32	59.576999999999998	55.469999999999999
614	33	59.777000000000001	55.450000000000003
614	34	60.322000000000003	55.390000000000001
614	35	60.887999999999998	55.359999999999999
614	36	61.076999999999998	55.350000000000001
614	37	61.454999999999998	55.329999999999998
614	38	61.822000000000003	55.310000000000002
614	39	61.999000000000002	55.310000000000002
614	40	62.509999999999998	55.299999999999997
614	41	63.109999999999999	55.289999999999999
614	42	63.755000000000003	55.280000000000001
614	43	64.221000000000004	55.280000000000001
614	44	64.655000000000001	55.280000000000001
614	45	65.331999999999994	55.270000000000003
614	46	66.043000000000006	55.259999999999998
614	47	66.310000000000002	55.259999999999998
614	48	66.442999999999998	55.25
614	49	66.810000000000002	55.25
614	50	67.554000000000002	55.259999999999998
614	51	68.343000000000004	55.259999999999998
614	52	68.665999999999997	55.25
614	53	69.310000000000002	55.240000000000002
614	54	69.777000000000001	55.240000000000002
614	55	70.054000000000002	55.240000000000002
614	56	70.643000000000001	55.25
614	57	70.810000000000002	55.25
614	58	70.888000000000005	55.259999999999998
614	59	71.554000000000002	55.280000000000001
614	60	71.998999999999995	55.289999999999999
614	61	72.299000000000007	55.289999999999999
614	62	72.932000000000002	55.299999999999997
614	63	73.054000000000002	55.299999999999997
614	64	73.109999999999999	55.299999999999997
614	65	73.799000000000007	55.32
614	66	74.221000000000004	55.340000000000003
614	67	74.554000000000002	55.350000000000001
614	68	75.231999999999999	55.369999999999997
614	69	75.298000000000002	55.369999999999997
614	70	75.331999999999994	55.369999999999997
614	71	75.432000000000002	55.369999999999997
614	72	76.442999999999998	55.359999999999999
614	73	77.519999999999996	55.359999999999999
614	74	77.543000000000006	55.359999999999999
614	75	77.554000000000002	55.359999999999999
614	76	78.287000000000006	55.359999999999999
614	77	78.665000000000006	55.369999999999997
614	78	79.742999999999995	55.380000000000003
614	79	79.775999999999996	55.380000000000003
614	80	79.819999999999993	55.380000000000003
614	81	80.531000000000006	55.369999999999997
614	82	80.887	55.380000000000003
614	83	81.897999999999996	55.369999999999997
614	84	81.998000000000005	55.359999999999999
614	85	82.108999999999995	55.359999999999999
614	86	83.108999999999995	55.340000000000003
614	87	84.042000000000002	55.350000000000001
614	88	84.219999999999999	55.350000000000001
614	89	84.409000000000006	55.350000000000001
614	90	85.331000000000003	55.380000000000003
614	91	86.197999999999993	55.380000000000003
614	92	86.441999999999993	55.390000000000001
614	93	86.697999999999993	55.390000000000001
614	94	87.552999999999997	55.399999999999999
614	95	88.352999999999994	55.399999999999999
614	96	88.664000000000001	55.409999999999997
614	97	88.997	55.409999999999997
614	98	89.519999999999996	55.390000000000001
614	99	89.775000000000006	55.380000000000003
614	100	90.263999999999996	55.359999999999999
614	101	90.885999999999996	55.340000000000003
614	102	91.019999999999996	55.340000000000003
614	103	91.286000000000001	55.340000000000003
614	104	91.763999999999996	55.340000000000003
614	105	91.997	55.329999999999998
614	106	92.664000000000001	55.340000000000003
614	107	93.108000000000004	55.340000000000003
614	108	93.585999999999999	55.340000000000003
614	109	94.218999999999994	55.350000000000001
614	110	94.819000000000003	55.350000000000001
614	111	95.329999999999998	55.350000000000001
614	112	95.507999999999996	55.359999999999999
614	113	95.875	55.369999999999997
614	114	96.441000000000003	55.369999999999997
614	115	96.974999999999994	55.359999999999999
614	116	97.552000000000007	55.359999999999999
614	117	98.174999999999997	55.359999999999999
614	118	98.662999999999997	55.359999999999999
614	119	99.129999999999995	55.369999999999997
614	120	99.775000000000006	55.380000000000003
614	121	99.997	55.380000000000003
614	122	100.46299999999999	55.390000000000001
614	123	100.886	55.399999999999999
614	124	101.497	55.390000000000001
614	125	101.997	55.380000000000003
614	126	102.241	55.369999999999997
614	127	102.76300000000001	55.350000000000001
614	128	103.108	55.350000000000001
614	129	103.43000000000001	55.340000000000003
614	130	104.21899999999999	55.32
614	131	105.05200000000001	55.32
614	132	105.241	55.32
614	133	105.33	55.32
614	134	105.58499999999999	55.32
614	135	106.441	55.32
614	136	107.352	55.32
614	137	107.485	55.32
614	138	107.55200000000001	55.32
614	139	108.241	55.340000000000003
614	140	108.663	55.350000000000001
614	141	108.985	55.350000000000001
614	142	109.64100000000001	55.369999999999997
614	143	109.729	55.369999999999997
614	144	109.774	55.369999999999997
614	145	109.896	55.380000000000003
614	146	110.88500000000001	55.420000000000002
614	147	111.94	55.450000000000003
614	148	111.996	55.450000000000003
614	149	112.051	55.450000000000003
614	150	113.107	55.43
614	151	113.474	55.420000000000002
614	152	114.218	55.359999999999999
614	153	114.229	55.359999999999999
614	154	115.32899999999999	55.359999999999999
614	155	116.36199999999999	55.359999999999999
614	156	116.44	55.359999999999999
614	157	116.529	55.359999999999999
614	158	117.551	55.390000000000001
614	159	118.50700000000001	55.399999999999999
614	160	118.66200000000001	55.399999999999999
614	161	118.82899999999999	55.399999999999999
614	162	119.462	55.439999999999998
614	163	119.773	55.450000000000003
614	164	120.66200000000001	55.460000000000001
614	165	120.884	55.460000000000001
614	166	121.11799999999999	55.450000000000003
614	167	121.995	55.420000000000002
614	168	122.81699999999999	55.409999999999997
614	169	123.10599999999999	55.409999999999997
614	170	123.417	55.409999999999997
614	171	123.95099999999999	55.390000000000001
614	172	124.217	55.359999999999999
614	173	124.706	55.329999999999998
614	174	125.328	55.289999999999999
614	175	125.706	55.280000000000001
614	176	126.43899999999999	55.259999999999998
614	177	127.128	55.25
614	178	127.55	55.240000000000002
614	179	127.69499999999999	55.240000000000002
614	180	128.006	55.229999999999997
614	181	128.661	55.210000000000001
614	182	129.28399999999999	55.189999999999998
614	183	129.77199999999999	55.170000000000002
614	184	130.29499999999999	55.149999999999999
614	185	130.69499999999999	55.149999999999999
614	186	130.88399999999999	55.140000000000001
614	187	131.43899999999999	55.119999999999997
614	188	131.995	55.100000000000001
614	189	132.59399999999999	55.07
614	190	133.10599999999999	55.07
614	191	133.68299999999999	55.060000000000002
614	192	134.21700000000001	55.030000000000001
614	193	134.88300000000001	55.009999999999998
614	194	135.328	55
614	195	135.739	55
614	196	136.43899999999999	55
614	197	137.18299999999999	55.009999999999998
614	198	137.55000000000001	55.020000000000003
614	199	137.89400000000001	55.030000000000001
614	200	138.661	55.060000000000002
614	201	139.47200000000001	55.07
614	202	139.77199999999999	55.07
614	203	140.42699999999999	55.039999999999999
614	204	140.88300000000001	55.039999999999999
614	205	141.172	55.020000000000003
614	206	141.77199999999999	55.009999999999998
614	207	141.916	55
614	208	141.994	55
614	209	142.20500000000001	55.009999999999998
614	210	143.10499999999999	55
614	211	144.06	55.009999999999998
614	212	144.21600000000001	55.009999999999998
614	213	144.36000000000001	55.009999999999998
614	214	145.327	55
614	215	146.36000000000001	55
614	216	146.416	55
614	217	146.43799999999999	55
614	218	146.51599999999999	55
614	219	147.54900000000001	55.009999999999998
614	220	148.649	55.009999999999998
614	221	148.66	55.009999999999998
614	222	148.67099999999999	55.009999999999998
614	223	149.77099999999999	55.020000000000003
614	224	150.815	55.009999999999998
614	225	150.88200000000001	55.009999999999998
614	226	150.904	55.009999999999998
614	227	150.94900000000001	55.020000000000003
614	228	151.649	55.039999999999999
614	229	151.99299999999999	55.049999999999997
614	230	152.404	55.07
614	231	153.10400000000001	55.130000000000003
614	232	153.149	55.130000000000003
614	233	153.249	55.140000000000001
614	234	153.893	55.189999999999998
614	235	154.215	55.210000000000001
614	236	154.649	55.240000000000002
614	237	155.32599999999999	55.289999999999999
614	238	155.393	55.289999999999999
614	239	155.53700000000001	55.299999999999997
614	240	156.148	55.340000000000003
614	241	156.43700000000001	55.350000000000001
614	242	156.893	55.369999999999997
614	243	157.548	55.390000000000001
614	244	157.637	55.390000000000001
614	245	157.83699999999999	55.390000000000001
614	246	158.65899999999999	55.399999999999999
614	247	159.43700000000001	55.380000000000003
614	248	159.77000000000001	55.369999999999997
614	249	159.893	55.369999999999997
614	250	160.126	55.359999999999999
614	251	160.637	55.340000000000003
614	252	171.54400000000001	56.832999999999998
614	253	183.44200000000001	57.423999999999999
614	254	188.88800000000001	57.920000000000002
614	255	197.28999999999999	58.293999999999997
614	256	197.28999999999999	58.295000000000002
614	257	200	58.310000000000002
614	258	203.316	58.329000000000001
614	259	205.99799999999999	58.798000000000002
614	260	210.83199999999999	59.326000000000001
614	261	218.48599999999999	60.591000000000001
614	262	223.351	62.048000000000002
614	263	238.18299999999999	61.381
614	264	272.54199999999997	61.493000000000002
614	265	313.09199999999998	61.292000000000002
614	266	340.125	61.064
614	267	380.67500000000001	60.533000000000001
614	268	394.19099999999997	60.103000000000002
614	269	407.70800000000003	59.862000000000002
614	270	421.22399999999999	59.222000000000001
614	271	434.74099999999999	59.109999999999999
614	272	448.25700000000001	59.863
614	273	461.774	60.744999999999997
614	274	475.29000000000002	61.802
614	275	488.80700000000002	61.866999999999997
614	276	502.32400000000001	61.124000000000002
614	277	529.35699999999997	59.972000000000001
614	278	583.423	59.994
614	279	583.423	65
616	3	38.906999999999996	59.406999999999996
616	4	42.432000000000002	58.978000000000002
616	5	45.265000000000001	58.052
616	6	48.570999999999998	57.195999999999998
616	7	49.960000000000001	56.759999999999998
616	8	50.945999999999998	56.57
616	9	52	56.140000000000001
616	10	52.088999999999999	56.140000000000001
616	11	52.277999999999999	56.140000000000001
616	12	53.110999999999997	56.109999999999999
616	13	53.588999999999999	56.100000000000001
616	14	54.222000000000001	56.060000000000002
616	15	54.332999999999998	56.060000000000002
616	16	54.578000000000003	56.060000000000002
616	17	55.088999999999999	56.039999999999999
616	18	55.332999999999998	56.030000000000001
616	19	55.832999999999998	55.990000000000002
616	20	56.444000000000003	55.939999999999998
616	21	56.588999999999999	55.920000000000002
616	22	56.866	55.880000000000003
616	23	57.332999999999998	55.799999999999997
616	24	57.555	55.759999999999998
616	25	58.076999999999998	55.670000000000002
616	26	58.665999999999997	55.579999999999998
616	27	58.832999999999998	55.549999999999997
616	28	59.165999999999997	55.520000000000003
616	29	59.576999999999998	55.469999999999999
616	30	59.777000000000001	55.450000000000003
616	31	60.322000000000003	55.390000000000001
616	32	60.887999999999998	55.359999999999999
616	33	61.076999999999998	55.350000000000001
616	34	61.454999999999998	55.329999999999998
616	35	61.822000000000003	55.310000000000002
616	36	61.999000000000002	55.310000000000002
616	37	62.509999999999998	55.299999999999997
616	38	63.109999999999999	55.289999999999999
616	39	63.755000000000003	55.280000000000001
616	40	64.221000000000004	55.280000000000001
616	41	64.655000000000001	55.280000000000001
616	42	65.331999999999994	55.270000000000003
616	43	66.043000000000006	55.259999999999998
616	44	66.310000000000002	55.259999999999998
616	45	66.442999999999998	55.25
616	46	66.810000000000002	55.25
616	47	67.554000000000002	55.259999999999998
616	48	68.343000000000004	55.259999999999998
616	49	68.665999999999997	55.25
616	50	69.310000000000002	55.240000000000002
616	51	69.777000000000001	55.240000000000002
616	52	70.054000000000002	55.240000000000002
616	53	70.643000000000001	55.25
616	54	70.810000000000002	55.25
616	55	70.888000000000005	55.259999999999998
616	56	71.554000000000002	55.280000000000001
616	57	71.998999999999995	55.289999999999999
616	58	72.299000000000007	55.289999999999999
616	59	72.932000000000002	55.299999999999997
616	60	73.054000000000002	55.299999999999997
616	61	73.109999999999999	55.299999999999997
616	62	73.799000000000007	55.32
616	63	74.221000000000004	55.340000000000003
616	64	74.554000000000002	55.350000000000001
616	65	75.231999999999999	55.369999999999997
616	66	75.298000000000002	55.369999999999997
616	67	75.331999999999994	55.369999999999997
616	68	75.432000000000002	55.369999999999997
616	69	76.442999999999998	55.359999999999999
616	70	77.519999999999996	55.359999999999999
616	71	77.543000000000006	55.359999999999999
616	72	77.554000000000002	55.359999999999999
616	73	78.287000000000006	55.359999999999999
616	74	78.665000000000006	55.369999999999997
616	75	79.742999999999995	55.380000000000003
616	76	79.775999999999996	55.380000000000003
616	77	79.819999999999993	55.380000000000003
616	78	80.531000000000006	55.369999999999997
616	79	80.887	55.380000000000003
616	80	81.897999999999996	55.369999999999997
616	81	81.998000000000005	55.359999999999999
616	82	82.108999999999995	55.359999999999999
616	83	83.108999999999995	55.340000000000003
616	84	84.042000000000002	55.350000000000001
616	85	84.219999999999999	55.350000000000001
616	86	84.409000000000006	55.350000000000001
616	87	85.331000000000003	55.380000000000003
616	88	86.197999999999993	55.380000000000003
616	89	86.441999999999993	55.390000000000001
616	90	86.697999999999993	55.390000000000001
616	91	87.552999999999997	55.399999999999999
616	92	88.352999999999994	55.399999999999999
616	93	88.664000000000001	55.409999999999997
616	94	88.997	55.409999999999997
616	95	89.519999999999996	55.390000000000001
616	96	89.775000000000006	55.380000000000003
616	97	90.263999999999996	55.359999999999999
616	98	90.885999999999996	55.340000000000003
616	99	91.019999999999996	55.340000000000003
616	100	91.286000000000001	55.340000000000003
616	101	91.763999999999996	55.340000000000003
616	102	91.997	55.329999999999998
616	103	92.664000000000001	55.340000000000003
616	104	93.108000000000004	55.340000000000003
616	105	93.585999999999999	55.340000000000003
616	106	94.218999999999994	55.350000000000001
616	107	94.819000000000003	55.350000000000001
616	108	95.329999999999998	55.350000000000001
616	109	95.507999999999996	55.359999999999999
616	110	95.875	55.369999999999997
616	111	96.441000000000003	55.369999999999997
616	112	96.974999999999994	55.359999999999999
616	113	97.552000000000007	55.359999999999999
616	114	98.174999999999997	55.359999999999999
616	115	98.662999999999997	55.359999999999999
616	116	99.129999999999995	55.369999999999997
616	117	99.775000000000006	55.380000000000003
616	118	99.997	55.380000000000003
616	119	100.46299999999999	55.390000000000001
616	120	100.886	55.399999999999999
616	121	101.497	55.390000000000001
616	122	101.997	55.380000000000003
616	123	102.241	55.369999999999997
616	124	102.76300000000001	55.350000000000001
616	125	103.108	55.350000000000001
616	126	103.43000000000001	55.340000000000003
616	127	104.21899999999999	55.32
616	128	105.05200000000001	55.32
616	129	105.241	55.32
616	130	105.33	55.32
616	131	105.58499999999999	55.32
616	132	106.441	55.32
616	133	107.352	55.32
616	134	107.485	55.32
616	135	107.55200000000001	55.32
616	136	108.241	55.340000000000003
616	137	108.663	55.350000000000001
616	138	108.985	55.350000000000001
616	139	109.64100000000001	55.369999999999997
616	140	109.729	55.369999999999997
616	141	109.774	55.369999999999997
616	142	109.896	55.380000000000003
616	143	110.88500000000001	55.420000000000002
616	144	111.94	55.450000000000003
616	145	111.996	55.450000000000003
616	146	112.051	55.450000000000003
616	147	113.107	55.43
616	148	113.474	55.420000000000002
616	149	114.218	55.359999999999999
616	150	114.229	55.359999999999999
616	151	115.32899999999999	55.359999999999999
616	152	116.36199999999999	55.359999999999999
616	153	116.44	55.359999999999999
616	154	116.529	55.359999999999999
616	155	117.551	55.390000000000001
616	156	118.50700000000001	55.399999999999999
616	157	118.66200000000001	55.399999999999999
616	158	118.82899999999999	55.399999999999999
616	159	119.462	55.439999999999998
616	160	119.773	55.450000000000003
616	161	120.66200000000001	55.460000000000001
616	162	120.884	55.460000000000001
616	163	121.11799999999999	55.450000000000003
616	164	121.995	55.420000000000002
616	165	122.81699999999999	55.409999999999997
616	166	123.10599999999999	55.409999999999997
616	167	123.417	55.409999999999997
616	168	123.95099999999999	55.390000000000001
616	169	124.217	55.359999999999999
616	170	124.706	55.329999999999998
616	171	125.328	55.289999999999999
616	172	125.706	55.280000000000001
616	173	126.43899999999999	55.259999999999998
616	174	127.128	55.25
616	175	127.55	55.240000000000002
616	176	127.69499999999999	55.240000000000002
616	177	128.006	55.229999999999997
616	178	128.661	55.210000000000001
616	179	129.28399999999999	55.189999999999998
616	180	129.77199999999999	55.170000000000002
616	181	130.29499999999999	55.149999999999999
616	182	130.69499999999999	55.149999999999999
616	183	130.88399999999999	55.140000000000001
616	184	131.43899999999999	55.119999999999997
616	185	131.995	55.100000000000001
616	186	132.59399999999999	55.07
616	187	133.10599999999999	55.07
616	188	133.68299999999999	55.060000000000002
616	189	134.21700000000001	55.030000000000001
616	190	134.88300000000001	55.009999999999998
616	191	135.328	55
616	192	135.739	55
616	193	136.43899999999999	55
616	194	137.18299999999999	55.009999999999998
616	195	137.55000000000001	55.020000000000003
616	196	137.89400000000001	55.030000000000001
616	197	138.661	55.060000000000002
616	198	139.47200000000001	55.07
616	199	139.77199999999999	55.07
616	200	140.42699999999999	55.039999999999999
616	201	140.88300000000001	55.039999999999999
616	202	141.172	55.020000000000003
616	203	141.77199999999999	55.009999999999998
616	204	141.916	55
616	205	141.994	55
616	206	142.20500000000001	55.009999999999998
616	207	143.10499999999999	55
616	208	144.06	55.009999999999998
616	209	144.21600000000001	55.009999999999998
616	210	144.36000000000001	55.009999999999998
616	211	145.327	55
616	212	146.36000000000001	55
616	213	146.416	55
616	214	146.43799999999999	55
616	215	146.51599999999999	55
616	216	147.54900000000001	55.009999999999998
616	217	148.649	55.009999999999998
616	218	148.66	55.009999999999998
616	219	148.67099999999999	55.009999999999998
616	220	149.77099999999999	55.020000000000003
616	221	150.815	55.009999999999998
616	222	150.88200000000001	55.009999999999998
616	223	150.904	55.009999999999998
616	224	150.94900000000001	55.020000000000003
616	225	151.649	55.039999999999999
616	226	151.99299999999999	55.049999999999997
616	227	152.404	55.07
616	228	153.10400000000001	55.130000000000003
616	229	153.149	55.130000000000003
616	230	153.249	55.140000000000001
616	231	153.893	55.189999999999998
616	232	154.215	55.210000000000001
616	233	154.649	55.240000000000002
616	234	155.32599999999999	55.289999999999999
616	235	155.393	55.289999999999999
616	236	155.53700000000001	55.299999999999997
616	237	156.148	55.340000000000003
616	238	156.43700000000001	55.350000000000001
616	239	156.893	55.369999999999997
616	240	157.548	55.390000000000001
616	241	157.637	55.390000000000001
616	242	157.83699999999999	55.390000000000001
616	243	158.65899999999999	55.399999999999999
616	244	159.43700000000001	55.380000000000003
616	245	159.77000000000001	55.369999999999997
616	246	159.893	55.369999999999997
616	247	160.126	55.359999999999999
616	248	160.637	55.340000000000003
616	249	171.54400000000001	56.832999999999998
616	250	183.44200000000001	57.423999999999999
616	251	188.88800000000001	57.920000000000002
616	252	197.28999999999999	58.293999999999997
616	253	197.28999999999999	58.295000000000002
616	254	200	58.310000000000002
616	255	203.316	58.329000000000001
616	256	205.99799999999999	58.798000000000002
616	257	210.83199999999999	59.326000000000001
616	258	218.48599999999999	60.591000000000001
616	259	223.351	62.048000000000002
616	1	23.716000000000001	62.899000000000001
616	2	35.829999999999998	59.972000000000001
636	3	-829.52999999999997	56.740000000000002
636	4	-826.83000000000004	55.32
636	5	-824.13	54.280000000000001
636	6	-821.42999999999995	53.840000000000003
636	1	-845.73000000000002	56.18
636	2	-832.23000000000002	56.890000000000001
636	7	-759.33000000000004	52.039999999999999
636	8	-756.63	52.060000000000002
636	9	-748.52999999999997	52.57
636	10	-732.33000000000004	53.950000000000003
636	11	-716.13	54
636	12	-705.33000000000004	53.57
636	13	-689.13	52.189999999999998
636	14	-678.33000000000004	52.649999999999999
636	15	-662.13	53.969999999999999
636	16	-429.93000000000001	53.979999999999997
636	17	-392.13	53.630000000000003
636	18	-324.63	53.619999999999997
636	19	-95.120000000000005	54.060000000000002
636	20	-87.019999999999996	54.399999999999999
636	21	-78.920000000000002	54.009999999999998
636	22	-54.619999999999997	54
636	23	-44.990000000000002	54.409999999999997
636	24	-39.659999999999997	53.789999999999999
636	25	-31.870000000000001	53.310000000000002
636	26	-25.09	53.25
636	27	-21.370000000000001	53
636	28	-4.3700000000000001	52.909999999999997
636	29	0	52.979999999999997
636	30	1.9299999999999999	52.770000000000003
636	31	3.21	52.630000000000003
636	32	10.880000000000001	51.469999999999999
636	33	14.800000000000001	50.399999999999999
636	34	15.66	50.259999999999998
636	35	17.140000000000001	49.590000000000003
636	36	17.949999999999999	49.659999999999997
636	37	18.539999999999999	49.340000000000003
636	38	19.300000000000001	49.149999999999999
636	39	21.170000000000002	48.009999999999998
636	40	22.030000000000001	47.75
636	41	23.350000000000001	47.549999999999997
636	42	27.699999999999999	47.920000000000002
636	43	30.629999999999999	47.810000000000002
636	44	32.380000000000003	47.939999999999998
636	45	40.68	47.350000000000001
636	46	42.609999999999999	47.32
636	47	47.670000000000002	47.619999999999997
636	48	47.799999999999997	48.380000000000003
636	49	47.869999999999997	48.380000000000003
636	50	49.090000000000003	48.380000000000003
636	51	49.229999999999997	48.380000000000003
636	52	49.359999999999999	48.380000000000003
636	53	50.450000000000003	48.350000000000001
636	54	50.640000000000001	48.340000000000003
636	55	50.850000000000001	48.329999999999998
636	56	51.340000000000003	48.289999999999999
636	57	51.799999999999997	48.229999999999997
636	58	52.049999999999997	48.200000000000003
636	59	52.329999999999998	48.170000000000002
636	60	52.770000000000003	48.109999999999999
636	61	53.149999999999999	48.07
636	62	53.460000000000001	48.020000000000003
636	63	53.82	47.979999999999997
636	64	54.18	47.939999999999998
636	65	54.5	47.920000000000002
636	66	54.880000000000003	47.880000000000003
636	67	55.310000000000002	47.859999999999999
636	68	55.590000000000003	47.850000000000001
636	69	55.840000000000003	47.859999999999999
636	70	56.299999999999997	47.850000000000001
636	71	56.789999999999999	47.850000000000001
636	72	57.200000000000003	47.859999999999999
636	73	58.280000000000001	47.869999999999997
636	74	58.549999999999997	47.869999999999997
636	75	59.770000000000003	47.859999999999999
636	76	59.899999999999999	47.859999999999999
636	77	61.240000000000002	47.840000000000003
636	78	61.25	47.840000000000003
636	79	61.25	47.840000000000003
636	80	61.25	47.840000000000003
636	81	61.969999999999999	47.82
636	82	62.609999999999999	47.810000000000002
636	83	62.670000000000002	47.810000000000002
636	84	62.740000000000002	47.810000000000002
636	85	63.380000000000003	47.799999999999997
636	86	63.960000000000001	47.799999999999997
636	87	64.230000000000004	47.799999999999997
636	88	65.310000000000002	47.799999999999997
636	89	65.709999999999994	47.789999999999999
636	90	66.200000000000003	47.780000000000001
636	91	66.670000000000002	47.780000000000001
636	92	66.920000000000002	47.780000000000001
636	93	67.200000000000003	47.770000000000003
636	94	67.629999999999995	47.759999999999998
636	95	68	47.75
636	96	68.329999999999998	47.740000000000002
636	97	68.689999999999998	47.729999999999997
636	98	69.040000000000006	47.710000000000001
636	99	69.359999999999999	47.700000000000003
636	100	69.739999999999995	47.689999999999998
636	101	70.170000000000002	47.68
636	102	70.459999999999994	47.670000000000002
636	103	70.709999999999994	47.659999999999997
636	104	71.170000000000002	47.630000000000003
636	105	71.659999999999997	47.619999999999997
636	106	71.870000000000005	47.609999999999999
636	107	72.060000000000002	47.609999999999999
636	108	72.579999999999998	47.590000000000003
636	109	73.150000000000006	47.57
636	110	73.280000000000001	47.57
636	111	73.409999999999997	47.57
636	112	74.629999999999995	47.549999999999997
636	113	74.769999999999996	47.549999999999997
636	114	76.079999999999998	47.549999999999997
636	115	76.120000000000005	47.549999999999997
636	116	76.120000000000005	47.549999999999997
636	117	77.469999999999999	47.549999999999997
636	118	77.609999999999999	47.549999999999997
636	119	78.25	47.539999999999999
636	120	78.829999999999998	47.539999999999999
636	121	79.090000000000003	47.539999999999999
636	122	79.659999999999997	47.530000000000001
636	123	80.159999999999997	47.520000000000003
636	124	80.370000000000005	47.509999999999998
636	125	80.579999999999998	47.509999999999998
636	126	81.069999999999993	47.490000000000002
636	127	81.519999999999996	47.460000000000001
636	128	81.780000000000001	47.450000000000003
636	129	82.069999999999993	47.43
636	130	82.480000000000004	47.420000000000002
636	131	82.870000000000005	47.390000000000001
636	132	83.549999999999997	47.380000000000003
636	133	84.219999999999999	47.369999999999997
636	134	85.040000000000006	47.359999999999999
636	135	85.579999999999998	47.350000000000001
636	136	86.530000000000001	47.32
636	137	86.930000000000007	47.32
636	138	88.010000000000005	47.32
636	139	88.280000000000001	47.329999999999998
636	140	89.5	47.380000000000003
636	141	89.629999999999995	47.380000000000003
636	142	90.909999999999997	47.43
636	143	90.989999999999995	47.43
636	144	90.989999999999995	47.43
636	145	92.340000000000003	47.460000000000001
636	146	92.469999999999999	47.460000000000001
636	147	93.680000000000007	47.460000000000001
636	148	93.959999999999994	47.460000000000001
636	149	95.030000000000001	47.469999999999999
636	150	95.450000000000003	47.469999999999999
636	151	96.379999999999995	47.450000000000003
636	152	96.930000000000007	47.43
636	153	97.349999999999994	47.390000000000001
636	154	97.739999999999995	47.390000000000001
636	155	98.420000000000002	47.369999999999997
636	156	99.090000000000003	47.350000000000001
636	157	99.909999999999997	47.340000000000003
636	158	100.44	47.340000000000003
636	159	101.39	47.350000000000001
636	160	101.79000000000001	47.369999999999997
636	161	102.88	47.399999999999999
636	162	103.15000000000001	47.409999999999997
636	163	104.37	47.43
636	164	104.5	47.43
636	165	105.75	47.43
636	166	105.84	47.43
636	167	105.84999999999999	47.43
636	168	107.19	47.390000000000001
636	169	107.34	47.390000000000001
636	170	107.98	47.369999999999997
636	171	108.54000000000001	47.359999999999999
636	172	108.83	47.359999999999999
636	173	109.39	47.350000000000001
636	174	109.90000000000001	47.350000000000001
636	175	110.09	47.340000000000003
636	176	110.31	47.350000000000001
636	177	111.25	47.350000000000001
636	178	111.52	47.350000000000001
636	179	111.8	47.350000000000001
636	180	112.59999999999999	47.340000000000003
636	181	112.93000000000001	47.329999999999998
636	182	113.29000000000001	47.329999999999998
636	183	113.95	47.310000000000002
636	184	114.34	47.299999999999997
636	185	114.77	47.289999999999999
636	186	115.05	47.289999999999999
636	187	115.31	47.299999999999997
636	188	115.75	47.299999999999997
636	189	116.26000000000001	47.32
636	190	116.65000000000001	47.329999999999998
636	191	117.75	47.359999999999999
636	192	117.88	47.359999999999999
636	193	118	47.359999999999999
636	194	118.59	47.350000000000001
636	195	119.23	47.350000000000001
636	196	119.29000000000001	47.340000000000003
636	197	119.34999999999999	47.340000000000003
636	198	120.01000000000001	47.32
636	199	120.7	47.280000000000001
636	200	120.72	47.280000000000001
636	201	120.72	47.280000000000001
636	202	121.42	47.240000000000002
636	203	122.06	47.219999999999999
636	204	122.13	47.219999999999999
636	205	122.20999999999999	47.219999999999999
636	206	123.41	47.210000000000001
636	207	123.69	47.210000000000001
636	208	124.76000000000001	47.200000000000003
636	209	125.18000000000001	47.200000000000003
636	210	126.12	47.210000000000001
636	211	126.67	47.219999999999999
636	212	127.08	47.229999999999997
636	213	127.47	47.25
636	214	127.8	47.259999999999998
636	215	128.15000000000001	47.280000000000001
636	216	128.81999999999999	47.310000000000002
636	217	129.21000000000001	47.310000000000002
636	218	129.63999999999999	47.32
636	219	130.16	47.310000000000002
636	220	130.62	47.299999999999997
636	221	131.13	47.32
636	222	131.50999999999999	47.329999999999998
636	223	132.03	47.329999999999998
636	224	132.61000000000001	47.350000000000001
636	225	132.86000000000001	47.350000000000001
636	226	133.46000000000001	47.329999999999998
636	227	134.09999999999999	47.350000000000001
636	228	134.22	47.350000000000001
636	229	134.87	47.32
636	230	135.56999999999999	47.329999999999998
636	231	135.59	47.329999999999998
636	232	136.28	47.299999999999997
636	233	136.91999999999999	47.32
636	234	137	47.32
636	235	137.06999999999999	47.329999999999998
636	236	137.69999999999999	47.329999999999998
636	237	138.28	47.359999999999999
636	238	138.41	47.369999999999997
636	239	138.56	47.369999999999997
636	240	139.12	47.380000000000003
636	241	139.63	47.390000000000001
636	242	139.81999999999999	47.399999999999999
636	243	140.05000000000001	47.399999999999999
636	244	140.53999999999999	47.420000000000002
636	245	140.97999999999999	47.43
636	246	141.53	47.43
636	247	141.94999999999999	47.420000000000002
636	248	142.33000000000001	47.420000000000002
636	249	142.66	47.399999999999999
636	250	143.02000000000001	47.390000000000001
636	251	143.36000000000001	47.380000000000003
636	252	143.66999999999999	47.380000000000003
636	253	144.5	47.380000000000003
636	254	144.77000000000001	47.369999999999997
636	255	145.03	47.359999999999999
636	256	145.49000000000001	47.350000000000001
636	257	145.99000000000001	47.340000000000003
636	258	146.38	47.340000000000003
636	259	147.47999999999999	47.32
636	260	147.72999999999999	47.32
636	261	148.96000000000001	47.289999999999999
636	262	149.08000000000001	47.289999999999999
636	263	150.25999999999999	47.289999999999999
636	264	150.44	47.289999999999999
636	265	150.44	47.289999999999999
636	266	150.44999999999999	47.289999999999999
636	267	151.78999999999999	47.329999999999998
636	268	151.86000000000001	47.329999999999998
636	269	151.94	47.329999999999998
636	270	152.56	47.359999999999999
636	271	153.13999999999999	47.380000000000003
636	272	153.41999999999999	47.390000000000001
636	273	154.5	47.409999999999997
636	274	154.91	47.420000000000002
636	275	155.83000000000001	47.409999999999997
636	276	156.40000000000001	47.409999999999997
636	277	157.19	47.390000000000001
636	278	157.53	47.380000000000003
636	279	157.88	47.380000000000003
636	280	158.22999999999999	47.369999999999997
636	281	158.53999999999999	47.369999999999997
636	282	159.37	47.369999999999997
636	283	159.88999999999999	47.369999999999997
636	284	160.34999999999999	47.369999999999997
636	285	160.86000000000001	47.369999999999997
636	286	161.24000000000001	47.369999999999997
636	287	162.34	47.369999999999997
636	288	162.47999999999999	47.369999999999997
636	289	162.59999999999999	47.369999999999997
636	290	163.18000000000001	47.350000000000001
636	291	163.83000000000001	47.329999999999998
636	292	163.88999999999999	47.329999999999998
636	293	163.94999999999999	47.329999999999998
636	294	164.59999999999999	47.310000000000002
636	295	165.30000000000001	47.299999999999997
636	296	165.30000000000001	47.299999999999997
636	297	165.31999999999999	47.299999999999997
636	298	166.02000000000001	47.299999999999997
636	299	166.63999999999999	47.310000000000002
636	300	166.72999999999999	47.32
636	301	166.80000000000001	47.32
636	302	167.43000000000001	47.350000000000001
636	303	167.99000000000001	47.369999999999997
636	304	168.28999999999999	47.390000000000001
636	305	168.84	47.420000000000002
636	306	169.34999999999999	47.450000000000003
636	307	169.55000000000001	47.460000000000001
636	308	169.78	47.460000000000001
636	309	170.27000000000001	47.490000000000002
636	310	175.41	51
636	311	183.71000000000001	51.049999999999997
636	312	202.91999999999999	52.460000000000001
636	313	212.22	52.700000000000003
636	314	237.97999999999999	52.590000000000003
636	315	249.16999999999999	51.880000000000003
636	316	255.53999999999999	51.590000000000003
636	317	262.13	52.25
636	318	281.94	51.560000000000002
636	319	288.31999999999999	52.770000000000003
636	320	289.68000000000001	53.030000000000001
636	321	294.06999999999999	54.170000000000002
636	322	295.61000000000001	54.740000000000002
636	323	299.07999999999998	56.560000000000002
637	1	-44.990000000000002	54.409999999999997
637	2	-39.659999999999997	53.789999999999999
637	3	-31.870000000000001	53.310000000000002
637	4	-25.09	53.25
637	5	-21.370000000000001	53
637	6	-4.3700000000000001	52.909999999999997
637	7	0	52.979999999999997
637	8	1.9299999999999999	52.770000000000003
637	9	3.21	52.630000000000003
637	10	10.880000000000001	51.469999999999999
637	11	14.800000000000001	50.399999999999999
637	12	15.66	50.259999999999998
637	13	17.140000000000001	49.590000000000003
637	14	17.949999999999999	49.659999999999997
637	15	18.539999999999999	49.340000000000003
637	16	19.300000000000001	49.149999999999999
637	17	21.170000000000002	48.009999999999998
637	18	22.030000000000001	47.75
637	19	23.350000000000001	47.549999999999997
637	20	27.699999999999999	47.920000000000002
637	21	30.629999999999999	47.810000000000002
637	22	32.380000000000003	47.939999999999998
637	23	40.68	47.350000000000001
637	24	42.609999999999999	47.32
637	25	47.670000000000002	47.619999999999997
637	26	47.799999999999997	48.380000000000003
637	27	47.869999999999997	48.380000000000003
637	28	49.090000000000003	48.380000000000003
637	29	49.229999999999997	48.380000000000003
637	30	49.359999999999999	48.380000000000003
637	31	50.450000000000003	48.350000000000001
637	32	50.640000000000001	48.340000000000003
637	33	50.850000000000001	48.329999999999998
637	34	51.340000000000003	48.289999999999999
637	35	51.799999999999997	48.229999999999997
637	36	52.049999999999997	48.200000000000003
637	37	52.329999999999998	48.170000000000002
637	38	52.770000000000003	48.109999999999999
637	39	53.149999999999999	48.07
637	40	53.460000000000001	48.020000000000003
637	41	53.82	47.979999999999997
637	42	54.18	47.939999999999998
637	43	54.5	47.920000000000002
637	44	54.880000000000003	47.880000000000003
637	45	55.310000000000002	47.859999999999999
637	46	55.590000000000003	47.850000000000001
637	47	55.840000000000003	47.859999999999999
637	48	56.299999999999997	47.850000000000001
637	49	56.789999999999999	47.850000000000001
637	50	57.200000000000003	47.859999999999999
637	51	58.280000000000001	47.869999999999997
637	52	58.549999999999997	47.869999999999997
637	53	59.770000000000003	47.859999999999999
637	54	59.899999999999999	47.859999999999999
637	55	61.240000000000002	47.840000000000003
637	56	61.25	47.840000000000003
637	57	61.25	47.840000000000003
637	58	61.25	47.840000000000003
637	59	61.969999999999999	47.82
637	60	62.609999999999999	47.810000000000002
637	61	62.670000000000002	47.810000000000002
637	62	62.740000000000002	47.810000000000002
637	63	63.380000000000003	47.799999999999997
637	64	63.960000000000001	47.799999999999997
637	65	64.230000000000004	47.799999999999997
637	66	65.310000000000002	47.799999999999997
637	67	65.709999999999994	47.789999999999999
637	68	66.200000000000003	47.780000000000001
637	69	66.670000000000002	47.780000000000001
637	70	66.920000000000002	47.780000000000001
637	71	67.200000000000003	47.770000000000003
637	72	67.629999999999995	47.759999999999998
637	73	68	47.75
637	74	68.329999999999998	47.740000000000002
637	75	68.689999999999998	47.729999999999997
637	76	69.040000000000006	47.710000000000001
637	77	69.359999999999999	47.700000000000003
637	78	69.739999999999995	47.689999999999998
637	79	70.170000000000002	47.68
637	80	70.459999999999994	47.670000000000002
637	81	70.709999999999994	47.659999999999997
637	82	71.170000000000002	47.630000000000003
637	83	71.659999999999997	47.619999999999997
637	84	71.870000000000005	47.609999999999999
637	85	72.060000000000002	47.609999999999999
637	86	72.579999999999998	47.590000000000003
637	87	73.150000000000006	47.57
637	88	73.280000000000001	47.57
637	89	73.409999999999997	47.57
637	90	74.629999999999995	47.549999999999997
637	91	74.769999999999996	47.549999999999997
637	92	76.079999999999998	47.549999999999997
637	93	76.120000000000005	47.549999999999997
637	94	76.120000000000005	47.549999999999997
637	95	77.469999999999999	47.549999999999997
637	96	77.609999999999999	47.549999999999997
637	97	78.25	47.539999999999999
637	98	78.829999999999998	47.539999999999999
637	99	79.090000000000003	47.539999999999999
637	100	79.659999999999997	47.530000000000001
637	101	80.159999999999997	47.520000000000003
637	102	80.370000000000005	47.509999999999998
637	103	80.579999999999998	47.509999999999998
637	104	81.069999999999993	47.490000000000002
637	105	81.519999999999996	47.460000000000001
637	106	81.780000000000001	47.450000000000003
637	107	82.069999999999993	47.43
637	108	82.480000000000004	47.420000000000002
637	109	82.870000000000005	47.390000000000001
637	110	83.549999999999997	47.380000000000003
637	111	84.219999999999999	47.369999999999997
637	112	85.040000000000006	47.359999999999999
637	113	85.579999999999998	47.350000000000001
637	114	86.530000000000001	47.32
637	115	86.930000000000007	47.32
637	116	88.010000000000005	47.32
637	117	88.280000000000001	47.329999999999998
637	118	89.5	47.380000000000003
637	119	89.629999999999995	47.380000000000003
637	120	90.909999999999997	47.43
637	121	90.989999999999995	47.43
637	122	90.989999999999995	47.43
637	123	92.340000000000003	47.460000000000001
637	124	92.469999999999999	47.460000000000001
637	125	93.680000000000007	47.460000000000001
637	126	93.959999999999994	47.460000000000001
637	127	95.030000000000001	47.469999999999999
637	128	95.450000000000003	47.469999999999999
637	129	96.379999999999995	47.450000000000003
637	130	96.930000000000007	47.43
637	131	97.349999999999994	47.390000000000001
637	132	97.739999999999995	47.390000000000001
637	133	98.420000000000002	47.369999999999997
637	134	99.090000000000003	47.350000000000001
637	135	99.909999999999997	47.340000000000003
637	136	100.44	47.340000000000003
637	137	101.39	47.350000000000001
637	138	101.79000000000001	47.369999999999997
637	139	102.88	47.399999999999999
637	140	103.15000000000001	47.409999999999997
637	141	104.37	47.43
637	142	104.5	47.43
637	143	105.75	47.43
637	144	105.84	47.43
637	145	105.84999999999999	47.43
637	146	107.19	47.390000000000001
637	147	107.34	47.390000000000001
637	148	107.98	47.369999999999997
637	149	108.54000000000001	47.359999999999999
637	150	108.83	47.359999999999999
637	151	109.39	47.350000000000001
637	152	109.90000000000001	47.350000000000001
637	153	110.09	47.340000000000003
637	154	110.31	47.350000000000001
637	155	111.25	47.350000000000001
637	156	111.52	47.350000000000001
637	157	111.8	47.350000000000001
637	158	112.59999999999999	47.340000000000003
637	159	112.93000000000001	47.329999999999998
637	160	113.29000000000001	47.329999999999998
637	161	113.95	47.310000000000002
637	162	114.34	47.299999999999997
637	163	114.77	47.289999999999999
637	164	115.05	47.289999999999999
637	165	115.31	47.299999999999997
637	166	115.75	47.299999999999997
637	167	116.26000000000001	47.32
637	168	116.65000000000001	47.329999999999998
637	169	117.75	47.359999999999999
637	170	117.88	47.359999999999999
637	171	118	47.359999999999999
637	172	118.59	47.350000000000001
637	173	119.23	47.350000000000001
637	174	119.29000000000001	47.340000000000003
637	175	119.34999999999999	47.340000000000003
637	176	120.01000000000001	47.32
637	177	120.7	47.280000000000001
637	178	120.72	47.280000000000001
637	179	120.72	47.280000000000001
637	180	121.42	47.240000000000002
637	181	122.06	47.219999999999999
637	182	122.13	47.219999999999999
637	183	122.20999999999999	47.219999999999999
637	184	123.41	47.210000000000001
637	185	123.69	47.210000000000001
637	186	124.76000000000001	47.200000000000003
637	187	125.18000000000001	47.200000000000003
637	188	126.12	47.210000000000001
637	189	126.67	47.219999999999999
637	190	127.08	47.229999999999997
637	191	127.47	47.25
637	192	127.8	47.259999999999998
637	193	128.15000000000001	47.280000000000001
637	194	128.81999999999999	47.310000000000002
637	195	129.21000000000001	47.310000000000002
637	196	129.63999999999999	47.32
637	197	130.16	47.310000000000002
637	198	130.62	47.299999999999997
637	199	131.13	47.32
637	200	131.50999999999999	47.329999999999998
637	201	132.03	47.329999999999998
637	202	132.61000000000001	47.350000000000001
637	203	132.86000000000001	47.350000000000001
637	204	133.46000000000001	47.329999999999998
637	205	134.09999999999999	47.350000000000001
637	206	134.22	47.350000000000001
637	207	134.87	47.32
637	208	135.56999999999999	47.329999999999998
637	209	135.59	47.329999999999998
637	210	136.28	47.299999999999997
637	211	136.91999999999999	47.32
637	212	137	47.32
637	213	137.06999999999999	47.329999999999998
637	214	137.69999999999999	47.329999999999998
637	215	138.28	47.359999999999999
637	216	138.41	47.369999999999997
637	217	138.56	47.369999999999997
637	218	139.12	47.380000000000003
637	219	139.63	47.390000000000001
637	220	139.81999999999999	47.399999999999999
637	221	140.05000000000001	47.399999999999999
637	222	140.53999999999999	47.420000000000002
637	223	140.97999999999999	47.43
637	224	141.53	47.43
637	225	141.94999999999999	47.420000000000002
637	226	142.33000000000001	47.420000000000002
637	227	142.66	47.399999999999999
637	228	143.02000000000001	47.390000000000001
637	229	143.36000000000001	47.380000000000003
637	230	143.66999999999999	47.380000000000003
637	231	144.5	47.380000000000003
637	232	144.77000000000001	47.369999999999997
637	233	145.03	47.359999999999999
637	234	145.49000000000001	47.350000000000001
637	235	145.99000000000001	47.340000000000003
637	236	146.38	47.340000000000003
637	237	147.47999999999999	47.32
637	238	147.72999999999999	47.32
637	239	148.96000000000001	47.289999999999999
637	240	149.08000000000001	47.289999999999999
637	241	150.25999999999999	47.289999999999999
637	242	150.44	47.289999999999999
637	243	150.44	47.289999999999999
637	244	150.44999999999999	47.289999999999999
637	245	151.78999999999999	47.329999999999998
637	246	151.86000000000001	47.329999999999998
637	247	151.94	47.329999999999998
637	248	152.56	47.359999999999999
637	249	153.13999999999999	47.380000000000003
637	250	153.41999999999999	47.390000000000001
637	251	154.5	47.409999999999997
637	252	154.91	47.420000000000002
637	253	155.83000000000001	47.409999999999997
637	254	156.40000000000001	47.409999999999997
637	255	157.19	47.390000000000001
637	256	157.53	47.380000000000003
637	257	157.88	47.380000000000003
637	258	158.22999999999999	47.369999999999997
637	259	158.53999999999999	47.369999999999997
637	260	159.37	47.369999999999997
637	261	159.88999999999999	47.369999999999997
637	262	160.34999999999999	47.369999999999997
637	263	160.86000000000001	47.369999999999997
637	264	161.24000000000001	47.369999999999997
637	265	162.34	47.369999999999997
637	266	162.47999999999999	47.369999999999997
637	267	162.59999999999999	47.369999999999997
637	268	163.18000000000001	47.350000000000001
637	269	163.83000000000001	47.329999999999998
637	270	163.88999999999999	47.329999999999998
637	271	163.94999999999999	47.329999999999998
637	272	164.59999999999999	47.310000000000002
637	273	165.30000000000001	47.299999999999997
637	274	165.30000000000001	47.299999999999997
637	275	165.31999999999999	47.299999999999997
637	276	166.02000000000001	47.299999999999997
637	277	166.63999999999999	47.310000000000002
637	278	166.72999999999999	47.32
637	279	166.80000000000001	47.32
637	280	167.43000000000001	47.350000000000001
637	281	167.99000000000001	47.369999999999997
637	282	168.28999999999999	47.390000000000001
637	283	168.84	47.420000000000002
637	284	169.34999999999999	47.450000000000003
637	285	169.55000000000001	47.460000000000001
637	286	169.78	47.460000000000001
637	287	170.27000000000001	47.490000000000002
637	288	175.41	51
637	289	183.71000000000001	51.049999999999997
637	290	202.91999999999999	52.460000000000001
637	291	212.22	52.700000000000003
637	292	237.97999999999999	52.590000000000003
637	293	249.16999999999999	51.880000000000003
637	294	255.53999999999999	51.590000000000003
637	295	262.13	52.25
637	296	281.94	51.560000000000002
637	297	288.31999999999999	52.770000000000003
637	298	289.68000000000001	53.030000000000001
637	299	294.06999999999999	54.170000000000002
637	300	295.61000000000001	54.740000000000002
1055	3	-12.651999999999999	57.359000000000002
1055	4	-5.2389999999999999	57.325000000000003
1055	5	0	57.280000000000001
1055	6	4.1219999999999999	57.244
1055	7	8.3480000000000008	57.008000000000003
1055	8	10.239000000000001	56.850999999999999
1055	9	11.691000000000001	56.646000000000001
1055	10	17.939	55.348999999999997
1055	11	21.535	54.622999999999998
1055	12	22.036999999999999	54.549999999999997
1055	13	23.023	54.359999999999999
1055	14	23.677	54.238
1055	15	25.292000000000002	53.770000000000003
1055	16	26.986999999999998	53.710000000000001
1055	17	28.648	53.82
1055	18	30.757999999999999	53.939999999999998
1055	19	31.353000000000002	53.838000000000001
1055	20	32.968000000000004	53.560000000000002
1055	21	35.198999999999998	52.969999999999999
1055	22	37.719999999999999	53.119999999999997
1055	23	40.390000000000001	53.359999999999999
1055	24	42.652999999999999	53.390000000000001
1055	25	44.905999999999999	53.469999999999999
1055	26	47.350000000000001	53.240000000000002
1055	27	49.982999999999997	53.200000000000003
1055	28	52.588999999999999	53.119999999999997
1055	29	55.362000000000002	53.07
1055	30	57.987000000000002	53.030000000000001
1055	31	60.655999999999999	52.950000000000003
1055	32	63.335000000000001	52.969999999999999
1055	33	66.001999999999995	52.880000000000003
1055	34	68.686999999999998	52.619999999999997
1055	35	71.334999999999994	52.719999999999999
1055	36	73.938000000000002	52.670000000000002
1055	37	76.427999999999997	52.640000000000001
1055	38	78.888999999999996	52.759999999999998
1055	39	81.382999999999996	52.619999999999997
1055	40	83.905000000000001	52.68
1055	41	86.403000000000006	52.740000000000002
1055	42	88.829999999999998	52.729999999999997
1055	43	91.284999999999997	52.539999999999999
1055	44	93.757000000000005	52.560000000000002
1055	45	96.260999999999996	52.579999999999998
1055	46	98.783000000000001	52.590000000000003
1055	47	101.349	52.57
1055	48	103.94	52.450000000000003
1055	49	106.505	52.469999999999999
1055	50	109.095	52.32
1055	51	111.81100000000001	52.259999999999998
1055	52	114.411	52.369999999999997
1055	53	116.81999999999999	52.420000000000002
1055	54	119.125	52.380000000000003
1055	55	121.575	52.399999999999999
1055	56	123.89400000000001	52.369999999999997
1055	57	126.117	52.420000000000002
1055	58	128.21100000000001	52.240000000000002
1055	59	130.31800000000001	52.219999999999999
1055	60	132.52000000000001	52.079999999999998
1055	61	134.68100000000001	51.990000000000002
1055	62	137.07499999999999	52.710000000000001
1055	63	139.15199999999999	53.369999999999997
1055	64	141.232	53.43
1055	65	143.41200000000001	53.990000000000002
1055	66	145.114	54.310000000000002
1055	67	145.608	54.399999999999999
1055	68	146.15199999999999	54.5
1055	69	146.76400000000001	54.594999999999999
1055	70	148.67500000000001	55.021000000000001
1055	71	153.19900000000001	56.134
1055	72	159.911	56.479999999999997
1055	73	168.89099999999999	56.841000000000001
1055	74	178.858	56.689999999999998
1055	75	188.52600000000001	56.526000000000003
1055	76	191.70099999999999	56.655000000000001
1055	77	196.55799999999999	57.890999999999998
1055	78	199.63	58.566000000000003
1055	79	200.001	58.567999999999998
1055	80	220.34	58.651000000000003
1055	81	245.161	58.707000000000001
1056	1	-116.962	61.542000000000002
1056	2	-111.562	58.103000000000002
1056	3	-108.86199999999999	58
1056	4	-98.061999999999998	57.975999999999999
1056	5	-79.162000000000006	57.5
1056	6	-70.192999999999998	57.594000000000001
1056	7	-43.165999999999997	57.356999999999999
1056	8	-33.761000000000003	57.853000000000002
1056	9	-15.388	58.052
1056	10	-8.2810000000000006	56.179000000000002
1056	11	-5.2750000000000004	56.377000000000002
1056	12	0	57.738
1056	13	1.175	58.040999999999997
1056	14	8.6180000000000003	58.200000000000003
1056	15	18.609999999999999	58.359999999999999
1056	16	25.632000000000001	58.523000000000003
1056	17	26.823	58.305
1056	18	29.625	57.018000000000001
1056	19	33.655000000000001	55.82
1056	20	37.006	54.823999999999998
1056	21	38.289999999999999	54.380000000000003
1056	22	38.609999999999999	54.302999999999997
1056	23	40.478000000000002	53.789999999999999
1056	24	42.055999999999997	53.399999999999999
1056	25	43.469999999999999	53.270000000000003
1056	26	45.465000000000003	52.850000000000001
1056	27	47.652999999999999	52.549999999999997
1056	28	49.829000000000001	53.090000000000003
1056	29	52.347999999999999	53.149999999999999
1056	30	55.277000000000001	53.119999999999997
1056	31	58.192	52.799999999999997
1056	32	61.133000000000003	52.530000000000001
1056	33	63.127000000000002	52.409999999999997
1056	34	65.117999999999995	52.280000000000001
1056	35	67.158000000000001	52.289999999999999
1056	36	69.245999999999995	52.140000000000001
1056	37	71.343999999999994	52.170000000000002
1056	38	74.278999999999996	52.100000000000001
1056	39	77.364999999999995	51.960000000000001
1056	40	79.388000000000005	51.93
1056	41	81.400999999999996	51.869999999999997
1056	42	83.491	51.770000000000003
1056	43	85.578999999999994	51.780000000000001
1056	44	87.578000000000003	51.880000000000003
1056	45	89.623000000000005	51.710000000000001
1056	46	92.510999999999996	51.68
1056	47	94.599999999999994	51.700000000000003
1056	48	96.668999999999997	51.740000000000002
1056	49	98.691999999999993	51.68
1056	50	101.539	51.640000000000001
1056	51	104.367	51.619999999999997
1056	52	107.236	51.57
1056	53	110.163	51.590000000000003
1056	54	112.377	51.490000000000002
1055	1	-21.526	58.116
1055	2	-17.227	57.462000000000003
1056	55	114.59699999999999	51.609999999999999
1056	56	116.79300000000001	51.700000000000003
1056	57	118.819	51.700000000000003
1056	58	121.01000000000001	51.729999999999997
1056	59	123.861	51.850000000000001
1056	60	125.965	51.93
1056	61	128.648	52.200000000000003
1056	62	131.27799999999999	52.259999999999998
1056	63	133.768	52.299999999999997
1056	64	136.364	52.369999999999997
1056	65	138.99299999999999	52.380000000000003
1056	66	141.34299999999999	52.350000000000001
1056	67	143.691	52.18
1056	68	145.822	52.240000000000002
1056	69	147.827	52.359999999999999
1056	70	149.83199999999999	52.899999999999999
1056	71	151.84200000000001	53.539999999999999
1056	72	153.84899999999999	54.030000000000001
1056	73	154.77600000000001	54.137
1056	74	155.048	54.270000000000003
1056	75	156.49299999999999	54.719999999999999
1056	76	160.392	55.819000000000003
1056	77	160.40799999999999	55.823999999999998
1056	78	162.76400000000001	55.731999999999999
1056	79	164.376	55.372
1056	80	166.62100000000001	54.950000000000003
1056	81	167.24100000000001	54.692
1056	82	168.333	54.159999999999997
1056	83	168.577	54.103000000000002
1056	84	170.41999999999999	54.060000000000002
1056	85	172.827	53.909999999999997
1056	86	174.97	53.700000000000003
1056	87	177.26599999999999	53.490000000000002
1056	88	179.352	53.329999999999998
1056	89	181.61799999999999	53.130000000000003
1056	90	183.816	52.950000000000003
1056	91	185.899	52.909999999999997
1056	92	187.92400000000001	52.990000000000002
1056	93	190.279	53.109999999999999
1056	94	192.37799999999999	53.299999999999997
1056	95	194.49799999999999	53.469999999999999
1056	96	196.61199999999999	53.560000000000002
1056	97	198.709	53.68
1056	98	200.001	53.704999999999998
1056	99	200.81299999999999	53.719999999999999
1056	100	202.732	53.710000000000001
1056	101	204.61199999999999	53.539999999999999
1056	102	206.68700000000001	53.5
1056	103	208.708	53.5
1056	104	210.48699999999999	53.469999999999999
1056	105	211.47900000000001	53.490000000000002
1056	106	213.43799999999999	53.840000000000003
1056	107	215.68899999999999	54.719999999999999
1056	108	217.18000000000001	56.252000000000002
1056	109	221.79900000000001	58.325000000000003
1056	110	227.137	58.384999999999998
1056	111	249.607	58.536999999999999
1056	112	282.81900000000002	58.779000000000003
1438	3	-78.924000000000007	54.014000000000003
1438	4	-54.624000000000002	54
1438	5	-44.984999999999999	54.412999999999997
1438	6	-39.661999999999999	53.787999999999997
1438	7	-31.869	53.311
1438	8	-25.085999999999999	53.244999999999997
1438	9	-21.373000000000001	53.000999999999998
1438	10	-4.3719999999999999	52.905000000000001
1438	11	0	52.984000000000002
1438	12	1.931	52.768000000000001
1438	13	3.2090000000000001	52.625
1438	14	10.880000000000001	51.470999999999997
1438	15	14.795999999999999	50.395000000000003
1438	16	15.663	50.259999999999998
1438	17	17.135999999999999	49.591000000000001
1438	18	17.952000000000002	49.655000000000001
1438	19	18.536999999999999	49.344000000000001
1438	20	19.297999999999998	49.152000000000001
1438	21	21.170999999999999	48.012
1438	22	22.026	47.749000000000002
1438	23	23.349	47.545999999999999
1438	24	27.699999999999999	47.915999999999997
1438	25	30.632999999999999	47.805
1438	26	32.375	47.938000000000002
1438	27	40.683	47.350000000000001
1438	28	42.613999999999997	47.317999999999998
1438	29	47.668999999999997	47.615000000000002
1438	30	52.366	47.518000000000001
1438	31	54.595999999999997	47.759
1438	32	56.731000000000002	47.664000000000001
1438	33	57.598999999999997	47.759
1438	34	63.826999999999998	47.877000000000002
1438	35	67.498999999999995	47.715000000000003
1438	36	73.236000000000004	47.749000000000002
1438	37	75.147999999999996	47.609000000000002
1438	38	80.531000000000006	47.750999999999998
1438	39	84.590999999999994	47.588999999999999
1438	40	85.582999999999998	47.393999999999998
1438	41	87.352999999999994	47.621000000000002
1438	42	96.5	47.616999999999997
1438	43	98.662999999999997	47.463000000000001
1438	44	108.706	47.695999999999998
1438	45	112.54900000000001	47.582000000000001
1438	46	118.188	47.558999999999997
1438	47	120.151	47.661999999999999
1438	48	123.253	47.554000000000002
1438	49	125.24299999999999	47.685000000000002
1438	50	129.911	47.273000000000003
1438	51	131.55799999999999	47.506999999999998
1438	52	136.12	47.475000000000001
1438	53	142.53700000000001	47.695
1438	54	146.16300000000001	47.594999999999999
1438	55	147.172	47.432000000000002
1438	56	149.708	49.546999999999997
1438	57	152.76499999999999	50.042000000000002
1438	58	159.57599999999999	51.893999999999998
1438	59	161.16900000000001	52.218000000000004
1438	60	163.51300000000001	52.018000000000001
1438	61	175.41399999999999	51.000999999999998
1438	62	183.70699999999999	51.054000000000002
1438	63	202.917	52.460999999999999
1438	64	212.21799999999999	52.698999999999998
1438	65	237.97999999999999	52.588000000000001
1438	66	249.16900000000001	51.875
1438	67	255.53800000000001	51.590000000000003
1438	68	262.125	52.250999999999998
1438	69	281.94099999999997	51.564
1438	70	288.31700000000001	52.768000000000001
1438	71	289.68299999999999	53.026000000000003
1438	72	294.06900000000002	54.173999999999999
1438	73	295.60599999999999	54.744
1438	74	299.07499999999999	56.561999999999998
1438	1	-95.123999999999995	54.063000000000002
1438	2	-87.024000000000001	54.396000000000001
\.


--
-- Data for Name: hpeilung; Type: TABLE DATA; Schema: public; Owner: -
--

COPY hpeilung (hpeilungid, stationid, km, datum, glwname, glwhoehe, buliabst, bulihoehe, bulifuss, buliruecken, bureabst, burehoehe, burefuss, bureruecken, fahrliabst, fahrreabst, fahrtief, ausbliabst, ausbreabst, achseabst, teilvonabst, teilbisabst, hmabst, lgkrechts, lgkhoch, lgkhoehe, rgkrechts, rgkhoch, rgkhoehe, bemerkung, lastupdated, oldprfid, mitteabst) FROM stdin;
178	82	46.599999999999994	1994-01-01 00:00:00	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2005-09-23 09:13:58	147	54.274000000000001
180	84	59.449999999999989	1994-01-01 00:00:00	\N	\N	\N	\N	\N	\N	151.28	75.150000000000006	5	89.599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2005-09-23 09:13:59	148	103.69799999999999
181	85	76.599999999999994	1994-01-01 00:00:00	\N	\N	44.149999999999999	72.590000000000003	4	50	143.44	71.969999999999999	5	300	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2005-09-23 09:14:03	150	93.795000000000002
182	86	18.199999999999989	1994-01-01 00:00:00	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	200	\N	\N	\N	\N	\N	\N	\N	2005-09-23 09:13:59	146	56.017000000000003
184	88	106.40000000000001	1994-01-01 00:00:00	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2005-09-23 09:13:59	151	98.182000000000002
185	89	137.19999999999999	1994-01-01 00:00:00	\N	\N	0	0	\N	\N	162.88999999999999	58.039999999999999	5	100	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2005-09-23 09:14:03	189	81.444999999999993
186	90	166.59999999999999	1994-01-01 00:00:00	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2005-09-23 09:13:59	191	95.640000000000001
501	353	33.599999999999994	1990-01-01 00:00:00	\N	76.950000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Torgau 1: MW (1984/1993)	2006-10-06 13:40:00	\N	\N
502	354	33.799999999999983	1990-01-01 00:00:00	\N	76.950000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Torgau 1: MW (1984/1993)	2006-10-06 13:40:00	\N	\N
503	358	34.400000000000006	1990-01-01 00:00:00	\N	76.950000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Torgau 1: MW (1984/1993)	2006-10-06 13:40:00	\N	\N
504	359	34.799999999999983	1990-01-01 00:00:00	\N	76.950000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Torgau 1: MW (1984/1993)	2006-10-06 13:40:00	\N	\N
505	360	35	1990-01-01 00:00:00	\N	76.950000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Torgau 1: MW (1984/1993)	2006-10-06 13:40:00	\N	\N
506	363	36.099999999999994	1990-01-01 00:00:00	\N	76.950000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Torgau 1: MW (1984/1993)	2006-10-06 13:40:00	\N	\N
507	366	37.099999999999994	1990-01-01 00:00:00	\N	76.950000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Torgau 1: MW (1984/1993)	2006-10-06 13:40:00	\N	\N
508	369	38.099999999999994	1990-01-01 00:00:00	\N	76.950000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Torgau 1: MW (1984/1993)	2006-10-06 13:40:00	\N	\N
509	377	41.099999999999994	1990-01-01 00:00:00	\N	76.950000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Torgau 1: MW (1984/1993)	2006-10-06 13:40:00	\N	\N
510	379	41.599999999999994	1990-01-01 00:00:00	\N	76.950000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Torgau 1: MW (1984/1993)	2006-10-06 13:40:00	\N	\N
511	381	44.599999999999994	1990-01-01 00:00:00	\N	76.950000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Torgau 1: MW (1984/1993)	2006-10-06 13:40:00	\N	\N
577	82	46.799999999999983	2004-01-01 00:00:00	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2006-11-27 00:00:00	\N	54
576	86	18.199999999999989	2004-01-01 00:00:00	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	200	\N	\N	\N	\N	\N	\N	\N	2006-11-27 00:00:00	\N	52
578	84	59.400000000000006	2004-01-01 00:00:00	\N	\N	\N	\N	\N	\N	151.28	75.150000000000006	5	89.599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Profil mit Vorland bis zum Deich (für Wst größer 78 m)	2006-11-27 00:00:00	\N	107
579	84	59.400000000000006	2004-01-02 00:00:00	\N	\N	\N	\N	\N	\N	151.28	75.150000000000006	5	89.599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Profil ohne Vorland (für Wst kleiner 78 m)	2006-11-27 00:00:00	\N	107
594	85	76.599999999999994	2004-01-01 00:00:00	\N	\N	44.149999999999999	72.590000000000003	4	50	143.44	71.969999999999999	5	300	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Profil mit Vorland bis zum Deich (für Wst größer 73,70 m)	2006-11-28 00:00:00	\N	93.795000000000002
599	88	106.40000000000001	2004-05-20 00:00:00	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Profil mit Vorland (für Wst größer 66,50 m) 	2006-11-28 00:00:00	\N	98.182000000000002
598	85	76.599999999999994	2004-01-02 00:00:00	\N	\N	44.149999999999999	72.590000000000003	4	50	143.44	71.969999999999999	5	300	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Profil ohne Vorland (für Wst kleiner 73,70 m) 	2006-11-28 00:00:00	\N	93.795000000000002
600	88	106.40000000000001	2004-05-21 00:00:00	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Profil ohne Vorland (für Wst kleiner 66,50 m)	2006-11-28 00:00:00	\N	98.182000000000002
614	89	137.40000000000001	2004-05-30 00:00:00	\N	\N	\N	\N	\N	\N	162.88999999999999	58.039999999999999	5	100	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Profil mit Vorland (für Wst größer 62 m) 	2006-11-28 00:00:00	\N	81.444999999999993
636	90	166.59999999999999	2004-06-10 00:00:00	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Profil (bei km 282,2) mit Vorland bis zum Deich (für Wst größer 54,41 m)	2006-11-28 00:00:00	\N	96.5
616	89	137.40000000000001	2004-05-31 00:00:00	\N	\N	\N	\N	\N	\N	162.88999999999999	58.039999999999999	5	100	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Profil ohne Vorland (für Wst kleiner 62 m) 	2006-11-28 00:00:00	\N	81.444999999999993
637	90	166.59999999999999	2004-06-11 00:00:00	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Profil (bei km 282,2) ohne Vorland (für Wst kleiner 54,41 m) 	2006-11-28 00:00:00	\N	96.5
1056	2801	151.40000000000001	1994-01-01 00:00:00	\N	\N	\N	\N	\N	\N	160.41	55.829999999999998	5	100	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2008-03-27 00:00:00	\N	100
1055	2800	150.99999999999997	1994-01-01 00:00:00	\N	\N	31.353000000000002	55.469000000000001	5	100	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2008-03-27 00:00:00	\N	75
1438	90	173.79999999999998	1990-01-01 00:00:00	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2011-07-01 16:47:39	\N	90
\.


--
-- Data for Name: messung; Type: TABLE DATA; Schema: public; Owner: -
--

COPY messung (messungid, stationid, datum, hpeilungid, mpeilungid, gfaengerid, gsiebsatzid, messnr, fgue, uhrvon, uhrbis, wspcm, q_bpegel, wspnn, ie, wtemp, gbreite, gbreitevon, gbreitebis, tgeschiebe, tsand, tschweb, cschweb, uferliabst, uferreabst, q, a_hpeil, a_mpeil, b, hm, vm, vsohle, tau, tauv, teil_q, teil_a_hpeil, teil_a_mpeil, teil_b, teil_hm, teil_vm, teil_vsohle, teil_tau, teil_tauv, mitteltyp, dm, sk, so, u, d90, d84, d80, d75, d70, d60, d50, d40, d30, d25, d20, d16, d10, dmin, durchdmin, dmax, durchdmax, n_geschieb, n_vielpkt, sys_date, bemerkung, lastupdated, km, glotabstoffset, slotabstoffset, gbreitevonlinks, gbreitebislinks, glotuferabstistvonlinks, slotuferabstistvonlinks) FROM stdin;
2025	86	2000-04-10 00:00:00	182	\N	\N	\N	36	WEL127-036	2000-04-10 09:00:00	2000-04-10 12:30:00	427	561.785071021877	87.25	0.28	8	\N	\N	\N	\N	1.587	13.311	16.515000000000001	-1.486	112.97499999999999	657.29300000000001	506.70001	\N	114.461	4.4269999999999996	1.5906	0.76300001	12.160500000000001	0.110275	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	2003-06-05 00:00:00	keine Geschiebemessung	2011-12-01 01:38:17	18.199999999999989	0	0	\N	\N	1	1
2082	88	2002-08-14 00:00:00	184	\N	3	\N	30	WEL215-030	2002-08-14 11:30:00	2002-08-14 15:30:00	577	1428.857810911722	68.099999999999994	0.22	17.799999	86.769999999999996	55.420000000000002	142.19	2.9729999999999999	\N	\N	\N	-96.480000000000004	447.26299999999998	\N	1300.7	\N	543.74300000000005	2.3919999999999999	1.5761	\N	5.1624999999999996	0.071850999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	6	0	2003-07-16 00:00:00	\N	2011-12-01 03:08:49	106.40000000000001	0	0	55.420000000000002	142.19	1	1
10866	90	2010-03-02 00:00:00	1438	\N	2	3	56	\N	2010-03-02 07:00:00	2010-03-02 14:00:00	433	694.21579496003665	53.280000000000001	0.17	4	97	42	139	16.475000000000001	\N	\N	\N	-28.683	290.65300000000002	\N	965.29999	\N	319.33600000000001	3.0230000000000001	1.0319	\N	5.0408999999999997	0.070999000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.0430000000000001	1.0840000000000001	2.5499999999999998	4.1970000000000001	6.4158999999999997	5.1532999999999998	4.3613999999999997	3.7605	3.3833000000000002	2.6288999999999998	1.9411	1.5869	1.2326999999999999	1.0556000000000001	0.90429999999999999	0.79279999999999995	0.62639999999999996	0.125	0.0040000002	16	99.401001	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:18:53	173.79999999999998	1	0	42	139	1	0
10867	90	2010-04-01 00:00:00	1438	\N	2	3	57	\N	2010-04-01 07:00:00	2010-04-01 11:15:00	467	787.61430552694924	53.479999999999997	0.19	9	88	42	130	7.1749999999999998	\N	\N	\N	-34.630000000000003	291.41800000000001	\N	1030	\N	326.048	3.1589999999999998	1.0971	\N	5.8883000000000001	0.076734999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.2730000000000001	1.0700000000000001	2.4180000000000001	3.907	6.8426999999999998	5.3113999999999999	4.5324999999999998	3.8439999999999999	3.4998999999999998	2.8115999999999999	2.1232000000000002	1.7197	1.3783000000000001	1.2075	1.0367999999999999	0.90820000000000001	0.71950000000000003	0.125	0.0070000002	16	98.988998	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:18:50	173.79999999999998	1	0	42	130	1	0
1895	82	1995-01-31 00:00:00	178	\N	2	5	9	\N	1995-01-31 10:00:00	1995-01-31 12:55:00	551	874.04277799185343	80.400000000000006	0.22	\N	86.5	27	113.5	5.6559999999999997	\N	\N	\N	-12.544	272.28899999999999	\N	750.59998	\N	284.83300000000003	2.6349999999999998	1.6708	\N	5.6870000000000003	0.075412000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	7.9870000000000001	0.71799999999999997	3.625	9.7460000000000004	18.4941	16.346699999999998	14.915100000000001	13.1256	11.3361	8.0032999999999994	5.3205	3.5684999999999998	2.3761000000000001	1.8713	1.5226999999999999	1.2438	0.82120000000000004	0.125	0.026000001	20	94.208	6	0	2003-06-05 00:00:00	Peilung von km 155,0 verwendet	2011-12-01 02:25:17	45.599999999999994	0	0	27	113.5	1	1
1896	82	1995-02-01 00:00:00	178	\N	2	5	10	\N	1995-02-01 09:00:00	1995-02-01 13:30:00	554	882.40682371426351	80.430000000000007	0.22	\N	49.960000000000001	53	102.95999999999999	2.2629999999999999	10.693	151.011	119.282	-12.837999999999999	272.66399999999999	1314.7909999999999	759.09998	\N	285.50099999999998	2.6589999999999998	1.6677001	0.44580001	5.7384000000000004	0.075752	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	7.5380000000000003	1.071	2.8530000000000002	4.5640000000000001	18.047999999999998	14.895099999999999	12.793100000000001	10.165699999999999	8.7217000000000002	6.3525999999999998	5.0437000000000003	3.8397000000000001	2.9906000000000001	2.5659999999999998	2.1415000000000002	1.8297000000000001	1.3916999999999999	0.25	0.043000001	20	93.714996	5	2	2003-06-05 00:00:00	Peilung von km 155,0 verwendet	2011-12-01 02:24:40	45.599999999999994	0	0	53	102.95999999999999	1	1
1897	82	1995-03-28 00:00:00	577	\N	2	5	11	\N	1995-03-28 10:30:00	1995-03-28 14:00:00	283	305.28766886796791	77.689999999999998	0.2	5	48	32	80	0.071999999999999995	2.0510000000000002	18.123999999999999	41.378999999999998	7.7869999999999999	103.13500000000001	422.45499999999998	378.20001	\N	95.347999999999999	3.9660000000000002	1.1583	0.58090001	7.7812999999999999	0.088211999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	7.141	0.83499999999999996	2.899	5.2450000000000001	16.618099999999998	14.005599999999999	12.2639	10.0868	8.9055	6.7874999999999996	5.2884000000000002	3.9630000000000001	2.9091999999999998	2.3824000000000001	1.9149	1.6665000000000001	1.2941	0.5	2.392	20	97.766998	6	4	2003-06-05 00:00:00	\N	2011-12-01 02:24:03	46.799999999999983	0	0	32	80	1	1
1898	82	1995-04-26 00:00:00	577	\N	2	5	12	\N	1995-04-26 09:00:00	1995-04-26 13:15:00	397	499.05472810380144	78.829999999999998	0.2	12	36	47	83	0.0060000000000000001	4.4610000000000003	41.628999999999998	58.140999999999998	2.8359999999999999	107.908	672.01400000000001	491.79999	\N	105.072	4.681	1.4558001	0.73290002	9.1841000000000008	0.095834000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.5700000000000001	0.78000000000000003	2.2429999999999999	3.7210000000000001	3.2629999999999999	2.5249000000000001	2.0329000000000002	1.8845000000000001	1.7625	1.5185	1.2745	1.0304	0.70320000000000005	0.59930000000000005	0.54530000000000001	0.502	0.40810000000000002	0.5	15.813	6.2999999999999998	97.773003	4	4	2003-06-05 00:00:00	\N	2011-12-01 02:23:42	46.799999999999983	0	0	47	83	1	1
1899	82	1995-07-11 00:00:00	577	\N	2	5	13	\N	1995-07-11 09:00:00	1995-07-11 13:15:00	211	213.28316592145705	76.969999999999999	0.2	22	26	31	57	0.019	1.1439999999999999	8.6940000000000008	28.411000000000001	9.8800000000000008	100.083	286.03300000000002	311.39999	\N	90.203000000000003	3.452	0.98280001	0.49329999	6.7721999999999998	0.082294000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.964	1.631	3.1539999999999999	4.1980000000000004	7.4779	5.6078000000000001	4.7460000000000004	3.8275999999999999	3.2667000000000002	2.145	1.3922000000000001	0.92210000000000003	0.74419999999999997	0.65529999999999999	0.59860000000000002	0.56359999999999999	0.51100000000000001	0.25	0.028999999	10	94.971001	6	5	2003-06-05 00:00:00	\N	2011-12-01 02:22:46	46.799999999999983	0	0	31	57	1	1
1900	82	1995-09-27 00:00:00	577	\N	2	\N	14	\N	1995-09-27 11:00:00	1995-09-27 14:30:00	286	309.46969172917295	77.719999999999999	0.2	14	0	0	0	\N	1.1519999999999999	6.1870000000000003	13.936	7.6989999999999998	103.26000000000001	405.39800000000002	381	\N	95.561000000000007	3.9870000000000001	1.1653	0.5147	7.8228	0.088445999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	4	4	2003-06-05 00:00:00	\N	2011-12-01 02:22:25	46.799999999999983	0	0	0	0	1	1
1901	82	1995-10-04 00:00:00	577	\N	2	5	15	\N	1995-10-04 11:00:00	1995-10-04 14:30:00	321	359.65396606363345	78.069999999999993	0.20999999	13	63.539999999999999	25.460000000000001	89	0.0030000000000000001	1.476	6.1630000000000003	11.944000000000001	6.5229999999999997	104.726	499.71600000000001	414.89999	\N	98.203000000000003	4.2249999999999996	1.2436	0.59219998	8.7042000000000002	0.093296000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.61599999999999999	1.1240000000000001	1.619	1.867	0.99229999999999996	0.86370000000000002	0.77800000000000002	0.67090000000000005	0.61299999999999999	0.55820000000000003	0.50329999999999997	0.45200000000000001	0.40100000000000002	0.3755	0.34999999999999998	0.3296	0.29899999999999999	0.25	0.40200001	2	99.196999	4	4	2003-06-05 00:00:00	\N	2011-12-01 02:21:44	46.799999999999983	0	0	25.460000000000001	89	1	1
1902	82	1996-06-13 00:00:00	178	\N	2	5	17	\N	1996-06-13 09:00:00	1996-06-13 16:30:00	200	200.04009352764109	77.219999999999999	0.2	18	63.469999999999999	24.530000000000001	88	0.19600000000000001	2.0190000000000001	22.388999999999999	78.010999999999996	9.1530000000000005	101.143	276.70100000000002	317.39999	\N	91.989999999999995	3.4510000000000001	0.9041	0.5061	6.7706	0.082283999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.748	1.105	1.665	1.962	1.2634000000000001	0.93869999999999998	0.87180000000000002	0.78820000000000001	0.70469999999999999	0.59660000000000002	0.53620000000000001	0.47689999999999999	0.41930000000000001	0.39050000000000001	0.36170000000000002	0.33860000000000001	0.30399999999999999	0.25	0.62699997	8	99.764999	6	6	2003-06-05 00:00:00	Peilung von km 155,0 verwendet	2011-12-01 02:19:57	45.599999999999994	0	0	24.530000000000001	88	1	1
1903	82	1996-07-12 00:00:00	178	\N	2	5	18	\N	1996-07-12 08:30:00	1996-07-12 11:00:00	447	606.39331487473078	79.689999999999998	0.20999999	15	59.640000000000001	33.359999999999999	93	7.8259999999999996	\N	\N	\N	-5.5919999999999996	112.20099999999999	\N	570.70001	\N	117.79300000000001	4.8449999999999998	1.5243	\N	9.9818999999999996	0.099908999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	6.9130000000000003	1.4490000000000001	5.3959999999999999	11.053000000000001	19.701000000000001	16.3597	14.132199999999999	11.3477	8.9781999999999993	5.0712000000000002	2.5188999999999999	1.5229999999999999	0.9476	0.78129999999999999	0.62309999999999999	0.56189999999999996	0.45879999999999999	0.25	0.086999997	20	90.537003	4	0	2003-06-05 00:00:00	Peilung von km 155,0 verwendet	2011-12-01 02:19:35	45.599999999999994	0	0	33.359999999999999	93	1	1
1904	82	1996-03-25 00:00:00	178	\N	2	\N	16	\N	1996-03-25 12:00:00	1996-03-25 15:00:00	288	312.25770696997631	77.890000000000001	0.20999999	4.8000002	0	0	0	\N	3.3420000000000001	18.135999999999999	40.482999999999997	7.141	103.97199999999999	368.25900000000001	380.70001	\N	96.831000000000003	3.931	1.1768	0.61970001	8.0991	0.089995000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	5	2003-06-05 00:00:00	kein Geschiebe auf dieser Messfahrt	2011-12-01 02:21:00	46.599999999999994	0	0	0	0	1	1
1905	82	1996-10-14 00:00:00	178	\N	2	5	19	\N	1996-10-14 10:30:00	1996-10-14 14:30:00	159	155.43184967478732	76.890000000000001	0.2	12	62.840000000000003	29.68	92.519999999999996	0.79600000000000004	0.63300000000000001	4.1909999999999998	18.792000000000002	10.112	99.744	197.762	287.5	\N	89.631	3.2069999999999999	0.77569997	0.39629999	6.2927999999999997	0.079326999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.1819999999999999	3.528	3.2690000000000001	2.5049999999999999	11.3652	4.9626000000000001	2.7502	1.7874000000000001	1.4648000000000001	0.95809999999999995	0.80820000000000003	0.6583	0.57589999999999997	0.54259999999999997	0.50929999999999997	0.46429999999999999	0.38240000000000002	0.125	0.018999999	20	96.642998	5	5	2003-06-05 00:00:00	Peilung von km 155,0 verwendet; Messung km 153.6	2011-12-01 02:18:44	45.199999999999989	0	0	29.68	92.519999999999996	1	1
1906	82	1997-10-20 00:00:00	178	\N	2	5	21	\N	1997-10-20 10:00:00	1997-10-20 14:30:00	146	142.18877728097135	76.760000000000005	0.2	5	53	34	87	0.40999999999999998	\N	\N	\N	10.49	99.191999999999993	\N	275.89999	\N	88.701999999999998	3.1099999999999999	0.73940003	\N	6.1022999999999996	0.078117000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.95999999999999996	1.413	1.9319999999999999	2.3130000000000002	1.7458	1.4428000000000001	1.2406999999999999	0.99650000000000005	0.92230000000000001	0.77390000000000003	0.62819999999999998	0.56659999999999999	0.50509999999999999	0.46400000000000002	0.4209	0.38640000000000002	0.33460000000000001	0.25	0.2	10	99.667	5	0	2003-06-05 00:00:00	Peilung von km 155,0 verwendet; Messung 153.6	2011-12-01 02:17:57	45.199999999999989	0	0	34	87	1	1
1907	82	1997-11-18 00:00:00	178	\N	2	5	22	\N	1997-11-18 08:00:00	1997-11-18 11:30:00	130	126.85469345655288	76.599999999999994	0.20999999	6	36	35	71	0.085999999999999993	0.59399999999999997	3.0590000000000002	16.806000000000001	10.955	98.513999999999996	153.501	261.79999	\N	87.558999999999997	2.9900000000000002	0.69520003	0.4718	6.1593	0.078480999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.81000000000000005	1.2569999999999999	1.831	2.2029999999999998	1.5799000000000001	1.2396	1.0126999999999999	0.93069999999999997	0.85809999999999997	0.71299999999999997	0.60389999999999999	0.54310000000000003	0.47749999999999998	0.439	0.40050000000000002	0.36980000000000002	0.3236	0.25	0.43200001	8	99.914001	5	3	2003-04-02 00:00:00	Peilung von km 155,0 verwendet; Messung 153.6	2011-12-01 02:17:28	45.199999999999989	0	0	35	71	1	1
1908	82	1998-03-05 00:00:00	178	\N	2	5	23	\N	1998-03-05 08:45:00	1998-03-05 11:00:00	178	175.64496017061168	77.079999999999998	0.20999999	7	29.899999999999999	46.100000000000001	76	0.0070000000000000001	0.60999999999999999	2.1469999999999998	8.5190000000000001	9.5600000000000005	100.54900000000001	190.12700000000001	304.60001	\N	90.989000000000004	3.3479999999999999	0.8272	0.40279999	6.8973000000000004	0.083049999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.2640000000000002	0.88300000000000001	3.1230000000000002	5.8550000000000004	11.4	7.5012999999999996	6.5266999999999999	5.6292	4.8049999999999997	3.5110999999999999	2.5556000000000001	1.8	1.3222	1.0832999999999999	0.89639999999999997	0.76910000000000001	0.59970000000000001	0.5	4.651	10	88.372002	3	3	2003-06-05 00:00:00	Messung km 153.6; Peilung von km 155,0 verwendet	2011-12-01 02:16:58	45.199999999999989	0	0	46.100000000000001	76	1	1
1909	82	1998-04-02 00:00:00	178	\N	2	5	24	\N	1998-04-02 08:15:00	1998-04-02 13:45:00	228	233.49627641728139	77.579999999999998	0.2	9	52.75	25.25	78	0.036999999999999998	0.96199999999999997	0.96199999999999997	2.8700000000000001	8.1069999999999993	102.67	301.822	351	\N	94.563000000000002	3.7120000000000002	0.95429999	0.4226	7.2831000000000001	0.085341	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.3380000000000001	2.1749999999999998	2.4079999999999999	2.246	5.3224999999999998	2.1025	1.6686000000000001	1.2250000000000001	0.94399999999999995	0.71650000000000003	0.59209999999999996	0.53090000000000004	0.46410000000000001	0.4279	0.3916	0.36259999999999998	0.31900000000000001	0.25	0.48300001	20	96.778999	4	5	2003-06-05 00:00:00	Peilung von km 155,0 verwendet; keine Messung von Feinschwebstoff Messung km 153.6	2011-12-01 02:16:27	45.199999999999989	0	0	25.25	78	1	1
1912	82	1999-09-15 00:00:00	178	\N	\N	\N	26	WEL155-026	1999-09-15 08:30:00	1999-09-15 14:45:00	108	106.64158296072853	76.379999999999995	0.20999999	19	\N	\N	\N	\N	0.26000000000000001	3.1579999999999999	20.641999999999999	11.593999999999999	97.581000000000003	89.462999999999994	242.7	\N	85.986999999999995	2.8220000000000001	0.6304	0.3267	5.8146000000000004	0.076253000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1	2003-06-05 00:00:00	Peilung von km 155,0 verwendet; Sondermessung, keine Geschiebemessung	2011-12-01 02:16:12	45.199999999999989	0	0	\N	\N	1	1
1913	82	2000-04-27 00:00:00	178	\N	\N	\N	27	WEL155-027	2000-04-27 09:00:00	2000-04-27 14:30:00	284	306.68167648836959	77.060000000000002	0.2	13.9	\N	\N	\N	\N	1.274	12.917999999999999	29.359000000000002	9.6180000000000003	100.465	280.29700000000003	302.79999	\N	90.846000000000004	3.3330000000000002	1.4529999	0.55150002	6.5399000000000003	0.080869999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1	2003-06-05 00:00:00	Peilung von km 155,0 verwendet; Sondermessung, keine Geschiebemessung	2011-12-01 02:16:04	45.599999999999994	0	0	\N	\N	1	1
1914	82	2000-04-28 00:00:00	178	\N	2	14	28	WEL155-028	2000-04-28 07:00:00	2000-04-28 09:30:00	268	285.07455837214354	77.900000000000006	0.2	11.9	60	27	87	0.14199999999999999	0.77900000000000003	9.4350000000000005	23.068000000000001	7.1070000000000002	104.014	379.24099999999999	381.70001	\N	96.908000000000001	3.9380000000000002	1.0717	0.66900003	7.7270000000000003	0.087902999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.4980000000000002	0.94899999999999995	1.8140000000000001	2.472	6.0444000000000004	5.0835999999999997	4.4429999999999996	3.9079000000000002	3.7018	3.2894999999999999	2.8772000000000002	2.4649000000000001	2.0526	1.8669	1.6881999999999999	1.5451999999999999	1.3308	0.5	0.213	10	96.915001	4	4	2003-06-05 00:00:00	Peilung von km 155,0 verwendet	2011-12-01 02:15:33	45.599999999999994	0	0	27	87	1	1
1915	82	2000-06-19 00:00:00	577	\N	2	14	29	WEL155-029	2000-06-19 10:00:00	2000-06-19 14:00:00	104	103.15656390972433	76.010000000000005	0.20999999	17.299999	36.880000000000003	22.120000000000001	59	0.01	0.26200000000000001	1.5600000000000001	10.542999999999999	12.436	96.350999999999999	154.40199999999999	228	\N	83.915000000000006	2.7170000000000001	0.64920002	0.43189999	5.5967000000000002	0.074811000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.29	1.137	1.95	2.7909999999999999	2.5777999999999999	1.8969	1.7695000000000001	1.6102000000000001	1.4508000000000001	1.1322000000000001	0.9123	0.76239999999999997	0.61990000000000001	0.57689999999999997	0.53390000000000004	0.499	0.40560000000000002	0.5	16.063999	6.2999999999999998	98.935997	5	5	2003-05-23 00:00:00	\N	2011-12-01 02:14:39	46.799999999999983	0	0	22.120000000000001	59	1	1
1916	82	2000-06-23 00:00:00	577	\N	2	14	31	WEL155-031	2000-06-23 06:30:00	2000-06-23 09:15:00	89	89.913491515908362	75.870000000000005	0.2	20.299999	50.979999999999997	38	88.980000000000004	0.0080000000000000002	0.27500000000000002	3.2160000000000002	24.934000000000001	12.712	95.915000000000006	132.53399999999999	216.3	\N	83.203000000000003	2.5990000000000002	0.59649998	0.39469999	5.0998999999999999	0.071414000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.637	1.788	3.339	4.4720000000000004	6.4699999999999998	4.8855000000000004	3.9279000000000002	3.1440999999999999	2.3603999999999998	1.6059000000000001	1.0941000000000001	0.83579999999999999	0.63460000000000005	0.56169999999999998	0.4909	0.43819999999999998	0.35909999999999997	0.25	1.724	10	94.252998	5	5	2003-06-05 00:00:00	\N	2011-12-01 02:13:41	46.799999999999983	0	0	38	88.980000000000004	1	1
1917	82	2001-03-28 00:00:00	577	\N	2	3	32	WEL155-032	2001-03-28 09:00:00	2001-03-28 13:30:00	523	795.97835124935932	80.189999999999998	0.22	4.6999998	61.409999999999997	29.100000000000001	90.510000000000005	2.7589999999999999	21.632999999999999	102.012	89.328000000000003	-10.488	178.267	1300.502	668.90002	\N	188.755	3.544	1.7072999	0.53759998	7.6482000000000001	0.087454000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	13.191000000000001	0.69499999999999995	2.464	4.9939999999999998	26.842199999999998	23.7941	21.762	19.221900000000002	16.681699999999999	13.9481	11.578099999999999	9.2280999999999995	6.9179000000000004	5.8087999999999997	4.7523999999999997	3.9178000000000002	2.7930000000000001	0.25	0.026000001	31.5	99.167999	3	5	2003-06-05 00:00:00	\N	2011-12-01 02:12:53	46.799999999999983	0	0	29.100000000000001	90.510000000000005	1	1
1918	82	2001-09-10 00:00:00	577	\N	2	\N	33	WEL155-033	2001-09-10 09:30:00	2001-09-10 15:00:00	208	209.79814687045285	77.049999999999997	0.20999999	15.3	0	0	0	\N	0.91700000000000004	6.8440000000000003	22.738	9.6470000000000002	100.422	245.88	318.60001	\N	90.775000000000006	3.5099999999999998	0.94480002	0.4377	7.2302999999999997	0.085030999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	5	2003-06-05 00:00:00	Geschiebemessung durchgeführt, kein Geschiebe gefangen	2011-12-01 02:12:08	46.799999999999983	0	0	0	0	1	1
1919	82	2002-03-13 00:00:00	577	\N	2	3	34	WEL155-034	2002-03-13 09:00:00	2002-03-13 11:15:00	381	466.99255283456279	78.790000000000006	0.2	6.5	50.600000000000001	32.399999999999999	83	0.753	\N	\N	\N	3.2429999999999999	107.741	\N	487.70001	\N	104.498	4.6669999999999998	1.3739001	\N	9.1559000000000008	0.095686999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	9.0899999999999999	1.119	2.1150000000000002	3.0609999999999999	19.8782	15.0345	13.584199999999999	11.7714	9.9814000000000007	8.3513999999999999	6.7214999999999998	5.6277999999999997	4.7210999999999999	4.2678000000000003	3.7839	3.3616000000000001	2.7282000000000002	2	3.1029999	16	86.663002	5	0	2003-06-05 00:00:00	keine Schwebstoffmessung	2011-12-01 02:11:45	46.799999999999983	0	0	32.399999999999999	83	1	1
1920	82	2002-03-27 00:00:00	577	\N	2	3	35	WEL155-035	2002-03-27 08:00:00	2002-03-27 12:00:00	538	836.40457224100805	80.340000000000003	0.22	6.3000002	67.25	34.950000000000003	102.2	4.6360000000000001	11.404999999999999	54.420999999999999	45.350999999999999	-11.957000000000001	186.571	1552.056	698	\N	198.52799999999999	3.516	1.7193	0.73540002	7.5873999999999997	0.087106000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	14.278	0.79700000000000004	2.645	5.173	29.7761	25.6418	22.8855	19.440200000000001	15.998100000000001	13.427	10.8558	8.3580000000000005	6.0259999999999998	5.1898	4.3536000000000001	3.6640999999999999	2.5954000000000002	0.25	0.11	31.5	92.501999	5	5	2003-06-05 00:00:00	\N	2011-12-01 02:10:55	46.799999999999983	0	0	34.950000000000003	102.2	1	1
1921	82	2002-08-27 00:00:00	577	\N	2	\N	36	WEL155-036	2002-08-27 10:30:00	2002-08-27 13:30:00	432	570.84612055448792	79.340000000000003	0.2	19.4	60.710000000000001	31.289999999999999	92	0.14099999999999999	\N	\N	\N	-2.165	110.044	\N	547.29999	\N	112.209	4.8769999999999998	1.4966	\N	9.5687999999999995	0.097820000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	0	2003-07-16 00:00:00	\N	2011-12-01 02:10:41	46.799999999999983	0	0	31.289999999999999	92	1	1
1922	82	2002-08-29 00:00:00	577	\N	2	\N	37	WEL155-037	2002-08-29 09:45:00	2002-08-29 13:45:00	368	442.59741947753344	78.659999999999997	0.2	20	52.25	32.75	85	0.049000000000000002	\N	\N	\N	4.4969999999999999	107.196	\N	474.20001	\N	102.699	4.617	1.3391	\N	9.0589999999999993	0.095179	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	0	2003-07-16 00:00:00	\N	2011-12-01 02:10:28	46.799999999999983	0	0	32.75	85	1	1
1923	82	2002-10-10 00:00:00	577	\N	3	\N	38	WEL155-038	2002-10-10 08:00:00	2002-10-10 13:45:00	262	274.61950121913094	77.590000000000003	0.20999999	11.6	59	27	86	0.14199999999999999	2.4129999999999998	14.628	37.128	8.0779999999999994	102.712	421.19799999999998	368.70001	\N	94.634	3.8959999999999999	1.0688	0.69999999	8.0252999999999997	0.089583999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	5	2003-08-26 00:00:00	\N	2011-12-01 02:09:45	46.799999999999983	0	0	27	86	1	1
1924	82	2003-03-19 00:00:00	577	\N	3	3	39	WEL155-039	2003-03-19 07:45:00	2003-03-19 12:00:00	353	401.47419467568386	78.5	0.20999999	5.9000001	64.75	31.25	96	0.37	5.0039999999999996	20.013999999999999	34.746000000000002	5.0469999999999997	106.526	655.14999999999998	457.89999	\N	101.48	4.5119999999999996	1.258	0.74589998	9.2947000000000006	0.096408999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.837	1.6679999999999999	2.9969999999999999	3.8889999999999998	4.4626999999999999	3.2042000000000002	2.5430000000000001	1.9198	1.6859	1.2181	0.8276	0.56759999999999999	0.45810000000000001	0.42180000000000001	0.3856	0.35659999999999997	0.31319999999999998	0.125	0.039999999	10	96.945999	5	5	2003-12-15 00:00:00	Nullpunkt: - 30 m	2011-12-01 02:09:11	46.799999999999983	0	0	31.25	96	1	1
1925	82	2003-04-02 00:00:00	577	\N	3	3	40	WEL155-040	2003-04-02 08:00:00	2003-04-02 13:36:00	282	305.28766886796791	77.799999999999997	0.2	9.1999998	71.159999999999997	18.84	90	0.42299999999999999	\N	\N	\N	7.4500000000000002	103.595	\N	388.70001	\N	96.144999999999996	4.0430000000000001	1.1269	\N	7.9317000000000002	0.08906	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.98999999999999999	1.1799999999999999	1.7130000000000001	1.9450000000000001	1.6308	0.99829999999999997	0.91549999999999998	0.81200000000000006	0.70850000000000002	0.59419999999999995	0.53639999999999999	0.47870000000000001	0.42099999999999999	0.3921	0.36320000000000002	0.34010000000000001	0.30549999999999999	0.125	0.013	10	99.024002	5	0	2003-12-15 00:00:00	Nullpunkt: - 36 m	2011-12-01 02:08:45	46.799999999999983	0	0	18.84	90	1	1
1948	84	2000-04-26 00:00:00	180	\N	2	5	9	\N	2000-04-26 09:00:00	2000-04-26 12:45:00	297	324.80377555359144	75.379999999999995	0.2	12.6	61.07	85.730000000000004	146.80000000000001	0.71699999999999997	1.1759999999999999	10.808	23.193000000000001	51.347999999999999	171.88800000000001	493.59899999999999	387.60001	\N	120.54000000000001	3.2160000000000002	1.2021	0.80540001	6.3094999999999999	0.079432000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	6.3710000000000004	1.482	3.6190000000000002	5.3079999999999998	18.472200000000001	13.6709	10.4701	8.3475000000000001	6.4749999999999996	4.2874999999999996	3.1025999999999998	2.0638000000000001	1.6163000000000001	1.4117999999999999	1.2074	1.0439000000000001	0.80769999999999997	0.25	0.052999999	20	91.908997	5	5	2003-05-23 00:00:00	\N	2011-12-01 02:43:27	59.400000000000006	0	0	85.730000000000004	146.80000000000001	1	1
1949	84	1995-09-26 00:00:00	180	\N	2	5	3	\N	1995-09-26 09:30:00	1995-09-26 13:00:00	286	315.74272602098051	75.189999999999998	0.2	15	40	75	115	2.2389999999999999	0.34799999999999998	1.712	3.778	52.268999999999998	154.864	388.60000000000002	366.39999	\N	102.595	3.5720000000000001	1.2362	0.49439999	7.0077999999999996	0.083711999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.2220000000000004	1.6519999999999999	3.7069999999999999	4.7839999999999998	12.624499999999999	8.2507999999999999	6.4390999999999998	4.8838999999999997	3.7414999999999998	2.4954000000000001	1.7316	1.286	0.91349999999999998	0.79269999999999996	0.67179999999999995	0.60029999999999994	0.52159999999999995	0.25	0.043000001	20	97.347	4	4	2003-04-02 00:00:00	\N	2011-12-01 02:46:53	59.400000000000006	0	0	75	115	1	1
1950	84	2000-06-22 00:00:00	180	\N	2	5	10	\N	2000-06-22 10:00:00	\N	95	94.792518187314244	73.349999999999994	0.2	20.799999	36.030000000000001	84.969999999999999	121	0.152	0.39800000000000002	5.0599999999999996	37.207000000000001	61.197000000000003	142.28	135.001	200.5	\N	81.082999999999998	2.4729999999999999	0.67830002	0.4179	4.8517000000000001	0.069653999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.758	2.004	3.1520000000000001	3.5960000000000001	12.380599999999999	5.2986000000000004	3.6812	2.9108000000000001	2.1404999999999998	1.6132	1.1877	0.89470000000000005	0.70630000000000004	0.62080000000000002	0.57220000000000004	0.53339999999999999	0.44869999999999999	0.25	0.088	20	94.475998	5	5	2003-05-23 00:00:00	\N	2011-12-01 02:42:54	59.400000000000006	0	0	84.969999999999999	121	1	1
1951	84	2001-03-29 00:00:00	180	\N	2	3	11	\N	2001-03-29 08:00:00	2001-03-29 11:30:00	536	831.52554556960217	77.590000000000003	0.22	4.8000002	80.700000000000003	66.370000000000005	147.06999999999999	8.641	11.920999999999999	60.305999999999997	50.549999999999997	-449.238	189.874	1676.3879999999999	911.79999	\N	639.11199999999997	1.427	1.3084	0.26910001	3.0790999999999999	0.055489999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	10.712	0.753	2.6389999999999998	5.5759999999999996	24.277999999999999	18.577100000000002	15.649900000000001	14.290699999999999	12.9314	10.212899999999999	8.1140000000000008	6.1314000000000002	4.6459000000000001	3.9100000000000001	3.2197	2.6675	1.8317000000000001	0.125	0.0070000002	31.5	97.600998	5	5	2003-05-23 00:00:00	\N	2011-12-01 02:42:01	59.400000000000006	0	0	66.370000000000005	147.06999999999999	1	1
1952	84	2001-09-11 00:00:00	180	\N	2	\N	12	\N	2001-09-11 09:00:00	2001-09-11 13:00:00	275	292.74160028435278	75.019999999999996	0.20999999	15	44	85	129	0.002	1.736	8.8070000000000004	20.969000000000001	53.094000000000001	150.63	401.32799999999997	349.70001	\N	97.536000000000001	3.585	1.2012	0.73040003	7.3851000000000004	0.085936999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	4	2003-04-02 00:00:00	Siebprotokolle liegen nicht vor	2011-12-01 02:41:47	59.400000000000006	0	0	85	129	1	1
1953	84	2002-03-12 00:00:00	180	\N	2	3	13	\N	2002-03-12 09:30:00	2002-03-12 12:40:00	392	489.29667476098967	76.329999999999998	0.2	6.3000002	61.579999999999998	85	146.58000000000001	2.468	\N	\N	\N	46.738	184.881	\N	514.79999	\N	138.143	3.7269999999999999	1.3635	\N	7.3120000000000003	0.085510000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	7.6529999999999996	0.73199999999999998	4.024	10.585000000000001	20.4207	15.205500000000001	13.624499999999999	11.648300000000001	9.7575000000000003	6.8353000000000002	4.4157999999999999	2.9769999999999999	1.8545	1.5194000000000001	1.1842999999999999	0.93889999999999996	0.64580000000000004	0.25	0.052000001	16	86.010002	5	0	2003-05-23 00:00:00	keine Schwebstoffmessung	2011-12-01 02:40:59	59.400000000000006	0	0	85	146.58000000000001	1	1
1954	84	2002-04-02 00:00:00	180	\N	2	3	14	\N	2002-04-02 09:30:00	2002-04-02 13:00:00	391	487.20566333038715	76.329999999999998	0.2	7.4000001	65.219999999999999	73.980000000000004	139.19999999999999	8.5860000000000003	1.641	9.1020000000000003	13.022	46.738	184.881	720.66300000000001	514.79999	\N	138.143	3.7269999999999999	1.3577	0.72649997	7.3120000000000003	0.085510000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	9.407	0.51700000000000002	3.2879999999999998	7.8739999999999997	22.635000000000002	17.315999999999999	15.300000000000001	13.9087	12.517300000000001	9.7667999999999999	7.3220999999999998	5.0342000000000002	3.1705000000000001	2.3797999999999999	1.8432999999999999	1.6022000000000001	1.2403999999999999	0.5	0.62199998	16	82.515999	5	5	2003-04-02 00:00:00	\N	2011-12-01 02:40:30	59.400000000000006	0	0	73.980000000000004	139.19999999999999	1	1
1955	84	1997-03-06 00:00:00	180	\N	\N	\N	6	\N	1997-03-06 09:00:00	1997-03-06 13:00:00	431	579.21016627689801	76.680000000000007	0.20999999	5	\N	\N	\N	\N	4.7450000000000001	29.143999999999998	35.070999999999998	42.863999999999997	185.834	804.05700000000002	563.70001	\N	142.97	3.9430000000000001	1.4743	0.63880002	8.1220999999999997	0.090122999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	2003-04-02 00:00:00	Protokolle zur Geschiebemessung liegen nicht vor	2011-12-01 02:44:52	59.400000000000006	0	0	\N	\N	1	1
1956	84	2002-09-02 00:00:00	180	\N	2	\N	15	WEL168-015	2002-09-02 10:30:00	2002-09-02 14:15:00	308	340.13785937800992	75.510000000000005	0.2	19.6	63.649999999999999	71	134.65000000000001	0.77100000000000002	\N	\N	\N	50.716999999999999	182.649	\N	404.10001	\N	131.93199999999999	3.0630000000000002	1.2076	\N	6.0095999999999998	0.077521000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	0	2003-07-16 00:00:00	\N	2011-12-01 02:40:23	59.400000000000006	0	0	71	134.65000000000001	1	1
1957	84	2002-10-14 00:00:00	180	\N	3	\N	16	WEL168-016	2002-10-14 10:45:00	2002-10-14 14:45:00	262	274.61950121913094	75	0.20999999	9.6999998	60.299999999999997	73	133.30000000000001	0.42799999999999999	2.4569999999999999	14.023	35.591999999999999	53.191000000000003	150.53	424.96699999999998	347.70001	\N	97.338999999999999	3.5720000000000001	1.1332	0.7913	7.3589000000000002	0.085783999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	5	2003-08-26 00:00:00	\N	2011-12-01 02:40:16	59.400000000000006	0	0	73	133.30000000000001	1	1
1958	84	2003-03-18 00:00:00	180	\N	3	3	17	WEL168-017	2003-03-18 09:30:00	2003-03-18 14:30:00	354	415.41427087970067	75.930000000000007	0.20999999	5.6999998	61.57	82.659999999999997	144.22999999999999	0.56699999999999995	6.0289999999999999	25.917000000000002	43.484000000000002	48.679000000000002	183.792	613.72400000000005	460.20001	\N	135.113	3.4060000000000001	1.2951	0.66280001	7.0164999999999997	0.083765000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.4940000000000002	1.115	3.782	5.4939999999999998	9.3272999999999993	6.0622999999999996	5.1459999999999999	4.0007000000000001	3.2827000000000002	1.9536	1.5181	1.0825	0.62139999999999995	0.5383	0.46939999999999998	0.4239	0.35560000000000003	0.125	0.014	16	96.524002	5	5	2003-12-15 00:00:00	Nullpunkt: + 50 m	2011-12-01 02:39:41	59.400000000000006	0	0	82.659999999999997	144.22999999999999	1	1
1959	84	2003-04-07 00:00:00	180	\N	3	3	18	WEL168-018	2003-04-07 11:15:00	2003-04-07 15:00:00	239	245.34534119069568	74.819999999999993	0.2	8	61.829999999999998	77	138.83000000000001	0.214	\N	\N	\N	54.064999999999998	149.63	\N	330.29999	\N	95.564999999999998	3.4569999999999999	1.0656	\N	6.782	0.082352999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.47999999999999998	0.99199999999999999	1.367	1.587	0.61260000000000003	0.55640000000000001	0.51900000000000002	0.49030000000000001	0.47399999999999998	0.44130000000000003	0.40870000000000001	0.376	0.34339999999999998	0.3271	0.31069999999999998	0.29770000000000002	0.27810000000000001	0.125	0.014	4	99.785004	5	0	2003-12-15 00:00:00	Nullpunkt: + 55 m	2011-12-01 02:39:09	59.400000000000006	0	0	77	138.83000000000001	1	1
1961	84	2004-10-18 00:00:00	579	\N	\N	\N	21	WEL168-021	2004-10-18 11:30:00	2004-10-18 15:10:00	82	92.701506756711723	73.209999999999994	0.2	\N	\N	\N	\N	\N	0.58899999999999997	2.282	17.158000000000001	51.021999999999998	141.58000000000001	109.121	195.8	\N	90.558000000000007	2.1619999999999999	0.67919999	0.36899999	4.2423000000000002	0.065132999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	2004-12-15 00:00:00	\N	2011-12-01 02:37:33	59.400000000000006	0	0	\N	\N	1	1
1964	85	1995-01-10 00:00:00	181	\N	2	5	1	\N	1995-01-10 10:10:00	1995-01-10 14:30:00	225	224.43522688467047	71.109999999999999	0.2	\N	63.890000000000001	65.920000000000002	129.81	0.016	\N	\N	\N	50.07	139.13999999999999	\N	282.79999	\N	89.069999999999993	3.1749999999999998	1.1387	\N	6.2287999999999997	0.078922999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	8.1829999999999998	0.52600000000000002	2.819	6.899	16.949100000000001	15.118600000000001	13.898199999999999	12.3727	10.847300000000001	8.8976000000000006	7.3949999999999996	5.8833000000000002	4.2454000000000001	3.3931	2.5265	1.9017999999999999	1.2897000000000001	0.5	2.642	10	67.223	5	0	2003-04-03 00:00:00	\N	2011-12-01 03:02:40	76.599999999999994	0	0	65.920000000000002	129.81	1	1
1965	85	1995-03-27 00:00:00	181	\N	2	5	2	\N	1995-03-27 12:00:00	1995-03-27 16:00:00	283	310.86369934957463	71.650000000000006	0.2	\N	66.370000000000005	65.420000000000002	131.78999999999999	1.383	0.48999999999999999	5.4740000000000002	12.273999999999999	47.909999999999997	141.84	444.13900000000001	332.20001	\N	93.930000000000007	3.536	1.3426	0.8678	6.9386000000000001	0.083297999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5.3419999999999996	1.1719999999999999	2.7349999999999999	3.8780000000000001	13.9659	9.4793000000000003	7.9558999999999997	6.4823000000000004	5.6069000000000004	4.0250000000000004	3.2017000000000002	2.3906000000000001	1.8019000000000001	1.6109	1.4198999999999999	1.2670999999999999	1.0378000000000001	0.5	0.43000001	20	97.067001	6	3	2003-04-03 00:00:00	BfG-Etagenfänger verwendet	2011-12-01 03:02:29	76.599999999999994	0	0	65.420000000000002	131.78999999999999	1	1
1966	85	1995-05-02 00:00:00	181	\N	2	5	3	\N	1995-05-02 11:00:00	1995-05-02 16:00:00	323	376.38205750845361	72.069999999999993	0.2	\N	60.229999999999997	63.149999999999999	123.38	6.1369999999999996	2.3690000000000002	29.331	54.317	46.229999999999997	173.44	624.92600000000004	373.89999	\N	127.20999999999999	2.9390000000000001	1.4442	0.61790001	5.7667999999999999	0.075939000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	7.8300000000000001	0.33400000000000002	4.5209999999999999	12.911	18.405000000000001	15.875999999999999	14.190099999999999	12.082599999999999	9.9882000000000009	7.9836999999999998	6.0723000000000003	4.1882999999999999	1.8907	1.1237999999999999	0.88570000000000004	0.77659999999999996	0.61839999999999995	0.25	0.02	20	93.783997	5	5	2003-04-03 00:00:00	\N	2011-12-01 03:02:16	76.599999999999994	0	0	63.149999999999999	123.38	1	1
1967	85	1995-07-06 00:00:00	181	\N	2	5	4	\N	1995-07-06 08:30:00	1995-07-06 12:00:00	240	245.34534119069568	71.319999999999993	0.2	\N	25.84	65.159999999999997	91	0.33900000000000002	1.0529999999999999	17.605	50.015000000000001	49.229999999999997	140.19	404.798	301.70001	\N	90.959999999999994	3.3170000000000002	1.1668	0.80010003	6.5071000000000003	0.080667000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.617	0.66000000000000003	4.4939999999999998	11.509	12.539	9.1972000000000005	8.0969999999999995	6.9626999999999999	5.9713000000000003	4.3529999999999998	2.5185	0.93999999999999995	0.59770000000000001	0.55130000000000001	0.505	0.45550000000000002	0.37819999999999998	0.25	0.043000001	20	99.053001	5	4	2003-04-03 00:00:00	\N	2011-12-01 03:01:59	76.599999999999994	0	0	65.159999999999997	91	1	1
1968	85	1995-09-21 00:00:00	181	\N	2	5	5	\N	1995-09-21 09:00:00	1995-09-21 13:00:00	298	335.25883270660404	71.879999999999995	0.2	\N	48.75	64.25	113	0.622	1.4530000000000001	6.8010000000000002	14.140000000000001	46.990000000000002	142.99000000000001	486.601	354	\N	96	3.6880000000000002	1.3587	0.54500002	7.2354000000000003	0.085060999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.3150000000000004	1.1259999999999999	3.9540000000000002	6.6790000000000003	12.156599999999999	8.5020000000000007	7.0227000000000004	5.6116999999999999	4.4512999999999998	3.1196000000000002	2.0266999999999999	1.4332	0.87790000000000001	0.6381	0.58289999999999997	0.54379999999999995	0.46710000000000002	0.25	0.075000003	20	98.273003	6	5	2003-04-03 00:00:00	\N	2011-12-01 03:01:47	76.599999999999994	0	0	64.25	113	1	1
1969	85	1996-04-11 00:00:00	181	\N	2	5	6	\N	1996-04-11 09:30:00	1996-04-11 13:00:00	390	496.96371667319892	72.599999999999994	0.20999999	8	40.119999999999997	65.879999999999995	106	0.028000000000000001	3.7810000000000001	21	29.452999999999999	43.649999999999999	224.435	829.78399999999999	461.5	\N	180.785	2.5529999999999999	1.5448999	0.61799997	5.2591999999999999	0.072520000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.173	1.736	3.3319999999999999	4.6120000000000001	11.98	8.4267000000000003	6.7800000000000002	5.5206	4.4958	3.0455000000000001	1.9194	1.4442999999999999	0.98929999999999996	0.90710000000000002	0.82479999999999998	0.75900000000000001	0.66039999999999999	0.5	2.1700001	10	87.530998	4	4	2003-04-03 00:00:00	\N	2011-12-01 03:01:36	76.599999999999994	0	0	65.879999999999995	106	1	1
1970	85	1996-07-15 00:00:00	181	\N	2	5	7	\N	1996-07-15 12:30:00	1996-07-15 16:30:00	476	676.79069970501564	73.329999999999998	0.20999999	18	63.259999999999998	62.119999999999997	125.38	3.6800000000000002	11.967000000000001	95.741	98.600999999999999	7.1500000000000004	237.07499999999999	1218.633	612.79999	\N	229.92500000000001	2.665	1.5846	0.65350002	5.4903000000000004	0.074096999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	8.3209999999999997	0.68000000000000005	3.6549999999999998	9.2140000000000004	19.4207	16.9572	15.3149	13.262	11.209	8.2410999999999994	5.6253000000000002	3.6349	2.3654000000000002	1.8606	1.532	1.2692000000000001	0.89439999999999997	0.25	0.064000003	20	91.411003	5	4	2003-04-03 00:00:00	\N	2011-12-01 03:01:20	76.599999999999994	0	0	62.119999999999997	125.38	1	1
1971	85	1996-10-16 00:00:00	181	\N	2	5	8	\N	1996-10-16 09:00:00	\N	152	134.52173536876211	70.340000000000003	0.20999999	13	54.670000000000002	65.430000000000007	120.09999999999999	1.111	0.88	4.306	22.311	53.149999999999999	135.28999999999999	211.779	216.89999	\N	82.140000000000001	2.6400000000000001	0.88999999	0.58490002	5.4387999999999996	0.073747999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.2629999999999999	2.2090000000000001	2.6160000000000001	2.7109999999999999	6.5289999999999999	3.4582000000000002	2.3429000000000002	1.8229	1.5881000000000001	1.1185	0.88939999999999997	0.74139999999999995	0.61129999999999995	0.57340000000000002	0.53559999999999997	0.50529999999999997	0.41260000000000002	0.25	0.12800001	10	95.133003	6	5	2003-04-03 00:00:00	\N	2011-12-01 03:00:58	76.599999999999994	0	0	65.430000000000007	120.09999999999999	1	1
1972	85	1997-05-09 00:00:00	181	\N	2	5	10	\N	1997-05-09 06:30:00	1997-05-09 10:00:00	279	304.59066505776707	71.689999999999998	0.2	12	68	54	122	0.80100000000000005	\N	\N	\N	47.75	142.03999999999999	\N	335.89999	\N	94.290000000000006	3.5630000000000002	1.3008	\N	6.9904000000000002	0.083609000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	6.8220000000000001	0.71799999999999997	3.4849999999999999	8.1120000000000001	16.8246	13.938700000000001	12.014699999999999	9.8097999999999992	8.6379999999999999	6.4233000000000002	4.7196999999999996	3.2406999999999999	1.9604999999999999	1.6701999999999999	1.3797999999999999	1.1475	0.79179999999999995	0.25	0.037999999	20	96.601997	9	0	2003-04-03 00:00:00	\N	2011-12-01 03:00:24	76.599999999999994	0	0	54	122	1	1
1973	85	1997-10-16 00:00:00	181	\N	2	5	11	\N	1997-10-16 08:30:00	1997-10-16 12:30:00	163	145.67379633197555	70.569999999999993	0.2	11	49.119999999999997	68.989999999999995	118.11	0.93300000000000005	0.76000000000000001	5.3079999999999998	25.396999999999998	52.229999999999997	136.44	240.495	236	\N	84.209999999999994	2.802	0.88559997	0.56480002	5.4981999999999998	0.074149999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.7720000000000002	2.2330000000000001	4.1849999999999996	4.8460000000000001	14.8141	10.4038	8.7089999999999996	6.7412000000000001	4.9486999999999997	2.4792000000000001	1.6634	1.2271000000000001	0.89019999999999999	0.77580000000000005	0.66139999999999999	0.59389999999999998	0.51160000000000005	0.25	0.096000001	20	97.055	5	5	2003-04-03 00:00:00	\N	2011-12-01 02:59:52	76.599999999999994	0	0	68.989999999999995	118.11	1	1
1974	85	1998-03-03 00:00:00	181	\N	2	5	12	\N	1998-03-03 09:00:00	1998-03-03 13:30:00	171	154.03784205438564	70.620000000000005	0.2	7	59.259999999999998	64.739999999999995	124	0.54700000000000004	0.48299999999999998	2.0499999999999998	9.2780000000000005	52.030000000000001	136.69	257.04700000000003	240.2	\N	84.659999999999997	2.8370000000000002	0.92000002	0.59060001	5.5667999999999997	0.074610999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.1500000000000004	1.79	3.169	3.851	9.8991000000000007	7.306	5.9607000000000001	4.6986999999999997	3.7090999999999998	2.4056000000000002	1.7230000000000001	1.3209	0.96560000000000001	0.88060000000000005	0.79549999999999998	0.72750000000000004	0.62470000000000003	0.25	0.039000001	20	95.944	4	4	2003-04-03 00:00:00	\N	2011-12-01 02:59:38	76.599999999999994	0	0	64.739999999999995	124	1	1
1975	85	1998-04-07 00:00:00	181	\N	2	5	13	\N	1998-04-07 08:30:00	1998-04-07 14:00:00	210	203.52511257864529	71.019999999999996	0.2	10	65.780000000000001	62.219999999999999	128	0.68100000000000005	1.0960000000000001	1.0960000000000001	3.7530000000000001	50.43	138.69	320.50999999999999	274.79999	\N	88.260000000000005	3.113	1.0626	0.6983	6.1086	0.078157000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.6080000000000001	2.052	3.129	3.3809999999999998	9.3681000000000001	7.1829000000000001	5.9016999999999999	4.5700000000000003	3.6057000000000001	2.2267999999999999	1.6023000000000001	1.1263000000000001	0.9083	0.84589999999999999	0.78349999999999997	0.73360000000000003	0.65869999999999995	0.25	0.075000003	20	99.476997	5	5	2003-04-03 00:00:00	\N	2011-12-01 02:59:26	76.599999999999994	0	0	62.219999999999999	128	1	1
1976	85	1998-05-12 00:00:00	181	\N	2	5	14	\N	1998-05-12 08:30:00	1998-05-12 14:00:00	115	101.06555247912181	70.010000000000005	0.20999999	19	58.859999999999999	62.140000000000001	121	0.22900000000000001	0.747	4.9969999999999999	34.462000000000003	54.469999999999999	133.63999999999999	161.374	190.2	\N	79.170000000000002	2.403	0.7622	0.56489998	4.9503000000000004	0.070358000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.0600000000000001	2.319	2.9129999999999998	2.7749999999999999	5.4908999999999999	3.5106999999999999	2.5777999999999999	1.8426	1.5305	0.9728	0.79139999999999999	0.62150000000000005	0.54459999999999997	0.50609999999999999	0.45569999999999999	0.41370000000000001	0.35060000000000002	0.125	0.043000001	10	96.189003	5	5	2003-04-03 00:00:00	\N	2011-12-01 02:59:05	76.599999999999994	0	0	62.140000000000001	121	1	1
1977	85	1998-05-18 00:00:00	181	\N	2	5	15	\N	1998-05-18 13:30:00	1998-05-18 15:30:00	98	88.519483895506681	69.829999999999998	0.20999999	18	53.990000000000002	66.010000000000005	120	0.151	0.57899999999999996	3.8620000000000001	30.41	55.189999999999998	132.74000000000001	139.90700000000001	176.10001	\N	77.549999999999997	2.2709999999999999	0.72100002	0.58109999	4.6790000000000003	0.068403000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.75	1.887	2.3500000000000001	2.4910000000000001	4.1665000000000001	2.7667999999999999	1.9749000000000001	1.734	1.4931000000000001	1.0113000000000001	0.85699999999999998	0.71050000000000002	0.59860000000000002	0.56369999999999998	0.52880000000000005	0.50090000000000001	0.40600000000000003	0.25	0.26499999	10	98.248001	4	4	2003-04-03 00:00:00	\N	2011-12-01 02:58:49	76.599999999999994	0	0	66.010000000000005	120	1	1
1978	85	1998-08-25 00:00:00	181	\N	2	5	16	\N	1998-08-25 09:30:00	1998-08-25 14:00:00	87	80.155438173096599	69.700000000000003	0.20999999	17	53.770000000000003	65.230000000000004	119	0.39000000000000001	0.56999999999999995	5.0979999999999999	44.328000000000003	55.710000000000001	132.09	127.26900000000001	166.10001	\N	76.379999999999995	2.1749999999999998	0.69220001	0.49039999	4.4808000000000003	0.066938999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.4769999999999999	2.9660000000000002	3.9550000000000001	3.9870000000000001	11.9856	7.2718999999999996	4.7645	3.1404999999999998	1.9879	1.5278	1.0676000000000001	0.82230000000000003	0.62180000000000002	0.56850000000000001	0.5151	0.46489999999999998	0.38319999999999999	0.25	0.212	20	98.454002	4	3	2003-04-03 00:00:00	\N	2011-12-01 02:58:41	76.599999999999994	0	0	65.230000000000004	119	1	1
1979	85	2000-05-03 00:00:00	181	\N	3	5	19	\N	2000-05-03 08:00:00	2000-05-03 12:00:00	209	210.49515068065369	71.060000000000002	0.2	17	56.770000000000003	63.619999999999997	120.39	2.6779999999999999	1.036	12.375	40.975000000000001	50.270000000000003	138.88999999999999	350.07100000000003	278.29999	\N	88.620000000000005	3.141	1.085	0.6832	6.1620999999999997	0.078498999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.915	1.24	2.863	4.2549999999999999	9.2045999999999992	7.0331999999999999	5.9900000000000002	5.0909000000000004	4.1919000000000004	3.1537000000000002	2.2063000000000001	1.681	1.2732000000000001	1.0692999999999999	0.93579999999999997	0.8579	0.74119999999999997	0.5	0.96799999	20	99.539001	5	5	2003-04-03 00:00:00	\N	2011-12-01 02:58:25	76.599999999999994	0	0	63.619999999999997	120.39	1	1
1980	85	2000-06-27 00:00:00	181	\N	3	5	20	\N	2000-06-27 08:30:00	2000-06-27 11:30:00	99	98.277537238318445	69.849999999999994	0.20999999	17	38.990000000000002	71.010000000000005	110	0.188	0.38800000000000001	5.3040000000000003	37.613999999999997	55.109999999999999	132.84	146.95099999999999	177.7	\N	77.730000000000004	2.286	0.79350001	0.46200001	4.7092999999999998	0.068624000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	7.5250000000000004	1.405	4.6189999999999998	8.1329999999999991	22.7225	18.0046	15.2507	11.808400000000001	8.5824999999999996	5.0038	3.2885	2.1202999999999999	1.5289999999999999	1.2665	1.004	0.84370000000000001	0.61519999999999997	0.25	0.083999999	20	86.898003	4	4	2003-04-03 00:00:00	\N	2011-12-01 02:58:14	76.599999999999994	0	0	71.010000000000005	110	1	1
1981	85	2000-10-17 00:00:00	181	\N	2	5	21	\N	2000-10-17 11:56:00	\N	123	119.88465535454448	70.090000000000003	0.20999999	14	54.469999999999999	66.260000000000005	120.73	0.72399999999999998	0.504	2.0129999999999999	11.706	54.149999999999999	134.03999999999999	183.40899999999999	196.60001	\N	79.890000000000001	2.4609999999999999	0.87489998	0.56669998	5.0697000000000001	0.071202000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.536	1.486	3.4169999999999998	4.5590000000000002	9.5949000000000009	6.8247	5.6406999999999998	4.4546000000000001	3.5958999999999999	2.2852999999999999	1.6383000000000001	1.1760999999999999	0.86450000000000005	0.75509999999999999	0.64559999999999995	0.58450000000000002	0.50129999999999997	0.25	0.035	10	90.830002	5	5	2003-04-03 00:00:00	\N	2011-12-01 02:58:02	76.599999999999994	0	0	66.260000000000005	120.73	1	1
1982	85	2001-08-23 00:00:00	181	\N	3	3	22	\N	2001-08-23 08:00:00	2001-08-23 10:30:00	208	209.79814687045285	70.430000000000007	0.20999999	21.5	57.960000000000001	64.040000000000006	122	0.24299999999999999	\N	\N	\N	52.789999999999999	135.74000000000001	\N	224.3	\N	82.950000000000003	2.7040000000000002	1.342	\N	5.5701999999999998	0.074634000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.722	0.79900000000000004	1.8879999999999999	2.8069999999999999	3.2648999999999999	2.2317	1.9449000000000001	1.8411	1.7373000000000001	1.5296000000000001	1.3220000000000001	1.1144000000000001	0.90869999999999995	0.80710000000000004	0.70540000000000003	0.62609999999999999	0.54490000000000005	0.25	0.050000001	10	98.944	5	0	2003-04-03 00:00:00	\N	2011-12-01 02:57:58	76.599999999999994	0	0	64.040000000000006	122	1	1
1983	85	2001-10-10 00:00:00	181	\N	3	3	23	\N	2001-10-10 08:00:00	2001-10-10 12:00:00	234	241.16331832949064	71.129999999999995	0.2	14.7	51.25	63.75	115	0.002	0.442	3.4620000000000002	10.007	49.990000000000002	139.24000000000001	387.85300000000001	284.60001	\N	89.25	3.1880000000000002	1.2158999	0.56410003	6.2553999999999998	0.079090999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.97399999999999998	1.5409999999999999	2.161	2.778	1.8999999999999999	1.6899999999999999	1.55	1.375	1.2	0.88900000000000001	0.63	0.53900000000000003	0.46000000000000002	0.42499999999999999	0.39000000000000001	0.36199999999999999	0.32000000000000001	0.5	35.714001	2	92.857002	5	5	2003-04-03 00:00:00	\N	2011-12-01 02:57:43	76.599999999999994	0	0	63.75	115	1	1
1984	85	2002-03-11 00:00:00	181	\N	3	\N	24	\N	2002-03-11 12:00:00	2002-03-11 14:45:00	413	531.81390718324099	72.909999999999997	0.2	6	67.569999999999993	55.100000000000001	122.67	7.8860000000000001	\N	\N	\N	28.149999999999999	232.482	\N	521.59998	\N	204.33199999999999	2.5529999999999999	1.4629	\N	5.0080999999999998	0.070767999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	0	2003-04-03 00:00:00	Siebprotokolle liegen nicht vor	2011-12-01 02:57:33	76.599999999999994	0	0	55.100000000000001	122.67	1	1
1985	85	2002-04-03 00:00:00	181	\N	3	3	25	\N	2002-04-03 08:30:00	2002-04-03 11:00:00	373	451.6584690101443	72.569999999999993	0.2	8	63.259999999999998	56.740000000000002	120	3.0830000000000002	1.137	8.1709999999999994	12.609	44.229999999999997	223.21100000000001	1049.49	456.10001	\N	178.98099999999999	2.548	1.4207	0.72960001	5.0000999999999998	0.070710999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	8.6649999999999991	0.80900000000000005	2.879	5.6779999999999999	20.826000000000001	15.520200000000001	14.222300000000001	12.6	10.9777	8.2730999999999995	5.9923999999999999	4.4672999999999998	3.2732000000000001	2.7492000000000001	2.2252000000000001	1.8718999999999999	1.4569000000000001	0.5	0.192	16	85.478996	5	5	2003-04-03 00:00:00	\N	2011-12-01 02:57:15	76.599999999999994	0	0	56.740000000000002	120	1	1
1986	85	1997-03-05 00:00:00	181	\N	\N	\N	9	\N	1997-03-05 11:00:00	1997-03-05 15:00:00	455	630.09144442155934	73.319999999999993	0.20999999	5	\N	\N	\N	\N	5.4589999999999996	43.463000000000001	48.078000000000003	7.6500000000000004	236.965	839.93899999999996	610.5	\N	229.315	2.6619999999999999	1.4808	0.42609999	5.4843000000000002	0.074055999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	2003-05-23 00:00:00	keine Geschiebemessung	2011-12-01 03:00:41	76.599999999999994	0	0	\N	\N	1	1
1987	85	2002-09-03 00:00:00	181	\N	2	\N	26	WEL185-026	2002-09-03 08:45:00	2002-09-03 14:30:00	328	371.50303083704773	72.049999999999997	0.2	19.200001	69.829999999999998	57.869999999999997	127.7	0.78200000000000003	\N	\N	\N	46.310000000000002	167.44	\N	371.39999	\N	121.13	3.0659999999999998	1.4349999	\N	6.016	0.077562999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	0	2003-07-16 00:00:00	\N	2011-12-01 02:57:09	76.599999999999994	0	0	57.869999999999997	127.7	1	1
1988	85	2002-10-15 00:00:00	181	\N	2	\N	27	WEL185-027	2002-10-15 10:30:00	2002-10-15 15:00:00	264	277.4075164599343	71.510000000000005	0.20999999	10.7	65.549999999999997	60.340000000000003	125.89	0.53400000000000003	3.7629999999999999	16.143999999999998	40.563000000000002	48.469999999999999	141.13999999999999	481.63499999999999	319.10001	\N	92.670000000000002	3.444	1.2472	0.61629999	7.0941999999999998	0.084226999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	5	2003-08-26 00:00:00	\N	2011-12-01 02:56:52	76.599999999999994	0	0	60.340000000000003	125.89	1	1
1989	85	2003-03-17 00:00:00	181	\N	3	3	28	WEL185-028	2003-03-17 12:00:00	2003-03-17 15:30:00	356	419.59629374090571	72.540000000000006	0.2	4.8000002	67.069999999999993	55.979999999999997	123.05	0.89300000000000002	\N	\N	\N	44.350000000000001	221.98699999999999	\N	450.79999	\N	177.637	2.5379999999999998	1.3355	\N	4.9787999999999997	0.070560999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.5529999999999999	1.9410000000000001	4.0220000000000002	4.641	11.822800000000001	7.3320999999999996	5.1482000000000001	3.6206999999999998	2.7254999999999998	1.7422	1.3086	0.92559999999999998	0.66749999999999998	0.57850000000000001	0.50590000000000002	0.45329999999999998	0.37540000000000001	0.125	0.0070000002	16	97.177002	5	0	2003-12-15 00:00:00	Nullpunkt: + 30 m	2011-12-01 02:56:33	76.599999999999994	0	0	55.979999999999997	123.05	1	1
1990	85	2003-04-08 00:00:00	181	\N	3	3	29	WEL185-029	2003-04-08 08:30:00	2003-04-08 14:43:00	232	236.28429165808475	71.269999999999996	0.2	5.4000001	60.479999999999997	65.280000000000001	125.76000000000001	0.32200000000000001	3.4790000000000001	13.196	38.927999999999997	49.43	139.94	376.59899999999999	297.10001	\N	90.510000000000005	3.2829999999999999	1.1409	0.70139998	6.4410999999999996	0.080256999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.6120000000000001	2.633	2.4689999999999999	2.0750000000000002	4.2710999999999997	1.9882	1.5696000000000001	1.0464	0.87329999999999997	0.61450000000000005	0.49630000000000002	0.44629999999999997	0.3962	0.37119999999999997	0.34620000000000001	0.32619999999999999	0.29620000000000002	0.125	0.021	16	99.537003	5	5	2003-12-15 00:00:00	Nullpunkt: + 50 m	2011-12-01 02:56:12	76.599999999999994	0	0	65.280000000000001	125.76000000000001	1	1
1991	85	2004-10-20 00:00:00	598	\N	2	3	32	WEL185-032	2004-10-20 08:30:00	2004-10-20 14:15:00	98	105.94457915052769	69.709999999999994	0.2	9.5	70	60	130	0.50900000000000001	0.47799999999999998	2.5030000000000001	16.469000000000001	55.670000000000002	132.13999999999999	140.63300000000001	183	\N	76.469999999999999	2.3929999999999998	0.83060002	0.53979999	4.6951000000000001	0.068520999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.6879999999999999	1.728	2.476	2.875	3.9573999999999998	2.8515000000000001	2.1141999999999999	1.7971999999999999	1.5657000000000001	1.1026	0.87609999999999999	0.71689999999999998	0.59299999999999997	0.55230000000000001	0.51160000000000005	0.46500000000000002	0.38350000000000001	0.063	0.001	10	98.565002	10	5	2004-12-15 00:00:00	\N	2011-12-01 02:55:11	76.599999999999994	40	0	60	130	1	1
1992	85	2004-04-05 00:00:00	598	\N	2	3	31	WEL185-031	2004-04-05 11:40:00	2004-04-05 16:20:00	265	282.28654313134018	71.609999999999999	0.20999999	9.1999998	70	60	130	0.60099999999999998	3.524	11.265000000000001	27.815000000000001	48.07	141.63999999999999	391.053	344.5	\N	93.569999999999993	3.6819999999999999	1.1755	0.56349999	7.5853999999999999	0.087094000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.5579999999999998	1.2609999999999999	4.1609999999999996	7.6609999999999996	12.675700000000001	9.1728000000000005	7.4923999999999999	5.8851000000000004	4.9253	3.2938000000000001	1.9633	1.2456	0.81740000000000002	0.67859999999999998	0.58509999999999995	0.52980000000000005	0.4299	0.063	0.001	16	95.008003	10	5	2004-12-15 00:00:00	\N	2011-12-01 02:55:24	76.599999999999994	40	0	60	130	1	1
1993	85	2004-03-15 00:00:00	181	\N	2	3	30	WEL185-030	2004-03-15 13:00:00	2004-03-15 15:30:00	155	159.61387253599236	70.459999999999994	0.2	6.3000002	75	55	130	0.89200000000000002	\N	\N	\N	52.670000000000002	135.88999999999999	\N	226.8	\N	83.219999999999999	2.7250000000000001	1.0098	\N	5.3464999999999998	0.073120000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.3180000000000001	1.788	3.6789999999999998	4.8460000000000001	9.7411999999999992	5.7961	4.5458999999999996	3.5316000000000001	2.8117000000000001	1.7504999999999999	1.1783999999999999	0.81030000000000002	0.58930000000000005	0.53049999999999997	0.47310000000000002	0.42830000000000001	0.36120000000000002	0.063	0.001	16	96.625	10	0	2004-12-15 00:00:00	\N	2011-12-01 02:55:59	76.599999999999994	40	0	55	130	1	1
1994	86	1994-11-21 00:00:00	182	\N	2	14	1	\N	1994-11-21 12:20:00	1994-11-21 14:30:00	162	144.97679252177471	84.909999999999997	0.30000001	\N	61	39	100	0.002	\N	\N	\N	2.9409999999999998	108.196	\N	248.2	\N	105.255	2.3580000000000001	0.83810002	\N	6.9390999999999998	0.083301	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.3119999999999998	0.76000000000000001	3.0459999999999998	5.9219999999999997	6.7614000000000001	5.5823999999999998	4.9695	4.2035	3.7056	2.9037000000000002	2.1019000000000001	1.5752999999999999	1.0888	0.88939999999999997	0.71530000000000005	0.6018	0.49030000000000001	0.25	0.23100001	10	93.532997	10	0	2003-04-01 00:00:00	\N	2011-12-01 01:56:09	18.199999999999989	0	0	39	100	1	1
1995	86	1995-01-17 00:00:00	182	\N	2	14	2	\N	1995-01-17 09:30:00	1995-01-17 13:00:00	219	216.07118116226042	85.439999999999998	0.30000001	\N	50	35	85	0.0040000000000000001	\N	\N	\N	1.1950000000000001	109.672	\N	305	\N	108.477	2.8109999999999999	1.0165	\N	8.2735000000000003	0.090958999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.9039999999999999	0.94899999999999995	2.6899999999999999	3.996	6.0700000000000003	4.5102000000000002	3.8365999999999998	3.4355000000000002	3.0344000000000002	2.2323	1.7211000000000001	1.3284	0.9597	0.83650000000000002	0.71319999999999995	0.62329999999999997	0.55859999999999999	0.5	4.5580001	10	94.905998	7	0	2003-06-05 00:00:00	\N	2011-12-01 01:55:31	18.199999999999989	0	0	35	85	1	1
1996	86	1995-01-26 00:00:00	182	\N	2	14	3	\N	1995-01-26 07:00:00	1995-01-26 09:45:00	389	494.8727052425964	87.079999999999998	0.28999999	\N	80	25	105	0.0089999999999999993	8.5510000000000002	48.366	68.120999999999995	-1.1890000000000001	112.68600000000001	723.14400000000001	487.29999	\N	113.875	4.2789999999999999	1.4569	0.5661	12.1747	0.11033900000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.879	1.6419999999999999	2.1179999999999999	2.2160000000000002	1.8416999999999999	1.5482	1.3525	1.1079000000000001	0.9304	0.68130000000000002	0.57050000000000001	0.49630000000000002	0.43330000000000002	0.40189999999999998	0.37040000000000001	0.34520000000000001	0.30740000000000001	0.25	0.88200003	2	93.235001	6	3	2003-06-05 00:00:00	\N	2011-12-01 01:54:35	18.199999999999989	0	0	25	105	1	1
1997	86	1995-01-30 00:00:00	182	\N	2	14	4	\N	1995-01-30 10:30:00	1995-01-30 13:00:00	558	871.25476275105007	88.629999999999995	0.28999999	\N	88	25	113	0.025000000000000001	\N	\N	\N	-3.8959999999999999	115.318	\N	668	\N	119.214	5.6029999999999998	1.8713	\N	15.940300000000001	0.12625500000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	6.3479999999999999	1.27	3.4169999999999998	6.2140000000000004	16.252400000000002	14.0038	12.504799999999999	10.631	9.0226000000000006	5.7443999999999997	3.6368999999999998	2.4702000000000002	1.7606999999999999	1.5603	1.3599000000000001	1.1996	0.92449999999999999	0.25	0.102	10	73.316002	6	0	2003-06-05 00:00:00	\N	2011-12-01 01:53:57	18.199999999999989	0	0	25	113	1	1
1998	86	1995-03-30 00:00:00	182	\N	2	14	5	\N	1995-03-30 07:00:00	1995-03-30 15:00:00	308	351.28992034122336	86.269999999999996	0.28999999	5	70	22	92	0.16700000000000001	2.02	22.760999999999999	45.161000000000001	0.22500000000000001	111.31100000000001	476.89999999999998	396.20001	\N	111.086	3.5670000000000002	1.272	0.67229998	10.1471	0.100733	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.9199999999999999	0.69999999999999996	2.105	3.1299999999999999	3.4811000000000001	2.5350000000000001	1.9888999999999999	1.8974	1.8059000000000001	1.6229	1.4398	1.2567999999999999	1.0738000000000001	0.89729999999999999	0.60780000000000001	0.57210000000000005	0.51849999999999996	0.5	7.9229999	10	98.163002	5	6	2003-06-05 00:00:00	\N	2011-12-01 01:53:06	18.199999999999989	0	0	22	92	1	1
1999	86	1995-03-31 00:00:00	182	\N	2	14	6	\N	1995-03-31 08:00:00	1995-03-31 12:00:00	317	366.62400416564185	86.310000000000002	0.28999999	\N	55	27	82	0.079000000000000001	1.796	17.145	32.594999999999999	0.155	111.378	478.11399999999998	400.70001	\N	111.223	3.6019999999999999	1.3128	0.72229999	10.2483	0.101234	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5.6340000000000003	1.0429999999999999	2.895	4.9329999999999998	14.3505	10.960800000000001	9.3854000000000006	8.0488	6.8491999999999997	5.0713999999999997	3.7073	2.8163	1.9609000000000001	1.7277	1.4944999999999999	1.3079000000000001	1.0281	0.5	2.464	10	82.299004	4	5	2003-04-02 00:00:00	\N	2011-12-01 01:52:26	18.199999999999989	0	0	27	82	1	1
2000	86	1995-04-20 00:00:00	182	\N	2	14	7	\N	1995-04-20 09:00:00	1995-04-20 14:00:00	466	654.48657777858875	87.719999999999999	0.28999999	8	69	27	96	0.036999999999999998	8.0960000000000001	63.133000000000003	67.233999999999995	-2.3069999999999999	113.773	840.73000000000002	560.90002	\N	116.08	4.8319999999999999	1.6741	0.69520003	13.7469	0.117247	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.9930000000000001	0.876	2.113	3.161	3.6873999999999998	2.9735	2.4975000000000001	1.9843	1.8882000000000001	1.6959	1.5037	1.3115000000000001	1.1193	1.0232000000000001	0.83740000000000003	0.66600000000000004	0.53659999999999997	0.25	0.121	10	98.738998	5	5	2003-06-05 00:00:00	\N	2011-12-01 01:51:35	18.199999999999989	0	0	27	96	1	1
2001	86	1995-07-13 00:00:00	182	\N	2	14	8	\N	1995-07-13 09:30:00	1995-07-13 13:30:00	188	174.25095255021	85.079999999999998	0.28999999	23	41.159999999999997	44.840000000000003	86	0.0040000000000000001	1.5660000000000001	14.087999999999999	56.350000000000001	2.0760000000000001	108.693	235.685	266.20001	\N	106.617	2.4969999999999999	0.93919998	0.65880001	7.1025	0.084277000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.77400000000000002	1.079	1.6000000000000001	2.0830000000000002	1.4341999999999999	1.0237000000000001	0.95609999999999995	0.89590000000000003	0.83579999999999999	0.71560000000000001	0.61570000000000003	0.56599999999999995	0.51619999999999999	0.48380000000000001	0.43709999999999999	0.39960000000000001	0.34350000000000003	0.5	26.731001	4	99.807999	4	4	2003-06-05 00:00:00	\N	2011-12-01 01:51:11	18.199999999999989	0	0	44.840000000000003	86	1	1
2002	86	1995-07-27 00:00:00	182	\N	2	14	9	\N	1995-07-27 09:00:00	1995-07-27 14:00:00	168	151.24982681358227	84.879999999999995	0.28999999	23	50	36	86	0.070999999999999994	0.85299999999999998	7.0540000000000003	32.509	3.052	108.089	185.386	245	\N	105.03700000000001	2.3330000000000002	0.88559997	0.45339999	6.6361999999999997	0.081462999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.79000000000000004	1.0509999999999999	1.5620000000000001	2.056	1.3971	0.98509999999999998	0.93910000000000005	0.88170000000000004	0.82420000000000004	0.70930000000000004	0.61519999999999997	0.56759999999999999	0.51990000000000003	0.4919	0.44290000000000002	0.40379999999999999	0.34499999999999997	0.25	0.29100001	6.2999999999999998	99.867996	5	5	2003-06-05 00:00:00	\N	2011-12-01 01:50:21	18.199999999999989	0	0	36	86	1	1
2003	86	1995-10-09 00:00:00	182	\N	2	\N	10	\N	1995-10-09 13:00:00	1995-10-09 15:00:00	209	202.13110495824361	85.269999999999996	0.28999999	15	\N	\N	\N	\N	0.81299999999999994	5.032	17.350999999999999	1.393	109.20999999999999	245.88900000000001	286.60001	\N	107.81699999999999	2.6579999999999999	1.012	0.40900001	7.5616000000000003	0.086957000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4	2003-06-05 00:00:00	kein Geschiebe auf dieser Messfahrt	2011-12-01 01:50:02	18.199999999999989	0	0	\N	\N	1	1
2004	86	1996-03-27 00:00:00	182	\N	2	\N	11	\N	1996-03-27 09:20:00	1996-03-27 12:10:00	377	472.56858331616951	86.930000000000007	0.28999999	5	\N	\N	\N	\N	\N	\N	\N	-0.92800000000000005	112.431	\N	470.29999	\N	113.35899999999999	4.149	1.4417	\N	11.8024	0.108639	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	2003-06-05 00:00:00	kein Geschiebe auf dieser Messfahrt	2011-12-01 01:49:58	18.199999999999989	0	0	\N	\N	1	1
2005	86	1996-04-22 00:00:00	182	\N	2	\N	12	\N	1996-04-22 11:30:00	1996-04-22 16:00:00	331	390.32213371247042	86.409999999999997	0.28999999	11	\N	\N	\N	\N	3.5139999999999998	17.981999999999999	32.110999999999997	-0.019	111.548	476.37700000000001	411.79999	\N	111.568	3.6909999999999998	1.3599	0.68980002	10.5007	0.10247299999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	6	2003-06-05 00:00:00	kein Geschiebe auf dieser Messfahrt	2011-12-01 01:49:35	18.199999999999989	0	0	\N	\N	1	1
2006	86	1996-05-22 00:00:00	182	\N	2	14	13	\N	1996-05-22 08:30:00	1996-05-22 14:15:00	497	724.88396260887362	87.799999999999997	0.28	12	40	27	67	0.001	10.186999999999999	85.176000000000002	81.900000000000006	-2.4470000000000001	113.908	869.54499999999996	570.20001	\N	116.355	4.9009999999999998	1.8239	0.7683	13.460900000000001	0.116021	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.1299999999999999	1.7689999999999999	2.3149999999999999	3.4369999999999998	2.6000000000000001	1.9399999999999999	1.8	1.625	1.45	1.1000000000000001	0.63	0.53900000000000003	0.46000000000000002	0.42499999999999999	0.39000000000000001	0.36199999999999999	0.32000000000000001	0.5	35.714001	2	85.713997	3	5	2003-06-05 00:00:00	\N	2011-12-01 01:49:08	18.199999999999989	0	0	27	67	1	1
2007	86	1996-05-28 00:00:00	182	\N	2	14	14	\N	1996-05-28 13:00:00	\N	353	428.65734327351663	86.629999999999995	0.28999999	13	70	26	96	0.023	4.875	30.957999999999998	50.338000000000001	-0.40400000000000003	111.922	507.77699999999999	436.39999	\N	112.325	3.8849999999999998	1.4092	0.55190003	11.053599999999999	0.10513599999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.91400000000000003	1.526	1.9870000000000001	2.3420000000000001	1.7929999999999999	1.5286999999999999	1.3525	1.1322000000000001	0.96440000000000003	0.78639999999999999	0.62290000000000001	0.56399999999999995	0.50519999999999998	0.4647	0.42170000000000002	0.38740000000000002	0.33589999999999998	0.5	29.115999	4	99.487999	5	4	2003-06-05 00:00:00	\N	2011-12-01 01:48:33	18.199999999999989	0	0	26	96	1	1
2008	86	1996-05-30 00:00:00	182	\N	2	14	15	\N	1996-05-30 08:00:00	1996-05-30 13:00:00	356	434.23337375512335	86.670000000000002	0.28999999	14	60	32	92	0.033000000000000002	4.0430000000000001	34.777999999999999	55.823999999999998	-0.47299999999999998	111.98999999999999	537.40700000000004	440.89999	\N	112.46299999999999	3.9209999999999998	1.4129	0.79280001	11.1538	0.105612	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.89000000000000001	1.5680000000000001	2.0049999999999999	2.1499999999999999	1.8	1.4895	1.2825	1.0238	0.90559999999999996	0.6976	0.59330000000000005	0.53900000000000003	0.4783	0.43990000000000001	0.40139999999999998	0.37069999999999997	0.32450000000000001	0.25	0.30700001	4	99.387001	4	5	2003-06-05 00:00:00	\N	2011-12-01 01:47:54	18.199999999999989	0	0	32	92	1	1
2009	86	1996-10-09 00:00:00	182	\N	2	14	16	\N	1996-10-09 09:30:00	1996-10-09 15:30:00	182	166.58391063800076	85.159999999999997	0.30000001	14	70.540000000000006	23.460000000000001	94	0.051999999999999998	1.2	7.4429999999999996	31.140999999999998	1.627	108.91	248.93899999999999	274.70001	\N	107.283	2.5609999999999999	0.86989999	0.66579998	7.5366	0.086813000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.9510000000000001	1.1919999999999999	2.4089999999999998	3.4780000000000002	3.8633000000000002	2.9853000000000001	2.3999999999999999	1.9280999999999999	1.7695000000000001	1.4523999999999999	1.1352	0.88970000000000005	0.69740000000000002	0.61360000000000003	0.55859999999999999	0.51459999999999995	0.41760000000000003	0.25	0.50700003	10	97.858002	6	5	2003-06-05 00:00:00	\N	2011-12-01 01:46:57	18.199999999999989	0	0	23.460000000000001	94	1	1
2010	86	1997-04-14 00:00:00	182	\N	2	14	22	\N	1997-04-14 11:00:00	1997-04-14 16:30:00	353	428.65734327351663	86.599999999999994	0.28999999	7	72.180000000000007	22.82	95	0.0040000000000000001	2.2269999999999999	15.978	25.981000000000002	-0.35099999999999998	111.871	504.82900000000001	433.10001	\N	112.22199999999999	3.859	1.4201	0.76090002	10.978400000000001	0.104778	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.0349999999999999	1.413	2.0379999999999998	2.4929999999999999	1.9288000000000001	1.6746000000000001	1.5051000000000001	1.2931999999999999	1.0813999999999999	0.86209999999999998	0.69140000000000001	0.58909999999999996	0.52510000000000001	0.48959999999999998	0.44169999999999998	0.40339999999999998	0.34589999999999999	0.5	26.08	4	98.040001	6	4	2003-06-05 00:00:00	\N	2011-12-01 01:45:54	18.199999999999989	0	0	22.82	95	1	1
2011	86	1997-04-15 00:00:00	182	\N	2	14	23	\N	1997-04-15 09:30:00	1997-04-15 15:00:00	344	413.32325944909815	86.5	0.28999999	7	30	34	64	0.019	2.2490000000000001	12.875999999999999	21.713000000000001	-0.17699999999999999	111.70099999999999	496.27699999999999	421.89999	\N	111.878	3.7709999999999999	1.4057	0.83920002	10.7273	0.103573	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5.3230000000000004	5.4290000000000003	3.657	2.1909999999999998	27.333300000000001	5.1959999999999997	1.6117999999999999	0.99239999999999995	0.90639999999999998	0.73419999999999996	0.60980000000000001	0.55869999999999997	0.50760000000000005	0.46879999999999999	0.42420000000000002	0.3886	0.3352	0.25	0.43900001	20	84.210999	6	6	2003-06-05 00:00:00	\N	2011-12-01 01:45:09	18.199999999999989	0	0	34	64	1	1
2012	86	1997-06-30 00:00:00	182	\N	2	14	26	\N	1997-06-30 11:00:00	1997-06-30 16:30:00	141	124.06667821574952	84.700000000000003	0.28999999	20	61.560000000000002	31.440000000000001	93	0.127	0.64000000000000001	6.9560000000000004	39.076999999999998	3.7130000000000001	107.44499999999999	163.83500000000001	226.2	\N	103.732	2.181	0.78680003	0.6006	6.2043999999999997	0.078768000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.7010000000000001	1.0109999999999999	1.9790000000000001	2.726	3.3296999999999999	2.3603999999999998	1.9547000000000001	1.8267	1.6986000000000001	1.4424999999999999	1.1863999999999999	0.95889999999999997	0.80779999999999996	0.73229999999999995	0.65669999999999995	0.60270000000000001	0.5292	0.25	0.13600001	10	98.776001	5	5	2003-06-05 00:00:00	\N	2011-12-01 01:43:26	18.199999999999989	0	0	31.440000000000001	93	1	1
2013	86	1997-04-16 00:00:00	182	\N	2	14	24	\N	1997-04-16 08:30:00	1997-04-16 14:30:00	339	404.26220991648722	86.489999999999995	0.28999999	6	39.509999999999998	55.490000000000002	95	0.0060000000000000001	2.8460000000000001	17.065999999999999	29.422999999999998	-0.159	111.684	516.12699999999995	420.70001	\N	111.843	3.762	1.3785	0.71179998	10.7021	0.103451	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.78000000000000003	1.296	1.829	1.9950000000000001	1.5916999999999999	1.1967000000000001	0.98150000000000004	0.89019999999999999	0.79879999999999995	0.62609999999999999	0.57479999999999998	0.52339999999999998	0.4602	0.42359999999999998	0.38700000000000001	0.35780000000000001	0.31390000000000001	0.25	1.266	2	96.203003	6	5	2003-06-05 00:00:00	\N	2011-12-01 01:44:28	18.199999999999989	0	0	55.490000000000002	95	1	1
2014	86	1997-10-22 00:00:00	182	\N	2	\N	27	\N	1997-10-22 09:00:00	1997-10-22 13:00:00	130	114.30862487293776	84.599999999999994	0.28999999	8	\N	\N	\N	\N	0.45800000000000002	2.899	17.677	4.0800000000000001	107.08799999999999	164.58000000000001	215.89999	\N	103.00700000000001	2.0960000000000001	0.75959998	0.53009999	5.9626000000000001	0.077217999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	2003-06-05 00:00:00	kein Geschiebe auf dieser Messfahrt	2011-12-01 01:43:03	18.199999999999989	0	0	\N	\N	1	1
2015	86	1998-03-31 00:00:00	182	\N	2	14	28	\N	1998-03-31 09:00:00	1998-03-31 12:16:00	236	239.76931070908896	85.590000000000003	0.28999999	7	40	48	88	0.17000000000000001	\N	\N	\N	1.0209999999999999	110.08	\N	321.29999	\N	109.059	2.9460000000000002	1.0707999	\N	8.3805999999999994	0.091545000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.381	1.4239999999999999	1.774	2.0779999999999998	1.9353	1.5824	1.3471	1.0528999999999999	0.95699999999999996	0.85219999999999996	0.74739999999999995	0.64259999999999995	0.58089999999999997	0.55300000000000005	0.52510000000000001	0.50280000000000002	0.41010000000000002	0.25	0.2	10	97.900002	3	0	2003-06-05 00:00:00	\N	2011-12-01 12:05:27	18.199999999999989	0	0	48	88	1	1
2016	86	1998-06-16 00:00:00	182	\N	2	14	29	\N	1998-06-16 08:30:00	1998-06-16 12:45:00	139	121.975666785147	84.689999999999998	0.28999999	18	40	45	85	0.041000000000000002	0.96199999999999997	5.6470000000000002	32.270000000000003	3.75	107.41	167.12100000000001	225.2	\N	103.66	2.1720000000000002	0.77710003	0.50559998	6.1802999999999999	0.078615000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.57199999999999995	1.05	1.5389999999999999	1.8220000000000001	0.89729999999999999	0.75680000000000003	0.66310000000000002	0.61080000000000001	0.58409999999999995	0.53069999999999995	0.47989999999999999	0.43269999999999997	0.3856	0.36199999999999999	0.33839999999999998	0.3196	0.2913	0.25	1.247	4	99.792	5	5	2003-06-05 00:00:00	\N	2011-12-01 01:41:51	18.199999999999989	0	0	45	85	1	1
2021	86	1999-04-06 00:00:00	182	\N	\N	\N	32	WEL127-032	1999-04-06 10:43:00	1999-04-06 13:17:00	306	337.34984413720656	86.150000000000006	0.28999999	9	\N	\N	\N	\N	1.0209999999999999	5.0439999999999996	10.422000000000001	0.36899999999999999	111.187	404.88799999999998	382.89999	\N	110.81699999999999	3.4550000000000001	1.2640001	0.51810002	9.8299000000000003	0.099145999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	2003-06-05 00:00:00	keine Geschiebemessung	2011-12-01 01:39:45	18.199999999999989	0	0	\N	\N	1	1
2022	86	1999-09-22 00:00:00	182	\N	\N	\N	33	WEL127-033	1999-09-22 09:00:00	1999-09-22 15:15:00	96	96.186525807715924	84.349999999999994	0.30000001	19	\N	\N	\N	\N	0.31	3.6110000000000002	26.164000000000001	4.9989999999999997	106.194	67.323999999999998	190.39999	\N	101.19499999999999	1.881	0.72490001	0.34240001	5.5362999999999998	0.074406	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1	2003-06-05 00:00:00	keine Geschiebemessung	2011-12-01 01:39:32	18.199999999999989	0	0	\N	\N	1	1
2023	86	1999-09-23 00:00:00	182	\N	\N	\N	34	WEL127-034	1999-09-23 08:00:00	1999-09-23 15:00:00	102	101.06555247912181	84.319999999999993	0.28999999	19	\N	\N	\N	\N	0.35599999999999998	3.431	23.664000000000001	5.109	106.087	57.256999999999998	187.3	\N	100.97799999999999	1.855	0.77399999	0.2087	5.2778999999999998	0.072649000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1	2003-06-05 00:00:00	keine Geschiebemessung	2011-12-01 01:39:30	18.199999999999989	0	0	\N	\N	1	1
2024	86	1999-09-24 00:00:00	182	\N	2	14	35	WEL127-035	1999-09-24 06:00:00	1999-09-24 09:00:00	90	90.610495326109202	84.25	0.30000001	19	40	50	90	0.0080000000000000002	0.314	2.9409999999999998	22.623999999999999	5.367	105.837	105.44499999999999	180.3	\N	100.47	1.794	0.72109997	0.4287	5.2808999999999999	0.072669999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.79000000000000004	1.1000000000000001	1.6930000000000001	2.173	1.5286	1.0743	0.96050000000000002	0.8952	0.82979999999999998	0.69910000000000005	0.60499999999999998	0.55200000000000005	0.49830000000000002	0.45419999999999999	0.40999999999999998	0.37469999999999998	0.32169999999999999	0.25	1.887	2	96.225998	3	3	2003-06-05 00:00:00	\N	2011-12-01 01:38:55	18.199999999999989	0	0	50	90	1	1
2026	86	2000-04-11 00:00:00	182	\N	\N	\N	37	WEL127-037	2000-04-11 08:30:00	2000-04-11 13:15:00	406	517.17682716902334	87.060000000000002	0.28	8	\N	\N	\N	\N	1.3500000000000001	10.436	14.065	-1.155	112.652	317.07299999999998	485	\N	113.806	4.2619999999999996	1.5297	0.58829999	11.707000000000001	0.108199	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1	2003-06-05 00:00:00	Sondermessung; keine Geschiebemessung	2011-12-01 01:38:10	18.199999999999989	0	0	\N	\N	1	1
2027	86	2000-10-12 00:00:00	182	\N	2	5	38	WEL127-038	2000-10-12 09:00:00	2000-10-12 13:45:00	137	133.12772774836046	84.709999999999994	0.30000001	13	23.27	36.469999999999999	59.740000000000002	0.001	0.41999999999999998	1.8899999999999999	9.8970000000000002	3.6760000000000002	107.48099999999999	172.59700000000001	227.3	\N	103.80500000000001	2.1890000000000001	0.84039998	0.45699999	6.4432999999999998	0.080269999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.734	0.94399999999999995	2.4590000000000001	3.9369999999999998	3.6454	3.2128999999999999	2.9245000000000001	2.5640999999999998	2.2037	1.7263999999999999	1.345	0.97819999999999996	0.74990000000000001	0.63580000000000003	0.57650000000000001	0.53139999999999998	0.4385	0.25	0.152	4	94.918999	5	5	2003-06-05 00:00:00	\N	2011-12-01 01:37:17	18.199999999999989	0	0	36.469999999999999	59.740000000000002	1	1
2028	86	2001-03-27 00:00:00	182	\N	\N	\N	39	WEL127-039	2001-03-27 09:00:00	2001-03-27 12:45:00	502	740.2180464332921	88.079999999999998	0.28999999	6	\N	\N	\N	\N	14.387	82.063999999999993	77.272999999999996	-2.9359999999999999	114.384	878.67399999999998	602.90002	\N	117.31999999999999	5.1390000000000002	1.7614	0.7942	14.6204	0.12091499999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	2003-06-05 00:00:00	keine Geschiebemessung	2011-12-01 01:36:40	18.199999999999989	0	0	\N	\N	1	1
2029	86	2001-09-06 00:00:00	182	\N	2	\N	40	WEL127-040	2001-09-06 09:00:00	2001-09-06 12:30:00	249	259.98242120491335	85.680000000000007	0.28999999	17.4	0	0	0	\N	0.80500000000000005	7.6879999999999997	20.611999999999998	0.91600000000000004	110.325	330.30500000000001	331.10001	\N	109.40900000000001	3.0259999999999998	1.1265	0.64219999	8.6094000000000008	0.092786999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	5	2003-06-05 00:00:00	\N	2011-12-01 01:36:20	18.199999999999989	0	0	0	0	1	1
2030	86	2002-03-26 00:00:00	182	\N	2	18	41	WEL127-041	2002-03-26 09:15:00	2002-03-26 12:45:00	542	850.34464844502486	88.379999999999995	0.28	1.9	91.269999999999996	13.98	105.25	0.32300000000000001	12.246	89.394000000000005	73.274000000000001	-3.46	114.893	1114.173	638.29999	\N	118.35299999999999	5.3929999999999998	1.9114	1.1434	14.8134	0.12171	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	15.404	0.53100000000000003	3.8879999999999999	10.519	35.3185	28.924600000000002	26.695	23.908100000000001	21.121099999999998	15.5647	10.2059	7.4991000000000003	3.6583000000000001	3.0106999999999999	2.363	1.9134	1.4796	0.5	0.98799998	31.5	88.621002	5	5	2003-06-05 00:00:00	\N	2011-12-01 01:36:02	18.199999999999989	0	0	13.98	105.25	1	1
2031	86	2002-08-28 00:00:00	182	\N	2	\N	42	WEL127-042	2002-08-28 09:00:00	2002-08-28 12:00:00	398	501.14573953440396	86.849999999999994	0.28	21	60	24	84	0.26800000000000002	\N	\N	\N	-0.78800000000000003	112.295	\N	461.20001	\N	113.083	4.0789999999999997	1.5589	\N	11.203200000000001	0.10584499999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	6	0	2003-07-16 00:00:00	\N	2011-12-01 01:35:42	18.199999999999989	0	0	24	84	1	1
2032	86	2002-10-09 00:00:00	182	\N	3	\N	43	WEL127-043	2002-10-09 09:00:00	2002-10-09 13:30:00	253	262.77043644571671	85.709999999999994	0.28999999	12	47.850000000000001	28	75.849999999999994	0.34699999999999998	2.4169999999999998	12.946	34.340000000000003	0.88100000000000001	110.40600000000001	378.70999999999998	334.39999	\N	109.52500000000001	3.0529999999999999	1.1274	0.75510001	8.6856000000000009	0.093196000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	5	2003-08-26 00:00:00	\N	2011-12-01 01:35:01	18.199999999999989	0	0	28	75.849999999999994	1	1
2033	86	2003-04-01 00:00:00	182	\N	3	3	44	WEL127-044	2003-04-01 08:00:00	2003-04-01 13:15:00	298	324.80377555359144	86.040000000000006	0.28999999	7.5	79	24	103	0.39000000000000001	2.1040000000000001	10.974	23.548999999999999	0.497	111.086	455.392	370.70001	\N	110.589	3.3519999999999999	1.257	0.92729998	9.5370000000000008	0.097656999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.0449999999999999	1.123	1.6799999999999999	1.9470000000000001	1.6635	0.99590000000000001	0.92200000000000004	0.8296	0.73709999999999998	0.60899999999999999	0.55910000000000004	0.50929999999999997	0.44579999999999997	0.41260000000000002	0.37930000000000003	0.35270000000000001	0.31280000000000002	0.125	0.014	10	98.390999	5	5	2003-12-15 00:00:00	\N	2011-12-01 01:34:23	18.199999999999989	0	0	24	103	1	1
2058	88	1994-11-24 00:00:00	184	\N	2	5	4	\N	1994-11-24 08:30:00	1994-11-24 11:30:00	204	163.7958953971974	64.370000000000005	0.20999999	\N	74.409999999999997	57.590000000000003	132	1.141	\N	\N	\N	50.799999999999997	149.017	\N	264.39999	\N	98.216999999999999	2.6920000000000002	0.88889998	\N	5.5453000000000001	0.074467000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.7109999999999999	1.0960000000000001	2.3029999999999999	3.3290000000000002	5.7133000000000003	4.2401999999999997	3.7542	3.3475000000000001	2.9407999999999999	2.1274000000000002	1.7584	1.472	1.1856	1.0424	0.90600000000000003	0.79930000000000001	0.6391	0.25	0.134	10	97.152	12	0	2003-04-03 00:00:00	\N	2011-12-01 03:12:21	106.40000000000001	0	0	57.590000000000003	132	1	1
2059	88	1995-02-02 00:00:00	184	\N	2	5	5	\N	1995-02-02 09:30:00	1995-02-02 13:15:00	523	894.95289229787852	67.569999999999993	0.2	\N	90.599999999999994	62	152.59999999999999	6.008	18.164999999999999	108.992	84.884	-96.480000000000004	447.26299999999998	2153.3099999999999	1012.5	\N	543.74300000000005	1.8620000000000001	1.2682	0.67259997	3.6533000000000002	0.060442999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	7.3099999999999996	0.79600000000000004	3.452	7.6639999999999997	17.692	15.036799999999999	13.2666	11.053900000000001	9.2812000000000001	6.7134999999999998	4.8819999999999997	3.4565999999999999	2.3351000000000002	1.8652	1.53	1.2619	0.876	0.25	0.064999998	20	95.214996	7	5	2003-04-03 00:00:00	\N	2011-12-01 03:12:09	106.40000000000001	0	0	62	152.59999999999999	1	1
2060	88	1995-02-06 00:00:00	184	\N	2	5	6	\N	1995-02-06 10:00:00	1995-02-06 14:00:00	508	757.64314168831311	67.420000000000002	0.2	\N	81.019999999999996	59.640000000000001	140.66	4.0309999999999997	13.829000000000001	63.375	58.302999999999997	-96.480000000000004	447.26299999999998	1833.9749999999999	930.90002	\N	543.74300000000005	1.712	1.1677001	0.60589999	3.359	0.057957000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5.2709999999999999	1.325	3.597	5.8209999999999997	15.1196	10.845599999999999	8.9144000000000005	6.9733000000000001	5.5572999999999997	3.6705999999999999	2.6193	1.8247	1.3982000000000001	1.1849000000000001	0.97699999999999998	0.83840000000000003	0.63049999999999995	0.25	0.131	20	96.850998	7	5	2003-04-03 00:00:00	\N	2011-12-01 03:11:59	106.40000000000001	0	0	59.640000000000001	140.66	1	1
2061	88	1995-03-23 00:00:00	184	\N	2	5	7	\N	1995-03-23 10:00:00	1995-03-23 14:00:00	312	294.83261171495531	65.450000000000003	0.20999999	6	79.859999999999999	60.719999999999999	140.58000000000001	2.2480000000000002	1.6659999999999999	9.1649999999999991	21.667000000000002	45.430999999999997	178.87799999999999	420.50099999999998	382.10001	\N	133.447	2.863	1.107	0.46689999	5.8987999999999996	0.076803999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.7069999999999999	0.90200000000000002	2.8199999999999998	5.2619999999999996	8.2469999999999999	6.1482999999999999	5.4436999999999998	4.5629	3.859	3.0775000000000001	2.2959999999999998	1.7552000000000001	1.3612	1.1640999999999999	0.96089999999999998	0.77339999999999998	0.58479999999999999	0.25	0.017999999	20	99.237999	6	3	2003-04-03 00:00:00	\N	2011-12-01 03:11:50	106.40000000000001	0	0	60.719999999999999	140.58000000000001	1	1
2062	88	1995-05-04 00:00:00	184	\N	2	5	8	\N	1995-05-04 08:45:00	1995-05-04 13:30:00	359	363.83598892483849	65.920000000000002	0.20999999	13	75.290000000000006	74	149.28999999999999	5.0780000000000003	3.2829999999999999	28.416	54.436999999999998	43.192	195.28800000000001	602.19000000000005	449.39999	\N	152.09700000000001	2.9540000000000002	1.1617	0.54089999	6.0862999999999996	0.078015000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.1849999999999996	1.5029999999999999	3.7240000000000002	6.0359999999999996	11.042199999999999	8.4933999999999994	7.3247999999999998	6.0110000000000001	4.9562999999999997	3.1724000000000001	1.8602000000000001	1.2406999999999999	0.88019999999999998	0.7823	0.68440000000000001	0.61229999999999996	0.52559999999999996	0.25	0.114	20	99.359001	5	5	2003-06-05 00:00:00	\N	2011-12-01 03:11:42	106.40000000000001	0	0	74	149.28999999999999	1	1
2063	88	1995-07-05 00:00:00	184	\N	2	5	9	\N	1995-07-05 09:30:00	1995-07-05 14:30:00	294	270.4374783579259	65.269999999999996	0.20999999	15	70	65	135	0.39700000000000002	1.3080000000000001	17.048999999999999	43.942	46.289000000000001	162.02099999999999	378.74400000000003	359.39999	\N	115.732	3.105	1.0796	0.55919999	6.3975999999999997	0.079985000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.5790000000000002	1.258	2.3620000000000001	2.9199999999999999	5.8003999999999998	4.0528000000000004	3.5724999999999998	3.0127000000000002	2.4529000000000001	1.8244	1.5296000000000001	1.2346999999999999	0.96519999999999995	0.87990000000000002	0.79459999999999997	0.72629999999999995	0.62470000000000003	0.5	1.618	10	96.764	6	5	2003-06-05 00:00:00	\N	2011-12-01 03:11:32	106.40000000000001	0	0	65	135	1	1
2064	88	1995-08-03 00:00:00	184	\N	2	5	10	\N	1995-08-03 09:00:00	1995-08-03 13:00:00	187	147.06780395237723	64.200000000000003	0.20999999	20	60.619999999999997	74.379999999999995	135	0.85199999999999998	0.36899999999999999	4.5650000000000004	21.637	51.753999999999998	147.60300000000001	196.79300000000001	247.89999	\N	95.849000000000004	2.5859999999999999	0.85119998	0.48289999	5.3277999999999999	0.072992000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.125	1.3240000000000001	2.0329999999999999	2.4630000000000001	1.9481999999999999	1.6466000000000001	1.4455	1.1940999999999999	0.98409999999999997	0.84389999999999998	0.70379999999999998	0.59540000000000004	0.52239999999999998	0.48209999999999997	0.43559999999999999	0.39839999999999998	0.34260000000000002	0.25	0.045000002	8	99.240997	5	5	2003-06-05 00:00:00	\N	2011-12-01 03:11:21	106.40000000000001	0	0	74.379999999999995	135	1	1
2065	88	1995-09-19 00:00:00	184	\N	2	5	11	\N	\N	\N	377	392.41314514307294	66.099999999999994	0.22	\N	80.530000000000001	68	148.53	0.76400000000000001	3.306	13.935	24.751000000000001	42.334000000000003	200	626.29100000000005	477.20001	\N	157.666	3.0270000000000001	1.1797	0.52240002	6.5326000000000004	0.080823999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.1389999999999998	2.1099999999999999	2.8650000000000002	2.754	5.8422000000000001	3.4769999999999999	2.4296000000000002	1.8043	1.5128999999999999	0.98240000000000005	0.83540000000000003	0.6885	0.57050000000000001	0.52110000000000001	0.46810000000000002	0.42349999999999999	0.35670000000000002	0.25	0.42399999	10	95.568001	5	5	2003-04-07 00:00:00	\N	2011-12-01 03:11:04	106.40000000000001	0	0	68	148.53	1	1
2066	88	1996-10-17 00:00:00	184	\N	2	5	12	\N	1996-10-17 08:30:00	1996-10-17 13:30:00	163	124.76368202595036	63.969999999999999	0.20999999	13	72.019999999999996	70.079999999999998	142.09999999999999	1.3109999999999999	0.497	4.0899999999999999	22.850000000000001	52.802999999999997	145.42099999999999	207.03200000000001	226.2	\N	92.617999999999995	2.4420000000000002	0.7913	0.63239998	5.0312999999999999	0.070931999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.758	1.3180000000000001	3.2370000000000001	4.7460000000000004	6.7619999999999996	5.2447999999999997	4.3596000000000004	3.6025	3.0135999999999998	1.9279999999999999	1.4115	0.94530000000000003	0.67589999999999995	0.59530000000000005	0.54269999999999996	0.50060000000000004	0.40620000000000001	0.25	0.093999997	20	99.758003	7	4	2003-06-05 00:00:00	\N	2011-12-01 03:10:55	106.40000000000001	0	0	70.079999999999998	142.09999999999999	1	1
2067	88	1997-07-07 00:00:00	184	\N	2	5	14	\N	1997-07-07 12:00:00	1997-07-07 17:30:00	189	149.15881538297975	64.219999999999999	0.20999999	18	63.719999999999999	77.569999999999993	141.28999999999999	0.80100000000000005	1.4239999999999999	11.361000000000001	53.088999999999999	51.625	147.762	194.57900000000001	249.8	\N	96.137	2.5979999999999999	0.8567	0.55489999	5.3529999999999998	0.073164000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.1230000000000002	1.093	3.1709999999999998	5.1699999999999999	7.3491999999999997	5.7752999999999997	5.0848000000000004	4.2215999999999996	3.6254	2.6173000000000002	1.7419	1.0761000000000001	0.81769999999999998	0.71479999999999999	0.62	0.57450000000000001	0.50629999999999997	0.25	0.097000003	10	95.130997	5	5	2003-06-05 00:00:00	\N	2011-12-01 03:10:41	106.40000000000001	0	0	77.569999999999993	141.28999999999999	1	1
2068	88	1997-10-15 00:00:00	184	\N	2	5	15	\N	1997-10-15 10:15:00	1997-10-15 13:30:00	248	212.58616211125621	64.810000000000002	0.20999999	13	81.670000000000002	64.709999999999994	146.38	1.758	0.94599999999999995	8.8089999999999993	28.881	48.497999999999998	153.91800000000001	286.33100000000002	309.20001	\N	105.42	2.9329999999999998	0.98650002	0.70520002	6.0419	0.077729999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.4630000000000001	0.92700000000000005	2.7629999999999999	5.085	9.8280999999999992	8.1219000000000001	7.0514999999999999	5.9695999999999998	5.2084999999999999	3.8382000000000001	3.0529000000000002	2.2675000000000001	1.7003999999999999	1.4732000000000001	1.2459	1.0642	0.75480000000000003	0.25	0.11	10	90.603996	5	5	2003-06-05 00:00:00	\N	2011-12-01 03:10:32	106.40000000000001	0	0	64.709999999999994	146.38	1	1
2069	88	1998-04-28 00:00:00	184	\N	2	5	16	\N	1998-04-28 11:35:00	1998-04-28 15:15:00	197	156.825857295189	64.299999999999997	0.20999999	13	63.469999999999999	76.530000000000001	140	1.853	1.2809999999999999	1.2809999999999999	5.6929999999999996	51.167999999999999	148.39699999999999	201.541	257.5	\N	97.228999999999999	2.649	0.87370002	0.5697	5.4568000000000003	0.073870000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.573	1.3120000000000001	3.0830000000000002	4.5	6.3391999999999999	4.7199999999999998	3.851	3.2778999999999998	2.7048999999999999	1.8156000000000001	1.3365	0.92320000000000002	0.66490000000000005	0.59179999999999999	0.53949999999999998	0.4965	0.40350000000000003	0.25	0.1	10	96.699997	5	4	2003-06-05 00:00:00	keine Messung von Feinschwebstoff	2011-12-01 03:10:24	106.40000000000001	0	0	76.530000000000001	140	1	1
2070	88	1998-06-23 00:00:00	184	\N	2	5	18	\N	1998-06-23 09:25:00	1998-06-23 12:50:00	136	101.76255628932265	63.689999999999998	0.20999999	17	68.989999999999995	69.010000000000005	138	0.68000000000000005	0.55600000000000005	4.4809999999999999	30.689	53.323999999999998	143.94399999999999	131.524	200.5	\N	90.619	2.2130000000000001	0.72820002	0.51840001	4.5582000000000003	0.067515000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.508	1.4330000000000001	2.351	2.7639999999999998	3.5693000000000001	2.3647	1.9006000000000001	1.673	1.4455	0.99670000000000003	0.84050000000000002	0.68440000000000001	0.56989999999999996	0.52390000000000003	0.47289999999999999	0.42799999999999999	0.36059999999999998	0.25	0.15099999	10	99.422997	5	5	2003-06-05 00:00:00	\N	2011-12-01 03:10:07	106.40000000000001	0	0	69.010000000000005	138	1	1
2071	88	1998-08-20 00:00:00	184	\N	2	5	19	\N	1998-08-20 09:45:00	1998-08-20 12:15:00	120	89.216487705707522	63.530000000000001	0.20999999	19	65.120000000000005	72.230000000000004	137.34999999999999	0.75800000000000001	0.315	5.2590000000000003	41.085999999999999	53.573999999999998	142.73699999999999	108.155	186.10001	\N	89.162999999999997	2.0880000000000001	0.68769997	0.4989	4.3006000000000002	0.065578999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.401	0.93700000000000006	1.9199999999999999	3.0880000000000001	2.7591999999999999	1.9481999999999999	1.8423	1.71	1.5777000000000001	1.3129999999999999	1.0484	0.88290000000000002	0.73970000000000002	0.66810000000000003	0.59240000000000004	0.52839999999999998	0.42520000000000002	0.25	0.082999997	10	99.834	5	5	2003-06-05 00:00:00	\N	2011-12-01 03:09:59	106.40000000000001	0	0	72.230000000000004	137.34999999999999	1	1
2072	88	2000-03-16 00:00:00	184	\N	3	5	21	\N	2000-03-16 09:00:00	2000-03-16 13:46:00	554	1264.3649117043237	67.879999999999995	0.19	5.1999998	112.83	51.710000000000001	164.53999999999999	19.306000000000001	30.363	93.546999999999997	51.57	-96.480000000000004	447.26299999999998	1473.1110000000001	1181	\N	543.74300000000005	2.1720000000000002	1.5359	0.4034	4.0484999999999998	0.063628000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	6.0739999999999998	1.097	2.7959999999999998	5.4340000000000002	15.898199999999999	10.7193	8.8971	7.3654000000000002	6.1619999999999999	4.6765999999999996	3.661	3.0381999999999998	2.4155000000000002	2.1040999999999999	1.7143999999999999	1.3711	0.86070000000000002	0.125	0.011	20	94.751999	6	5	2003-04-07 00:00:00	\N	2011-12-01 03:09:51	106.40000000000001	0	0	51.710000000000001	164.53999999999999	1	1
2073	88	2000-03-17 00:00:00	184	\N	2	5	22	\N	2000-03-17 07:00:00	2000-03-17 09:20:00	542	1103.3570315479296	67.769999999999996	0.19	5.1999998	82.400000000000006	58.100000000000001	140.5	6.9809999999999999	25.504999999999999	67.585999999999999	42.695	-96.480000000000004	447.26299999999998	2258.9960000000001	1121.2	\N	543.74300000000005	2.0619999999999998	1.4118	0.3276	3.8435000000000001	0.061996000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	6.2530000000000001	1.054	2.7919999999999998	4.8630000000000004	15.888500000000001	11.4369	9.3310999999999993	7.7755999999999998	6.5206999999999997	5.1954000000000002	3.9901	3.2235999999999998	2.4571000000000001	2.0737999999999999	1.7321	1.4666999999999999	1.0685	0.25	0.052000001	20	95.542	4	4	2003-04-07 00:00:00	\N	2011-12-01 03:09:44	106.40000000000001	0	0	58.100000000000001	140.5	1	1
2074	88	2000-05-08 00:00:00	184	\N	3	5	23	\N	2000-05-08 10:00:00	2000-05-08 13:30:00	247	211.19215449085453	64.799999999999997	0.20999999	16	73.180000000000007	68.819999999999993	142	9.827	2.3660000000000001	11.448	37.780999999999999	48.549999999999997	153.80699999999999	265.14499999999998	308.10001	\N	105.25700000000001	2.927	0.98339999	0.58579999	6.0307000000000004	0.077657000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.585	2.6360000000000001	3.6389999999999998	4.3330000000000002	9.7256999999999998	7.391	6.0228999999999999	4.8188000000000004	3.7381000000000002	2.101	1.2507999999999999	0.8952	0.74239999999999995	0.66600000000000004	0.60129999999999995	0.55800000000000005	0.4849	0.25	0.056000002	20	99.428001	5	5	2003-05-23 00:00:00	\N	2011-12-01 03:09:34	106.40000000000001	0	0	68.819999999999993	142	1	1
2075	88	2000-06-28 00:00:00	184	\N	3	5	24	\N	2000-06-28 09:00:00	2000-06-28 12:30:00	141	105.24757534032685	63.740000000000002	0.20999999	16	60.920000000000002	75.739999999999995	136.66	0.040000000000000001	0.40899999999999997	6.4550000000000001	42.749000000000002	53.231000000000002	144.45500000000001	137.572	205.10001	\N	91.222999999999999	2.2480000000000002	0.73640001	0.4623	4.6307	0.068048999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.921	4.069	3.3530000000000002	2.504	5.3681999999999999	3.9217	3.2250000000000001	2.3542000000000001	1.6125	0.77800000000000002	0.57989999999999997	0.50219999999999998	0.43809999999999999	0.40620000000000001	0.37440000000000001	0.34889999999999999	0.31069999999999998	0.25	0.47799999	10	97.847	5	5	2003-04-07 00:00:00	\N	2011-12-01 03:09:27	106.40000000000001	0	0	75.739999999999995	136.66	1	1
2076	88	2001-04-03 00:00:00	184	\N	3	3	26	\N	2001-04-03 09:00:00	2001-04-03 13:00:00	424	484.41764808958379	66.609999999999999	0.20999999	6.8000002	110.73	58.450000000000003	169.18000000000001	3.9470000000000001	3.105	16.974	24.422999999999998	38.302999999999997	326.80700000000002	779.46100000000001	577.29999	\N	288.50400000000002	2.0009999999999999	1.2039	0.31290001	4.1223999999999998	0.064205999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5.6020000000000003	0.76700000000000002	2.6779999999999999	5.79	12.372999999999999	9.4977999999999998	8.5429999999999993	7.3494000000000002	6.234	5.1412000000000004	4.0484999999999998	3.2284999999999999	2.4211	2.0173999999999999	1.6318999999999999	1.3241000000000001	0.88800000000000001	0.25	0.098999999	16	95.956001	5	5	2003-04-07 00:00:00	Peilung von km 214,8 verwendet	2011-12-01 03:09:18	106.19999999999999	0	0	58.450000000000003	169.18000000000001	1	1
2077	88	2001-09-13 00:00:00	184	\N	3	3	27	\N	2001-09-13 09:00:00	2001-09-13 10:30:00	352	353.38093177182589	65.849999999999994	0.20999999	13.9	80.950000000000003	68.719999999999999	149.66999999999999	0.91600000000000004	4.1109999999999998	18.419	36.329000000000001	43.524999999999999	193.45599999999999	582.20100000000002	438.79999	\N	149.93100000000001	2.927	1.1555001	0.54409999	6.0289999999999999	0.077646999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.0609999999999999	0.88200000000000001	2.9060000000000001	6.173	6.9196999999999997	5.5987	4.9748999999999999	4.1951999999999998	3.6926000000000001	2.8721999999999999	2.0518999999999998	1.6184000000000001	1.2110000000000001	1.0073000000000001	0.81579999999999997	0.66300000000000003	0.46529999999999999	0.25	0.33000001	10	97.468002	5	5	2003-04-07 00:00:00	Ergebnisse der Geschiebemessung unter Vorbehalt, da Fängeröffnung vermutlich nicht immer auf Sohle	2011-12-01 03:09:11	106.40000000000001	0	0	68.719999999999999	149.66999999999999	1	1
2078	88	2002-03-06 00:00:00	184	\N	3	3	28	\N	2002-03-06 09:00:00	2002-03-06 12:30:00	518	885.19483895506687	67.5	0.2	4.8000002	108.40000000000001	39.850000000000001	148.25	16.812999999999999	10.589	27.542999999999999	21.687000000000001	-96.480000000000004	447.26299999999998	1788.0830000000001	974.40002	\N	543.74300000000005	1.792	1.3033	0.61790001	3.516	0.059296000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5.7709999999999999	0.40400000000000003	3.6920000000000002	10.058999999999999	13.2491	9.9596	9.1083999999999996	8.0444999999999993	6.9805000000000001	5.468	4.2447999999999997	3.0768	1.9291	1.3996	0.93679999999999997	0.73060000000000003	0.54359999999999997	0.25	0.139	16	94.918999	5	5	2003-04-07 00:00:00	\N	2011-12-01 03:09:03	106.40000000000001	0	0	39.850000000000001	148.25	1	1
2079	88	2002-04-04 00:00:00	184	\N	3	3	29	\N	2002-04-04 08:30:00	2002-04-04 12:00:00	399	446.08243852853764	66.319999999999993	0.20999999	8	84.739999999999995	63.780000000000001	148.52000000000001	5.3010000000000002	\N	\N	\N	40.789999999999999	205.215	\N	512.59998	\N	164.42500000000001	3.1179999999999999	1.2484	\N	6.4229000000000003	0.080143000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.2960000000000003	0.58299999999999996	3.1280000000000001	7.2199999999999998	9.3668999999999993	7.6391	6.4871999999999996	5.7866	5.1963999999999997	4.0162000000000004	3.1987000000000001	2.3864000000000001	1.6738999999999999	1.363	1.0521	0.78080000000000005	0.55630000000000002	0.25	0.050999999	16	98.666	5	0	2003-06-05 00:00:00	\N	2011-12-01 03:08:58	106.40000000000001	0	0	63.780000000000001	148.52000000000001	1	1
2081	88	1998-05-14 00:00:00	184	\N	2	5	17	\N	1998-05-14 09:00:00	\N	150	112.91461725253608	63.829999999999998	0.20999999	15	63.950000000000003	71.159999999999997	135.11000000000001	0.86499999999999999	0.68700000000000006	6.4870000000000001	40.040999999999997	53.064	144.85599999999999	149.28299999999999	213.3	\N	91.792000000000002	2.3239999999999998	0.75950003	0.50940001	4.7869000000000002	0.069186999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.069	1.9179999999999999	2.5609999999999999	3.1320000000000001	5.1604000000000001	3.5954000000000002	2.9428000000000001	2.1269999999999998	1.8281000000000001	1.4209000000000001	1.0136000000000001	0.86909999999999998	0.73360000000000003	0.66590000000000005	0.59970000000000001	0.54820000000000002	0.4536	0.25	0.079000004	10	98.225998	5	5	2003-04-07 00:00:00	\N	2011-12-01 03:10:16	106.40000000000001	0	0	71.159999999999997	135.11000000000001	1	1
2083	88	2002-08-15 00:00:00	184	\N	3	\N	31	WEL215-031	2002-08-15 12:15:00	2002-08-15 15:30:00	622	1867.9702113382511	68.560000000000002	0.20999999	18	91.689999999999998	43.329999999999998	135.02000000000001	5.1219999999999999	\N	\N	\N	-96.480000000000004	447.26299999999998	\N	1550.8	\N	543.74300000000005	2.8519999999999999	1.7282	\N	5.8754999999999997	0.076651999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	0	2003-07-16 00:00:00	\N	2011-12-01 03:08:38	106.40000000000001	0	0	43.329999999999998	135.02000000000001	1	1
2084	88	2002-08-22 00:00:00	184	\N	3	\N	32	WEL215-032	2002-08-22 08:30:00	2002-08-22 11:15:00	596	1610.0788015639405	68.310000000000002	0.19	21.5	86.569999999999993	57.789999999999999	144.36000000000001	3.6899999999999999	\N	\N	\N	-96.480000000000004	447.26299999999998	\N	1414.8	\N	543.74300000000005	2.6019999999999999	1.6327	\N	4.8499999999999996	0.069641999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	6	0	2003-07-16 00:00:00	\N	2011-12-01 03:08:21	106.40000000000001	0	0	57.789999999999999	144.36000000000001	1	1
2085	88	2002-09-05 00:00:00	184	\N	3	\N	33	WEL215-033	2002-09-05 08:45:00	2002-09-05 12:15:00	410	468.38656045496447	66.430000000000007	0.20999999	19.299999	85.209999999999994	63.759999999999998	148.97	1.651	\N	\N	\N	39.847000000000001	213.57400000000001	\N	531.09998	\N	173.726	3.0569999999999999	1.2654001	\N	6.2973999999999997	0.079355999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	6	0	2003-07-16 00:00:00	\N	2011-12-01 03:08:01	106.40000000000001	0	0	63.759999999999998	148.97	1	1
2086	88	2002-10-16 00:00:00	184	\N	3	\N	34	WEL215-034	2002-10-16 10:30:00	2002-10-16 13:45:00	319	309.46969172917295	65.519999999999996	0.20999999	11.1	84.959999999999994	59.829999999999998	144.78999999999999	0.51100000000000001	4.1210000000000004	17.956	40.442	45.097999999999999	181.43100000000001	505.50599999999997	391.5	\N	136.333	2.8719999999999999	1.1339999	0.6146	5.9165999999999999	0.076919000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	6	5	2003-08-26 00:00:00	\N	2011-12-01 03:07:18	106.40000000000001	0	0	59.829999999999998	144.78999999999999	1	1
2087	88	2003-03-12 00:00:00	184	\N	3	3	35	WEL215-035	2003-03-12 09:00:00	2003-03-12 11:20:00	374	399.38318324508134	66.069999999999993	0.20999999	5.5	80.590000000000003	74.379999999999995	154.97	1.236	5.1589999999999998	20.457000000000001	35.701000000000001	42.476999999999997	199.215	680.86099999999999	472.5	\N	156.738	3.0150000000000001	1.2127	0.55970001	6.2106000000000003	0.078807000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.0899999999999999	1.6870000000000001	3.71	4.9420000000000002	8.3168000000000006	5.4009	4.1685999999999996	3.3149000000000002	2.5457000000000001	1.6552	1.1208	0.75849999999999995	0.54139999999999999	0.47839999999999999	0.43059999999999998	0.39229999999999998	0.33489999999999998	0.125	0.011	16	96.627998	5	5	2003-12-16 00:00:00	Nullpunkt: + 45 m	2011-12-01 03:06:32	106.40000000000001	0	0	74.379999999999995	154.97	1	1
2088	88	2003-04-09 00:00:00	184	\N	3	3	36	WEL215-036	2003-04-09 09:00:00	2003-04-09 12:30:00	283	260.67942501511419	65.159999999999997	0.20999999	6.8000002	71.159999999999997	79.810000000000002	150.97	0.14099999999999999	\N	\N	\N	46.813000000000002	157.81800000000001	\N	347.10001	\N	111.005	3.1269999999999998	1.0776	\N	6.4409000000000001	0.080255000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.6970000000000001	1.8700000000000001	2.9009999999999998	3.407	4.0297000000000001	3.1267	2.5369000000000002	1.9256	1.6515	1.1033999999999999	0.78810000000000002	0.58630000000000004	0.48249999999999998	0.44280000000000003	0.4032	0.37140000000000001	0.32379999999999998	0.125	0.041000001	10	98.538002	5	0	2003-12-12 00:00:00	\N	2011-12-01 03:06:11	106.40000000000001	0	0	79.810000000000002	150.97	1	1
2089	88	2003-10-16 00:00:00	184	\N	2	3	37	WEL215-037	2003-10-16 10:30:00	2003-10-16 14:04:00	143	117.09664011374112	63.759999999999998	0.20999999	10	60.920000000000002	70.079999999999998	131	0.79900000000000004	0.41799999999999998	5.7119999999999997	33.997999999999998	53.194000000000003	144.59399999999999	177.054	206.89999	\N	91.400000000000006	2.2629999999999999	0.81209999	0.5478	4.6628999999999996	0.068284999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.0009999999999999	1.274	1.774	2.1829999999999998	1.794	1.4590000000000001	1.2357	0.99180000000000001	0.93910000000000005	0.83379999999999999	0.72850000000000004	0.62619999999999998	0.56699999999999995	0.5373	0.50770000000000004	0.46339999999999998	0.38200000000000001	0.125	0.024	6.2999999999999998	99.553001	4	5	2003-12-16 00:00:00	Nullpunkt: +30 m	2011-12-01 03:05:58	106.40000000000001	0	0	70.079999999999998	131	1	1
2093	89	2002-03-05 00:00:00	185	\N	3	3	1	WEL246-001	2002-03-05 09:00:00	2002-03-05 14:00:00	533	1010.655524791218	61.549999999999997	0.2	5	115.06999999999999	39.380000000000003	154.44999999999999	26.504000000000001	36	54.140999999999998	37.338999999999999	29.298999999999999	221.68799999999999	1189.038	868.20001	\N	192.38900000000001	4.5129999999999999	1.6702	0.43259999	8.8537999999999997	0.094094999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5.1840000000000002	0.76000000000000001	2.6480000000000001	5.9269999999999996	11.214499999999999	8.8039000000000005	7.6845999999999997	6.2946999999999997	5.7850000000000001	4.7653999999999996	3.8142999999999998	3.0693999999999999	2.3243999999999998	1.9501999999999999	1.5645	1.256	0.80410000000000004	0.25	0.026000001	16	96.797997	5	5	2003-12-18 00:00:00	\N	2011-12-01 03:16:09	137.19999999999999	0	0	39.380000000000003	154.44999999999999	1	1
2094	89	2002-04-09 00:00:00	185	\N	3	3	2	WEL246-002	2002-04-09 09:00:00	2002-04-09 12:00:00	363	379.86707655945781	59.32	0.22	7.5999999	93.659999999999997	32.659999999999997	126.31999999999999	6.7670000000000003	\N	\N	\N	39.622	210.77699999999999	\N	460.20001	\N	171.155	2.6890000000000001	1.1842	\N	5.8033000000000001	0.076178999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.4129999999999998	0.76500000000000001	3.1709999999999998	6.319	5.5616000000000003	4.5697999999999999	3.9563999999999999	3.5625	3.1684999999999999	2.3805999999999998	1.6478999999999999	0.98329999999999995	0.64080000000000004	0.57020000000000004	0.50629999999999997	0.45450000000000002	0.37680000000000002	0.25	0.222	10	99.070999	5	0	2003-12-18 00:00:00	\N	2011-12-01 03:16:04	137.19999999999999	0	0	32.659999999999997	126.31999999999999	1	1
2095	89	2002-09-19 00:00:00	185	\N	3	\N	3	WEL246-003	2002-09-19 10:30:00	2002-09-19 14:00:00	292	272.52848978852842	58.630000000000003	0.20999999	16	99.159999999999997	62.840000000000003	162	0.64200000000000002	\N	\N	\N	43.497	205.03700000000001	\N	345.89999	\N	161.541	2.141	1.1303999	\N	4.4112999999999998	0.066417000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	0	2004-08-13 00:00:00	\N	2011-12-01 03:16:00	137.19999999999999	0	0	62.840000000000003	162	1	1
2096	89	2002-10-22 00:00:00	185	\N	3	\N	4	WEL246-004	2002-10-22 08:45:00	2002-10-22 11:30:00	423	496.26671286299808	59.859999999999999	0.22	\N	136.72999999999999	38.939999999999998	175.66999999999999	1.9239999999999999	3.4199999999999999	23.728999999999999	33.326999999999998	36.439999999999998	214.06299999999999	696.74199999999996	554.5	\N	177.62299999999999	3.1219999999999999	1.2841001	0.60229999	6.7369000000000003	0.082078999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	5	2003-08-26 00:00:00	\N	2011-12-01 03:15:52	137.19999999999999	0	0	38.939999999999998	175.66999999999999	1	1
2097	89	2003-03-11 00:00:00	185	\N	3	3	5	WEL246-005	2003-03-11 08:45:00	2003-03-11 13:40:00	369	390.32213371247042	59.350000000000001	0.22	4	91.290000000000006	73.540000000000006	164.83000000000001	1.8240000000000001	2.6389999999999998	19.609000000000002	35.015999999999998	39.375	210.977	652.67399999999998	465.39999	\N	171.602	2.7120000000000002	1.2033	0.66180003	5.8528000000000002	0.076504000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.1120000000000001	1.7589999999999999	3.012	3.9079999999999999	5.0430999999999999	3.5956000000000001	3.0308000000000002	2.3248000000000002	1.8572	1.3282	0.90010000000000001	0.63690000000000002	0.53080000000000005	0.48130000000000001	0.43419999999999997	0.39639999999999997	0.33989999999999998	0.125	0.0080000004	16	99.061996	5	5	2003-12-16 00:00:00	Nullpunkt: + 30 m	2011-12-01 03:15:41	137.19999999999999	0	0	73.540000000000006	164.83000000000001	1	1
2098	89	2003-04-14 00:00:00	185	\N	3	3	6	WEL246-006	2003-04-14 10:20:00	2003-04-14 14:10:00	214	184.00900589302177	58.390000000000001	0.2	7.6999998	95.719999999999999	60.810000000000002	156.53	0.26200000000000001	\N	\N	\N	44.231000000000002	197.88999999999999	\N	307.60001	\N	153.65899999999999	2.0019999999999998	0.85839999	\N	3.9270999999999998	0.062667	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.167	1.881	2.234	2.1040000000000001	2.5749	1.6818	1.3761000000000001	0.99809999999999999	0.87749999999999995	0.63619999999999999	0.54890000000000005	0.47610000000000002	0.41820000000000002	0.38919999999999999	0.36030000000000001	0.33710000000000001	0.30230000000000001	0.125	0.017999999	10	99.116997	5	0	2003-12-12 00:00:00	Nullpunkt: + 45 m	2011-12-01 03:15:35	137.19999999999999	0	0	60.810000000000002	156.53	1	1
2099	89	2003-10-21 00:00:00	185	\N	2	3	7	WEL246-007	2003-10-21 08:55:00	2003-10-21 14:00:00	139	114.30862487293776	57.219999999999999	0.20999999	8	79.049999999999997	75.760000000000005	154.81	1.159	0.38800000000000001	4.3419999999999996	26.472999999999999	48.478000000000002	158.78999999999999	170.99799999999999	166.7	\N	110.312	1.5109999999999999	0.98400003	0.5747	3.1124000000000001	0.055788999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.395	1.5429999999999999	2.2570000000000001	2.6419999999999999	3.2873999999999999	1.9774	1.7498	1.4652000000000001	1.1807000000000001	0.88039999999999996	0.70530000000000004	0.58760000000000001	0.51329999999999998	0.47060000000000002	0.42480000000000001	0.38819999999999999	0.3332	0.125	0.066	10	98.917	5	5	2003-12-16 00:00:00	Nullpunkt: + 30 m	2011-12-01 03:15:27	137.19999999999999	0	0	75.760000000000005	154.81	1	1
2104	90	1994-04-26 00:00:00	186	\N	2	14	1	\N	1994-04-26 09:00:00	1994-04-26 14:00:00	374	547.8449948178602	53.950000000000003	0.16	\N	112.02	40.979999999999997	153	1.8089999999999999	\N	\N	\N	3.2010000000000001	402.55900000000003	\N	1043.1	\N	399.358	2.6120000000000001	0.7536	\N	4.0994999999999999	0.064028000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.7959999999999998	1.738	2.6960000000000002	3.1299999999999999	6.6882999999999999	4.0411999999999999	3.4468999999999999	2.7376	2.0284	1.5728	1.137	0.88749999999999996	0.72350000000000003	0.64149999999999996	0.5917	0.55600000000000005	0.50249999999999995	0.125	0.0049999999	20	98.920998	9	0	2004-05-06 00:00:00	Peilung von km 275 verwendet	2011-12-01 03:25:40	166.49999999999997	0	0	40.979999999999997	153	1	1
2105	90	1994-05-26 00:00:00	186	\N	2	14	2	WEL275-002	1994-05-26 09:45:00	1994-05-26 13:00:00	216	262.07343263551587	52.350000000000001	0.18000001	\N	122.78	39.399999999999999	162.18000000000001	4.6280000000000001	\N	\N	\N	11.116	259.76400000000001	\N	510.10001	\N	248.648	2.0510000000000002	0.73720002	\N	3.6221999999999999	0.060185000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.7689999999999999	1.633	2.27	2.6779999999999999	3.7330000000000001	2.8837000000000002	2.3174000000000001	1.8991	1.7161	1.3501000000000001	0.99399999999999999	0.85599999999999998	0.71799999999999997	0.64900000000000002	0.59650000000000003	0.55959999999999999	0.50409999999999999	0.25	0.071000002	10	98.918999	8	0	2004-05-06 00:00:00	\N	2011-12-01 03:25:33	166.59999999999999	0	0	39.399999999999999	162.18000000000001	1	1
2106	90	1994-11-02 00:00:00	186	\N	2	14	3	WEL275-003	1994-11-02 10:00:00	1994-11-02 15:30:00	127	151.24982681358227	51.450000000000003	0.2	\N	138.56	24.210000000000001	162.77000000000001	3.7759999999999998	0.74199999999999999	5.5750000000000002	25.693000000000001	12.932	202.84	238.83600000000001	312.70001	\N	189.90799999999999	1.647	0.69400001	0.4219	3.2305999999999999	0.056839000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.375	1.4510000000000001	1.966	2.3239999999999998	3.0148000000000001	1.9426000000000001	1.7569999999999999	1.5250999999999999	1.2931999999999999	0.9516	0.82010000000000005	0.68869999999999998	0.59379999999999999	0.56120000000000003	0.52849999999999997	0.50239999999999996	0.40939999999999999	0.25	0.082000002	10	99.524002	8	5	2003-07-16 00:00:00	\N	2011-12-01 03:25:22	166.59999999999999	0	0	24.210000000000001	162.77000000000001	1	1
2107	90	1995-05-09 00:00:00	186	\N	2	14	4	WEL275-004	1995-05-09 09:00:00	1995-05-09 15:00:00	272	344.31988223921496	52.899999999999999	0.2	15	119.8	29.359999999999999	149.16	2.3439999999999999	2.2559999999999998	23.413	47.395000000000003	10.006	294.55099999999999	779.43200000000002	656.70001	\N	284.54500000000002	2.3079999999999998	0.75230002	0.4136	4.5279999999999996	0.067290000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.673	1.722	2.3370000000000002	2.625	3.6328	2.6042000000000001	1.9774	1.7397	1.502	1.0266	0.84909999999999997	0.68930000000000002	0.58620000000000005	0.55130000000000001	0.51649999999999996	0.47670000000000001	0.3911	0.25	0.121	10	98.146004	5	5	2003-07-16 00:00:00	\N	2011-12-01 03:25:12	166.59999999999999	0	0	29.359999999999999	149.16	1	1
2108	90	1995-07-03 00:00:00	186	\N	2	14	5	WEL275-005	1995-07-03 11:00:00	1995-07-03 16:00:00	277	352.68392796162505	52.950000000000003	0.2	17	120.59	15.41	136	1.3999999999999999	1.2070000000000001	22.829999999999998	45.119999999999997	9.9049999999999994	299.01999999999998	768.96699999999998	671	\N	289.11500000000001	2.3210000000000002	0.75410002	0.39030001	4.5536000000000003	0.067479999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.1840000000000002	1.272	2.5529999999999999	3.5209999999999999	4.649	3.6644999999999999	3.3289	2.9094000000000002	2.4899	1.7862	1.2725	0.91830000000000001	0.74419999999999997	0.65710000000000002	0.59860000000000002	0.56210000000000004	0.50729999999999997	0.25	0.050999999	20	99.847	7	5	2003-07-16 00:00:00	\N	2011-12-01 03:25:02	166.59999999999999	0	0	15.41	136	1	1
2109	90	1995-09-14 00:00:00	186	\N	2	14	6	WEL275-006	1995-09-14 09:00:00	1995-09-14 13:15:00	257	321.31875650258723	52.75	0.2	17	120.91	15.44	136.34999999999999	0.34699999999999998	1.1060000000000001	10.356999999999999	22.465	10.308999999999999	285.06400000000002	653.53200000000004	614.70001	\N	274.755	2.2370000000000001	0.74989998	0.47870001	4.3898000000000001	0.066254999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.159	1.28	1.9830000000000001	2.4529999999999998	2.1402000000000001	1.7592000000000001	1.5826	1.3620000000000001	1.1413	0.91269999999999996	0.78420000000000001	0.65569999999999995	0.5716	0.53520000000000001	0.49769999999999998	0.44750000000000001	0.37209999999999999	0.25	0.278	10	99.921997	7	5	2004-05-06 00:00:00	\N	2011-12-01 03:24:52	166.59999999999999	0	0	15.44	136.34999999999999	1	1
2110	90	1995-11-08 00:00:00	186	\N	2	14	7	WEL275-007	1995-11-08 08:45:00	1995-11-08 13:15:00	222	270.4374783579259	52.399999999999999	0.2	9	119.90000000000001	23.100000000000001	143	4.726	0.84199999999999997	1.085	2.7970000000000002	11.015000000000001	262.92700000000002	472.63999999999999	522.59998	\N	251.91200000000001	2.0739999999999998	0.74250001	0.54220003	4.0700000000000003	0.063796000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.728	1.6559999999999999	2.3180000000000001	2.8479999999999999	3.6579999999999999	2.7454999999999998	2.1371000000000002	1.8275999999999999	1.6172	1.1964999999999999	0.92059999999999997	0.77159999999999995	0.626	0.58489999999999998	0.54390000000000005	0.5111	0.42020000000000002	0.25	0.079000004	10	98.359001	7	3	2003-07-16 00:00:00	\N	2011-12-01 03:24:44	166.59999999999999	0	0	23.100000000000001	143	1	1
2111	90	1996-07-22 00:00:00	186	\N	2	14	8	WEL275-008	1996-07-22 10:15:00	1996-07-22 15:00:00	286	366.62400416564185	53.039999999999999	0.2	19	112.25	31.960000000000001	144.21000000000001	3.9870000000000001	2.278	28.192	53.597999999999999	9.7230000000000008	309.23700000000002	815.27599999999995	697.5	\N	299.51299999999998	2.3290000000000002	0.75410002	0.54040003	4.569	0.067595000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.4910000000000001	1.9950000000000001	2.8530000000000002	3.621	6.1970000000000001	4.1845999999999997	3.5066999999999999	2.7915999999999999	2.0766	1.5324	1.0383	0.82750000000000001	0.64039999999999997	0.5917	0.54849999999999999	0.51400000000000001	0.42330000000000001	0.25	0.111	10	95.217003	6	6	2003-07-16 00:00:00	\N	2011-12-01 03:24:32	166.59999999999999	0	0	31.960000000000001	144.21000000000001	1	1
2112	90	1996-09-04 00:00:00	186	\N	2	14	9	WEL275-009	1996-09-04 08:30:00	1996-09-04 14:40:00	199	239.07230689888812	52.170000000000002	0.2	18	129.22	23.420000000000002	152.63999999999999	3.3799999999999999	1.246	12.442	36.274000000000001	11.478999999999999	248.37899999999999	445.06599999999997	466.39999	\N	236.90000000000001	1.9690000000000001	0.73549998	0.49219999	3.8622999999999998	0.062148000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.96	1.847	2.48	2.9750000000000001	4.4973000000000001	3.1661999999999999	2.5053999999999998	1.9158999999999999	1.6992	1.2657	0.93930000000000002	0.78249999999999997	0.62780000000000002	0.58740000000000003	0.54700000000000004	0.51470000000000005	0.42549999999999999	0.25	0.155	10	97.786003	9	5	2004-05-06 00:00:00	\N	2011-12-01 03:24:20	166.59999999999999	0	0	23.420000000000002	152.63999999999999	1	1
2113	90	1996-10-21 00:00:00	186	\N	2	14	10	WEL275-010	1996-10-21 11:00:00	1996-10-21 14:45:00	188	224.43522688467047	52.060000000000002	0.2	11	131.09999999999999	13.24	144.34	5.2320000000000002	0.996	7.3799999999999999	22.919	11.701000000000001	241.422	385.02300000000002	440.70001	\N	229.721	1.9179999999999999	0.73070002	0.51310003	3.7637999999999998	0.061350000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.9419999999999999	1.5	2.4399999999999999	3.1699999999999999	4.1219000000000001	3.1867999999999999	2.6194000000000002	1.9769000000000001	1.7948	1.4305000000000001	1.0662	0.86509999999999998	0.70030000000000003	0.62290000000000001	0.57420000000000004	0.53520000000000001	0.45119999999999999	0.25	0.167	10	98.282997	6	5	2003-07-16 00:00:00	\N	2011-12-01 03:24:11	166.59999999999999	0	0	13.24	144.34	1	1
2114	90	1997-09-08 00:00:00	186	\N	2	14	12	WEL275-012	1997-09-08 10:30:00	1997-09-08 14:30:00	128	151.24982681358227	51.460000000000001	0.19	19.5	110.95	6.2000000000000002	117.15000000000001	3.173	0.623	7.6470000000000002	35.238999999999997	12.912000000000001	203.47300000000001	229.863	314.60001	\N	190.56100000000001	1.651	0.68980002	0.58609998	3.0771999999999999	0.055472	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.9910000000000001	1.5269999999999999	2.3719999999999999	2.8260000000000001	4.1261999999999999	3.2050000000000001	2.6509999999999998	1.9892000000000001	1.8100000000000001	1.4516	1.0931999999999999	0.89000000000000001	0.74119999999999997	0.66690000000000005	0.60660000000000003	0.56950000000000001	0.51370000000000005	0.25	0.1	10	98.080002	5	5	2003-07-16 00:00:00	keine genauen Angaben zum Nullpunkt vorliegend, daher bis auf weiteres keine Abänderung des Uferbezuges auf links (es liegen nur Abstände zum rechten Ufer vor)	2011-12-01 03:23:56	166.59999999999999	0	0	6.2000000000000002	117.15000000000001	1	1
2115	90	1997-11-27 00:00:00	186	\N	2	14	13	WEL275-013	1997-11-27 09:00:00	1997-11-27 14:30:00	102	124.76368202595036	51.200000000000003	0.19	4	128.06	14.25	142.31	3.8570000000000002	0.36499999999999999	1.97	11.004	13.436999999999999	187.02799999999999	146.27600000000001	267.29999	\N	173.59200000000001	1.54	0.66970003	0.40540001	2.8696999999999999	0.05357	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.554	1.5229999999999999	2.2069999999999999	2.734	3.4662000000000002	2.6316000000000002	2.0752000000000002	1.8351999999999999	1.6503000000000001	1.2806999999999999	0.96599999999999997	0.82469999999999999	0.6835	0.61929999999999996	0.57530000000000003	0.54020000000000001	0.46839999999999998	0.25	0.108	10	99.837997	4	2	2003-07-16 00:00:00	\N	2011-12-01 03:23:51	166.59999999999999	0	0	14.25	142.31	1	1
2116	90	1998-04-16 00:00:00	186	\N	2	14	14	WEL275-014	1998-04-16 09:00:00	1998-04-16 14:00:00	204	245.34534119069568	52.219999999999999	0.19	9	105.31999999999999	29.68	135	1.883	\N	\N	\N	11.378	251.542	\N	478.29999	\N	240.16399999999999	1.9910000000000001	0.736	\N	3.7119	0.060925	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.2919999999999998	1.2210000000000001	2.4359999999999999	3.1680000000000001	5.0987999999999998	3.6433	3.1753999999999998	2.5905999999999998	2.0057999999999998	1.6777	1.3537999999999999	1.03	0.84699999999999998	0.76270000000000004	0.67849999999999999	0.61409999999999998	0.52959999999999996	0.25	0.125	10	97.300003	5	0	2003-07-16 00:00:00	Schwebstoffmessung unvollständig	2011-12-01 03:23:46	166.59999999999999	0	0	29.68	135	1	1
2117	90	1998-06-25 00:00:00	186	\N	2	14	15	WEL275-015	1998-06-25 08:45:00	1998-06-25 13:30:00	113	135.91574298916379	51.270000000000003	0.19	\N	110.64	21.300000000000001	131.94	1.9450000000000001	0.73699999999999999	4.2290000000000001	21.687999999999999	13.295	191.45500000000001	245.28999999999999	279.60001	\N	178.16	1.569	0.69749999	0.49380001	2.9249000000000001	0.054081999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.758	1.298	2.3740000000000001	3.113	3.7555000000000001	3.1379000000000001	2.7262	2.2115999999999998	1.8922000000000001	1.5262	1.1600999999999999	0.90720000000000001	0.74229999999999996	0.65980000000000005	0.59760000000000002	0.55689999999999995	0.49030000000000001	0.25	0.088	10	99.753998	7	5	2003-07-16 00:00:00	Peilung von km 275 verwendet	2011-12-01 03:23:37	166.79999999999998	0	0	21.300000000000001	131.94	1	1
2118	90	1998-09-22 00:00:00	1438	\N	2	14	16	WEL275-016	1998-09-22 10:40:00	1998-09-22 14:30:00	324	438.41539661632839	52.100000000000001	0.18000001	14	122.73999999999999	19.260000000000002	142	5.7119999999999997	2.4529999999999998	19.402999999999999	30.847000000000001	6.6989999999999998	160.589	619.23699999999997	610.5	\N	153.88999999999999	3.9670000000000001	1.0303	0.61369997	7.0050999999999997	0.083696000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.3959999999999999	1.4139999999999999	2.6190000000000002	3.2989999999999999	5.7058999999999997	3.8119999999999998	3.2905000000000002	2.6387	1.9961	1.6099000000000001	1.2238	0.9254	0.748	0.6593	0.59609999999999996	0.55569999999999997	0.48809999999999998	0.25	0.07	20	99.846001	7	5	2004-05-06 00:00:00	keine Angabe darï¿½ber, ob Nullpunkt links oder rechts!	2011-12-01 03:23:25	173.79999999999998	0	0	19.260000000000002	142	1	1
2119	90	1999-02-25 00:00:00	1438	\N	2	14	17	WEL275-017	1999-02-25 08:30:00	1999-02-25 13:00:00	436	703.97384830284841	53.229999999999997	0.18000001	2	132.66	31.120000000000001	163.78	15.289999999999999	4.9829999999999997	22.552	22.329000000000001	-24.858000000000001	290.46199999999999	1401.018	949.40002	\N	315.31999999999999	3.0110000000000001	1.0638	0.51440001	5.3167	0.072915999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.4199999999999999	1.4079999999999999	2.6219999999999999	3.1400000000000001	7.8562000000000003	5.2184999999999997	4.0327000000000002	3.4842	2.9567000000000001	1.9725999999999999	1.6777	1.3827	1.0878000000000001	0.95579999999999998	0.84660000000000002	0.75919999999999999	0.62819999999999998	0.25	0.064999998	20	98.135002	5	5	2004-05-06 00:00:00	\N	2011-12-01 03:23:17	173.79999999999998	0	0	31.120000000000001	163.78	1	1
2120	90	1999-07-15 00:00:00	1438	\N	2	14	18	WEL275-018	1999-07-15 09:00:00	1999-07-15 12:30:00	178	211.19215449085453	50.560000000000002	0.19	22	105.86	25.579999999999998	131.44	2.9129999999999998	0.85899999999999999	10.927	36.064	14.195	154.66999999999999	326.23500000000001	384.89999	\N	140.47499999999999	2.7400000000000002	0.78729999	0.38960001	5.1066000000000003	0.071460999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.1259999999999999	1.3360000000000001	1.9690000000000001	2.395	1.9574	1.6645000000000001	1.4692000000000001	1.2251000000000001	0.99490000000000001	0.86309999999999998	0.73140000000000005	0.61519999999999997	0.55069999999999997	0.51849999999999996	0.47549999999999998	0.42949999999999999	0.3604	0.25	0.419	10	99.751999	6	5	2003-07-16 00:00:00	keine genaue Angabe zum Nullpunkt!	2011-12-01 03:23:08	173.79999999999998	0	0	25.579999999999998	131.44	1	1
2121	90	1999-10-20 00:00:00	1438	\N	2	14	19	WEL275-019	1999-10-20 09:15:00	1999-10-20 13:00:00	108	131.03671631775794	49.840000000000003	0.2	8	98.530000000000001	21.739999999999998	120.27	1.605	0.40200000000000002	2.04	10.85	16.588000000000001	151.517	200.071	285.70001	\N	134.93000000000001	2.1179999999999999	0.65799999	0.53939998	4.1547000000000001	0.064457	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.621	1.339	2.246	2.9159999999999999	3.5099	2.7736000000000001	2.2827000000000002	1.9092	1.7407999999999999	1.4039999999999999	1.0672999999999999	0.87460000000000004	0.71789999999999998	0.63949999999999996	0.58799999999999997	0.54979999999999996	0.48159999999999997	0.25	0.131	10	99.738998	5	5	2004-05-06 00:00:00	Peilung von km 282,2 verwendet	2011-12-01 03:22:59	173.59999999999999	0	0	21.739999999999998	120.27	1	1
2122	90	2000-03-13 00:00:00	1438	\N	2	14	20	WEL275-020	2000-03-13 09:00:00	2000-03-13 13:45:00	518	961.16825426695834	53.969999999999999	0.19	7.5999999	138.02000000000001	55.979999999999997	194	39.560000000000002	24.763999999999999	86.694000000000003	62.866999999999997	-41.212000000000003	293.29000000000002	1690.6790000000001	1192.1	\N	334.50200000000001	3.5640000000000001	1.1568	0.486	6.6424000000000003	0.081501000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.3159999999999998	0.79200000000000004	2.044	3.4620000000000002	5.8842999999999996	4.4353999999999996	3.8935	3.6509999999999998	3.4085999999999999	2.9237000000000002	2.4388000000000001	1.9641999999999999	1.5882000000000001	1.4000999999999999	1.2121	1.0617000000000001	0.84460000000000002	0.125	0.013	20	99.061996	5	5	2003-07-16 00:00:00	\N	2011-12-01 03:22:48	173.79999999999998	0	0	55.979999999999997	194	1	1
2123	90	2000-10-23 00:00:00	1438	\N	2	14	22	WEL275-022	2000-10-23 11:00:00	2000-10-23 15:20:00	143	169.37192587880412	50.149999999999999	0.2	12.5	91.859999999999999	31.140000000000001	123	5.351	1.0489999999999999	2.4510000000000001	10.086	15.904999999999999	153.16200000000001	252.65100000000001	327.89999	\N	137.25700000000001	2.3889999999999998	0.741	0.4217	4.6877000000000004	0.068467	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.363	1.448	1.9570000000000001	2.2850000000000001	2.9618000000000002	1.9497	1.7716000000000001	1.5489999999999999	1.3263	0.9637	0.82799999999999996	0.69220000000000004	0.59630000000000005	0.56510000000000005	0.53400000000000003	0.5091	0.42170000000000002	0.25	0.035	10	99.516998	5	5	2004-05-06 00:00:00	\N	2011-12-01 03:22:39	173.79999999999998	0	0	31.140000000000001	123	1	1
2124	90	2001-04-05 00:00:00	1438	\N	3	3	23	WEL275-023	2001-04-05 09:00:00	2001-04-05 13:15:00	339	469.78056807536615	52.229999999999997	0.19	8.3000002	102.17	26.829999999999998	129	13.76	2.6909999999999998	10.733000000000001	15.925000000000001	5.835	199.76300000000001	748.08699999999999	658.79999	\N	193.928	3.3969999999999998	1.023	0.53359997	6.3323999999999998	0.079575999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.4279999999999999	0.93700000000000006	1.9490000000000001	3.0329999999999999	3.9699	3.6579999999999999	3.4500000000000002	3.1899999999999999	2.9300000000000002	2.4100000000000001	1.9392	1.6517999999999999	1.3643000000000001	1.2205999999999999	1.0769	0.96279999999999999	0.79449999999999998	0.25	0.030999999	10	99.272003	5	5	2004-05-06 00:00:00	\N	2011-12-01 03:22:32	173.79999999999998	0	0	26.829999999999998	129	1	1
2125	90	2001-10-17 00:00:00	1438	\N	3	3	24	WEL275-024	2001-10-17 11:00:00	2001-10-17 14:00:00	164	193.76705923583353	50.369999999999997	0.2	12.3	49.329999999999998	52.670000000000002	102	0.0040000000000000001	0.78600000000000003	4.0039999999999996	14.401999999999999	14.957000000000001	153.971	278.07999999999998	358.29999	\N	139.01499999999999	2.577	0.77590001	0.51840001	5.0570000000000004	0.071112999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.115	1.4930000000000001	1.78	2.0190000000000001	2	1.6000000000000001	1.3332999999999999	1	0.94710000000000005	0.84140000000000004	0.73570000000000002	0.63	0.57799999999999996	0.55200000000000005	0.52600000000000002	0.50519999999999998	0.41670000000000001	0.5	15	4	95	5	5	2004-05-06 00:00:00	\N	2011-12-01 03:22:23	173.79999999999998	0	0	52.670000000000002	102	1	1
2126	90	2002-02-28 00:00:00	1438	\N	3	3	25	WEL275-025	2002-02-28 09:00:00	2002-02-28 14:00:00	488	850.34464844502486	53.710000000000001	0.19	5.3000002	128	60	188	36.372999999999998	10.34	26.446000000000002	21.677	-38.387999999999998	292.29599999999999	1405.154	1105.5	\N	330.68400000000003	3.343	1.1035	0.55430001	6.2313999999999998	0.078938999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.3230000000000004	0.94799999999999995	2.702	4.4340000000000002	9.5411999999999999	7.0011000000000001	5.8670999999999998	4.9436	4.0201000000000002	3.3342999999999998	2.6613000000000002	1.9923999999999999	1.5573999999999999	1.3398000000000001	1.1223000000000001	0.95899999999999996	0.75190000000000001	0.25	0.037999999	31.5	99.431999	5	5	2003-07-16 00:00:00	\N	2011-12-01 03:22:14	173.79999999999998	0	0	60	188	1	1
6802	84	2005-03-23 00:00:00	579	\N	2	3	23	\N	2005-03-23 09:00:00	2005-03-23 14:30:00	641	1098.4780048765238	78.5	0.23	5.9000001	92	60	152	2.9430000000000001	59.378999999999998	240.595	152.66200000000001	4.8860000000000001	206.399	1215.835	989.70001	\N	201.51300000000001	4.9119999999999999	1.5924	0.52380002	11.081799999999999	0.10527	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	11.598000000000001	0.70099999999999996	3.4380000000000002	10.176	26.966999999999999	23.299600000000002	20.854600000000001	17.798400000000001	15.212400000000001	11.3848	8.0939999999999994	5.6761999999999997	4.1139999999999999	3.3464999999999998	2.5813999999999999	1.9715	1.1187	0.063	0.0020000001	31.5	97.416	5	2	1970-01-01 00:00:00	\N	2011-12-01 02:36:48	59.400000000000006	0	0	60	152	1	1
6822	84	2005-10-04 00:00:00	579	\N	2	3	25	\N	2005-10-04 10:00:00	2005-10-04 13:30:00	199	205.61612400924781	74.390000000000001	0.2	17.6	55	62	117	0.76900000000000002	\N	\N	\N	37.031999999999996	147.47999999999999	\N	314.39999	\N	110.44799999999999	2.847	0.93830001	\N	5.5850999999999997	0.074732999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.7350000000000001	1.4330000000000001	2.1139999999999999	2.5489999999999999	3.6213000000000002	2.4718	1.9484999999999999	1.7810999999999999	1.6135999999999999	1.2786999999999999	0.9768	0.83860000000000001	0.70040000000000002	0.63129999999999997	0.58779999999999999	0.55330000000000001	0.50160000000000005	0.063	0.0080000004	10	97.950996	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:36:29	59.400000000000006	40	0	62	117	1	1
6823	84	2005-11-02 00:00:00	579	\N	2	3	26	\N	2005-11-02 08:30:00	2005-11-02 14:00:00	104	111.52060963213441	73.459999999999994	0.2	11.6	49	60	109	0.307	0.16900000000000001	1.0760000000000001	6.7220000000000004	48.058	142.83000000000001	184.85499999999999	219	\N	94.772000000000006	2.3109999999999999	0.73070002	0.5187	4.5332999999999997	0.067330000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.7509999999999999	1.73	2.4399999999999999	3.0800000000000001	3.9003999999999999	3.0236000000000001	2.4390999999999998	1.9154	1.7034	1.2794000000000001	0.94230000000000003	0.77310000000000001	0.6179	0.5786	0.53939999999999999	0.50790000000000002	0.41539999999999999	0.063	0.013	10	98.488998	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:35:58	59.400000000000006	40	40	60	109	1	1
6741	85	2005-03-22 00:00:00	598	\N	2	3	33	\N	2005-03-22 10:30:00	2005-03-22 15:40:00	659	1165.3903706558044	74.799999999999997	0.23999999	4.5	70	65	135	5.0750000000000002	\N	\N	\N	-24.152000000000001	242.09399999999999	\N	1006.7	\N	266.24599999999998	3.7810000000000001	1.6608	\N	8.9023000000000003	0.094352000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	8.1080000000000005	0.57499999999999996	4.4509999999999996	11.458	22.102399999999999	16.010200000000001	14.2971	12.1632	10.029299999999999	6.5944000000000003	4.7424999999999997	3.2374000000000001	1.9249000000000001	1.4802999999999999	1.0357000000000001	0.80820000000000003	0.57550000000000001	0.063	0.0060000001	31.5	99.254997	6	0	1970-01-01 00:00:00	\N	2011-12-01 02:54:53	76.599999999999994	-25	0	65	135	1	1
6742	85	2005-04-25 00:00:00	598	\N	2	3	34	\N	2005-04-25 12:20:00	2005-04-25 15:30:00	226	236.28429165808475	71.299999999999997	0.2	11	53	65	118	0.66600000000000004	3.1629999999999998	15.272	45.051000000000002	49.310000000000002	140.09	351.85399999999998	316	\N	90.780000000000001	3.48	1.0729001	0.61269999	6.8287000000000004	0.082636000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.9740000000000002	2.4180000000000001	3.335	4.0730000000000004	8.3524999999999991	5.5895999999999999	4.5579999999999998	3.532	2.7069999999999999	1.6646000000000001	1.0777000000000001	0.81910000000000005	0.62209999999999999	0.57940000000000003	0.53669999999999995	0.50249999999999995	0.40870000000000001	0.125	0.0060000001	16	98.439003	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:54:42	76.599999999999994	40	40	65	118	1	1
6743	85	2005-09-29 00:00:00	598	\N	2	3	35	\N	2005-09-29 08:00:00	2005-09-29 10:57:00	153	157.52286110538984	70.349999999999994	0.2	16.5	55	60	115	1.044	\N	\N	\N	53.109999999999999	135.34	\N	233.8	\N	82.230000000000004	2.843	0.96670002	\N	5.5778999999999996	0.074685000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.9399999999999999	1.8779999999999999	2.7679999999999998	3.3260000000000001	4.8215000000000003	3.4184999999999999	2.7593000000000001	1.9804999999999999	1.7323	1.2359	0.90139999999999998	0.71350000000000002	0.58260000000000001	0.54000000000000004	0.49609999999999999	0.44629999999999997	0.3715	0.063	0.011	16	99.744003	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:54:39	76.599999999999994	40	0	60	115	1	1
6761	84	2004-03-16 00:00:00	579	\N	2	3	19	\N	2004-03-16 09:30:00	2004-03-16 14:00:00	167	171.46293730940664	74.069999999999993	0.2	6.5999999	52	60	112	1.2669999999999999	1.6279999999999999	6.9119999999999999	28.097000000000001	40.826000000000001	145.88	244.98599999999999	279.89999	\N	105.054	2.665	0.87879997	0.55220002	5.2279	0.072303999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.1200000000000001	2.1339999999999999	2.988	3.2959999999999998	8.6607000000000003	4.8693999999999997	3.6576	2.7450999999999999	1.9612000000000001	1.5384	1.1154999999999999	0.88270000000000004	0.72119999999999995	0.64039999999999997	0.58589999999999998	0.54530000000000001	0.4667	0.063	0.0020000001	16	96.188004	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:38:21	59.400000000000006	40	40	60	112	1	1
6781	84	2004-04-01 00:00:00	579	\N	2	3	20	\N	2004-04-01 09:00:00	2004-04-01 14:00:00	396	464.90154140396027	76.310000000000002	0.20999999	7.3000002	75	65	140	1.768	\N	\N	\N	22.597999999999999	193.33799999999999	\N	588.09998	\N	170.74000000000001	3.444	1.1342	\N	7.0952999999999999	0.084234000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	7.0670000000000002	0.45100000000000001	4.9630000000000001	13.298999999999999	17.995699999999999	14.308199999999999	12.8118	10.9412	9.2401999999999997	6.2249999999999996	4.2904	2.5789	1.3665	0.93940000000000001	0.69089999999999996	0.58079999999999998	0.46810000000000002	0.063	0.003	16	88.522003	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:37:59	59.400000000000006	40	0	65	140	1	1
6801	84	2004-10-19 00:00:00	579	\N	2	3	22	\N	2004-10-19 09:30:00	2004-10-19 14:15:00	94	102.45956009952349	73.299999999999997	0.20999999	12.5	50	60	110	0.59299999999999997	\N	\N	\N	49.954999999999998	142.03	\N	204	\N	92.075000000000003	2.2160000000000002	0.72049999	\N	4.5648999999999997	0.067563999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.716	2.4689999999999999	2.7120000000000002	2.6179999999999999	4.0186000000000002	2.9036	2.1673	1.7020999999999999	1.3380000000000001	0.88880000000000003	0.68140000000000001	0.58130000000000004	0.51659999999999995	0.47760000000000002	0.43159999999999998	0.3947	0.33950000000000002	0.063	0.0049999999	16	99.264999	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:37:09	59.400000000000006	40	0	60	110	1	1
6881	82	2004-03-31 00:00:00	577	\N	2	3	42	\N	2004-03-31 07:30:00	2004-03-31 14:40:00	404	476.75060617737455	79.010000000000005	0.20999999	6.9000001	55	25	80	0.97299999999999998	\N	\N	\N	1.0660000000000001	108.66200000000001	\N	511	\N	107.596	4.7489999999999997	1.3386	\N	9.7835999999999999	0.098912	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5.5179999999999998	1.7729999999999999	3.3650000000000002	4.5670000000000002	15.557399999999999	10.986700000000001	8.6332000000000004	6.2126999999999999	5.0738000000000003	3.4647999999999999	2.4523000000000001	1.8071999999999999	1.4588000000000001	1.2845	1.1103000000000001	0.97060000000000002	0.75870000000000004	0.063	0.0020000001	16	90.581001	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:07:46	46.799999999999983	-35	0	25	80	1	1
6861	82	2004-03-17 00:00:00	577	\N	2	3	41	\N	2004-03-17 07:45:00	2004-03-17 12:00:00	203	210.49515068065369	77	0.20999999	7.1999998	51	23	74	0.46100000000000002	1.829	8.5259999999999998	28.231000000000002	9.7929999999999993	100.20999999999999	349.262	314.10001	\N	90.418000000000006	3.4729999999999999	0.96160001	0.64660001	7.1557000000000004	0.084591	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.3540000000000001	1.6080000000000001	2.4670000000000001	2.8149999999999999	5.8663999999999996	3.9121999999999999	3.3273000000000001	2.5962000000000001	1.9670000000000001	1.6087	1.2504	0.96020000000000005	0.82789999999999997	0.76180000000000003	0.69569999999999999	0.64280000000000004	0.57140000000000002	0.063	0.003	10	96.623001	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:08:08	46.799999999999983	-35	-35	23	74	1	1
6883	82	2004-06-23 00:00:00	577	\N	2	3	43	\N	2004-06-23 08:00:00	2004-06-23 13:15:00	151	155.43184967478732	76.489999999999995	0.2	14.8	45	30	75	0.66800000000000004	\N	\N	\N	11.275	98.046999999999997	\N	268.89999	\N	86.772999999999996	3.0990000000000002	0.8294	\N	6.0796000000000001	0.077972	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.5189999999999999	1.446	2.02	2.3159999999999998	3.2738	2.2801999999999998	1.9156	1.7329000000000001	1.5501	1.1846000000000001	0.93889999999999996	0.81530000000000002	0.69179999999999997	0.63009999999999999	0.59050000000000002	0.55889999999999995	0.51139999999999997	0.063	0.001	10	99.501999	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:07:16	46.799999999999983	-35	0	30	75	1	1
6901	82	2004-10-14 00:00:00	577	\N	2	3	44	\N	2004-10-14 08:00:00	2004-10-14 14:00:00	95	103.15656390972433	75.920000000000002	0.20999999	13.7	52	30	82	0.20399999999999999	0.36399999999999999	2.3050000000000002	15.576000000000001	12.613	96.070999999999998	163.554	220.39999	\N	83.457999999999998	2.641	0.67140001	0.4614	5.4413999999999998	0.073765999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.3899999999999999	1.429	2.0169999999999999	2.3849999999999998	2.7972000000000001	1.8400000000000001	1.6282000000000001	1.3633999999999999	1.0986	0.89370000000000005	0.7631	0.63239999999999996	0.5665	0.53420000000000001	0.50180000000000002	0.4521	0.37469999999999998	0.063	0.0049999999	10	97.954002	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:06:31	46.799999999999983	-35	-35	30	82	1	1
6941	86	2004-03-30 00:00:00	576	\N	2	3	45	\N	2004-03-30 09:00:00	2004-03-30 13:40:00	417	496.26671286299808	86.120000000000005	0.25	5.6999998	63	22	85	0.76000000000000001	8.1150000000000002	37.098999999999997	52.104999999999997	-2.456	108.29900000000001	663.27800000000002	399.39999	\N	110.755	3.6059999999999999	1.7826999	0.86799997	8.8440999999999992	0.094043000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	10.212	0.57599999999999996	3.3959999999999999	8.5920000000000005	24.4937	20.289999999999999	17.487500000000001	15.174899999999999	13.741	10.873100000000001	7.8750999999999998	5.3415999999999997	3.5499000000000001	2.8506999999999998	2.1515	1.7597	1.2655000000000001	0.063	0.0060000001	16	77.876999	5	5	1970-01-01 00:00:00	\N	2011-12-01 01:33:50	18.199999999999989	-15	-15	22	85	1	1
6942	86	2004-10-12 00:00:00	576	\N	3	3	46	\N	2004-10-12 10:00:00	2004-10-12 15:15:00	86	96.186525807715924	84.239999999999995	0.30000001	11	50	40	90	0.105	0.52300000000000002	2.3650000000000002	17.137	2.5430000000000001	102.941	110.30800000000001	199.10001	\N	100.398	1.9830000000000001	0.69309998	0.50260001	5.8362999999999996	0.076396000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.976	1.6080000000000001	2.2970000000000002	2.609	3.7347000000000001	2.4384999999999999	1.9078999999999999	1.6741999999999999	1.4403999999999999	0.99109999999999998	0.83730000000000004	0.68340000000000001	0.58230000000000004	0.54569999999999996	0.50919999999999999	0.46229999999999999	0.37990000000000002	0.063	0.0070000002	16	97.952003	5	5	1970-01-01 00:00:00	\N	2011-12-01 01:33:15	18.199999999999989	0	0	40	90	1	1
6943	86	2004-10-13 00:00:00	576	\N	3	3	47	\N	2004-10-13 08:00:00	2004-10-13 13:00:00	84	94.095514377113403	84.290000000000006	0.30000001	10.3	43	48	91	0.17399999999999999	\N	\N	\N	2.3599999999999999	103.12	\N	204.10001	\N	100.76000000000001	2.0259999999999998	0.6613	\N	5.9622000000000002	0.077215000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.659	1.5009999999999999	2.1619999999999999	2.548	3.5724999999999998	1.9307000000000001	1.7132000000000001	1.4413	1.1695	0.88949999999999996	0.72889999999999999	0.60470000000000002	0.53879999999999995	0.50580000000000003	0.45600000000000002	0.41320000000000001	0.34899999999999998	0.063	0.0040000002	10	96.152	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:32:59	18.199999999999989	0	0	48	91	1	1
7001	88	2004-03-11 00:00:00	599	\N	2	3	38	\N	2004-03-11 08:00:00	2004-03-11 14:00:00	223	192.37305161543185	64.560000000000002	0.20999999	3.2	12	124	136	0.082000000000000003	1.2190000000000001	5.0970000000000004	18.466000000000001	49.799999999999997	151.13300000000001	189.36699999999999	279.60001	\N	101.333	2.7589999999999999	0.98710001	0.30579999	5.6844999999999999	0.075396000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.0309999999999999	1.24	1.7090000000000001	1.867	2.2341000000000002	0.97209999999999996	0.84699999999999998	0.69069999999999998	0.61419999999999997	0.5625	0.51080000000000003	0.45850000000000002	0.40610000000000002	0.37980000000000003	0.35360000000000003	0.3327	0.30120000000000002	0.125	0.0049999999	6.2999999999999998	96.383003	2	2	1970-01-01 00:00:00	Messung nach 2 Lotrechten abgebrochen, da Messschiff defekt	2011-12-01 03:05:54	106.40000000000001	30	30	124	136	1	1
7002	88	2004-04-06 00:00:00	599	\N	2	3	39	\N	2004-04-06 07:30:00	2004-04-06 12:00:00	307	292.74160028435278	65.400000000000006	0.20999999	\N	70	65	135	0.92500000000000004	\N	\N	\N	45.668999999999997	177.054	\N	371.79999	\N	131.38499999999999	2.8300000000000001	1.1298	\N	5.8292000000000002	0.076349	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.1180000000000003	1.3049999999999999	3.0569999999999999	5.0860000000000003	9.9957999999999991	7.6227	6.1818	5.2804000000000002	4.3789999999999996	3.1983999999999999	2.1835	1.6884999999999999	1.3083	1.1182000000000001	0.94089999999999996	0.81589999999999996	0.62880000000000003	0.063	0.0040000002	16	97.487	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:05:50	106.40000000000001	30	0	65	135	1	1
7003	88	2004-10-21 00:00:00	600	\N	2	3	40	\N	2004-10-21 09:30:00	2004-10-21 15:00:00	139	114.30862487293776	63.719999999999999	0.20999999	10.5	68	75	143	0.78800000000000003	0.89000000000000001	3.468	21.148	53.268999999999998	144.25	158.221	199.5	\N	90.981999999999999	2.1930000000000001	0.82200003	0.56559998	4.5174000000000003	0.067211999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.6899999999999999	2.1160000000000001	2.79	2.9100000000000001	4.3888999999999996	3.2176	2.5537999999999998	1.9024000000000001	1.6089	1.0219	0.79290000000000005	0.61260000000000003	0.54069999999999996	0.50480000000000003	0.45500000000000002	0.41349999999999998	0.35120000000000001	0.063	0.003	10	99.009003	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:05:41	106.40000000000001	40	40	75	143	1	1
7021	88	2005-04-27 00:00:00	600	\N	2	3	42	\N	2005-04-27 09:45:00	2005-04-27 14:00:00	269	243.25432976009316	65.019999999999996	0.20999999	9.8000002	68	57	125	1.502	1.9219999999999999	11.691000000000001	33.497999999999998	47.479999999999997	156.25800000000001	305.27499999999998	327.89999	\N	108.77800000000001	3.0150000000000001	1.0642	0.6196	6.2108999999999996	0.078809000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.0720000000000001	1.4339999999999999	2.9809999999999999	3.7519999999999998	8.1014999999999997	5.4348000000000001	4.3449	3.5230000000000001	2.8843999999999999	1.8876999999999999	1.5225	1.1573	0.88719999999999999	0.78810000000000002	0.68910000000000005	0.61160000000000003	0.50309999999999999	0.063	0.001	16	98.682999	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:05:27	106.40000000000001	20	20	57	125	1	1
7041	88	2005-09-27 00:00:00	600	\N	2	3	43	\N	2005-09-27 09:57:00	2005-09-27 10:06:00	204	172.85694492980832	64.370000000000005	0.20999999	\N	70	60	130	0.63700000000000001	\N	\N	\N	50.799999999999997	149.017	\N	260.70001	\N	98.216999999999999	2.6539999999999999	0.9515	\N	5.4672000000000001	0.073941000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.1859999999999999	1.26	2.7149999999999999	4.0309999999999997	5.1311	3.8826000000000001	3.4864000000000002	2.9912000000000001	2.4958999999999998	1.7583	1.2744	0.91059999999999997	0.70430000000000004	0.61609999999999998	0.5665	0.52690000000000003	0.43619999999999998	0.063	0.0040000002	10	98.206001	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:05:22	106.40000000000001	20	0	60	130	1	1
7082	89	2004-03-10 00:00:00	185	\N	2	3	8	\N	2004-03-10 08:00:00	2004-03-10 10:56:00	222	190.97904399503017	58	0.20999999	3	80	65	145	1.8080000000000001	1.054	4.6799999999999997	17.079000000000001	45.466000000000001	162.69	281.41800000000001	255.39999	\N	117.224	2.1789999999999998	1.0728	0.67449999	4.4884000000000004	0.066994999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.8169999999999999	1.8640000000000001	2.831	3.4279999999999999	4.6349999999999998	3.4550000000000001	2.8673999999999999	2.1328999999999998	1.7799	1.2425999999999999	0.89380000000000004	0.70020000000000004	0.57210000000000005	0.52680000000000005	0.47660000000000002	0.43090000000000001	0.36249999999999999	0.063	0.0020000001	10	98.816002	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:15:19	137.19999999999999	20	20	65	145	1	1
7063	89	2004-04-13 00:00:00	185	\N	2	3	9	\N	2004-04-13 09:45:00	2004-04-13 14:40:00	357	369.41201940644521	59.210000000000001	0.22	9.5	85	45	130	1.8460000000000001	\N	\N	\N	40.526000000000003	209.77000000000001	\N	441.5	\N	169.244	2.609	1.2004	\N	5.6300999999999997	0.075034000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.5990000000000002	0.76600000000000001	2.9060000000000001	5.7140000000000004	8.1084999999999994	5.8772000000000002	5.2904999999999998	4.5571999999999999	3.9043000000000001	3.1080000000000001	2.3115999999999999	1.7141999999999999	1.2446999999999999	1.0099	0.83450000000000002	0.69620000000000004	0.54390000000000005	0.063	0.0049999999	16	98.412003	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:15:14	137.19999999999999	0	0	45	130	1	1
7121	89	2004-10-26 00:00:00	616	\N	2	3	11	\N	2004-10-26 09:00:00	2004-10-26 14:00:00	135	110.82360582193357	57.200000000000003	0.20999999	12.3	70	67	137	0.72699999999999998	0.35899999999999999	2.8079999999999998	17.663	48.555999999999997	158.69	127.509	192.39999	\N	110.134	1.7470000000000001	0.82630002	0.48899999	3.5994000000000002	0.059995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.6479999999999999	1.5980000000000001	2.8370000000000002	3.7490000000000001	3.9636	3.2208000000000001	2.7256	2.1067	1.7901	1.2829999999999999	0.89790000000000003	0.66690000000000005	0.53910000000000002	0.48670000000000002	0.43859999999999999	0.40000000000000002	0.34229999999999999	0.063	0.003	10	99.801003	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:14:58	137.40000000000001	10	10	67	137	1	1
7101	89	2004-06-29 00:00:00	185	\N	2	3	10	\N	2004-06-29 08:00:00	\N	188	157.52286110538984	57.670000000000002	0.20999999	18.700001	70	50	120	1.2629999999999999	1.4119999999999999	11.353	50.234000000000002	46.740000000000002	161.03999999999999	210.08600000000001	217.2	\N	114.3	1.8999999999999999	1.0405	0.52600002	3.9146999999999998	0.062567999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.9219999999999999	1.613	2.6970000000000001	3.8100000000000001	4.6875	3.6545999999999998	3.2084999999999999	2.6509	2.0931999999999999	1.5538000000000001	1.0669	0.83189999999999997	0.6371	0.58660000000000001	0.53979999999999995	0.50239999999999996	0.4078	0.063	0.0020000001	10	99.501999	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:15:04	137.19999999999999	0	20	50	120	1	1
7142	89	2005-04-28 00:00:00	185	\N	2	3	13	\N	2005-04-28 08:00:00	2005-04-28 14:10:00	272	247.4363526212982	58.409999999999997	0.22	11.5	88	50	138	1.5920000000000001	\N	\N	\N	44.170000000000002	199.88999999999999	\N	310.70001	\N	155.72	1.9950000000000001	1.1427	\N	4.3055000000000003	0.065616999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.8170000000000002	0.76700000000000002	3.0299999999999998	5.8449999999999998	6.0084999999999997	4.7797999999999998	3.9851000000000001	3.5983999999999998	3.2115999999999998	2.4380999999999999	1.8015000000000001	1.3438000000000001	0.90749999999999997	0.7218	0.58760000000000001	0.52059999999999995	0.41710000000000003	0.063	0.0060000001	16	98.906998	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:14:49	137.19999999999999	0	0	50	138	1	1
7143	89	2005-09-26 00:00:00	185	\N	2	3	14	\N	2005-09-26 12:01:00	2005-09-26 14:51:00	221	188.88803256442765	58	0.20999999	15.7	82	50	132	1.472	\N	\N	\N	45.466000000000001	162.69	\N	255.39999	\N	117.224	2.1789999999999998	1.0611	\N	4.4884000000000004	0.066994999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.339	1.2470000000000001	2.75	3.988	5.4927000000000001	4.0138999999999996	3.5638000000000001	3.0108000000000001	2.4578000000000002	1.7439	1.3069	0.9395	0.73640000000000005	0.63490000000000002	0.57609999999999995	0.53080000000000005	0.43730000000000002	0.063	0.0080000004	16	99.667	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:14:45	137.19999999999999	10	0	50	132	1	1
7161	89	2005-11-09 00:00:00	614	\N	2	3	15	\N	2005-11-09 08:00:00	2005-11-09 13:30:00	154	127.55169726675372	57.350000000000001	0.20999999	8.8000002	66	60	126	0.432	0.16300000000000001	1.3080000000000001	7.149	47.975999999999999	159.44	129.14699999999999	209	\N	111.464	1.875	0.87540001	0.54360002	3.8635999999999999	0.062157999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.7170000000000001	2.1499999999999999	2.6360000000000001	2.6579999999999999	4.6398999999999999	3.2818999999999998	2.4788999999999999	1.8555999999999999	1.5792999999999999	1.0267999999999999	0.84919999999999995	0.69069999999999998	0.58599999999999997	0.5504	0.51480000000000004	0.47239999999999999	0.38629999999999998	0.063	0.013	10	99.250999	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:14:38	137.19999999999999	0	0	60	126	1	1
7181	90	2004-03-08 00:00:00	1438	\N	2	3	32	\N	2004-03-08 07:00:00	2004-03-08 13:15:00	187	238.37530308868728	50.640000000000001	0.2	\N	96	44	140	1.677	0.80300000000000005	5.3929999999999998	15.769	13.904	154.964	346.66899999999998	396.10001	\N	141.06	2.8079999999999998	0.86339998	0.66189998	5.5096999999999996	0.074227000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.0419999999999998	1.49	2.4830000000000001	3.0289999999999999	4.5598000000000001	3.4493999999999998	2.9594999999999998	2.3471000000000002	1.9157999999999999	1.5268999999999999	1.1379999999999999	0.8952	0.73270000000000002	0.65139999999999998	0.59609999999999996	0.55930000000000002	0.50409999999999999	0.063	0.0070000002	10	97.667999	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:21:19	173.79999999999998	0	0	44	140	1	1
7182	90	2004-04-14 00:00:00	1438	\N	2	3	33	\N	2004-04-14 09:00:00	2004-04-14 13:00:00	294	402.1711984858847	51.659999999999997	0.2	9.5	100	45	145	1.9379999999999999	\N	\N	\N	9.6240000000000006	158.715	\N	543.90002	\N	149.09200000000001	3.6480000000000001	1.0609	\N	7.1570999999999998	0.084599999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.762	1.0600000000000001	2.5830000000000002	3.7679999999999998	5.8962000000000003	4.5327999999999999	3.8565999999999998	3.4235000000000002	2.9904000000000002	2.1242000000000001	1.7040999999999999	1.3587	1.0133000000000001	0.89129999999999998	0.77349999999999997	0.67920000000000003	0.56369999999999998	0.063	0.003	16	99.383003	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:21:13	173.79999999999998	0	0	45	145	1	1
7183	90	2004-06-30 00:00:00	1438	\N	2	3	34	\N	2004-06-30 10:00:00	2004-06-30 13:30:00	136	174.94795636041084	50.109999999999999	0.2	16.799999	98	42	140	1.643	0.68200000000000005	8.9350000000000005	35.595999999999997	15.993	153.01499999999999	249.345	322.5	\N	137.02199999999999	2.3530000000000002	0.7784	0.51929998	4.6172000000000004	0.067949999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.7370000000000001	1.647	2.4780000000000002	3.2919999999999998	3.8883999999999999	3.1324000000000001	2.6284999999999998	1.9995000000000001	1.7928999999999999	1.3794999999999999	0.98499999999999999	0.80110000000000003	0.62439999999999996	0.58350000000000002	0.54269999999999996	0.5101	0.41909999999999997	0.125	0.003	10	99.299004	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:21:06	173.79999999999998	0	0	42	140	1	1
7201	90	2004-10-27 00:00:00	1438	\N	2	3	35	\N	2004-10-27 09:30:00	2004-10-27 14:00:00	87	123.36967440554868	49.630000000000003	0.2	12.1	85	50	135	1.3280000000000001	0.33100000000000002	2.6850000000000001	15.170999999999999	17.998999999999999	150.221	151.614	257.60001	\N	132.22200000000001	1.948	0.68720001	0.42480001	3.8220000000000001	0.061822000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.708	1.5049999999999999	2.3079999999999998	2.8599999999999999	3.7698999999999998	2.9664000000000001	2.4306999999999999	1.9366000000000001	1.7587999999999999	1.4032	1.0476000000000001	0.874	0.72850000000000004	0.65569999999999995	0.59730000000000005	0.55689999999999995	0.49070000000000003	0.063	0.003	10	99.475998	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:20:58	173.79999999999998	0	0	50	135	1	1
7221	90	2005-03-15 00:00:00	1438	\N	2	3	36	\N	2005-03-15 08:00:00	2005-03-15 13:27:00	268	358.95696225343261	51.479999999999997	0.19	5	104	35	139	3.2639999999999998	\N	\N	\N	10.82	158.053	0	517.20001	\N	147.233	3.5129999999999999	0.99580002	0	6.5475000000000003	0.080916000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.367	1.089	2.3140000000000001	3.1829999999999998	5.0384000000000002	3.7702	3.3950999999999998	2.9262999999999999	2.4575	1.8512999999999999	1.5609	1.2705	0.98619999999999997	0.88539999999999996	0.78459999999999996	0.70389999999999997	0.58160000000000001	0.063	0.0020000001	10	97.232002	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:20:49	173.79999999999998	0	0	35	139	1	1
7222	90	2005-05-02 00:00:00	1438	\N	2	3	37	\N	2005-05-02 10:00:00	2005-05-02 14:15:00	239	312.95471078017715	51.130000000000003	0.2	14	110	40	150	1.7789999999999999	\N	\N	\N	12.121	156.76599999999999	\N	466.10001	\N	144.64500000000001	3.2229999999999999	0.96329999	\N	6.3226000000000004	0.079515000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.968	1.671	2.5760000000000001	3.4340000000000002	4.5175999999999998	3.3995000000000002	2.875	2.2193999999999998	1.8604000000000001	1.4406000000000001	1.0207999999999999	0.83389999999999997	0.65910000000000002	0.59819999999999995	0.5504	0.51229999999999998	0.41949999999999998	0.063	0.0049999999	10	97.800003	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:20:45	173.79999999999998	0	0	40	150	1	1
7223	90	2005-09-22 00:00:00	1438	\N	2	3	38	\N	2005-09-22 10:30:00	2005-09-22 14:10:00	196	250.22436786210156	50.719999999999999	0.2	15	105	35	140	1.5369999999999999	\N	\N	\N	13.613	155.25800000000001	\N	407.39999	\N	141.64500000000001	2.8759999999999999	0.8811	\N	5.6436000000000002	0.075123999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.7529999999999999	1.581	2.1789999999999998	2.5019999999999998	3.5876999999999999	2.6564999999999999	2.0356999999999998	1.8267	1.645	1.2816000000000001	0.96940000000000004	0.8337	0.69789999999999996	0.63	0.59079999999999999	0.55930000000000002	0.51219999999999999	0.063	0.0020000001	16	99.550003	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:20:43	173.79999999999998	0	0	35	140	1	1
7224	90	2005-11-10 00:00:00	1438	\N	2	3	39	\N	2005-11-10 08:00:00	2005-11-10 13:20:00	117	154.03784205438564	49.909999999999997	0.2	10.4	88	50	138	1.081	0.19800000000000001	1.6080000000000001	7.274	16.434000000000001	151.94999999999999	224.124	295.20001	\N	135.51599999999999	2.1779999999999999	0.74870002	0.50849998	4.2737999999999996	0.065374000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.6950000000000001	1.905	2.4870000000000001	2.9660000000000002	3.9750999999999999	3.1839	2.6564999999999999	1.9988999999999999	1.7548999999999999	1.2668999999999999	0.92759999999999998	0.76790000000000003	0.61980000000000002	0.58230000000000004	0.54479999999999995	0.51480000000000004	0.42709999999999998	0.063	0.0099999998	10	99.871002	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:20:32	173.79999999999998	0	0	50	138	1	1
7241	88	2005-03-21 00:00:00	599	\N	2	3	41	\N	2005-03-21 12:00:00	2005-03-21 16:00:00	519	892.16487705707527	67.519999999999996	0.20999999	5.3000002	98	52	150	5.6870000000000003	\N	\N	\N	-96.480000000000004	447.26299999999998	\N	981.59998	\N	543.74300000000005	1.8049999999999999	1.304	\N	3.7189000000000001	0.060983000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.8769999999999998	0.61899999999999999	3.7989999999999999	8.9410000000000007	12.034800000000001	8.9515999999999991	7.6756000000000002	6.2061000000000002	5.5233999999999996	4.1580000000000004	2.9961000000000002	1.9189000000000001	1.2568999999999999	0.95750000000000002	0.7681	0.62029999999999996	0.46510000000000001	0.063	0.0040000002	16	95.287003	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:05:36	106.40000000000001	25	0	52	150	1	1
7261	86	2006-10-26 00:00:00	576	\N	2	3	52	\N	2006-10-26 11:00:00	2006-10-26 14:15:00	107	113.61162106273692	84.459999999999994	0.30000001	12.6	60	25	85	0.023	\N	\N	\N	1.7350000000000001	103.727	\N	221.39999	\N	101.99299999999999	2.1699999999999999	0.73629999	\N	6.3874000000000004	0.079921000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.98699999999999999	1.4450000000000001	1.8380000000000001	2.0550000000000002	1.8126	1.3359000000000001	1.0181	0.92720000000000002	0.85099999999999998	0.6986	0.60470000000000002	0.55859999999999999	0.51249999999999996	0.4788	0.4325	0.39550000000000002	0.33989999999999998	0.063	0.016000001	6.2999999999999998	98.942001	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:31:05	18.199999999999989	-20	0	25	85	1	1
7262	82	2006-11-01 00:00:00	577	\N	2	3	49	\N	2006-11-01 10:49:00	2006-11-01 14:36:00	144	148.46181157277891	76.409999999999997	0.20999999	11.2	58	25	83	0.52600000000000002	\N	\N	\N	11.507	97.707999999999998	\N	262	\N	86.200999999999993	3.0390000000000001	0.81309998	\N	6.2606000000000002	0.079124	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.7409999999999997	1.159	4.7169999999999996	9.2309999999999999	13.193899999999999	11.510199999999999	10.387700000000001	8.4822000000000006	6.3848000000000003	3.8601999999999999	2.2665999999999999	1.4374	0.86180000000000001	0.66579999999999995	0.57299999999999995	0.51729999999999998	0.41820000000000002	0.063	0.0040000002	10	78.617996	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:04:22	46.799999999999983	-35	0	25	83	1	1
7264	84	2006-11-27 00:00:00	579	\N	2	3	28	\N	2006-11-27 11:00:00	2006-11-27 15:00:00	139	152.64383443398395	73.819999999999993	0.2	8	52	70	122	5.617	0.83699999999999997	2.5939999999999999	11.843	43.789999999999999	144.63	256.43900000000002	254.2	\N	100.84	2.5209999999999999	0.86159998	0.5517	4.9455999999999998	0.070324999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.694	1.9890000000000001	2.294	2.4289999999999998	3.8363	2.5141	1.9116	1.6465000000000001	1.3813	0.95109999999999995	0.77700000000000002	0.62160000000000004	0.56740000000000002	0.5403	0.51319999999999999	0.47760000000000002	0.3916	0.063	0.0060000001	10	97.403	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:34:51	59.400000000000006	50	50	70	122	1	1
7281	85	2006-08-23 00:00:00	598	\N	2	3	37	\N	2006-08-23 11:00:00	2006-08-23 15:00:00	146	150.55282300338143	70.409999999999997	0.2	18	57	65	122	1.274	\N	\N	\N	52.869999999999997	135.63999999999999	\N	238.7	\N	82.769999999999996	2.8839999999999999	0.9048	\N	5.6588000000000003	0.075225	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.7389999999999999	1.4039999999999999	3.52	5.1269999999999998	10.2643	6.8676000000000004	5.6382000000000003	4.5244	3.6738	2.4411	1.6462000000000001	1.0952999999999999	0.8004	0.67979999999999996	0.59789999999999999	0.55420000000000003	0.47610000000000002	0.063	0.003	16	96.958	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:54:07	76.599999999999994	45	0	65	122	1	1
7282	85	2006-11-28 00:00:00	598	\N	2	3	39	\N	2006-11-28 08:00:00	2006-11-28 14:30:00	124	137.30975060956547	70.159999999999997	0.2	7.8000002	52	65	117	7.6470000000000002	0.45600000000000002	2.2919999999999998	11.635	53.869999999999997	134.38999999999999	209.971	218.3	\N	80.519999999999996	2.7109999999999999	0.90240002	0.58469999	5.3196000000000003	0.072936000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.8220000000000001	1.835	2.4209999999999998	2.5579999999999998	4.5187999999999997	2.7946	1.9635	1.7217	1.4799	0.99890000000000001	0.85219999999999996	0.70550000000000002	0.59340000000000004	0.55569999999999997	0.51800000000000002	0.4768	0.39050000000000001	0.063	0.011	10	97.137001	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:53:25	76.599999999999994	45	45	65	117	1	1
7284	88	2006-08-24 00:00:00	600	\N	2	3	45	\N	2006-08-24 11:30:00	2006-08-24 14:58:00	200	169.37192587880412	64.329999999999998	0.20999999	18.5	65	65	130	1.111	\N	\N	\N	51.009999999999998	148.63499999999999	\N	256.70001	\N	97.625	2.6299999999999999	0.9465	\N	5.4177	0.073605000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.911	2.3290000000000002	2.7639999999999998	2.677	4.9302999999999999	3.3252000000000002	2.5573999999999999	1.8680000000000001	1.5531999999999999	0.97709999999999997	0.7883	0.61950000000000005	0.55479999999999996	0.52239999999999998	0.48199999999999998	0.43519999999999998	0.36499999999999999	0.063	0.003	10	96.432999	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:05:11	106.40000000000001	40	0	65	130	1	1
7302	88	2006-10-23 00:00:00	600	\N	2	3	46	\N	2006-10-23 11:03:00	2006-10-23 14:58:00	160	131.73372012795878	63.93	0.20999999	12.5	68	65	133	2.8519999999999999	\N	\N	\N	52.877000000000002	145.22999999999999	\N	218.8	\N	92.352000000000004	2.3690000000000002	0.86390001	\N	4.8802000000000003	0.069858000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.496	2.0049999999999999	2.3260000000000001	2.3719999999999999	4.3573000000000004	2.1718000000000002	1.6909000000000001	1.2496	0.96660000000000001	0.81299999999999994	0.6593	0.58209999999999995	0.52290000000000003	0.48899999999999999	0.44030000000000002	0.40129999999999999	0.34279999999999999	0.063	0.0040000002	6.2999999999999998	93.890999	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:05:07	106.40000000000001	30	0	65	133	1	1
7305	89	2006-08-29 00:00:00	185	\N	2	3	17	\N	2006-08-29 10:00:00	2006-08-29 15:02:00	208	177.03896779101336	57.75	0.22	18	80	60	140	3.5390000000000001	\N	\N	\N	46.430999999999997	161.44	\N	226.39999	\N	115.009	1.968	1.1221	\N	4.2480000000000002	0.065175999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.8899999999999999	1.7430000000000001	2.532	3.2930000000000001	4.1509	3.2117	2.6535000000000002	1.9863	1.7694000000000001	1.3354999999999999	0.96060000000000001	0.78690000000000004	0.62160000000000004	0.57850000000000001	0.53539999999999999	0.501	0.40560000000000002	0.063	0.0040000002	10	97.663002	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:14:27	137.19999999999999	15	0	60	140	1	1
7306	89	2006-12-04 00:00:00	185	\N	2	3	19	\N	2006-12-04 10:30:00	2006-12-04 15:30:00	164	131.03671631775794	57.420000000000002	0.20999999	7	80	60	140	3.6389999999999998	0.374	1.901	10.109999999999999	47.706000000000003	159.78999999999999	163.03100000000001	188.89999	\N	112.084	1.6850000000000001	0.99519998	0.55369997	3.472	0.058923000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.5669999999999999	1.7490000000000001	2.6520000000000001	3.02	3.8727	2.9148999999999998	2.2764000000000002	1.8307	1.5718000000000001	1.0539000000000001	0.83099999999999996	0.64239999999999997	0.55149999999999999	0.50949999999999995	0.45789999999999997	0.4143	0.34889999999999999	0.063	0.013	10	99.43	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:14:16	137.19999999999999	10	10	60	140	1	1
7308	90	2006-07-20 00:00:00	1438	\N	2	3	40	\N	2006-07-20 07:30:00	2006-07-20 11:37:00	193	246.04234500089652	50.640000000000001	0.2	23.4	97	50	147	4.8460000000000001	\N	\N	\N	13.904	154.964	\N	396.10001	\N	141.06	2.8079999999999998	0.89109999	\N	5.5096999999999996	0.074227000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.1819999999999999	1.4359999999999999	2.0899999999999999	2.508	2.5514000000000001	1.8307	1.6353	1.3911	1.1468	0.88919999999999999	0.73070000000000002	0.60640000000000005	0.54169999999999996	0.50939999999999996	0.46189999999999998	0.41899999999999998	0.35460000000000003	0.063	0.0049999999	10	99.878998	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:20:28	173.79999999999998	10	0	50	147	1	1
7309	90	2006-09-04 00:00:00	1438	\N	2	3	41	\N	2006-09-04 10:00:00	2006-09-04 14:45:00	213	274.61950121913094	50.810000000000002	0.20999999	18.700001	108	40	148	8.0960000000000001	\N	\N	\N	13.286	155.589	\N	420.20001	\N	142.304	2.9529999999999998	0.93760002	\N	6.0833000000000004	0.077995999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.6479999999999999	1.5129999999999999	2.3170000000000002	3.044	3.6311	2.7936000000000001	2.2353000000000001	1.8779999999999999	1.694	1.3259000000000001	0.98029999999999995	0.80810000000000004	0.63600000000000001	0.5927	0.55259999999999998	0.52049999999999996	0.4355	0.063	0.0040000002	10	99.223999	6	0	1970-01-01 00:00:00	\N	2011-12-01 03:20:24	173.79999999999998	0	0	40	148	1	1
7311	90	2006-12-06 00:00:00	1438	\N	2	3	43	\N	2006-12-06 08:45:00	2006-12-06 14:00:00	117	154.03784205438564	49.920000000000002	0.2	8	80	60	140	6.4980000000000002	0.34300000000000003	2.2519999999999998	10.189	16.411999999999999	152.012	220.46600000000001	296.5	\N	135.59999999999999	2.1869999999999998	0.74519998	0.51410002	4.2907999999999999	0.065504000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.605	1.5980000000000001	2.1970000000000001	2.552	3.6032000000000002	2.7130000000000001	2.1196000000000002	1.8471	1.6648000000000001	1.3002	0.97670000000000001	0.84440000000000004	0.71220000000000006	0.64610000000000001	0.59689999999999999	0.56189999999999996	0.50939999999999996	0.063	0.016000001	10	99.531998	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:20:10	173.79999999999998	0	0	60	140	1	1
7321	2800	2006-07-25 00:00:00	1055	\N	2	3	1	\N	2006-07-25 07:45:00	2006-07-25 14:00:00	151	124.06667821574952	54.479999999999997	0.20999999	24	84	30	114	8.7520000000000007	\N	\N	\N	36.298000000000002	146.04300000000001	\N	184.10001	\N	109.745	1.6779999999999999	0.96679997	\N	3.4561000000000002	0.058789000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.1469999999999998	1.1120000000000001	3.0059999999999998	4.4690000000000003	7.6273	5.3781999999999996	4.5083000000000002	3.7404999999999999	3.2532000000000001	2.2785000000000002	1.6967000000000001	1.2722	0.9123	0.79010000000000002	0.66790000000000005	0.59519999999999995	0.50980000000000003	0.063	0.0089999996	16	98.766998	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:17:30	150.99999999999997	0	0	30	114	1	1
7322	2800	2006-08-30 00:00:00	1055	\N	2	3	2	\N	2006-08-30 08:00:00	2006-08-30 14:08:00	206	174.94795636041084	55	0.20999999	\N	90	30	120	12.066000000000001	\N	\N	\N	33.698	148.58099999999999	\N	242.60001	\N	114.883	2.1110000000000002	1.0348001	\N	4.3495999999999997	0.065951999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.3740000000000001	0.94799999999999995	2.6230000000000002	3.907	5.3224999999999998	3.9790999999999999	3.6244999999999998	3.1812999999999998	2.7381000000000002	1.9367000000000001	1.5583	1.1798999999999999	0.874	0.75390000000000001	0.63380000000000003	0.57830000000000004	0.49569999999999997	0.063	0.003	10	97.964996	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:17:25	150.99999999999997	0	0	30	120	1	1
7323	2801	2006-07-24 00:00:00	1056	\N	2	3	1	\N	2006-07-24 11:34:00	2006-07-24 14:33:00	96	132.43072393815962	54.130000000000003	0.20999999	24	80	55	135	4.2000000000000002	\N	\N	\N	39.240000000000002	151.91	\N	211.5	\N	112.67	1.877	0.89840001	\N	3.8666999999999998	0.062183000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.8319999999999999	0.72899999999999998	2.7509999999999999	5.6470000000000002	8.6393000000000004	6.2968999999999999	5.7933000000000003	5.1638000000000002	4.5343	3.5182000000000002	2.6810999999999998	1.9117	1.4377	1.2007000000000001	0.97309999999999997	0.83220000000000005	0.62309999999999999	0.063	0.0020000001	16	99.009003	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:18:42	151.40000000000001	30	0	55	135	1	1
7324	2801	2006-08-31 00:00:00	1056	\N	2	3	2	\N	2006-08-31 08:00:00	2006-08-31 13:39:00	153	195.16106685623521	54.939999999999998	0.20999999	16.5	88	55	143	7.7930000000000001	\N	\N	\N	36.616	155.96000000000001	\N	305.5	\N	119.34399999999999	2.5600000000000001	0.91659999	\N	5.2732000000000001	0.072617000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.8010000000000002	0.98799999999999999	2.7759999999999998	4.423	5.9988000000000001	4.9301000000000004	4.2176	3.6774	3.2505000000000002	2.3967000000000001	1.7867999999999999	1.3884000000000001	0.99370000000000003	0.86729999999999996	0.74080000000000001	0.63970000000000005	0.54179999999999995	0.063	0.003	16	99.459999	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:18:38	151.40000000000001	30	0	55	143	1	1
7721	86	2007-10-16 00:00:00	576	\N	2	3	54	\N	2007-10-16 08:00:00	2007-10-16 13:30:00	131	135.91574298916379	84.689999999999998	0.30000001	11.5	52	25	77	0.074999999999999997	0.29499999999999998	2.302	11.805999999999999	0.89000000000000001	104.55	192.012	245	\N	103.66	2.3639999999999999	0.79589999	0.68620002	6.9561000000000002	0.083403000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.79	1.468	2.2210000000000001	2.5950000000000002	3.3982000000000001	2.1541000000000001	1.8360000000000001	1.5843	1.3326	0.94940000000000002	0.80049999999999999	0.65159999999999996	0.56530000000000002	0.52739999999999998	0.48370000000000002	0.43659999999999999	0.3659	0.125	0.028999999	16	98.339996	5	5	1970-01-01 00:00:00	\N	2011-12-01 01:29:40	18.199999999999989	-20	-20	25	77	1	1
7763	82	2007-10-15 00:00:00	577	\N	2	3	51	\N	2007-10-15 09:30:00	2007-10-15 13:15:00	126	139.40076204016799	76.239999999999995	0.2	11.5	54	31	85	1.0029999999999999	0.36199999999999999	2.5550000000000002	12.773999999999999	11.981999999999999	97.066000000000003	212.631	247.39999	\N	85.084000000000003	2.9079999999999999	0.80839998	0.51740003	5.7050999999999998	0.075532000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.8759999999999999	1.8839999999999999	2.548	3.1669999999999998	4.3491999999999997	3.3391000000000002	2.8170000000000002	2.1644000000000001	1.821	1.3423	0.95489999999999997	0.79649999999999999	0.6381	0.59150000000000003	0.54859999999999998	0.51429999999999998	0.42380000000000001	0.25	0.132	16	99.862999	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:03:11	46.799999999999983	-35	-35	31	85	1	1
7761	82	2007-04-05 00:00:00	577	\N	2	3	50	\N	2007-04-05 06:45:00	2007-04-05 10:30:00	227	249.52736405190072	77.25	0.2	9.8000002	61	30	91	1.0209999999999999	\N	\N	\N	9.0660000000000007	101.27	\N	336.89999	\N	92.203999999999994	3.6539999999999999	1.0627	\N	7.1685999999999996	0.084667999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.3029999999999999	1.1759999999999999	3.3410000000000002	5.2220000000000004	9.0298999999999996	6.1729000000000003	5.3029000000000002	4.2153	3.5752000000000002	2.5158999999999998	1.704	1.1268	0.79679999999999995	0.66669999999999996	0.59360000000000002	0.55300000000000005	0.48180000000000001	0.125	0.003	16	99.485001	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:03:48	46.799999999999983	-30	0	30	91	1	1
7781	84	2007-03-13 00:00:00	579	\N	2	3	29	\N	2007-03-13 09:45:00	2007-03-13 15:00:00	314	356.16894701262925	75.549999999999997	0.2	8	61	76	137	6.3129999999999997	1.575	10.286	20.129999999999999	25.481000000000002	187.12	612.51900000000001	460.29999	\N	161.63900000000001	2.8479999999999999	1.1101	0.58249998	5.5876000000000001	0.074749999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.0169999999999999	1.51	2.6720000000000002	3.073	7.3996000000000004	4.8113999999999999	3.8039000000000001	3.1227999999999998	2.4417	1.7844	1.4654	1.1464000000000001	0.90920000000000001	0.82520000000000004	0.74129999999999996	0.67410000000000003	0.58069999999999999	0.125	0.0049999999	16	97.871002	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:34:13	59.400000000000006	50	50	76	137	1	1
7782	84	2007-04-04 00:00:00	579	\N	2	3	30	\N	2007-04-04 09:45:00	2007-04-04 14:30:00	235	259.28541739471251	74.790000000000006	0.2	9.5	61	73	134	3.234	\N	\N	\N	32.289999999999999	149.47999999999999	\N	359.89999	\N	117.19	3.0710000000000002	1.0335	\N	6.0259999999999998	0.077627000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.1280000000000001	1.444	2.589	3.1989999999999998	6.5377999999999998	3.9693000000000001	3.395	2.6772999999999998	1.9899	1.6331	1.2762	0.96440000000000003	0.80700000000000005	0.72819999999999996	0.64949999999999997	0.59240000000000004	0.51060000000000005	0.25	0.067000002	31.5	98.871002	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:33:42	59.400000000000006	50	0	73	134	1	1
7783	84	2007-10-11 00:00:00	579	\N	2	3	31	\N	2007-10-11 09:45:00	2007-10-11 14:20:00	181	197.25207828683773	74.230000000000004	0.2	13.2	55	71	126	5.9269999999999996	0.75800000000000001	3.9159999999999999	13.836	38.929000000000002	146.68000000000001	301.75999999999999	296.89999	\N	107.751	2.7559999999999998	0.95300001	0.5923	5.407	0.073532	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.8120000000000001	1.5620000000000001	2.3140000000000001	2.891	3.7637999999999998	3.0125999999999999	2.5118	1.9662999999999999	1.7813000000000001	1.4114	1.0416000000000001	0.878	0.74060000000000004	0.67190000000000005	0.6079	0.5625	0.48820000000000002	0.125	0.0020000001	16	99.767998	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:33:17	59.400000000000006	50	50	71	126	1	1
7801	85	2007-03-12 00:00:00	594	\N	2	3	40	\N	2007-03-12 13:12:00	2007-03-12 17:00:00	329	375.68505369825277	72.25	0.20999999	7.8000002	65	67	132	13.058999999999999	4.8689999999999998	16.484999999999999	30.584	45.509999999999998	210.15799999999999	735.46600000000001	417.20001	\N	164.648	2.5339999999999998	1.2918	0.5571	5.2206999999999999	0.072253999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.4369999999999998	1.369	3.214	4.3339999999999996	9.0365000000000002	6.1673999999999998	5.1928000000000001	3.9878	3.4051999999999998	2.2401	1.6403000000000001	1.1873	0.87539999999999996	0.76910000000000001	0.66290000000000004	0.59719999999999995	0.51690000000000003	0.25	0.068000004	16	97.921997	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:53:15	76.599999999999994	50	50	67	132	1	1
7802	85	2007-04-03 00:00:00	594	\N	2	3	41	\N	2007-04-03 10:48:00	2007-04-03 15:31:00	239	264.16444406611839	71.400000000000006	0.2	9.6000004	58	72	130	3.5670000000000002	\N	\N	\N	48.909999999999997	140.59	\N	325.10001	\N	91.680000000000007	3.5459999999999998	1.1659	\N	6.9569000000000001	0.083407999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.8959999999999999	2.0009999999999999	3.4870000000000001	4.5839999999999996	8.0839999999999996	5.4314999999999998	4.2458999999999998	3.4171999999999998	2.7185000000000001	1.7060999999999999	1.1012	0.79859999999999998	0.59909999999999997	0.54820000000000002	0.49659999999999999	0.44679999999999997	0.37219999999999998	0.125	0.0060000001	16	98.550003	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:53:00	76.599999999999994	50	0	72	130	1	1
7803	85	2007-10-10 00:00:00	598	\N	2	3	42	\N	2007-10-10 09:30:00	2007-10-10 14:30:00	178	194.46406304603437	70.659999999999997	0.2	13.5	67	66	133	9.923	1.044	4.5339999999999998	16.248999999999999	51.869999999999997	136.88999999999999	287.94799999999998	259.70001	\N	85.019999999999996	3.0550000000000002	1.0743001	0.68629998	5.9931000000000001	0.077414999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.8049999999999999	1.788	2.4670000000000001	2.8929999999999998	4.0980999999999996	2.9881000000000002	2.2888000000000002	1.8461000000000001	1.6163000000000001	1.1567000000000001	0.90569999999999995	0.76249999999999996	0.62319999999999998	0.57720000000000005	0.53120000000000001	0.4909	0.39979999999999999	0.125	0.0040000002	16	99.876999	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:52:26	76.599999999999994	50	50	66	133	1	1
7841	88	2007-03-08 00:00:00	600	\N	2	3	48	\N	2007-03-08 09:15:00	2007-03-08 14:20:00	405	249.52736405190072	66.379999999999995	0.20999999	6.5	75	63	138	13.196999999999999	2.2709999999999999	9.9760000000000009	27.867000000000001	40.276000000000003	206.637	740.77499999999998	518.79999	\N	166.36000000000001	3.1190000000000002	0.69	0.86650002	6.4249999999999998	0.080156000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.0030000000000001	1.4139999999999999	2.895	3.7690000000000001	7.5332999999999997	5.1626000000000003	4.0307000000000004	3.3965000000000001	2.7795999999999998	1.8654999999999999	1.5	1.1345000000000001	0.88080000000000003	0.78659999999999997	0.69230000000000003	0.61609999999999998	0.495	0.25	0.050999999	16	98.289001	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:04:47	106.40000000000001	25	25	63	138	1	1
7842	88	2007-04-02 00:00:00	600	\N	2	3	49	\N	2007-04-02 11:00:00	2007-04-02 14:00:00	306	291.3475926639511	65.390000000000001	0.20999999	9.3000002	74	56	130	5.6020000000000003	\N	\N	\N	45.716999999999999	176.12200000000001	\N	370.5	\N	130.405	2.8410000000000002	1.1284	\N	5.8521999999999998	0.076499999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.8170000000000002	2.1880000000000002	3.5430000000000001	4.282	8.4581999999999997	5.8265000000000002	4.5353000000000003	3.4228000000000001	2.5592000000000001	1.6416999999999999	1.1117999999999999	0.83630000000000004	0.62929999999999997	0.57230000000000003	0.51529999999999998	0.4642	0.38340000000000002	0.125	0.0040000002	16	99.740997	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:04:41	106.40000000000001	20	0	56	130	1	1
7861	88	2007-10-09 00:00:00	600	\N	2	3	50	\N	2007-10-09 08:00:00	2007-10-09 13:45:00	221	190.28204018482933	64.549999999999997	0.20999999	13.7	66	62	128	5.8769999999999998	0.55700000000000005	3.7349999999999999	13.680999999999999	49.853000000000002	151.02199999999999	285.07799999999997	278.60001	\N	101.169	2.754	0.9799	0.67699999	5.6730999999999998	0.075319999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.7310000000000001	2.1499999999999999	2.4609999999999999	2.4209999999999998	4.1657000000000002	3.0447000000000002	2.3616000000000001	1.8347	1.5479000000000001	0.99329999999999996	0.84389999999999998	0.69450000000000001	0.59330000000000005	0.56100000000000005	0.52869999999999995	0.50290000000000001	0.41039999999999999	0.125	0.0020000001	16	99.940002	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:04:29	106.40000000000001	20	20	62	128	1	1
7881	89	2007-03-07 00:00:00	185	\N	2	3	20	\N	2007-03-07 07:45:00	2007-03-07 14:10:00	417	483.02364046918211	59.810000000000002	0.22	6.3000002	94	56	150	17.672999999999998	2.6549999999999998	17.603000000000002	25.401	36.712000000000003	213.75999999999999	644.27300000000002	545.59998	\N	177.048	3.0819999999999999	1.2702	0.57499999	6.6506999999999996	0.081551999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.0089999999999999	1.079	3.0230000000000001	4.8019999999999996	7.1458000000000004	5.2683	4.3592000000000004	3.6675	3.1814	2.2090999999999998	1.6777	1.2670999999999999	0.91149999999999998	0.78490000000000004	0.6583	0.57650000000000001	0.46000000000000002	0.125	0.003	16	98.864998	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:14:07	137.19999999999999	20	20	56	150	1	1
7882	89	2007-04-24 00:00:00	185	\N	2	3	21	\N	2007-04-24 09:30:00	2007-04-24 15:15:00	188	155.43184967478732	57.640000000000001	0.20999999	14.8	68	75	143	5.1500000000000004	\N	\N	\N	46.856000000000002	160.88999999999999	\N	213.8	\N	114.03400000000001	1.875	1.0432	\N	3.8620000000000001	0.062144999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.2509999999999999	1.5760000000000001	2.1030000000000002	2.4369999999999998	2.7995999999999999	1.8451	1.6198999999999999	1.3385	1.0569999999999999	0.85740000000000005	0.69879999999999998	0.59660000000000002	0.53759999999999997	0.50819999999999999	0.4607	0.41720000000000002	0.35189999999999999	0.125	0.0089999996	10	99.472	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:14:02	137.19999999999999	20	0	75	143	1	1
8001	2801	2007-10-02 00:00:00	1056	\N	2	3	5	\N	2007-10-02 07:30:00	2007-10-02 13:30:00	261	347.10789748001832	56.009999999999998	0.2	14	92	50	142	23.934999999999999	\N	\N	\N	33.015999999999998	178.41	\N	439.5	\N	145.39400000000001	3.0230000000000001	1.1331	\N	5.9309000000000003	0.077011999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.9620000000000002	1.222	2.879	3.96	6.9596	5.0556000000000001	4.0530999999999997	3.5158	3.0102000000000002	1.9996	1.5886	1.1775	0.88670000000000004	0.78690000000000004	0.68720000000000003	0.61009999999999998	0.50490000000000002	0.125	0.0049999999	16	98.612	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:18:24	151.40000000000001	25	0	50	142	1	1
8021	90	2007-03-01 00:00:00	1438	\N	2	3	44	\N	2007-03-01 09:00:00	2007-03-01 13:45:00	267	356.86595082283009	51.469999999999999	0.19	6.1999998	105	50	155	11.628	1.464	8.2560000000000002	16.125	10.884	158.017	485.07900000000001	515.70001	\N	147.13300000000001	3.5049999999999999	0.9928	0.64709997	6.5332999999999997	0.080828999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.0760000000000001	1.266	2.1869999999999998	2.754	3.9289000000000001	3.0649000000000002	2.4887999999999999	1.9544999999999999	1.8127	1.5293000000000001	1.2458	0.98119999999999996	0.83940000000000003	0.76859999999999995	0.69769999999999999	0.64100000000000001	0.55530000000000002	0.25	0.071000002	16	99.345001	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:20:01	173.79999999999998	10	10	50	155	1	1
8022	90	2007-04-27 00:00:00	1438	\N	2	3	46	\N	2007-04-27 06:00:00	2007-04-27 11:00:00	125	163.09889158699656	50	0.2	16.5	90	50	140	8.9019999999999992	\N	\N	\N	16.234999999999999	152.506	\N	307.39999	\N	136.27000000000001	2.2559999999999998	0.76120001	\N	4.4261999999999997	0.066530000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.246	1.29	1.97	2.4460000000000002	2.5026000000000002	1.8394999999999999	1.6748000000000001	1.4689000000000001	1.2630999999999999	0.95279999999999998	0.82199999999999995	0.69130000000000003	0.59040000000000004	0.55320000000000003	0.51590000000000003	0.4738	0.38950000000000001	0.25	0.074000001	10	99.820999	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:19:53	173.79999999999998	5	0	50	140	1	1
8023	90	2007-10-01 00:00:00	1438	\N	2	3	47	\N	2007-10-01 09:45:00	2007-10-01 14:00:00	270	361.74497749423597	51.740000000000002	0.16	\N	106	50	156	12.398	2.968	12.928000000000001	24.91	9.0920000000000005	159.00999999999999	534.51800000000003	555.79999	\N	149.91800000000001	3.7080000000000002	0.93370003	0.65439999	5.8193999999999999	0.076285000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.873	1.3420000000000001	2.4390000000000001	3.2410000000000001	3.9220999999999999	3.282	2.8552	2.3218000000000001	1.9242999999999999	1.5429999999999999	1.1616	0.90439999999999998	0.73860000000000003	0.65569999999999995	0.59379999999999999	0.55189999999999995	0.47610000000000002	0.125	0.0099999998	16	99.874001	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:19:45	173.79999999999998	10	10	50	156	1	1
8926	86	2008-11-24 00:00:00	576	\N	2	3	59	\N	2008-11-24 10:00:00	2008-11-24 14:30:00	141	149.85581919318059	84.819999999999993	0.30000001	5	41	38	79	0.021999999999999999	\N	\N	\N	0.41199999999999998	105.014	\N	258.5	\N	104.602	2.472	0.83160001	\N	7.2743000000000002	0.085290000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.5820000000000001	1.3779999999999999	2.3399999999999999	3.3380000000000001	3.4794	2.7713000000000001	2.2991999999999999	1.9111	1.7306999999999999	1.3697999999999999	1.0089999999999999	0.82779999999999998	0.65110000000000001	0.59319999999999995	0.54490000000000005	0.50619999999999998	0.41039999999999999	0.125	0.13600001	6.2999999999999998	97.774002	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:26:46	18.199999999999989	-14	0	38	79	1	1
8941	82	2007-11-01 00:00:00	577	\N	2	3	52	\N	2007-11-01 11:00:00	2007-11-01 14:45:00	130	139.40076204016799	76.280000000000001	0.2	9	54	29	83	2.7130000000000001	\N	\N	\N	11.885	97.191000000000003	\N	250.8	\N	85.305999999999997	2.9399999999999999	0.7974	\N	5.7686000000000002	0.075952000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.421	1.329	1.829	1.962	2.7496	1.9026000000000001	1.7532000000000001	1.5664	1.3795999999999999	1.006	0.90229999999999999	0.80310000000000004	0.70379999999999998	0.6542	0.60609999999999997	0.56869999999999998	0.51259999999999994	0.125	0.003	16	99.752998	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:02:45	46.799999999999983	-35	0	29	83	1	1
8942	82	2008-03-13 00:00:00	577	\N	2	3	53	\N	2008-03-13 09:37:00	2008-03-13 14:45:00	313	356.16894701262925	78.109999999999999	0.2	7	62	26	88	5.5300000000000002	2.27	9.5199999999999996	18.629999999999999	6.3860000000000001	104.893	510.01799999999997	418.89999	\N	98.507999999999996	4.2519999999999998	1.22	0.671	8.3423999999999996	0.091337000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.6459999999999999	1.421	3.4590000000000001	5.2649999999999997	9.4977999999999998	7.2720000000000002	6.0415000000000001	5.1048999999999998	4.1683000000000003	2.8654999999999999	1.7632000000000001	0.99750000000000005	0.82969999999999999	0.74570000000000003	0.66180000000000005	0.60770000000000002	0.54420000000000002	0.125	0.003	31.5	99.866997	6	5	1970-01-01 00:00:00	\N	2011-12-01 02:02:00	46.799999999999983	-36	-36	26	88	1	1
8943	82	2008-04-17 00:00:00	577	\N	2	3	54	\N	2008-04-17 09:00:00	2008-04-17 14:00:00	336	388.92812609206874	78.340000000000003	0.2	9	65	22	87	0.066000000000000003	\N	\N	\N	5.5960000000000001	105.857	\N	441.70001	\N	100.261	4.4059999999999997	1.2632999	\N	8.6439000000000004	0.092973	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.7939999999999996	3.3090000000000002	4.4390000000000001	3.6040000000000001	14.867599999999999	11.622400000000001	9.1469000000000005	5.3655999999999997	3.5308000000000002	1.9222999999999999	1.4393	0.98380000000000001	0.80459999999999998	0.71489999999999998	0.62749999999999995	0.58989999999999998	0.53339999999999999	0.125	0.033	16	92.094002	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:01:45	46.799999999999983	-35	0	22	87	1	1
8944	82	2008-11-04 00:00:00	577	\N	2	3	55	\N	2008-11-04 07:45:00	2008-11-04 12:30:00	125	134.52173536876211	76.230000000000004	0.2	10	54	29	83	0.85799999999999998	0.54500000000000004	2.1890000000000001	11.340999999999999	12.002000000000001	97.034999999999997	175.64599999999999	246.60001	\N	85.033000000000001	2.8999999999999999	0.78280002	0.5449	5.6889000000000003	0.075425000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.3360000000000001	1.1020000000000001	1.8009999999999999	2.431	2.2877999999999998	1.8771	1.7721	1.6408	1.5095000000000001	1.2468999999999999	0.99260000000000004	0.86890000000000001	0.74519999999999997	0.68330000000000002	0.62239999999999995	0.5786	0.51280000000000003	0.125	0.0049999999	10	99.697998	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:00:28	46.799999999999983	-35	-35	29	83	1	1
8964	84	2007-11-20 00:00:00	579	\N	2	3	32	\N	2007-11-20 09:45:00	2007-11-20 14:15:00	291	326.19778317399312	75.329999999999998	0.2	5.4000001	64	64	128	4.2759999999999998	\N	\N	\N	26.315000000000001	167.40799999999999	\N	427	\N	141.09299999999999	3.0270000000000001	1.0959001	\N	5.9382000000000001	0.077060000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.8300000000000001	1.49	2.8039999999999998	3.5899999999999999	9.8726000000000003	6.0922000000000001	4.8906999999999998	3.8022	3.3161999999999998	2.3443000000000001	1.7801	1.4397	1.0992	0.95760000000000001	0.85609999999999997	0.77490000000000003	0.65310000000000001	0.125	0.0099999998	16	95.695999	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:32:53	59.400000000000006	38	0	64	128	1	1
8965	84	2008-03-12 00:00:00	579	\N	2	3	33	\N	2008-03-12 09:30:00	2008-03-12 14:00:00	320	365.92700035544101	75.609999999999999	0.2	\N	57	66	123	7.9020000000000001	3.5939999999999999	12.83	24.437999999999999	25.253	191.273	532.51800000000003	470.20001	\N	166.02000000000001	2.8319999999999999	1.1166	0.40900001	5.5566000000000004	0.074542999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.6360000000000001	2.056	3.1640000000000001	3.419	9.5898000000000003	6.4053000000000004	5.2880000000000003	3.9761000000000002	3.2368999999999999	1.9174	1.4118999999999999	0.97419999999999995	0.83489999999999998	0.76519999999999999	0.6956	0.63980000000000004	0.56079999999999997	0.125	0.001	31.5	99.748001	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:32:02	59.400000000000006	38	38	66	123	1	1
8966	84	2008-04-16 00:00:00	579	\N	2	3	34	\N	2008-04-16 10:00:00	2008-04-16 14:30:00	327	375.68505369825277	75.739999999999995	0.2	10	68	62	130	1.1120000000000001	\N	\N	\N	24.760000000000002	191.65600000000001	\N	491.79999	\N	166.89699999999999	2.9470000000000001	1.0959001	\N	5.7817999999999996	0.076037999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.1189999999999998	0.93899999999999995	2.0369999999999999	2.9950000000000001	7.9165999999999999	5.3878000000000004	4.4348000000000001	3.8569	3.6315	3.1806999999999999	2.7299000000000002	2.2791000000000001	1.8500000000000001	1.653	1.4559	1.2983	1.0619000000000001	0.125	0.0040000002	31.5	99.505997	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:31:46	59.400000000000006	36	0	62	130	1	1
8986	85	2007-11-19 00:00:00	598	\N	2	3	43	\N	2007-11-19 13:24:00	2007-11-19 16:29:00	305	345.0168860494158	72.079999999999998	0.20999999	5.5	63	70	133	7.9130000000000003	\N	\N	\N	46.189999999999998	176.44	\N	391.29999	\N	130.25	3.004	1.2651	\N	6.1887999999999996	0.078669000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.4619999999999997	2.3570000000000002	3.9470000000000001	4.3730000000000002	12.8681	9.2588000000000008	7.5065999999999997	5.6223999999999998	4.1136999999999997	2.3254000000000001	1.5279	0.98429999999999995	0.81200000000000006	0.72589999999999999	0.63970000000000005	0.59430000000000005	0.53180000000000005	0.125	0.0020000001	31.5	99.671997	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:51:58	76.599999999999994	50	0	70	133	1	1
8968	84	2008-11-25 00:00:00	579	\N	2	3	35	\N	2008-11-25 08:10:00	2008-11-25 13:30:00	142	151.24982681358227	73.849999999999994	0.2	4.5	52	69	121	0.95799999999999996	0.39800000000000002	2.2229999999999999	10.243	43.433999999999997	144.78	241.49199999999999	257.20001	\N	101.346	2.5379999999999998	0.84359998	0.53079998	4.9795999999999996	0.070566000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.0529999999999999	1.3100000000000001	2.2360000000000002	2.8519999999999999	3.7972999999999999	2.9994999999999998	2.4676	1.9536	1.7971999999999999	1.4843999999999999	1.1717	0.93630000000000002	0.79520000000000002	0.72470000000000001	0.65410000000000001	0.5998	0.52049999999999996	0.125	0.0060000001	16	99.009003	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:31:08	59.400000000000006	47	47	69	121	1	1
8987	85	2008-03-11 00:00:00	598	\N	2	3	44	\N	2008-03-11 08:00:00	2008-03-11 14:50:00	327	375.68505369825277	72.25	0.20999999	6	66	73	139	26.486000000000001	4.4720000000000004	16.420000000000002	30.463999999999999	45.509999999999998	210.15799999999999	607.62400000000002	417.20001	\N	164.648	2.5339999999999998	1.2918	0.45109999	5.2206999999999999	0.072253999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.5209999999999999	2.4950000000000001	3.2000000000000002	3.0550000000000002	10.2691	6.6661000000000001	5.1298000000000004	3.6802999999999999	2.7614000000000001	1.7484	1.3188	0.96609999999999996	0.83489999999999998	0.76919999999999999	0.7036	0.65110000000000001	0.57230000000000003	0.125	0.0040000002	31.5	99.916	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:51:34	76.599999999999994	50	50	73	139	1	1
8988	85	2008-04-15 00:00:00	598	\N	2	3	45	\N	2008-04-15 08:00:00	2008-04-15 14:30:00	346	403.56520610628638	72.400000000000006	0.2	11	68	70	138	8.6389999999999993	\N	\N	\N	44.909999999999997	216.27699999999999	\N	442.39999	\N	171.36699999999999	2.5819999999999999	1.3085999	\N	5.0656999999999996	0.071173	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.8889999999999998	1.3009999999999999	3.6259999999999999	5.5679999999999996	9.9763000000000002	7.5225999999999997	6.1025	5.1252000000000004	4.1478000000000002	2.8357999999999999	1.8184	1.2786	0.86529999999999996	0.72619999999999996	0.61380000000000001	0.57199999999999995	0.50929999999999997	0.125	0.0040000002	16	97.333	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:51:00	76.599999999999994	50	0	70	138	1	1
8989	85	2008-11-26 00:00:00	598	\N	2	3	46	\N	2008-11-26 08:00:00	2008-11-26 12:10:00	132	141.49177347077051	70.170000000000002	0.2	4.5	45	68	113	3.4289999999999998	0.96999999999999997	2.6389999999999998	13.002000000000001	53.829999999999998	134.44	198.38200000000001	219.10001	\N	80.609999999999999	2.718	0.92640001	0.4912	5.3333000000000004	0.073028999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.8520000000000001	1.55	1.974	2.323	3.7799	2.4127999999999998	1.9281999999999999	1.7641	1.6000000000000001	1.2718	0.98170000000000002	0.87539999999999996	0.76910000000000001	0.71599999999999997	0.66279999999999994	0.61909999999999998	0.54749999999999999	0.125	0.0049999999	16	99.760002	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:50:31	76.599999999999994	50	50	68	113	1	1
8991	88	2007-11-15 00:00:00	600	\N	2	3	51	\N	2007-11-15 07:20:00	2007-11-15 11:00:00	389	434.93037756532419	66.230000000000004	0.2	5.8000002	75	56	131	14.500999999999999	\N	\N	\N	41.557000000000002	203.08099999999999	\N	494.20001	\N	161.524	3.0600000000000001	1.2625	\N	6.0034999999999998	0.077481999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.569	1.1990000000000001	3.5129999999999999	5.7999999999999998	9.2141000000000002	6.5663	5.5430999999999999	4.4290000000000003	3.6423000000000001	2.4790000000000001	1.7065999999999999	1.208	0.8448	0.71160000000000001	0.59809999999999997	0.53200000000000003	0.4274	0.125	0.0060000001	31.5	99.936996	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:04:23	106.40000000000001	20	0	56	131	1	1
8993	88	2008-04-10 00:00:00	600	\N	2	3	53	\N	2008-04-10 09:00:00	2008-04-10 14:30:00	367	395.89816419407714	66	0.20999999	7.4000001	82	55	137	3.6070000000000002	\N	\N	\N	42.811	197.38200000000001	\N	457.89999	\N	154.572	2.9620000000000002	1.2405	\N	6.1026999999999996	0.078119999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.9889999999999999	0.76400000000000001	3.339	6.3300000000000001	9.3409999999999993	7.4112999999999998	6.2202000000000002	5.4869000000000003	4.7535999999999996	3.5225	2.54	1.7081999999999999	1.0602	0.89559999999999995	0.76739999999999997	0.66490000000000005	0.55640000000000001	0.125	0.0049999999	16	98.329002	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:04:08	106.40000000000001	20	0	55	137	1	1
8995	88	2008-11-27 00:00:00	600	\N	2	3	55	\N	2008-11-27 07:40:00	2008-11-27 11:30:00	185	151.24982681358227	64.180000000000007	0.20999999	4.3000002	63	57	120	3.0169999999999999	\N	\N	\N	51.883000000000003	147.46299999999999	\N	242.2	\N	95.579999999999998	2.5339999999999998	0.89579999	\N	5.2213000000000003	0.072258000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.5649999999999999	1.641	2.2410000000000001	2.6739999999999999	3.5265	2.6032999999999999	1.9966999999999999	1.7904	1.5841000000000001	1.1714	0.90680000000000005	0.74729999999999996	0.61229999999999996	0.57879999999999998	0.54520000000000002	0.51839999999999997	0.43809999999999999	0.125	0.0049999999	10	99.403	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:03:51	106.40000000000001	19	0	57	120	1	1
8996	89	2007-11-26 00:00:00	185	\N	2	3	23	\N	2007-11-26 10:30:00	2007-11-26 14:00:00	321	320.62175269238639	58.880000000000003	0.22	4.8000002	77	70	147	11.663	\N	\N	\N	42.731999999999999	206.749	\N	386.60001	\N	164.017	2.3570000000000002	1.1899	\N	5.0867000000000004	0.071320999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.4900000000000002	1.1519999999999999	2.706	3.7669999999999999	5.6849999999999996	4.335	3.7513999999999998	3.2565	2.7616000000000001	1.9049	1.4925999999999999	1.0802	0.84660000000000002	0.75129999999999997	0.65610000000000002	0.59209999999999996	0.50570000000000004	0.125	0.003	16	99.617996	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:13:49	137.19999999999999	22	0	70	147	1	1
8999	89	2008-04-09 00:00:00	185	\N	2	3	25	\N	2008-04-09 08:30:00	2008-04-09 12:00:00	362	386.83711466146622	59.299999999999997	0.22	8	93	65	158	3.0049999999999999	\N	\N	\N	39.786000000000001	210.59399999999999	\N	456.79999	\N	170.80799999999999	2.6739999999999999	1.215	\N	5.7718999999999996	0.075972999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.169	0.86399999999999999	3.0009999999999999	5.4740000000000002	6.8775000000000004	5.5579000000000001	4.9500999999999999	4.1905000000000001	3.6825999999999999	2.8355000000000001	1.9927999999999999	1.4693000000000001	0.97309999999999997	0.84350000000000003	0.71379999999999999	0.61729999999999996	0.51800000000000002	0.125	0.0049999999	16	99.049004	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:13:36	137.19999999999999	19	0	65	158	1	1
9000	89	2008-10-28 00:00:00	185	\N	2	3	26	\N	2008-10-28 07:15:00	2008-10-28 11:30:00	144	114.30862487293776	57.359999999999999	0.20999999	8	76	77	153	7.391	0.56599999999999995	1.345	8.1989999999999998	47.938000000000002	159.49000000000001	116.869	182.2	\N	111.55200000000001	1.633	0.90020001	0.49219999	3.3645999999999998	0.058005000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.7090000000000001	1.468	2.4750000000000001	3.4729999999999999	3.7865000000000002	3.1229	2.6806000000000001	2.1276000000000002	1.8453999999999999	1.4434	1.0415000000000001	0.84330000000000005	0.66849999999999998	0.60150000000000003	0.55059999999999998	0.50990000000000002	0.41560000000000002	0.125	0.0060000001	10	99.712997	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:13:28	137.19999999999999	29	29	77	153	1	1
9002	2800	2007-11-13 00:00:00	1055	\N	2	3	6	\N	2007-11-13 07:30:00	2007-11-13 13:15:00	343	355.47194320242841	56.869999999999997	0.2	6.4000001	94	43	137	6.3029999999999999	\N	\N	\N	10.01	192.54599999999999	\N	500.79999	\N	182.536	2.7440000000000002	1.0183001	\N	5.3830999999999998	0.073370000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.3149999999999999	1.212	1.778	2.2309999999999999	2.3355999999999999	1.871	1.7543	1.6085	1.4626999999999999	1.1711	0.95599999999999996	0.84940000000000004	0.74280000000000002	0.68959999999999999	0.63629999999999998	0.59189999999999998	0.52490000000000003	0.125	0.003	16	99.962997	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:17:06	150.99999999999997	12	0	43	137	1	1
9003	2800	2007-11-27 00:00:00	1055	\N	2	3	7	\N	2007-11-27 07:45:00	2007-11-27 13:40:00	336	344.31988223921496	56.490000000000002	0.20999999	4.1999998	100	41	141	14.976000000000001	\N	\N	\N	12.442	160.16	\N	437.89999	\N	147.71700000000001	2.9649999999999999	1.128	\N	6.1077000000000004	0.078151999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.5840000000000001	1.546	2.1120000000000001	2.569	3.3879999999999999	2.6137000000000001	2.0975000000000001	1.8529	1.6795	1.3329	0.99519999999999997	0.87360000000000004	0.752	0.69120000000000004	0.63049999999999995	0.58579999999999999	0.51890000000000003	0.125	0.001	16	99.914001	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:17:01	150.99999999999997	13	0	41	141	1	1
9006	2800	2008-04-08 00:00:00	1055	\N	2	3	9	\N	2008-04-08 13:15:00	2008-04-08 16:00:00	361	385.44310704106454	56.869999999999997	0.2	7.6999998	95	37	132	7.9740000000000002	\N	\N	\N	10.01	192.54599999999999	\N	500.79999	\N	182.536	2.7440000000000002	1.1042	\N	5.3830999999999998	0.073370000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.8939999999999999	1.228	2.4420000000000002	3.3610000000000002	3.8883999999999999	3.2795999999999998	2.8736000000000002	2.3662000000000001	1.9487000000000001	1.5802	1.2116	0.92410000000000003	0.746	0.65700000000000003	0.5927	0.54979999999999996	0.47010000000000002	0.125	0.003	16	99.911003	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:16:51	150.99999999999997	8	0	37	132	1	1
9005	2800	2008-03-05 00:00:00	1055	\N	2	3	8	\N	2008-03-05 08:00:00	2008-03-05 14:15:00	447	550.63301005866356	57.340000000000003	0.20999999	5.5999999	107	39	146	27.370000000000001	\N	\N	\N	-8.5090000000000003	194.393	\N	589.20001	\N	202.90199999999999	2.9039999999999999	1.3408999	\N	5.9817999999999998	0.077341999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.9199999999999999	1.554	2.2090000000000001	2.6400000000000001	3.7035999999999998	2.7237	2.0705	1.8412999999999999	1.6676	1.3201000000000001	0.98939999999999995	0.85440000000000005	0.71940000000000004	0.65190000000000003	0.59719999999999995	0.55830000000000002	0.50009999999999999	0.125	0.0020000001	16	99.250999	6	0	1970-01-01 00:00:00	\N	2011-12-01 03:16:56	150.99999999999997	13	0	39	146	1	1
9007	2800	2008-10-22 00:00:00	1055	\N	2	3	10	\N	2008-10-22 13:10:00	2008-10-22 15:45:00	164	131.03671631775794	54.670000000000002	0.20999999	12.3	84	50	134	4.1120000000000001	\N	\N	\N	35.347999999999999	147.09999999999999	\N	205.2	\N	111.752	1.8360000000000001	0.9163	\N	3.7820999999999998	0.061498999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.478	1.3109999999999999	2.0209999999999999	2.6160000000000001	3.1362999999999999	2.3041	1.9426000000000001	1.7838000000000001	1.6249	1.3072999999999999	0.99570000000000003	0.86429999999999996	0.73280000000000001	0.66710000000000003	0.60670000000000002	0.56399999999999995	0.49959999999999999	0.125	0.0040000002	16	99.963997	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:16:46	150.99999999999997	17	0	50	134	1	1
9048	2801	2008-10-22 00:00:00	1056	\N	2	3	10	\N	2008-10-22 07:30:00	2008-10-22 11:00:00	119	156.12885348498816	54.579999999999998	0.20999999	12.3	85	45	130	7.6870000000000003	\N	\N	\N	37.712000000000003	154.16	\N	263	\N	116.44799999999999	2.2589999999999999	0.85159999	\N	4.6536	0.068217	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.0510000000000002	1.1020000000000001	2.415	3.3780000000000001	4.1955999999999998	3.4849999999999999	3.1061999999999999	2.6326999999999998	2.1591999999999998	1.7161	1.3749	1.0337000000000001	0.84009999999999996	0.75139999999999996	0.66269999999999996	0.59770000000000001	0.50800000000000001	0.125	0.0049999999	16	99.948997	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:17:59	151.40000000000001	25	0	45	130	1	1
9063	90	2007-11-29 00:00:00	1438	\N	2	3	48	\N	2007-11-29 07:45:00	2007-11-29 11:34:00	308	427.26333565311495	51.939999999999998	0.18000001	4	103	49	152	19.751000000000001	\N	\N	\N	7.7619999999999996	159.80199999999999	\N	586	\N	152.03999999999999	3.8540000000000001	1.046	\N	6.8060999999999998	0.082499000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.173	1.1539999999999999	2.2530000000000001	2.9660000000000002	4.3625999999999996	3.5223	3.1364000000000001	2.6539000000000001	2.1715	1.7542	1.4552	1.1561999999999999	0.92210000000000003	0.84050000000000002	0.75890000000000002	0.69369999999999998	0.59150000000000003	0.125	0.0049999999	16	99.670998	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:19:40	173.79999999999998	11	0	49	152	1	1
9067	90	2008-04-07 00:00:00	1438	\N	2	3	50	\N	2008-04-07 12:00:00	2008-04-07 16:00:00	343	494.8727052425964	52.289999999999999	0.18000001	9	103	37	140	15.156000000000001	\N	\N	\N	5.4359999999999999	200.58199999999999	\N	670.5	\N	195.14599999999999	3.4359999999999999	1.0589	\N	6.0671999999999997	0.077893000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.0609999999999999	1.611	2.4580000000000002	2.891	4.1166999999999998	3.4321999999999999	3.0358000000000001	2.5402	2.0446	1.5604	1.1002000000000001	0.84509999999999996	0.64710000000000001	0.61050000000000004	0.58689999999999998	0.56799999999999995	0.53969999999999996	0.125	0.0020000001	16	99.602997	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:19:26	173.79999999999998	1	0	37	140	1	1
9066	90	2008-03-03 00:00:00	1438	\N	2	3	49	\N	2008-03-03 09:30:00	2008-03-03 14:45:00	268	358.95696225343261	51.5	0.19	\N	104	42	146	8.7750000000000004	2.4740000000000002	9.968	19.356000000000002	10.686999999999999	158.12700000000001	526.25400000000002	520.09998	\N	147.44	3.528	0.99010003	0.61510003	6.5754999999999999	0.081089999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.996	1.157	2.2690000000000001	3.0019999999999998	3.9539	3.3763999999999998	2.9914999999999998	2.5103	2.0291000000000001	1.6963999999999999	1.3833	1.0702	0.87729999999999997	0.79820000000000002	0.71909999999999996	0.65580000000000005	0.56510000000000005	0.25	0.064999998	10	99.168999	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:19:31	173.79999999999998	13	13	42	146	1	1
9081	90	2008-09-22 00:00:00	1438	\N	2	3	51	\N	2008-09-22 11:10:00	2008-09-22 14:03:00	61	99.671544858720125	49.350000000000001	0.2	14	87	78	165	2.6800000000000002	0.13100000000000001	0.71699999999999997	5.0110000000000001	18.526	149.47200000000001	155.667	220.8	\N	130.946	1.6859999999999999	0.64770001	0.49700001	3.3077999999999999	0.057514000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.98199999999999998	1.351	1.6890000000000001	2.1600000000000001	1.7619	1.4291	1.2072000000000001	0.9869	0.93510000000000004	0.83140000000000003	0.7278	0.627	0.57440000000000002	0.54810000000000003	0.52180000000000004	0.50070000000000003	0.38490000000000002	0.125	0.026000001	16	99.919998	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:19:17	173.79999999999998	24	24	78	165	1	1
9082	90	2008-10-23 00:00:00	1438	\N	2	3	52	\N	2008-10-23 08:30:00	2008-10-23 13:15:00	115	151.94683062378311	49.899999999999999	0.2	11.5	84	63	147	8.093	\N	\N	\N	16.456	151.88800000000001	\N	293.79999	\N	135.43199999999999	2.1699999999999999	0.74190003	\N	4.2568000000000001	0.065243999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.4470000000000001	1.3160000000000001	1.9119999999999999	2.355	3.0535999999999999	2.1055999999999999	1.8885000000000001	1.7212000000000001	1.5539000000000001	1.2193000000000001	0.95999999999999996	0.84409999999999996	0.72819999999999996	0.67020000000000002	0.61509999999999998	0.57620000000000005	0.51780000000000004	0.125	0.0040000002	10	99.809998	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:19:12	173.79999999999998	21	0	63	147	1	1
10070	86	2009-10-14 00:00:00	576	\N	2	3	62	\N	2009-10-14 07:30:00	2009-10-14 14:30:00	122	131.73372012795878	84.659999999999997	0.30000001	11	60	31	91	0.127	\N	\N	\N	1	104.44199999999999	\N	241.89999	\N	103.44199999999999	2.339	0.78130001	\N	6.8823999999999996	0.082960000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.089	1.0580000000000001	2.0859999999999999	2.8079999999999998	3.7570000000000001	3.0987	2.6598000000000002	2.1112000000000002	1.9075	1.6756	1.4438	1.2119	0.98319999999999996	0.88629999999999998	0.78939999999999999	0.71179999999999999	0.59670000000000001	0.25	0.034000002	16	99.176003	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:21:32	18.199999999999989	-15	0	31	91	1	0
10071	82	2009-05-11 00:00:00	577	\N	2	3	57	\N	2009-05-11 09:00:00	2009-05-11 14:15:00	165	174.25095255021	76.629999999999995	0.2	13.1	45	23	68	0.32100000000000001	\N	\N	\N	10.868	98.641000000000005	\N	281.10001	\N	87.772999999999996	3.2029999999999998	0.88940001	\N	6.2834000000000003	0.079268000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.4529999999999998	1.1619999999999999	2.157	2.7530000000000001	5.0759999999999996	3.6766000000000001	3.2723	2.7667999999999999	2.2614000000000001	1.8220000000000001	1.5818000000000001	1.3416999999999999	1.1014999999999999	0.98340000000000005	0.87629999999999997	0.79049999999999998	0.66190000000000004	0.125	0.0089999996	16	99.463997	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:58:41	46.799999999999983	-40	0	23	68	1	0
10072	82	2009-10-13 00:00:00	577	\N	2	3	58	\N	2009-10-13 07:30:00	2009-10-13 13:45:00	108	118.4906477341428	76.049999999999997	0.20999999	12	51	24	75	0.111	\N	\N	\N	12.356999999999999	96.474999999999994	\N	231.3	\N	84.117999999999995	2.75	0.7349	\N	5.6654999999999998	0.075269000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.7569999999999999	1.5429999999999999	2.2029999999999998	2.617	3.5661999999999998	2.7193000000000001	2.1547999999999998	1.8629	1.6872	1.3360000000000001	0.99380000000000002	0.85199999999999998	0.71009999999999995	0.63919999999999999	0.59379999999999999	0.5605	0.51060000000000005	0.25	0.090000004	16	99.510002	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:58:22	46.799999999999983	-47	0	24	75	1	0
10073	84	2009-05-07 00:00:00	579	\N	2	3	37	\N	2009-05-07 09:20:00	2009-05-07 14:20:00	173	183.31200208282092	74.159999999999997	0.2	14	44	73	117	2.1230000000000002	\N	\N	\N	39.759	146.33000000000001	\N	289.39999	\N	106.571	2.7160000000000002	0.90859997	\N	5.3288000000000002	0.072997999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.7809999999999999	1.008	2.1040000000000001	2.8660000000000001	3.4882	2.9049	2.516	2.0299	1.8813	1.6283000000000001	1.3753	1.1223000000000001	0.9073	0.81759999999999999	0.72789999999999999	0.65620000000000001	0.56810000000000005	0.125	0.0049999999	16	99.914001	6	0	1970-01-01 00:00:00	\N	2011-12-01 02:30:42	59.400000000000006	45	0	73	117	1	0
10075	84	2009-10-12 00:00:00	579	\N	2	3	38	\N	2009-10-12 10:30:00	2009-10-12 14:15:00	98	110.12660201173273	73.390000000000001	0.2	14	34	79	113	0.79000000000000004	\N	\N	\N	48.887999999999998	142.47999999999999	\N	212.39999	\N	93.591999999999999	2.2690000000000001	0.7439	\N	4.4522000000000004	0.066725000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.087	1.387	1.8740000000000001	2.2290000000000001	1.9194	1.5683	1.3342000000000001	1.0416000000000001	0.94889999999999997	0.82979999999999998	0.71060000000000001	0.61170000000000002	0.55500000000000005	0.52669999999999995	0.49640000000000001	0.44669999999999999	0.37219999999999998	0.125	0.013	10	99.792	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:30:19	59.400000000000006	49	0	79	113	1	0
10087	85	2009-05-06 00:00:00	598	\N	2	3	48	\N	2009-05-06 11:00:00	2009-05-06 15:15:00	170	179.82698303181672	70.659999999999997	0.2	14	53	62	115	2.7509999999999999	\N	\N	\N	51.869999999999997	136.88999999999999	\N	259.70001	\N	85.019999999999996	3.0550000000000002	0.99349999	\N	5.9931000000000001	0.077414999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.9359999999999999	2.1600000000000001	2.3519999999999999	2.2160000000000002	4.5663	3.2242999999999999	2.5670000000000002	1.9236	1.6771	1.1840999999999999	0.93269999999999997	0.82530000000000003	0.71779999999999999	0.66410000000000002	0.61519999999999997	0.58289999999999997	0.53439999999999999	0.125	0.0020000001	16	99.882004	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:49:37	76.599999999999994	40	0	62	115	1	0
10089	85	2009-10-08 00:00:00	598	\N	2	3	49	\N	2009-10-08 07:50:00	2009-10-08 12:30:00	101	112.21761344233524	69.530000000000001	0.2	16	45	70	115	1.718	\N	\N	\N	56.390000000000001	131.24000000000001	\N	169.39999	\N	74.849999999999994	2.2629999999999999	0.95060003	\N	4.4397000000000002	0.066630999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.431	1.325	2.6019999999999999	3.3300000000000001	5.8411999999999997	3.9558	3.4390999999999998	2.7932000000000001	2.1474000000000002	1.6809000000000001	1.3207	0.98129999999999995	0.81040000000000001	0.72489999999999999	0.63949999999999996	0.58430000000000004	0.50480000000000003	0.125	0.0040000002	16	99.294998	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:49:31	76.599999999999994	50	0	70	115	1	0
10090	88	2009-05-05 00:00:00	600	\N	2	3	57	\N	2009-05-05 09:00:00	2009-05-05 14:30:00	236	205.61612400924781	64.689999999999998	0.20999999	14.8	64	58	122	5.1950000000000003	\N	\N	\N	49.122	152.58199999999999	\N	292.89999	\N	103.45999999999999	2.831	1.0071	\N	5.8327	0.076371999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.9450000000000001	3.109	2.6600000000000001	2.1269999999999998	5.5060000000000002	3.6225000000000001	2.6631	1.8192999999999999	1.4152	0.92549999999999999	0.77229999999999999	0.62660000000000005	0.57889999999999997	0.55500000000000005	0.53110000000000002	0.51200000000000001	0.43519999999999998	0.125	0.001	16	99.724998	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:03:27	106.40000000000001	18	0	58	122	1	0
10091	88	2009-10-07 00:00:00	600	\N	2	3	58	\N	2009-10-07 07:30:00	2009-10-07 11:00:00	116	92.004502946510883	63.490000000000002	0.20999999	14.5	57	63	120	1.7030000000000001	\N	\N	\N	53.631999999999998	142.471	\N	178.8	\N	88.838999999999999	2.0129999999999999	0.73809999	\N	4.1474000000000002	0.064399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.0820000000000001	1.3149999999999999	1.6240000000000001	1.742	1.8028	1.3849	1.1063000000000001	0.96870000000000001	0.92369999999999997	0.83360000000000001	0.74360000000000004	0.65349999999999997	0.59370000000000001	0.56910000000000005	0.54449999999999998	0.52490000000000003	0.47849999999999998	0.125	0.0040000002	16	99.953003	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:03:19	106.40000000000001	41	0	63	120	1	0
10093	89	2009-05-04 00:00:00	616	\N	2	3	28	\N	2009-05-04 13:00:00	2009-05-04 16:00:00	246	217.4651887826621	58.170000000000002	0.20999999	15.5	64	82	146	2.472	\N	\N	\N	44.904000000000003	175.88999999999999	\N	304.20001	\N	130.98599999999999	2.323	1.0256	\N	4.7847	0.069170999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.2230000000000001	1.9450000000000001	2.27	2.29	3.0160999999999998	1.9041999999999999	1.6000000000000001	1.2197	0.95520000000000005	0.7429	0.60150000000000003	0.54069999999999996	0.47520000000000001	0.4375	0.39979999999999999	0.36969999999999997	0.32440000000000002	0.125	0.0060000001	16	99.958	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:13:14	137.19999999999999	25	0	82	146	1	0
10094	2800	2009-03-03 00:00:00	1055	\N	2	3	11	\N	2009-03-03 11:00:00	2009-03-03 15:30:00	435	524.84386908123258	57.57	0.2	3.8	86	44	130	10.141	\N	\N	\N	-17.937000000000001	195.297	\N	637.59998	\N	213.23400000000001	2.9900000000000002	1.181	\N	5.8667999999999996	0.076594999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.754	1.1479999999999999	2.2490000000000001	3.0209999999999999	3.6398000000000001	2.9658000000000002	2.5165000000000002	1.9878	1.8364	1.5337000000000001	1.2309000000000001	0.96189999999999998	0.80149999999999999	0.72130000000000005	0.6411	0.58650000000000002	0.50760000000000005	0.125	0.0089999996	16	99.964996	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:16:41	150.99999999999997	4	0	44	130	1	0
10095	2800	2009-05-04 00:00:00	1055	\N	2	3	12	\N	2009-05-04 08:30:00	2009-05-04 11:15:00	246	217.4651887826621	55.509999999999998	0.20999999	15.5	79	56	135	7.1429999999999998	\N	\N	\N	27.253	150.66300000000001	\N	302.39999	\N	123.41	2.4500000000000002	1.0317	\N	5.0481999999999996	0.071051000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.544	1.345	2.8679999999999999	3.8570000000000002	5.8973000000000004	4.6128	3.8740000000000001	3.3199999999999998	2.7660999999999998	1.8553999999999999	1.387	0.96760000000000002	0.78129999999999999	0.68810000000000004	0.6079	0.56089999999999995	0.48110000000000003	0.125	0.0040000002	16	99.461998	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:16:36	150.99999999999997	18	0	56	135	1	0
10096	2801	2009-03-03 00:00:00	1056	\N	2	3	11	\N	2009-03-03 07:15:00	2009-03-03 11:00:00	412	645.42552824597783	57.450000000000003	0.2	3.8	84	51	135	7.6550000000000002	\N	\N	\N	28.684000000000001	219.84899999999999	\N	702.09998	\N	191.16499999999999	3.673	1.3188	\N	7.2064000000000004	0.084889999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.5990000000000002	1.044	2.8490000000000002	4.2380000000000004	5.9221000000000004	4.4928999999999997	3.8102999999999998	3.3191000000000002	2.8279000000000001	1.9379999999999999	1.5435000000000001	1.1491	0.84050000000000002	0.71230000000000004	0.60629999999999995	0.55349999999999999	0.45729999999999998	0.125	0.015	16	99.489998	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:17:55	151.40000000000001	25	0	51	135	1	0
10097	2801	2009-04-30 00:00:00	1056	\N	2	3	12	\N	2009-04-30 08:00:00	2009-04-30 10:15:00	205	262.77043644571671	55.490000000000002	0.20999999	14.7	66	49	115	1.462	\N	\N	\N	34.765000000000001	158.71000000000001	\N	372.39999	\N	123.94499999999999	3.004	1.0124	\N	6.1894999999999998	0.078673000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.4710000000000001	1.5189999999999999	2.5230000000000001	3.3740000000000001	3.4754	2.4165999999999999	1.9157	1.6585000000000001	1.4014	0.95989999999999998	0.7772	0.61619999999999997	0.5454	0.51000000000000001	0.443	0.37959999999999999	0.28449999999999998	0.125	0.045000002	10	99.082001	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:17:49	151.40000000000001	11	0	49	115	1	0
10834	85	2009-11-03 00:00:00	598	\N	2	3	50	\N	2009-11-03 08:00:00	2009-11-03 13:30:00	162	171.46293730940664	70.5	0.2	8.5	55	66	121	1.5840000000000001	\N	\N	\N	52.509999999999998	136.09	\N	246.2	\N	83.579999999999998	2.9460000000000002	0.99910003	\N	5.7797000000000001	0.076024999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.0920000000000001	1.8899999999999999	2.3839999999999999	2.569	4.9966999999999997	3.4958	2.7448000000000001	1.9630000000000001	1.7837000000000001	1.4253	1.0668	0.90190000000000003	0.78120000000000001	0.72089999999999999	0.66059999999999997	0.61519999999999997	0.55479999999999996	0.125	0.0049999999	16	99.462997	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:49:21	76.599999999999994	47	0	66	121	1	0
10835	88	2009-11-04 00:00:00	600	\N	2	3	59	\N	2009-11-04 07:00:00	2009-11-04 14:00:00	224	191.67604780523101	64.569999999999993	0.20999999	7	68	62	130	3.2559999999999998	\N	\N	\N	49.747999999999998	151.245	\N	280.60001	\N	101.497	2.7650000000000001	0.98000002	\N	5.6959	0.075470999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.0009999999999999	2.415	2.8180000000000001	3.1379999999999999	5.2743000000000002	3.8077999999999999	3.274	2.6067999999999998	1.9668000000000001	1.2325999999999999	0.86939999999999995	0.6784	0.58160000000000001	0.54910000000000003	0.51670000000000005	0.47939999999999999	0.39279999999999998	0.125	0.0060000001	10	98.537003	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:03:12	106.40000000000001	26	0	62	130	1	0
10836	89	2009-11-05 00:00:00	185	\N	2	3	29	\N	2009-11-05 07:00:00	2009-11-05 12:00:00	232	200.73709733784193	58.090000000000003	0.20999999	6.5	80	70	150	4.9409999999999998	\N	\N	\N	45.149000000000001	167.88999999999999	\N	266.10001	\N	122.741	2.1680000000000001	1.0822999	\N	4.4663000000000004	0.066830000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.9930000000000001	1.431	2.6070000000000002	3.6269999999999998	4.6054000000000004	3.6105999999999998	3.2048000000000001	2.6974999999999998	2.1903000000000001	1.6225000000000001	1.1578999999999999	0.878	0.69330000000000003	0.61529999999999996	0.56869999999999998	0.53139999999999998	0.44740000000000002	0.125	0.0049999999	16	99.939003	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:13:07	137.19999999999999	26	0	70	150	1	0
10837	2800	2009-11-06 00:00:00	1055	\N	2	3	13	\N	2009-11-06 07:00:00	2009-11-06 10:00:00	236	205.61612400924781	55.789999999999999	0.2	7.6999998	87	50	137	75.091999999999999	\N	\N	\N	15.815	151.80099999999999	\N	339.60001	\N	135.98599999999999	2.4969999999999999	0.86870003	\N	4.8997999999999999	0.069999000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.802	1.2669999999999999	2.3340000000000001	3.0030000000000001	3.8115999999999999	3.0899999999999999	2.609	2.0076999999999998	1.8369	1.5065	1.1760999999999999	0.92459999999999998	0.7631	0.68230000000000002	0.61080000000000001	0.56710000000000005	0.50160000000000005	0.125	0.0080000004	16	99.935997	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:16:31	150.99999999999997	15	0	50	137	1	0
10838	2801	2009-11-09 00:00:00	1056	\N	2	3	13	\N	2009-11-09 08:00:00	2009-11-09 12:00:00	228	296.22661933535699	55.689999999999998	0.2	7.3000002	89	40	129	11.122999999999999	\N	\N	\N	34.091999999999999	159.71000000000001	\N	397.29999	\N	125.61799999999999	3.1629999999999998	1.0696	\N	6.2061000000000002	0.078779000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.6389999999999998	1.0609999999999999	2.7410000000000001	3.919	5.8978000000000002	4.6837999999999997	3.9434999999999998	3.4883999999999999	3.0331999999999999	2.1229	1.6584000000000001	1.2634000000000001	0.92679999999999996	0.81689999999999996	0.70689999999999997	0.62319999999999998	0.54169999999999996	0.125	0.0040000002	16	99.763	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:17:45	151.40000000000001	20	0	40	129	1	0
10839	90	2009-11-10 00:00:00	1438	\N	2	3	55	\N	2009-11-10 07:00:00	2009-11-10 12:00:00	218	281.58953932113934	50.939999999999998	0.2	7	108	37	145	11.023	\N	\N	\N	12.813000000000001	156.06800000000001	\N	438.79999	\N	143.255	3.0630000000000002	0.92070001	\N	6.0094000000000003	0.077520000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.1869999999999998	1.1659999999999999	2.3849999999999998	3.1539999999999999	4.7923999999999998	3.6516999999999999	3.2435999999999998	2.7336	2.2235999999999998	1.7450000000000001	1.4182999999999999	1.0916999999999999	0.87849999999999995	0.79410000000000003	0.7097	0.6421	0.55330000000000001	0.125	0.003	16	99.922997	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:18:57	173.79999999999998	0	0	37	145	1	0
10849	86	2010-03-11 00:00:00	576	\N	2	3	64	\N	2010-03-11 07:00:00	2010-03-11 12:10:00	272	301.10564600676287	85.920000000000002	0.28999999	2	63	22	85	0.019	\N	\N	\N	-2.2229999999999999	108.116	\N	377.29999	\N	110.339	3.419	1.145	\N	9.7278000000000002	0.098629999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.7389999999999999	1.157	3.101	4.9450000000000003	6.4705000000000004	5.5115999999999996	4.9436	4.2337999999999996	3.5720000000000001	2.2957000000000001	1.6524000000000001	1.2	0.87009999999999998	0.75380000000000003	0.63739999999999997	0.57299999999999995	0.4642	0.125	0.15099999	10	99.242996	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:19:29	18.199999999999989	-14	0	22	85	1	0
10850	86	2010-03-22 00:00:00	576	\N	2	3	65	\N	2010-03-22 10:00:00	2010-03-22 14:00:00	358	420.99030136130739	86.790000000000006	0.28999999	6	70	21	91	1.383	\N	\N	\N	-3.5430000000000001	109.333	\N	474.29999	\N	112.877	4.202	1.2735	\N	11.9533	0.109331	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.8759999999999999	1.3939999999999999	2.4289999999999998	3.1469999999999998	8.7866	5.0980999999999996	3.8963999999999999	3.4563000000000001	3.0162	2.1360000000000001	1.7778	1.5148999999999999	1.2521	1.1207	0.98740000000000006	0.86399999999999999	0.67879999999999996	0.125	0.003	31.5	99.154999	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:19:04	18.199999999999989	-10	0	21	91	1	0
10852	82	2010-03-23 00:00:00	577	\N	2	3	61	\N	2010-03-23 07:30:00	2010-03-23 12:00:00	388	466.99255283456279	78.849999999999994	0.20999999	7	50	26	76	0.10199999999999999	\N	\N	\N	2.633	107.992	\N	493.89999	\N	105.35899999999999	4.6879999999999997	1.3564	\N	9.6582000000000008	0.098276000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	6.077	4.181	4.9509999999999996	3.9119999999999999	22.831099999999999	17.629799999999999	9.5243000000000002	5.5422000000000002	3.7103000000000002	2.1957	1.7415	1.4447000000000001	1.1478999999999999	0.99939999999999996	0.84379999999999999	0.71919999999999995	0.56120000000000003	0.25	0.107	16	82.120003	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:56:59	46.799999999999983	-34	0	26	76	1	0
10853	84	2010-03-24 00:00:00	579	\N	2	3	41	\N	2010-03-24 09:15:00	2010-03-24 14:00:00	476	616.15136821754254	76.989999999999995	0.22	7	64	63	127	5.25	\N	\N	\N	19.949000000000002	195.345	\N	705.70001	\N	175.39599999999999	4.024	1.2526	\N	8.6837	0.093186000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	9.8510000000000009	0.59399999999999997	4.6239999999999997	12.781000000000001	25.909099999999999	19.84	15.9101	13.7036	11.497199999999999	8.0434000000000001	5.5682	3.8001	2.1166999999999998	1.6369	1.2155	0.92779999999999996	0.62929999999999997	0.125	0.003	31.5	95.527	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:29:03	59.400000000000006	28	0	63	127	1	0
10854	85	2010-03-08 00:00:00	598	\N	2	3	51	\N	2010-03-08 12:30:00	2010-03-08 17:15:00	317	361.74497749423597	72.200000000000003	0.2	2.5	66	61	127	1.0429999999999999	\N	\N	\N	45.710000000000001	208.11799999999999	\N	409.10001	\N	162.40799999999999	2.5190000000000001	1.2687	\N	4.9417999999999997	0.070297999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5.9050000000000002	0.873	3.3580000000000001	7.6029999999999998	14.581	10.945499999999999	9.3315999999999999	7.9615999999999998	6.5915999999999997	4.7634999999999996	3.4887000000000001	2.569	1.7796000000000001	1.4905999999999999	1.2016	0.97050000000000003	0.62660000000000005	0.125	0.011	16	92.342003	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:48:51	76.599999999999994	41	0	61	127	1	0
10855	85	2010-03-25 00:00:00	598	\N	2	3	52	\N	2010-03-25 08:30:00	2010-03-25 14:05:00	489	646.12253205617867	73.719999999999999	0.22	7	66	62	128	21.811	\N	\N	\N	-10.676	241.339	\N	723.09998	\N	252.01599999999999	2.8690000000000002	1.2819	\N	6.1925999999999997	0.078692999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5.3730000000000002	0.81899999999999995	3.7610000000000001	7.4420000000000002	13.706099999999999	10.1279	8.7925000000000004	7.1976000000000004	5.9245999999999999	4.2072000000000003	2.9754999999999998	1.9027000000000001	1.3045	1.0053000000000001	0.84350000000000003	0.71599999999999997	0.56530000000000002	0.125	0.0049999999	31.5	99.804001	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:48:28	76.599999999999994	40	0	62	128	1	0
10856	88	2010-03-05 00:00:00	600	\N	2	3	60	\N	2010-03-05 06:00:00	2010-03-05 10:00:00	492	697.00381020084001	67.25	0.20999999	3	87	58	145	11.919	\N	\N	\N	33.677999999999997	217.87899999999999	\N	676.70001	\N	184.20099999999999	3.6739999999999999	1.4777	\N	7.5685000000000002	0.086997000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5.9580000000000002	0.73799999999999999	2.911	6.641	13.4938	10.476699999999999	9.3194999999999997	8.2047000000000008	7.0899000000000001	5.4717000000000002	4.1890000000000001	3.2082000000000002	2.2795999999999998	1.8617999999999999	1.5144	1.2364999999999999	0.82399999999999995	0.125	0.0080000004	16	94.984001	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:03:04	106.40000000000001	26	0	58	145	1	0
10857	88	2010-03-29 00:00:00	600	\N	2	3	61	\N	2010-03-29 09:00:00	2010-03-29 14:15:00	498	738.82403881289042	67.310000000000002	0.20999999	8.1999998	70	60	130	15.044	\N	\N	\N	33.677999999999997	217.87899999999999	\N	687.79999	\N	184.20099999999999	3.734	1.5412	\N	7.6920999999999999	0.087705000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.4199999999999999	0.92000000000000004	3.1320000000000001	5.5030000000000001	10.178800000000001	8.0378000000000007	6.6830999999999996	5.6771000000000003	4.8722000000000003	3.5834999999999999	2.6747999999999998	1.8720000000000001	1.3747	1.1261000000000001	0.93110000000000004	0.81910000000000005	0.6512	0.125	0.001	16	96.710999	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:02:56	106.40000000000001	26	0	60	130	1	0
10861	89	2010-03-30 00:00:00	185	\N	2	3	31	\N	2010-03-30 07:30:00	2010-03-30 12:00:00	500	752.76411501690723	60.670000000000002	0.22	8	88	44	132	8.5310000000000006	\N	\N	\N	32.941000000000003	218.75	\N	701.79999	\N	185.809	3.7770000000000001	1.539	\N	8.1511999999999993	0.090284000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.9180000000000001	0.85499999999999998	3.262	6.1299999999999999	6.6303000000000001	5.2805999999999997	4.5209000000000001	3.8001	3.3572000000000002	2.4716	1.7504999999999999	1.2166999999999999	0.78059999999999996	0.61760000000000004	0.55049999999999999	0.49640000000000001	0.4032	0.125	0.0060000001	16	99.065002	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:12:57	137.19999999999999	8	0	44	132	1	0
10860	89	2010-03-04 00:00:00	185	\N	2	3	30	\N	2010-03-04 07:00:00	2010-03-04 12:30:00	491	692.82178733963497	60.5	0.22	3	90	53	143	14.06	\N	\N	\N	33.645000000000003	217.935	\N	670.29999	\N	184.291	3.637	1.4829	\N	7.8498999999999999	0.088598999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.222	0.93999999999999995	2.524	4.4379999999999997	6.6707999999999998	5.4958999999999998	4.8846999999999996	4.1207000000000003	3.6951000000000001	2.9708000000000001	2.2465000000000002	1.7496	1.3700000000000001	1.1801999999999999	0.9919	0.8629	0.6694	0.125	0.0040000002	16	99.542999	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:13:03	137.19999999999999	8	0	53	143	1	0
10862	2800	2010-03-03 00:00:00	1055	\N	2	3	14	\N	2010-03-03 10:45:00	2010-03-03 14:15:00	489	680.97272256622068	57.880000000000003	0.20999999	2.5999999	83	38	121	14.861000000000001	\N	\N	\N	-19.975000000000001	196.51499999999999	\N	704.20001	\N	216.489	3.2530000000000001	1.3874	\N	6.7012999999999998	0.081861000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.4500000000000002	1.1739999999999999	2.4849999999999999	3.302	5.3891999999999998	3.8083999999999998	3.3742000000000001	2.8313999999999999	2.2886000000000002	1.752	1.4140999999999999	1.0763	0.86240000000000006	0.77349999999999997	0.68459999999999999	0.61670000000000003	0.53049999999999997	0.125	0.0049999999	16	99.166	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:16:27	150.99999999999997	0	0	38	121	1	0
10863	2800	2010-03-31 00:00:00	1055	\N	2	3	15	\N	2010-03-31 10:20:00	2010-03-31 13:30:00	497	731.85400071088202	58.060000000000002	0.20999999	\N	85	42	127	3.7690000000000001	\N	\N	\N	-21.158000000000001	197.327	\N	743.40002	\N	218.48500000000001	3.4020000000000001	1.4125	\N	7.0091999999999999	0.083721000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.1749999999999998	0.91100000000000003	2.532	4.5960000000000001	6.1642000000000001	4.7899000000000003	3.9632999999999998	3.6305999999999998	3.2978000000000001	2.6322999999999999	1.9814000000000001	1.6077999999999999	1.2342	1.0474000000000001	0.87790000000000001	0.747	0.57269999999999999	0.25	0.054000001	16	98.002998	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:16:21	150.99999999999997	0	0	42	127	1	0
10864	2801	2010-03-03 00:00:00	1056	\N	2	3	14	\N	2010-03-03 07:00:00	2010-03-03 10:40:00	447	724.88396260887362	57.799999999999997	0.20999999	2.5999999	88	35	123	18.129999999999999	\N	\N	\N	27.922000000000001	220.62899999999999	\N	769.29999	\N	192.70699999999999	3.992	1.3518	\N	8.2242999999999995	0.090688000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.5670000000000002	1.01	2.702	3.8719999999999999	5.6497999999999999	4.2093999999999996	3.7158000000000002	3.2614999999999998	2.8071999999999999	1.9549000000000001	1.5505	1.1462000000000001	0.85150000000000003	0.73529999999999995	0.62439999999999996	0.5766	0.50490000000000002	0.125	0.0049999999	16	99.272003	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:17:40	151.40000000000001	2	0	35	123	1	0
10865	2801	2010-03-31 00:00:00	1056	\N	2	3	15	\N	2010-03-31 07:00:00	2010-03-31 10:20:00	470	794.58434362895764	57.979999999999997	0.20999999	8.6000004	86	31	117	17.09	\N	\N	\N	27.530999999999999	221.03	\N	804.09998	\N	193.5	4.1550000000000002	1.4177999	\N	8.5606000000000009	0.092523999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.843	1.093	2.3999999999999999	3.5939999999999999	5.8925000000000001	4.5072999999999999	3.8578999999999999	3.4638	3.0697999999999999	2.2816000000000001	1.7964	1.4797	1.163	1.0045999999999999	0.88060000000000005	0.7823	0.63480000000000003	0.125	0.003	16	99.163002	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:17:36	151.40000000000001	2	0	31	117	1	0
11371	86	2011-07-19 00:00:00	576	\N	2	3	68	\N	2011-07-19 07:30:00	2011-07-19 13:10:00	137	146.37080014217639	84.700000000000003	0.30000001	21	47	37	84	0.058000000000000003	\N	\N	\N	0.85299999999999998	104.58499999999999	\N	246	\N	103.732	2.3719999999999999	0.85350001	\N	6.9806999999999997	0.083549999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.335	1.3600000000000001	1.9399999999999999	2.3450000000000002	2.5154000000000001	1.8019000000000001	1.6172	1.3864000000000001	1.1556	0.91879999999999995	0.7964	0.67390000000000005	0.58599999999999997	0.55159999999999998	0.51729999999999998	0.47849999999999998	0.39179999999999998	0.125	0.048999999	10	98.905998	5	0	1970-01-01 00:00:00	\N	2012-04-24 09:40:02	18.199999999999989	0	0	37	84	1	0
11372	82	2011-01-28 00:00:00	577	\N	2	3	62	\N	2011-01-28 09:00:00	2011-01-28 14:00:00	228	245.34534119069568	77.290000000000006	0.17	3	45	39	84	1.0349999999999999	\N	\N	\N	8.9499999999999993	101.44	\N	340.60001	\N	92.489999999999995	3.6819999999999999	1.0335	\N	6.1410999999999998	0.078365000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5.3019999999999996	0.92600000000000005	2.5760000000000001	4.391	11.685600000000001	9.0624000000000002	8.0307999999999993	6.7412999999999998	5.8992000000000004	4.6806000000000001	3.6568999999999998	2.8797000000000001	2.1025	1.8159000000000001	1.5659000000000001	1.3658999999999999	1.0659000000000001	0.125	0.0040000002	16	96.052002	5	0	1970-01-01 00:00:00	\N	2012-04-24 09:44:14	46.799999999999983	-30	0	39	84	1	0
11373	82	2011-03-08 00:00:00	577	\N	2	3	63	\N	2011-03-08 11:30:00	2011-03-08 15:00:00	197	209.79814687045285	76.950000000000003	0.2	3	55	33	88	0.016	\N	\N	\N	9.9380000000000006	99.998000000000005	\N	309.60001	\N	90.060000000000002	3.4369999999999998	0.97240001	\N	6.7436999999999996	0.082119999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.5249999999999999	1.5569999999999999	3.2890000000000001	4.6360000000000001	9.1827000000000005	7.3956	6.2255000000000003	5.0669000000000004	3.9453	2.5615999999999999	1.8024	1.4698	1.1373	0.97209999999999996	0.81189999999999996	0.68379999999999996	0.55259999999999998	0.125	0.168	16	99.884003	5	0	1970-01-01 00:00:00	\N	2012-04-24 09:46:55	46.799999999999983	-30	0	33	88	1	0
11374	82	2011-07-06 00:00:00	577	\N	2	3	64	\N	2011-07-06 08:00:00	2011-07-06 11:20:00	131	140.09776585036883	76.290000000000006	0.2	18	59	31	90	0.019	\N	\N	\N	11.856	97.221999999999994	\N	251.7	\N	85.366	2.948	0.79869998	\N	5.7842000000000002	0.076053999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.93899999999999995	1.3140000000000001	1.7210000000000001	2.1190000000000002	1.7081	1.3507	1.1123000000000001	0.96509999999999996	0.90900000000000003	0.79690000000000005	0.68479999999999996	0.60419999999999996	0.55389999999999995	0.52869999999999995	0.50349999999999995	0.45610000000000001	0.37609999999999999	0.125	0.213	6.2999999999999998	99.385002	5	0	1970-01-01 00:00:00	\N	2012-04-24 09:50:06	46.799999999999983	14	0	31	90	1	0
11375	82	2011-07-21 00:00:00	577	\N	2	3	65	\N	2011-07-21 07:30:00	2011-07-21 12:45:00	143	151.94683062378311	76.400000000000006	0.20999999	20	43	41	84	0.021999999999999999	\N	\N	\N	11.536	97.665999999999997	\N	261.10001	\N	86.129999999999995	3.0310000000000001	0.83490002	\N	6.2450999999999999	0.079025999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.0529999999999999	1.2250000000000001	1.7769999999999999	2.1779999999999999	1.8314999999999999	1.6296999999999999	1.4951000000000001	1.3269	1.1587000000000001	0.94079999999999997	0.82879999999999998	0.71679999999999999	0.61429999999999996	0.57920000000000005	0.54420000000000002	0.51619999999999999	0.43190000000000001	0.125	0.059999999	6.2999999999999998	99.588997	5	0	1970-01-01 00:00:00	\N	2012-04-24 09:54:25	46.799999999999983	-30	0	41	84	1	0
11376	84	2011-02-25 00:00:00	579	\N	2	3	42	\N	2011-02-25 07:00:00	2011-02-25 09:45:00	264	290.65058885375026	75.109999999999999	0.2	1	36	71	107	0.628	\N	\N	\N	28.495999999999999	151.08000000000001	\N	398.29999	\N	122.584	3.2490000000000001	1.0470001	\N	6.3747999999999996	0.079842999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5.0659999999999998	0.96099999999999997	3.9540000000000002	7.5679999999999996	12.846399999999999	9.6571999999999996	8.3690999999999995	6.7590000000000003	5.6238000000000001	3.8129	2.4916999999999998	1.7019	1.2270000000000001	0.99050000000000005	0.77449999999999997	0.61760000000000004	0.50380000000000003	0.125	0.0099999998	31.5	99.32	5	0	1970-01-01 00:00:00	\N	2012-04-24 10:05:01	59.400000000000006	41	0	71	107	1	0
11377	84	2011-03-09 00:00:00	579	\N	2	3	43	\N	2011-03-09 08:00:00	2011-03-09 14:00:00	194	206.31312781944865	74.420000000000002	0.2	3	43	69	112	3.8079999999999998	\N	\N	\N	36.676000000000002	147.63	\N	317.70001	\N	110.95399999999999	2.8639999999999999	0.93159997	\N	5.6182999999999996	0.074955999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.2280000000000002	1.379	2.407	2.887	4.5423999999999998	3.3578999999999999	2.8288000000000002	2.1675	1.8722000000000001	1.5301	1.1879	0.92549999999999999	0.76019999999999999	0.67759999999999998	0.61250000000000004	0.57950000000000002	0.53010000000000002	0.125	0.012	31.5	99.960999	5	0	1970-01-01 00:00:00	\N	2012-04-24 12:11:47	59.400000000000006	41	0	69	112	1	0
11378	84	2011-07-05 00:00:00	579	\N	2	3	44	\N	2011-07-05 09:20:00	2011-07-05 13:10:00	126	135.21873917896295	73.620000000000005	0.20999999	18	49	68	117	0.86799999999999999	\N	\N	\N	46.161000000000001	143.63	\N	234.39999	\N	97.468999999999994	2.4039999999999999	0.82779998	\N	4.9532999999999996	0.070379999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.4219999999999999	1.2569999999999999	1.9319999999999999	2.4279999999999999	2.9655	1.9252	1.7762	1.5899000000000001	1.4036	1.0310999999999999	0.88849999999999996	0.76690000000000003	0.64529999999999998	0.59640000000000004	0.55149999999999999	0.51559999999999995	0.42470000000000002	0.125	0.016000001	16	99.884003	5	0	1970-01-01 00:00:00	\N	2012-04-24 12:17:48	59.400000000000006	47	0	68	117	1	0
11379	84	2011-07-20 00:00:00	579	\N	2	3	45	\N	2011-07-20 09:00:00	2011-07-20 12:12:00	131	140.09776585036883	73.719999999999999	0.2	21.5	43	70	113	0.97599999999999998	\N	\N	\N	44.975000000000001	144.13	\N	244.2	\N	99.155000000000001	2.4630000000000001	0.82309997	\N	4.8318000000000003	0.069511000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.7210000000000001	1.089	2.0870000000000002	2.9569999999999999	3.3734000000000002	2.4100999999999999	1.9589000000000001	1.8169	1.6748000000000001	1.3907	1.1065	0.90190000000000003	0.745	0.66649999999999998	0.59930000000000005	0.55349999999999999	0.47020000000000001	0.125	0.0049999999	16	99.758003	5	0	1970-01-01 00:00:00	\N	2012-04-24 12:20:30	59.400000000000006	46	0	70	113	1	0
11381	85	2011-01-18 00:00:00	598	\N	2	3	53	\N	2011-01-18 11:30:00	2011-01-18 14:30:00	739	1575.2286110538985	75.260000000000005	0.23999999	4	67	88	155	2.6989999999999998	\N	\N	\N	-24.152000000000001	242.09399999999999	\N	1129.2	\N	266.24599999999998	4.2409999999999997	2.0014	\N	9.9854000000000003	0.099927000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	9.4250000000000007	0.93300000000000005	3.8730000000000002	8.4689999999999994	24.007999999999999	17.3931	14.7493	12.4641	10.178900000000001	6.7011000000000003	4.6500000000000004	3.2906	2.2027000000000001	1.7827999999999999	1.4366000000000001	1.1596	0.7913	0.125	0.0099999998	63	98.545998	5	0	1970-01-01 00:00:00	\N	2012-04-24 12:34:03	76.599999999999994	0	0	88	155	1	0
11382	85	2011-02-24 00:00:00	598	\N	2	3	54	\N	2011-02-24 09:00:00	2011-02-24 13:00:00	273	302.49965362716455	71.790000000000006	0.2	0	43	76	119	1.1399999999999999	\N	\N	\N	47.350000000000001	142.53999999999999	\N	361.5	\N	95.189999999999998	3.798	1.2005	\N	7.4513999999999996	0.086321999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.8820000000000001	1.5640000000000001	2.4249999999999998	3.383	8.7104999999999997	5.9718	5.1952999999999996	4.2245999999999997	3.6619999999999999	2.7826	1.9691000000000001	1.6887000000000001	1.4081999999999999	1.268	1.1276999999999999	1.0155000000000001	0.82240000000000002	0.125	0.029999999	31.5	99.606003	5	0	1970-01-01 00:00:00	\N	2012-04-24 12:38:31	76.599999999999994	44	0	76	119	1	0
11383	85	2011-03-10 00:00:00	598	\N	2	3	55	\N	2011-03-10 07:00:00	2011-03-10 12:30:00	188	199.34308971744025	70.849999999999994	0.19	4	46	74	120	1.103	\N	\N	\N	51.109999999999999	137.84	\N	276	\N	86.730000000000004	3.1819999999999999	1.0362	\N	5.9318	0.077018000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.306	1.161	2.016	2.544	4.1260000000000003	3.3936000000000002	2.9683999999999999	2.4367999999999999	1.9813000000000001	1.7719	1.5624	1.353	1.1435999999999999	1.0387999999999999	0.9274	0.83509999999999995	0.6966	0.125	0.0020000001	16	99.357002	5	0	1970-01-01 00:00:00	\N	2012-04-24 12:43:58	76.599999999999994	44	0	74	120	1	0
1890	82	1994-05-03 00:00:00	178	\N	2	5	4	\N	1994-05-03 09:45:00	1994-05-03 14:00:00	291	316.43972983118135	77.810000000000002	0.2	\N	40	26	66	0.114	\N	\N	\N	7.4160000000000004	103.637	\N	373	\N	96.221999999999994	3.8759999999999999	1.2173001	\N	7.6048999999999998	0.087206000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	6.4379999999999997	1.0469999999999999	4.6989999999999998	8.827	17.0321	12.7834	9.9779999999999998	8.3877000000000006	6.8620999999999999	4.5282999999999998	2.6589999999999998	1.4741	0.88270000000000004	0.74770000000000003	0.62290000000000001	0.57899999999999996	0.51300000000000001	0.125	0.0049999999	31.5	94.191002	7	0	2003-04-01 00:00:00	\N	2011-12-01 02:27:39	46.599999999999994	0	0	26	66	1	1
1891	82	1994-05-19 00:00:00	178	\N	2	5	5	\N	1994-05-19 07:00:00	\N	172	168.67492206860328	76.620000000000005	0.2	\N	53.460000000000001	27.539999999999999	81	0.027	\N	\N	\N	10.897	98.599000000000004	\N	263.5	\N	87.701999999999998	3.0049999999999999	0.91829997	\N	5.8956999999999997	0.076783000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.85599999999999998	1.0329999999999999	1.6040000000000001	2.1469999999999998	1.5215000000000001	1.1066	0.97570000000000001	0.92620000000000002	0.87670000000000003	0.77780000000000005	0.67879999999999996	0.60129999999999995	0.54449999999999998	0.5161	0.47549999999999998	0.43030000000000002	0.36230000000000001	0.25	0.079999998	8	99.788002	6	0	2003-06-05 00:00:00	\N	2011-12-01 02:27:18	46.599999999999994	0	0	27.539999999999999	81	1	1
1892	82	1994-11-22 00:00:00	577	\N	2	5	6	\N	1994-11-22 10:00:00	1994-11-22 12:20:00	169	165.88690682779992	76.590000000000003	0.2	\N	22	34	56	0.017999999999999999	\N	\N	\N	10.984	98.471000000000004	\N	277.60001	\N	87.486999999999995	3.173	0.8574	\N	6.2252999999999998	0.078900999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.82099999999999995	1.091	1.6659999999999999	1.97	1.5019	0.99280000000000002	0.9294	0.85019999999999996	0.77100000000000002	0.62409999999999999	0.57050000000000001	0.51680000000000004	0.45319999999999999	0.41909999999999997	0.38500000000000001	0.35770000000000002	0.31680000000000003	0.25	0.212	8	99.822998	12	0	2003-04-01 00:00:00	Messung an km 155.247 wegen Baufahrzeug	2011-12-01 02:26:43	46.847000000000008	0	0	34	56	1	1
1893	82	1995-01-11 00:00:00	178	\N	2	5	7	\N	1995-01-11 09:15:00	1995-01-11 13:45:00	223	227.22324212547383	77.129999999999995	0.2	\N	0	0	0	\N	\N	\N	\N	9.4149999999999991	100.761	\N	309.20001	\N	91.346999999999994	3.3849999999999998	1.0544	\N	6.6410999999999998	0.081492999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	7	0	2003-04-01 00:00:00	\N	2011-12-01 11:25:27	46.599999999999994	0	0	0	0	1	1
1894	82	1995-01-12 00:00:00	178	\N	2	\N	8	\N	1995-01-12 09:20:00	1995-01-12 12:45:00	226	230.70826117647803	77.159999999999997	0.2	\N	41	36	77	0.002	\N	\N	\N	9.3279999999999994	100.889	\N	311.89999	\N	91.561000000000007	3.407	1.0611	\N	6.6843000000000004	0.081757999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	8	0	2003-04-01 00:00:00	\N	2011-12-01 02:25:51	46.599999999999994	0	0	36	77	1	1
2132	90	2003-04-15 00:00:00	1438	\N	3	3	30	WEL275-030	2003-04-15 09:00:00	2003-04-15 14:00:00	214	266.95245930692175	50.93	0.19	\N	107.40000000000001	37.369999999999997	144.77000000000001	0.46200000000000002	\N	\N	\N	12.849	156.03100000000001	\N	437.29999	\N	143.18199999999999	3.0539999999999998	0.8757	\N	5.6932	0.075453000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.0529999999999999	1.583	2.032	2.0099999999999998	1.9792000000000001	1.4473	1.0927	0.92000000000000004	0.81879999999999997	0.626	0.56599999999999995	0.50609999999999999	0.44159999999999999	0.40910000000000002	0.3765	0.35049999999999998	0.3115	0.125	0.0080000004	10	99.454002	5	0	2003-12-11 00:00:00	\N	2011-12-01 03:21:43	173.79999999999998	0	0	37.369999999999997	144.77000000000001	1	1
2133	90	2003-10-22 00:00:00	1438	\N	2	3	31	WEL275-031	2003-10-22 08:45:00	2003-10-22 12:00:00	88	126.15768964635204	49.630000000000003	0.2	7.5999999	101.13	46.109999999999999	147.24000000000001	1.5029999999999999	0.33200000000000002	3.9569999999999999	21.859999999999999	17.998999999999999	150.221	212.23599999999999	257.60001	\N	132.22200000000001	1.948	0.70270002	0.63450003	3.8220000000000001	0.061822000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.839	1.1910000000000001	2.3500000000000001	3.0390000000000001	3.887	3.1943999999999999	2.7326999999999999	2.1556000000000002	1.8835999999999999	1.5648	1.246	0.96060000000000001	0.78820000000000001	0.70199999999999996	0.62119999999999997	0.57869999999999999	0.51490000000000002	0.125	0.0049999999	10	99.512001	5	5	2004-06-23 00:00:00	\N	2011-12-01 03:21:28	173.79999999999998	0	0	46.109999999999999	147.24000000000001	1	1
1945	84	1996-10-15 00:00:00	180	\N	2	5	5	\N	1996-10-15 09:30:00	1996-10-15 14:30:00	152	134.52173536876211	73.909999999999997	0.20999999	\N	49	85	134	0.59499999999999997	0.78700000000000003	4.4290000000000003	22.949999999999999	58.479999999999997	145.08000000000001	189.637	247.5	\N	86.599999999999994	2.8570000000000002	0.77990001	0.50889999	5.8865999999999996	0.076724000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.3460000000000001	2.73	3.04	2.6949999999999998	7.3775000000000004	3.7555000000000001	2.4737	1.7662	1.4342999999999999	0.93520000000000003	0.74770000000000003	0.60350000000000004	0.53220000000000001	0.49519999999999997	0.44579999999999997	0.40629999999999999	0.34699999999999998	0.25	0.17399999	20	99.615997	6	5	2003-04-02 00:00:00	\N	2011-12-01 02:45:27	59.400000000000006	0	0	85	134	1	1
1946	84	1998-04-06 00:00:00	180	\N	2	5	7	\N	1998-04-06 09:00:00	1998-04-06 14:30:00	221	218.85919640306378	74.620000000000005	0.2	9	40.170000000000002	85.829999999999998	126	0.56100000000000005	1.429	1.429	4.5499999999999998	55.034999999999997	148.63	271.99700000000001	311.39999	\N	93.594999999999999	3.327	1.0082999	0.53719997	6.5282999999999998	0.080797999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.347	3.7360000000000002	3.702	3.5619999999999998	9.8978999999999999	7.0343999999999998	5.2595000000000001	3.5156000000000001	2.2408000000000001	1.4970000000000001	0.98319999999999996	0.82330000000000003	0.66339999999999999	0.60150000000000003	0.55249999999999999	0.51329999999999998	0.42030000000000001	0.25	0.090999998	20	98.727997	5	5	2003-04-02 00:00:00	\N	2011-12-01 02:44:42	59.400000000000006	0	0	85.829999999999998	126	1	1
1947	84	1998-05-07 00:00:00	180	\N	2	5	8	\N	1998-05-07 10:00:00	1998-05-07 13:45:00	131	115.0056286831386	73.700000000000003	0.20999999	12	30	93	123	0.014	0.84399999999999997	3.5089999999999999	21.265999999999998	59.499000000000002	144.03	132.602	229.5	\N	84.531000000000006	2.7149999999999999	0.71899998	0.4111	5.5928000000000004	0.074785000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.53100000000000003	1.0149999999999999	1.4179999999999999	1.6459999999999999	0.75329999999999997	0.59440000000000004	0.55779999999999996	0.51200000000000001	0.4869	0.45150000000000001	0.41599999999999998	0.38059999999999999	0.34510000000000002	0.32740000000000002	0.30969999999999998	0.29549999999999998	0.27429999999999999	0.125	0.52600002	4	99.473999	5	4	2003-04-02 00:00:00	\N	2011-12-01 02:44:06	59.400000000000006	0	0	93	123	1	1
9653	86	2009-03-11 00:00:00	576	\N	2	3	60	\N	2009-03-11 10:30:00	2009-03-11 15:30:00	503	680.27571875601984	87.980000000000004	0.28	5	70	21	91	0.27800000000000002	5.9870000000000001	22.315000000000001	22.864000000000001	-5.6210000000000004	111.354	951.92899999999997	611	\N	116.97499999999999	5.2240000000000002	1.5973001	0.86559999	14.348100000000001	0.119784	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	12.141	0.38500000000000001	4.2460000000000004	15.661	27.462599999999998	25.040099999999999	23.4251	21.406400000000001	19.387699999999999	15.071099999999999	9.5058000000000007	5.4802	2.9302000000000001	2.0626000000000002	1.6718	1.3888	0.96230000000000004	0.25	0.071999997	16	61.609001	5	5	1970-01-01 00:00:00	\N	2011-12-01 01:22:45	18.199999999999989	-14	-14	21	91	1	1
9655	82	2009-03-10 00:00:00	577	\N	2	3	56	\N	2009-03-10 11:00:00	2009-03-10 15:30:00	526	738.82403881289042	80.230000000000004	0.20999999	5	46	38	84	0.16800000000000001	13.617000000000001	40.862000000000002	38.548999999999999	-10.879	180.482	1636.99	676.5	\N	191.36099999999999	3.5350000000000001	1.5669	0.7687	7.2828999999999997	0.085339999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	8.9760000000000009	1.47	3.6389999999999998	5.8849999999999998	24.421399999999998	20.174199999999999	17.3428	14.4786	12.027200000000001	7.3920000000000003	4.5715000000000003	3.2783000000000002	2.3167	1.9239999999999999	1.7014	1.5232000000000001	1.2561	0.125	0.0099999998	16	78.102997	5	3	1970-01-01 00:00:00	\N	2011-12-01 01:59:40	46.799999999999983	-30	-30	38	84	1	1
9657	90	2009-03-02 00:00:00	1438	\N	2	3	53	\N	2009-03-02 09:30:00	2009-03-02 15:45:00	376	565.2700900728812	52.57	0.19	4	104	44	148	13.08	13.9	38.726999999999997	47.752000000000002	3.5750000000000002	207.17699999999999	953.41499999999996	726.09998	\N	203.602	3.5659999999999998	1.1169	0.50260001	6.6471999999999998	0.081531000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.3490000000000002	1.1839999999999999	2.5350000000000001	3.379	5.4116999999999997	3.8963000000000001	3.4748999999999999	2.9481000000000002	2.4214000000000002	1.7797000000000001	1.4127000000000001	1.0456000000000001	0.84570000000000001	0.75749999999999995	0.6694	0.60650000000000004	0.52680000000000005	0.063	0.001	16	99.696999	6	5	1970-01-01 00:00:00	\N	2011-12-01 03:19:03	173.79999999999998	8	8	44	148	1	1
9658	89	2009-03-04 00:00:00	185	\N	2	3	27	\N	2009-03-04 07:30:00	2009-03-04 12:15:00	443	541.57196052605264	60.07	0.22	5.5	85	62	147	10.724	27.039999999999999	54.186999999999998	69.738	35.423999999999999	215.334	740.01199999999994	592	\N	179.90899999999999	3.2909999999999999	1.3125	0.53439999	7.1017000000000001	0.084272	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.7549999999999999	0.84099999999999997	2.907	5.2590000000000003	5.9363999999999999	5.0632000000000001	4.4812000000000003	3.8618999999999999	3.4542999999999999	2.6389999999999998	1.8999999999999999	1.4372	0.9839	0.83779999999999999	0.69169999999999998	0.59930000000000005	0.50190000000000001	0.125	0.0089999996	16	99.864998	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:13:18	137.19999999999999	16	16	62	147	1	1
9659	85	2009-03-09 00:00:00	598	\N	2	3	47	\N	2009-03-09 13:00:00	2009-03-09 18:10:00	545	787.61430552694924	74.180000000000007	0.23	5	45	85	130	9.5839999999999996	9.5470000000000006	112.26300000000001	99.347999999999999	-21.327000000000002	242.09399999999999	1539.396	841.79999	\N	263.42099999999999	3.1960000000000002	1.3423001	0.3373	7.2104999999999997	0.084914000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	7.0750000000000002	1.1799999999999999	3.4049999999999998	6.101	18.252099999999999	13.8698	11.9472	9.6679999999999993	7.9188000000000001	5.3276000000000003	3.7494999999999998	2.8090000000000002	1.927	1.6658999999999999	1.4048	1.196	0.87329999999999997	0.125	0.0040000002	31.5	99.223999	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:49:51	76.599999999999994	-10	-10	85	130	1	1
1887	82	1992-11-20 00:00:00	178	\N	\N	\N	1	\N	\N	\N	101	100.36854866892097	75.909999999999997	0.2	\N	\N	\N	\N	\N	\N	\N	\N	12.632999999999999	96.040000000000006	\N	202.89999	\N	83.406999999999996	2.4329999999999998	0.70959997	\N	4.7733999999999996	0.069089999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0	2003-06-05 00:00:00	\N	2011-12-01 02:28:57	46.599999999999994	0	0	\N	\N	1	1
1888	82	1993-04-19 00:00:00	178	\N	2	14	2	\N	1993-04-19 09:00:00	1993-04-19 13:00:00	186	184.00900589302177	76.760000000000005	0.2	\N	55	15	70	0.031	\N	\N	\N	10.49	99.191999999999993	\N	275.89999	\N	88.701999999999998	3.1099999999999999	0.9569	\N	6.1022999999999996	0.078117000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.4849999999999999	1.0860000000000001	3.9609999999999999	6.9029999999999996	9.3659999999999997	6.7973999999999997	5.7606000000000002	4.6673999999999998	3.7494999999999998	2.4630000000000001	1.6464000000000001	1.0940000000000001	0.60809999999999997	0.54630000000000001	0.48409999999999997	0.43319999999999997	0.35680000000000001	0.063	0.296	10	91.065002	5	0	2003-06-05 00:00:00	\N	2011-12-01 02:28:49	46.599999999999994	0	0	15	70	1	1
1889	82	1994-01-11 00:00:00	178	\N	2	5	3	\N	1994-01-11 07:30:00	1994-01-11 13:40:00	415	535.99593004444591	79.049999999999997	0.2	\N	70.109999999999999	8	78.109999999999999	1.486	\N	\N	\N	0.67500000000000004	108.82899999999999	\N	498.60001	\N	108.155	4.6100000000000003	1.5423	\N	9.0451999999999995	0.095105999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	8.2230000000000008	1.03	2.9950000000000001	5.0970000000000004	19.0151	15.646100000000001	13.4001	10.592499999999999	8.8582000000000001	6.6269999999999998	5.1458000000000004	3.8439999999999999	2.9460000000000002	2.4969999999999999	2.048	1.7438	1.3002	0.125	0.0080000004	40	98.084999	10	0	2003-04-01 00:00:00	\N	2011-12-01 02:28:10	46.599999999999994	0	0	8	78.109999999999999	1	1
1910	82	1997-03-11 00:00:00	178	\N	\N	\N	20	\N	1997-03-11 09:00:00	1997-03-11 14:00:00	341	389.62512990226958	78.709999999999994	0.20999999	6	\N	\N	\N	\N	2.77	18.422000000000001	32.954999999999998	4.056	107.40600000000001	518.75800000000004	462.70001	\N	103.349	4.4770000000000003	1.2082	0.602	9.2222000000000008	0.096032999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	2003-06-05 00:00:00	Peilung von km 155,0 verwendet; Protokolle fï¿½r Geschiebemesung nicht vorliegend Messung km 153.6	2011-12-01 02:18:20	45.199999999999989	0	0	\N	\N	1	1
1911	82	1999-04-08 00:00:00	178	\N	\N	\N	25	WEL155-025	1999-04-08 10:00:00	1999-04-08 14:00:00	303	333.16782127600152	78.25	0.20999999	10	\N	\N	\N	\N	2.48	25.902000000000001	54.188000000000002	5.9050000000000002	105.48	224.34200000000001	416	\N	99.575000000000003	4.1779999999999999	1.1489	0.3687	8.6074000000000002	0.092775999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1	2003-06-05 00:00:00	Peilung von km 155,0 verwendet; Sondermessung, keine Geschiebemessung	2011-12-01 02:16:15	45.599999999999994	0	0	\N	\N	1	1
2127	90	2002-04-10 00:00:00	1438	\N	3	3	26	WEL275-026	2002-04-10 10:00:00	2002-04-10 12:00:00	309	425.17232422251243	51.859999999999999	0.2	8	106.29000000000001	24.710000000000001	131	3.4860000000000002	\N	\N	\N	8.2940000000000005	159.45099999999999	\N	573.90002	\N	151.15700000000001	3.7970000000000002	1.0628999	\N	7.4490999999999996	0.086307999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.9820000000000002	0.94499999999999995	2.5960000000000001	4.4690000000000003	6.1379000000000001	4.8910999999999998	4.0598999999999998	3.6654	3.3102999999999998	2.6002000000000001	1.9381999999999999	1.5392999999999999	1.1403000000000001	0.96120000000000005	0.83040000000000003	0.72570000000000001	0.58179999999999998	0.25	0.071999997	16	99.015999	5	0	2003-07-16 00:00:00	\N	2011-12-01 03:22:09	173.79999999999998	0	0	24.710000000000001	131	1	1
2128	90	1997-02-27 00:00:00	186	\N	\N	\N	11	WEL275-011	1997-02-27 09:30:00	1997-02-27 14:00:00	381	564.57308626268036	54	0.17	5	\N	\N	\N	\N	9.3580000000000005	47.716000000000001	58.908000000000001	2.0499999999999998	402.88799999999998	1613.7550000000001	1063.1	\N	400.83800000000002	2.6520000000000001	0.76190001	0.55830002	4.4229000000000003	0.066504999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	2004-05-06 00:00:00	\N	2011-12-01 03:24:05	166.59999999999999	0	0	\N	\N	1	1
2129	90	2002-09-18 00:00:00	1438	\N	3	\N	27	WEL275-027	2002-09-18 08:45:00	2002-09-18 13:00:00	249	315.04572221077967	51.240000000000002	0.2	17.4	115.92	21.079999999999998	137	1.373	\N	\N	\N	11.721	157.17099999999999	\N	482.10001	\N	145.44999999999999	3.3140000000000001	0.93760002	\N	6.5027999999999997	0.080640000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	0	2004-05-06 00:00:00	\N	2011-12-01 03:22:05	173.79999999999998	0	0	21.079999999999998	137	1	1
2130	90	2002-10-23 00:00:00	1438	\N	3	\N	28	WEL275-028	2002-10-23 09:15:00	2002-10-23 12:45:00	360	530.4198995628393	52.32	0.2	12.3	111.89	26.57	138.46000000000001	2.1349999999999998	4.6399999999999997	27.489000000000001	36.122	5.2359999999999998	200.99199999999999	908.49300000000005	676.40002	\N	195.755	3.4550000000000001	1.1251	0.5905	6.7792000000000003	0.082336000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	5	5	2004-05-06 00:00:00	\N	2011-12-01 03:21:58	173.79999999999998	0	0	26.57	138.46000000000001	1	1
2131	90	2003-03-06 00:00:00	1438	\N	3	3	29	WEL275-029	2003-03-06 09:00:00	2003-03-06 13:30:00	266	342.22887080861244	51.530000000000001	0.18000001	\N	92.959999999999994	46.039999999999999	139	1.331	2.3359999999999999	11.835000000000001	24.103999999999999	10.488	158.23699999999999	526.29399999999998	524.59998	\N	147.75	3.5499999999999998	0.93599999	0.5381	6.2693000000000003	0.079178999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.83099999999999996	1.238	1.9450000000000001	2.4319999999999999	1.5943000000000001	0.97109999999999996	0.84550000000000003	0.6885	0.60099999999999998	0.50849999999999995	0.44869999999999999	0.39219999999999999	0.3357	0.3075	0.27929999999999999	0.25669999999999998	0.20910000000000001	0.125	0.078000002	10	99.371002	6	5	2003-12-15 00:00:00	\N	2011-12-01 03:21:48	173.79999999999998	0	0	46.039999999999999	139	1	1
1942	84	1995-04-27 00:00:00	180	\N	2	5	1	\N	1995-04-27 10:40:00	1995-04-27 15:40:00	378	474.65959474677203	76.079999999999998	0.2	12	70.450000000000003	82.129999999999995	152.58000000000001	0.10299999999999999	1.984	30.707000000000001	45.091000000000001	47.951000000000001	184.20099999999999	635.58299999999997	480.5	\N	136.249	3.5270000000000001	1.4172	0.5169	6.9196999999999997	0.083184999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	6.0060000000000002	0.83099999999999996	3.5630000000000002	10.462999999999999	15.4954	12.7927	10.9908	9.1270000000000007	7.6497000000000002	5.5366999999999997	3.9378000000000002	2.9201999999999999	1.9365000000000001	1.6047	1.2729999999999999	1.0076000000000001	0.5292	0.5	9.0629997	10	77.800003	4	4	2003-04-02 00:00:00	\N	2011-12-01 02:48:17	59.449999999999989	0	0	82.129999999999995	152.58000000000001	1	1
1943	84	1995-07-10 00:00:00	180	\N	2	5	2	\N	1995-07-10 11:00:00	1995-07-10 14:30:00	224	223.04121926426882	74.590000000000003	0.2	\N	46	75	121	0.091999999999999998	0.95199999999999996	12.640000000000001	39.499000000000002	55.180999999999997	148.47999999999999	322.226	308.60001	\N	93.299000000000007	3.3079999999999998	1.0369	0.70490003	6.4900000000000002	0.080560999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.399	1.9199999999999999	2.5369999999999999	2.73	6.3056999999999999	4.1760000000000002	3.2437	2.1644999999999999	1.8580000000000001	1.5228999999999999	1.1878	0.9456	0.82189999999999996	0.76000000000000001	0.69810000000000005	0.64859999999999995	0.55789999999999995	0.5	6.3959999	10	96.885002	6	4	2003-04-02 00:00:00	\N	2011-12-01 02:47:39	59.400000000000006	0	0	75	121	1	1
1944	84	1996-07-11 00:00:00	180	\N	2	5	4	\N	1996-07-11 08:00:00	1996-07-11 14:15:00	400	515.78281954862166	76.239999999999995	0.22	15	61.520000000000003	80	141.52000000000001	5.2279999999999998	14.246	94.265000000000001	127.386	47.174999999999997	184.636	750.27099999999996	502.39999	\N	137.46100000000001	3.6549999999999998	1.4728	0.79360002	7.8883999999999999	0.088816999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	9.2449999999999992	0.34599999999999997	4.8819999999999997	19.460999999999999	22.4056	18.4879	16.872900000000001	14.854100000000001	12.8353	9.1957000000000004	6.4386999999999999	4.2417999999999996	2.4967999999999999	1.7753000000000001	1.2310000000000001	0.77580000000000005	0.47249999999999998	0.25	0.15800001	31.5	98.525002	6	5	2003-04-02 00:00:00	\N	2011-12-01 02:46:18	59.400000000000006	0	0	80	141.52000000000001	1	1
2017	86	1997-03-13 00:00:00	182	\N	\N	\N	17	\N	1997-03-13 09:00:00	1997-03-13 13:30:00	322	374.98804988805193	86.290000000000006	0.28999999	7	\N	\N	\N	\N	2.3849999999999998	12.967000000000001	24.103000000000002	0.19	111.345	463.322	398.39999	\N	111.154	3.585	1.3503	0.60170001	10.197699999999999	0.100984	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	2003-06-05 00:00:00	kein Geschiebe gemessen (?) - Protokoll oder Auswertung liegen nicht vor	2011-12-01 01:46:33	18.199999999999989	0	0	\N	\N	1	1
2018	86	1997-06-03 00:00:00	182	\N	\N	\N	25	\N	1997-06-03 09:00:00	1997-06-03 12:30:00	174	156.825857295189	84.989999999999995	0.28999999	14	\N	\N	\N	\N	0.71999999999999997	6.4619999999999997	28.719000000000001	2.5800000000000001	108.44799999999999	214.75299999999999	256.60001	\N	105.86799999999999	2.4239999999999999	0.8768	0.56260002	6.8958000000000004	0.083041000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	2003-04-02 00:00:00	\N	2011-12-01 01:44:05	18.199999999999989	0	0	\N	\N	1	1
2019	86	1998-10-14 00:00:00	182	\N	\N	\N	30	WEL127-030	1998-10-14 09:00:00	1998-10-14 16:30:00	211	204.91912019904697	85.450000000000003	0.30000001	11	\N	\N	\N	\N	1.2609999999999999	1.2609999999999999	4.2880000000000003	1.1839999999999999	109.699	272.54199999999997	306	\N	108.51600000000001	2.8199999999999998	0.96069998	0.52130002	8.2998999999999992	0.091104000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	9	2003-06-05 00:00:00	Sondermessung; keine getrennte Messung von Feinschwebstoff; keine Geschiebemessung	2011-12-01 01:41:07	18.199999999999989	0	0	\N	\N	1	1
2020	86	1998-10-15 00:00:00	182	\N	\N	\N	31	WEL127-031	1998-10-15 09:00:00	1998-10-15 12:00:00	239	243.951333570294	85.719999999999999	0.30000001	11	\N	\N	\N	\N	1.9330000000000001	1.9330000000000001	5.524	0.86899999999999999	110.434	353.30900000000003	335.5	\N	109.56399999999999	3.0619999999999998	1.0433	0.597	9.0113000000000003	0.094927999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	9	2003-06-05 00:00:00	Sondermessung; keine getrennte Messung von Feinschwebstoff; keine Geschiebemessung	2011-12-01 01:40:12	18.199999999999989	0	0	\N	\N	1	1
2055	88	1994-04-28 00:00:00	184	\N	2	5	1	\N	1994-04-28 09:30:00	1994-04-28 13:00:00	398	422.38430898170907	66.310000000000002	0.20999999	\N	73.760000000000005	68	141.75999999999999	3.1160000000000001	\N	\N	\N	40.875	204.97800000000001	\N	511	\N	164.102	3.1139999999999999	1.1859	\N	6.4149000000000003	0.080092999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.718	0.70699999999999996	3.7440000000000002	7.173	12.6897	8.6766000000000005	7.3037999999999998	6.0214999999999996	5.1026999999999996	3.6446999999999998	2.7564000000000002	1.9106000000000001	1.3091999999999999	1.0085	0.78220000000000001	0.61890000000000001	0.5081	0.125	0.0020000001	20	97.889999	9	0	2003-06-05 00:00:00	\N	2011-12-01 03:12:47	106.40000000000001	0	0	68	141.75999999999999	1	1
2056	88	1994-05-24 00:00:00	184	\N	2	5	2	\N	1994-05-24 09:30:00	1994-05-24 13:00:00	272	215.37417735205958	65.049999999999997	0.20999999	\N	76.870000000000005	59.119999999999997	135.99000000000001	1.256	\N	\N	\N	47.337000000000003	156.59200000000001	\N	334.89999	\N	109.255	3.0659999999999998	0.92250001	\N	6.3155999999999999	0.079471	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.4569999999999999	1.2589999999999999	2.8140000000000001	3.8860000000000001	5.9545000000000003	4.2394999999999996	3.6286	3.0413999999999999	2.4542000000000002	1.7501	1.3426	0.96360000000000001	0.7349	0.62580000000000002	0.5756	0.53549999999999998	0.45040000000000002	0.25	0.037	10	96.957001	8	0	2003-06-05 00:00:00	\N	2011-12-01 03:12:39	106.40000000000001	0	0	59.119999999999997	135.99000000000001	1	1
2057	88	1994-11-04 00:00:00	184	\N	2	5	3	\N	1994-11-04 09:00:00	1994-11-04 13:00:00	193	152.64383443398395	64.260000000000005	0.20999999	\N	75.659999999999997	59.850000000000001	135.50999999999999	0.81100000000000005	\N	\N	\N	51.378	148.07900000000001	\N	253.7	\N	96.700999999999993	2.6230000000000002	0.86339998	\N	5.4039000000000001	0.073511000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.6989999999999998	1.113	2.762	3.9700000000000002	6.0503999999999998	4.7942999999999998	3.9802	3.4982000000000002	3.0162	2.0522999999999998	1.6451	1.2699	0.93789999999999996	0.82720000000000005	0.71650000000000003	0.62829999999999997	0.51700000000000002	0.25	0.15899999	10	97.116997	12	0	2003-04-03 00:00:00	Vergelichsmessung zweier Geschiebefänger (neuer Fänger des WSA Dresden)	2011-12-01 03:12:31	106.40000000000001	0	0	59.850000000000001	135.50999999999999	1	1
2080	88	1997-03-04 00:00:00	184	\N	\N	\N	13	\N	1997-03-04 09:00:00	1997-03-04 15:30:00	502	728.36898165987782	67.359999999999999	0.20999999	6	\N	\N	\N	\N	14.554	77.185000000000002	73.861000000000004	-96.480000000000004	447.26299999999998	1897.569	898.29999	\N	543.74300000000005	1.6519999999999999	1.1633	0.36489999	3.4034	0.058339000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	2003-04-07 00:00:00	\N	2011-12-01 03:10:49	106.40000000000001	0	0	\N	\N	1	1
6921	82	2005-03-30 00:00:00	577	\N	2	3	45	\N	2005-03-30 07:30:00	2005-03-30 14:10:00	533	757.64314168831311	80.290000000000006	0.22	8	79	23	102	1.2050000000000001	10.989000000000001	42.200000000000003	38.823	-11.467000000000001	183.803	1539.5940000000001	688.09998	\N	195.27000000000001	3.524	1.5797	0.5133	7.6052	0.087207999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	10.430999999999999	0.71099999999999997	3.3620000000000001	7.3079999999999998	25.203399999999998	20.845199999999998	17.939699999999998	15.233499999999999	13.588200000000001	10.297700000000001	7.3544	4.9996	3.3984000000000001	2.8085	2.2185000000000001	1.8443000000000001	1.4091	0.25	0.0089999996	31.5	98.668999	5	5	1970-01-01 00:00:00	keine Abflussmessung vorhanden, Q aus Abflusstafel	2011-12-01 02:05:56	46.799999999999983	0	0	23	102	1	1
6922	82	2005-04-20 00:00:00	577	\N	2	3	46	\N	2005-04-20 08:00:00	2005-04-20 13:30:00	340	383.35209561046202	78.370000000000005	0.20999999	13.2	52	27	79	1.3979999999999999	\N	\N	\N	5.4930000000000003	105.982	\N	444.70001	\N	100.489	4.4260000000000002	1.2367001	\N	9.1172000000000004	0.095483999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.0810000000000004	0.72599999999999998	2.8959999999999999	5.774	9.3899000000000008	6.2714999999999996	5.6729000000000003	4.9245999999999999	4.1763000000000003	3.3167	2.5421999999999998	1.8487	1.3441000000000001	1.0918000000000001	0.88819999999999999	0.74770000000000003	0.57440000000000002	0.125	0.0070000002	16	96.704002	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:05:41	46.799999999999983	-35	0	27	79	1	1
6923	82	2005-10-05 00:00:00	577	\N	2	3	47	\N	2005-10-05 08:00:00	2005-10-05 12:00:00	201	207.70713543985033	76.989999999999995	0.2	18	53	24	77	0.33800000000000002	\N	\N	\N	9.8219999999999992	100.16800000000001	\N	313.20001	\N	90.346000000000004	3.4660000000000002	0.95160002	\N	6.8007	0.082465999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.633	1.2809999999999999	2.7309999999999999	3.391	6.1942000000000004	4.4682000000000004	3.7073999999999998	3.0908000000000002	2.4742000000000002	1.7888999999999999	1.4458	1.1027	0.85929999999999995	0.75880000000000003	0.65839999999999999	0.59919999999999995	0.52759999999999996	0.063	0.003	10	94.386002	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:05:24	46.799999999999983	-35	0	24	77	1	1
6924	82	2005-11-01 00:00:00	577	\N	2	3	48	\N	2005-11-01 10:15:00	2005-11-01 14:45:00	109	115.70263249333944	76.069999999999993	0.2	11.5	54	30	84	0.26500000000000001	\N	\N	\N	12.317	96.537000000000006	0	233	\N	84.219999999999999	2.7669999999999999	0.71240002	0	5.4283999999999999	0.073677999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.087	1.3560000000000001	1.8959999999999999	2.2890000000000001	1.8936999999999999	1.5873999999999999	1.3832	1.1279999999999999	0.96889999999999998	0.84389999999999998	0.71899999999999997	0.61299999999999999	0.55410000000000004	0.52470000000000006	0.49020000000000002	0.44159999999999999	0.36870000000000003	0.063	0.013	10	99.806	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:04:41	46.799999999999983	-35	-35	30	84	1	1
6961	86	2005-03-31 00:00:00	576	\N	2	3	48	\N	2005-03-31 07:30:00	2005-03-31 13:30:00	517	715.12590926606185	88.030000000000001	0.28	6.5	81	14	95	1.1519999999999999	13.798	41.345999999999997	40.298000000000002	-5.7080000000000002	111.43899999999999	932.053	616.90002	\N	117.14700000000001	5.266	1.6632	1.0185	14.4643	0.120267	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	11.103	0.69799999999999995	3.1349999999999998	7.4109999999999996	25.769100000000002	22.330500000000001	20.0381	17.172699999999999	15.026999999999999	11.732900000000001	8.5273000000000003	5.8414999999999999	4.2229999999999999	3.5043000000000002	2.8201000000000001	2.2726999999999999	1.5831	0.063	0.001	16	72.954002	5	5	1970-01-01 00:00:00	\N	2011-12-01 01:32:21	18.199999999999989	-20	0	14	95	1	1
6962	86	2005-04-19 00:00:00	576	\N	2	3	49	\N	2005-04-19 07:30:00	2005-04-19 13:30:00	340	383.35209561046202	86.489999999999995	0.28999999	11.5	61	12	73	0.89900000000000002	\N	\N	\N	-3.0190000000000001	108.824	\N	440.60001	\N	111.843	3.9390000000000001	1.2484	\N	11.206300000000001	0.10586	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	7.0209999999999999	1.1579999999999999	3.5800000000000001	6.1180000000000003	19.1951	13.1534	10.350899999999999	7.8429000000000002	6.0145	4.4119999999999999	3.4148000000000001	2.6269999999999998	1.8761000000000001	1.5726	1.2689999999999999	1.0262	0.72109999999999996	0.063	0.003	31.5	97.459999	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:32:11	18.199999999999989	-20	0	12	73	1	1
6963	86	2005-10-10 00:00:00	576	\N	2	3	50	\N	2005-10-10 13:30:00	2005-10-10 16:15:00	194	200.04009352764109	85.230000000000004	0.28999999	15.2	46	30	76	0.23799999999999999	\N	\N	\N	-1.421	106.241	\N	302.10001	\N	107.661	2.806	0.9501	\N	7.9823000000000004	0.089344000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.8979999999999999	1.119	2.157	2.8220000000000001	3.6629	2.8039000000000001	2.2313000000000001	1.9080999999999999	1.7723	1.5005999999999999	1.2290000000000001	0.97509999999999997	0.81610000000000005	0.73660000000000003	0.65720000000000001	0.6028	0.53169999999999995	0.063	0.013	10	97.324997	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:32:04	18.199999999999989	-20	0	30	76	1	1
6964	86	2005-10-27 00:00:00	576	\N	2	3	51	\N	2005-10-27 08:00:00	2005-10-27 13:30:00	122	127.55169726675372	84.609999999999999	0.30000001	12.2	38	36	74	0.021000000000000001	0.17899999999999999	1.3580000000000001	7.4210000000000003	1.1839999999999999	104.264	177.66499999999999	236.7	\N	103.08	2.2970000000000002	0.773	0.68220001	6.7591999999999999	0.082213999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.2649999999999999	1.3959999999999999	2.1949999999999998	2.7570000000000001	2.8523000000000001	1.9273	1.7507999999999999	1.5302	1.3096000000000001	0.94089999999999996	0.74299999999999999	0.59899999999999998	0.52690000000000003	0.48759999999999998	0.43890000000000001	0.39989999999999998	0.34129999999999999	0.063	0.0070000002	6.2999999999999998	98.197998	5	5	1970-01-01 00:00:00	\N	2011-12-01 01:31:23	18.199999999999989	-20	-20	36	74	1	1
7263	84	2006-10-25 00:00:00	579	\N	2	3	27	\N	2006-10-25 09:00:00	2006-10-25 14:00:00	109	115.70263249333944	73.5	0.2	12.7	42	75	117	1.927	\N	\N	\N	47.584000000000003	143.03	\N	222.8	\N	95.445999999999998	2.3340000000000001	0.74510002	\N	4.5795000000000003	0.067671999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.85999999999999999	1.147	1.6970000000000001	2.0249999999999999	1.5693999999999999	1.0699000000000001	0.95350000000000001	0.87990000000000002	0.80630000000000002	0.65920000000000001	0.58889999999999998	0.53769999999999996	0.47960000000000003	0.441	0.40250000000000002	0.37169999999999997	0.32540000000000002	0.063	0.0049999999	6.2999999999999998	99.278999	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:35:40	59.400000000000006	50	0	75	117	1	1
7381	85	2006-10-24 00:00:00	598	\N	2	3	38	\N	2006-10-24 12:00:00	2006-10-24 15:45:00	108	115.0056286831386	69.890000000000001	0.2	13	51	69	120	2.3900000000000001	\N	\N	\N	54.950000000000003	133.03999999999999	\N	196.89999	\N	78.090000000000003	2.5209999999999999	0.838	\N	4.9471999999999996	0.070335999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.137	2.444	2.9079999999999999	3.2770000000000001	5.6486999999999998	4.2683999999999997	3.4904000000000002	2.5912999999999999	1.9043000000000001	1.3451	0.93889999999999996	0.77929999999999999	0.62450000000000006	0.58169999999999999	0.53890000000000005	0.50470000000000004	0.41039999999999999	0.063	0.003	10	97.861	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:54:02	76.599999999999994	50	0	69	120	1	1
7401	89	2006-10-19 00:00:00	185	\N	2	3	18	\N	2006-10-19 10:03:00	2006-10-19 14:44:00	172	142.88578109117219	57.450000000000003	0.20999999	\N	85	55	140	4.2569999999999997	\N	\N	\N	47.590000000000003	159.94	\N	192.3	\N	112.34999999999999	1.7110000000000001	1.0662	\N	3.5255000000000001	0.059375999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.5	1.585	2.4969999999999999	2.919	3.6627999999999998	2.6692999999999998	2.0070000000000001	1.7639	1.5258	1.0496000000000001	0.84909999999999997	0.68059999999999998	0.56820000000000004	0.52410000000000001	0.47399999999999998	0.42820000000000003	0.35959999999999998	0.063	0.003	6.2999999999999998	97.746002	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:14:23	137.19999999999999	10	0	55	140	1	1
7421	90	2006-10-18 00:00:00	1438	\N	2	3	42	\N	2006-10-18 09:30:00	2006-10-18 14:39:00	122	159.61387253599236	49.969999999999999	0.2	12.2	85	55	140	4.25	0.46700000000000003	3.952	17.257999999999999	16.302	152.31999999999999	222.41900000000001	303.29999	\N	136.01900000000001	2.23	0.75489998	0.4842	4.3754999999999997	0.066147999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.514	1.4650000000000001	2.032	2.254	3.4184000000000001	2.2536999999999998	1.8968	1.7052	1.5136000000000001	1.1304000000000001	0.91639999999999999	0.78959999999999997	0.66279999999999994	0.61219999999999997	0.57530000000000003	0.54579999999999995	0.50160000000000005	0.063	0.0020000001	6.2999999999999998	97.375999	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:20:17	173.79999999999998	0	0	55	140	1	1
7702	86	2007-04-10 00:00:00	576	\N	2	3	53	\N	2007-04-10 13:00:00	2007-04-10 16:00:00	217	225.82923450507215	85.450000000000003	0.28999999	10.4	-30	110	140	0.754	\N	\N	\N	-1.6759999999999999	106.839	\N	325.89999	\N	108.51600000000001	3.0030000000000001	0.99430001	\N	8.5428999999999995	0.092427999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.1960000000000002	1.508	2.294	2.7210000000000001	4.6044999999999998	3.2010000000000001	2.5535999999999999	1.9487000000000001	1.7862	1.4612000000000001	1.1363000000000001	0.92320000000000002	0.79090000000000005	0.72470000000000001	0.65859999999999996	0.60819999999999996	0.53700000000000003	0.25	0.072999999	16	99.123001	2	0	1970-01-01 00:00:00	\N	2011-12-01 01:30:48	18.199999999999989	50	0	90	60	0	1
7901	89	2007-10-08 00:00:00	185	\N	2	3	22	\N	2007-10-08 10:00:00	2007-10-08 15:00:00	238	197.94908209703857	58.060000000000002	0.22	\N	93	57	150	13.571	1.389	5.944	20.931000000000001	45.241	164.88999999999999	308.35599999999999	262.5	\N	119.649	2.194	1.082	0.58350003	4.7343000000000002	0.068806000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.589	1.6419999999999999	2.1819999999999999	2.4350000000000001	3.5394999999999999	2.5787	1.984	1.7764	1.5689	1.1537999999999999	0.92259999999999998	0.79959999999999998	0.67659999999999998	0.61950000000000005	0.57640000000000002	0.54179999999999995	0.47389999999999999	0.25	0.075999998	16	99.957001	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:13:54	137.19999999999999	15	15	57	150	1	1
7921	2800	2007-03-06 00:00:00	1055	\N	2	3	3	\N	2007-03-06 07:30:00	2007-03-06 13:45:00	423	496.26671286299808	57.310000000000002	0.20999999	6	101	43	144	13.945	\N	\N	\N	-3.4929999999999999	194.27500000000001	\N	583.20001	\N	197.768	2.9489999999999998	1.2209001	\N	6.0746000000000002	0.077939999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.4850000000000001	1.419	2.2389999999999999	2.8050000000000002	3.2814000000000001	2.3159000000000001	1.9139999999999999	1.7028000000000001	1.4916	1.0692999999999999	0.86809999999999998	0.71040000000000003	0.59030000000000005	0.54979999999999996	0.50929999999999997	0.46179999999999999	0.38119999999999998	0.125	0.001	16	99.838997	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:17:20	150.99999999999997	10	0	43	144	1	1
7941	2800	2007-04-26 00:00:00	1055	\N	2	3	4	\N	2007-04-26 07:30:00	2007-04-26 13:15:00	180	147.06780395237723	54.840000000000003	0.20999999	15.3	87	45	132	8.1690000000000005	\N	\N	\N	34.497999999999998	147.863	\N	224.3	\N	113.36499999999999	1.9790000000000001	0.94069999	\N	4.0759999999999996	0.063843999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.2	1.236	1.871	2.3220000000000001	2.0550000000000002	1.8003	1.6618999999999999	1.4888999999999999	1.3160000000000001	0.98929999999999996	0.86570000000000003	0.74209999999999998	0.62280000000000002	0.58409999999999995	0.5454	0.51439999999999997	0.42609999999999998	0.125	0.0089999996	16	99.940002	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:17:15	150.99999999999997	15	0	45	132	1	1
7981	2801	2007-03-05 00:00:00	1056	\N	2	3	3	\N	2007-03-05 10:20:00	2007-03-05 14:40:00	360	530.4198995628393	57.049999999999997	0.20999999	6.1999998	90	52	142	14.868	\N	\N	\N	29.555	218.958	\N	626	\N	189.40299999999999	3.3050000000000002	1.2156	\N	6.8091999999999997	0.082517999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.3559999999999999	1.3819999999999999	2.6309999999999998	3.4380000000000002	5.4546000000000001	3.8656000000000001	3.3847999999999998	2.7837999999999998	2.1827999999999999	1.6557999999999999	1.2498	0.93369999999999997	0.76149999999999995	0.6754	0.60350000000000004	0.55859999999999999	0.48159999999999997	0.125	0.003	16	99.339996	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:18:32	151.40000000000001	30	0	52	142	1	1
7961	2800	2007-10-04 00:00:00	1055	\N	2	3	5	\N	2007-10-04 08:30:00	2007-10-04 14:00:00	255	227.22324212547383	56.07	0.2	13.6	103	42	145	3.6669999999999998	\N	\N	\N	14.465999999999999	152.93899999999999	\N	378	\N	138.47300000000001	2.73	0.8624	\N	5.3562000000000003	0.073186000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.1539999999999999	1.365	1.851	2.1890000000000001	2.129	1.7313000000000001	1.5356000000000001	1.2909999999999999	1.0464	0.90529999999999999	0.80069999999999997	0.69610000000000005	0.60409999999999997	0.56879999999999997	0.53359999999999996	0.50529999999999997	0.41349999999999998	0.125	0.003	10	99.905998	6	0	1970-01-01 00:00:00	\N	2011-12-01 03:17:11	150.99999999999997	20	0	42	145	1	1
7982	2801	2007-04-25 00:00:00	1056	\N	2	3	4	\N	2007-04-25 12:30:00	2007-04-25 15:15:00	136	174.94795636041084	54.799999999999997	0.20999999	15.3	87	50	137	2.77	\N	\N	\N	37.075000000000003	155.25999999999999	\N	288.89999	\N	118.185	2.444	0.8689	\N	5.0350999999999999	0.070958999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.056	1.349	1.944	2.3530000000000002	1.8797999999999999	1.5654999999999999	1.3559000000000001	1.0940000000000001	0.95760000000000001	0.82540000000000002	0.69330000000000003	0.5978	0.53610000000000002	0.50529999999999997	0.45619999999999999	0.41399999999999998	0.3508	0.25	0.44800001	10	99.560997	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:18:27	151.40000000000001	25	0	50	137	1	1
8381	84	2005-04-21 00:00:00	579	\N	\N	\N	24	\N	2005-04-21 08:20:00	2005-04-21 14:00:00	319	354.07793558202673	75.579999999999998	0.20999999	11.9	\N	\N	\N	\N	2.3690000000000002	11.991	23.603000000000002	25.367000000000001	189.80799999999999	638.92499999999995	465.20001	\N	164.441	2.8290000000000002	1.092	0.6591	5.8281999999999998	0.076342999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	1970-01-01 00:00:00	\N	2011-12-01 02:36:33	59.400000000000006	0	40	\N	\N	1	1
8402	89	2005-03-16 00:00:00	185	\N	\N	\N	12	\N	2005-03-16 09:00:00	2005-03-16 14:15:00	311	298.31763076595951	58.799999999999997	0.22	4	\N	\N	\N	\N	3.9430000000000001	7.1299999999999999	16.658000000000001	42.976999999999997	206.01599999999999	377.28399999999999	373.5	\N	163.03999999999999	2.2909999999999999	1.1459	0.54720002	4.944	0.070314000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	1970-01-01 00:00:00	\N	2011-12-01 03:14:53	137.19999999999999	0	10	\N	\N	1	1
8441	88	2006-11-29 00:00:00	600	\N	2	3	47	\N	2006-11-29 09:15:00	2006-11-29 14:20:00	175	142.18877728097135	64.079999999999998	0.20999999	7.4000001	67	70	137	0.64600000000000002	0.38900000000000001	2.4550000000000001	12.036	52.529000000000003	146.76499999999999	202.79499999999999	232.8	\N	94.236000000000004	2.4700000000000002	0.87650001	0.57849997	5.0883000000000003	0.071332000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.4159999999999999	2.2599999999999998	2.9620000000000002	3.1299999999999999	6.5064000000000002	3.7843	2.9607999999999999	1.9812000000000001	1.698	1.1317999999999999	0.84970000000000001	0.65380000000000005	0.56230000000000002	0.52370000000000005	0.47770000000000001	0.43130000000000002	0.36159999999999998	0.063	0.013	16	98.771004	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:04:57	106.40000000000001	30	30	70	137	1	1
8442	88	2005-11-07 00:00:00	600	\N	2	3	44	\N	2005-11-07 11:20:00	2005-11-07 14:48:00	148	121.27866297494616	63.810000000000002	0.20999999	11.7	56	70	126	0.34000000000000002	0.22	1.242	7.1369999999999996	53.100999999999999	144.78100000000001	161.47900000000001	207.7	\N	91.680000000000007	2.266	0.83759999	0.57950002	4.6677999999999997	0.068321999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.2270000000000001	1.3340000000000001	1.964	2.367	2.3849999999999998	1.7567999999999999	1.5563	1.3056000000000001	1.0548999999999999	0.89370000000000005	0.77429999999999999	0.65490000000000004	0.57430000000000003	0.53920000000000001	0.504	0.45540000000000003	0.3775	0.063	0.0080000004	10	99.777	4	5	1970-01-01 00:00:00	\N	2011-12-01 03:05:15	106.40000000000001	30	30	70	126	1	1
8443	89	2006-07-26 00:00:00	616	\N	2	3	16	\N	2006-07-26 10:00:00	2006-07-26 15:10:00	145	119.18765154434364	57.18	0.20999999	24.700001	73	61	134	0.46500000000000002	0.33700000000000002	7.2050000000000001	42.134999999999998	48.622	158.59	159.994	190.2	\N	109.968	1.73	0.89889997	0.53509998	3.5636000000000001	0.059695999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.6539999999999999	1.8129999999999999	2.4529999999999998	2.9500000000000002	3.9358	3.0082	2.3898999999999999	1.8862000000000001	1.6565000000000001	1.1971000000000001	0.91110000000000002	0.75529999999999997	0.61409999999999998	0.57340000000000002	0.53269999999999995	0.50009999999999999	0.40579999999999999	0.063	0.003	10	99.594002	4	5	1970-01-01 00:00:00	\N	2011-12-01 03:14:31	137.40000000000001	20	20	61	134	1	1
8581	85	2005-11-03 00:00:00	598	\N	2	3	36	\N	2005-11-03 07:30:00	2005-11-03 13:40:00	104	111.52060963213441	69.849999999999994	0.2	10	51	70	121	0.29099999999999998	0.498	1.7769999999999999	11.106999999999999	55.109999999999999	132.84	165.96899999999999	193.8	\N	77.730000000000004	2.4929999999999999	0.82560003	0.4887	4.8914	0.069939000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.224	1.669	2.0760000000000001	2.3740000000000001	2.2759	1.7056	1.4831000000000001	1.2051000000000001	0.97760000000000002	0.80679999999999996	0.63600000000000001	0.57410000000000005	0.51629999999999998	0.47960000000000003	0.433	0.3957	0.33979999999999999	0.063	0.0060000001	10	99.205002	5	5	1970-01-01 00:00:00	\N	2011-12-01 02:54:12	76.599999999999994	50	50	70	121	1	1
8922	86	2007-10-30 00:00:00	576	\N	2	3	55	\N	2007-10-30 07:00:00	2007-10-30 11:15:00	137	141.49177347077051	84.760000000000005	0.30000001	9.1999998	60	34	94	0.40100000000000002	\N	\N	\N	0.63300000000000001	104.8	\N	252.3	\N	104.167	2.4220000000000002	0.8046	\N	7.1276999999999999	0.084426000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.4199999999999999	1.361	1.8169999999999999	1.9570000000000001	2.4895999999999998	1.7999000000000001	1.6145	1.3827	1.1509	0.93910000000000005	0.84889999999999999	0.75870000000000004	0.66849999999999998	0.62360000000000004	0.57989999999999997	0.54490000000000005	0.47989999999999999	0.25	0.078000002	16	99.382004	6	0	1970-01-01 00:00:00	\N	2011-12-01 01:29:10	18.199999999999989	-14	0	34	94	1	1
8923	86	2008-03-18 00:00:00	576	\N	2	3	56	\N	2008-03-18 08:00:00	2008-03-18 13:30:00	319	364.53299273503933	86.329999999999998	0.28999999	5.5999999	62	30	92	0.158	2.1709999999999998	7.5049999999999999	14.35	-2.7400000000000002	108.55200000000001	478.69299999999998	422.70001	\N	111.292	3.798	1.2373	0.70779997	10.8055	0.103949	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.8250000000000002	1.1599999999999999	3.2229999999999999	4.9640000000000004	9.6875	6.5045000000000002	5.4161000000000001	4.1932999999999998	3.5979000000000001	2.6425999999999998	1.8738999999999999	1.4885999999999999	1.1032999999999999	0.92259999999999998	0.75570000000000004	0.62629999999999997	0.5323	0.125	0.028999999	16	96.602997	5	5	1970-01-01 00:00:00	\N	2011-12-01 01:28:19	18.199999999999989	-10	-10	30	92	1	1
8924	86	2008-04-21 00:00:00	576	\N	2	3	57	\N	2008-04-21 10:40:00	2008-04-21 14:45:00	297	333.86482508620236	86.129999999999995	0.28999999	10	61	31	92	1.9319999999999999	\N	\N	\N	-2.4670000000000001	108.30800000000001	\N	400.5	\N	110.776	3.6150000000000002	1.196	\N	10.2857	0.10141799999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.0739999999999998	1.244	2.8290000000000002	4.4299999999999997	9.6311999999999998	6.5511999999999997	5.4885000000000002	4.3327999999999998	3.7092999999999998	2.8929	2.0764	1.6579999999999999	1.2806999999999999	1.0920000000000001	0.92930000000000001	0.81879999999999997	0.65300000000000002	0.125	0.0040000002	31.5	99.599998	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:27:53	18.199999999999989	-11	0	31	92	1	1
8925	86	2008-11-05 00:00:00	576	\N	2	3	58	\N	2008-11-05 07:30:00	2008-11-05 13:30:00	113	123.36967440554868	84.5	0.30000001	10	40	42	82	0.0060000000000000001	0.35999999999999999	1.5629999999999999	8.8300000000000001	1.5880000000000001	103.87	133.64699999999999	225.39999	\N	102.283	2.2040000000000002	0.78509998	0.3928	6.4869000000000003	0.080541000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	0.67700000000000005	1.016	1.546	1.899	0.98089999999999999	0.90610000000000002	0.85629999999999995	0.79400000000000004	0.73170000000000002	0.62250000000000005	0.58130000000000004	0.54020000000000001	0.49809999999999999	0.45550000000000002	0.41289999999999999	0.37890000000000001	0.32779999999999998	0.125	0.17299999	2	98.791	5	5	1970-01-01 00:00:00	\N	2011-12-01 01:27:12	18.199999999999989	-17	-17	42	82	1	1
9042	2801	2007-11-12 00:00:00	1056	\N	2	3	6	\N	2007-11-12 10:30:00	2007-11-12 15:30:00	300	412.62625563889731	56.460000000000001	0.2	6.8000002	90	52	142	12.869	\N	\N	\N	31.501999999999999	217.643	\N	515.20001	\N	186.14099999999999	2.7679999999999998	1.149	\N	5.4306999999999999	0.073693999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.9319999999999999	1.3149999999999999	2.8260000000000001	3.593	6.9290000000000003	4.8300000000000001	3.8713000000000002	3.2846000000000002	2.6978	1.853	1.4903	1.1276999999999999	0.87239999999999995	0.77400000000000002	0.67559999999999998	0.60489999999999999	0.51570000000000005	0.125	0.0070000002	31.5	99.952003	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:18:20	151.40000000000001	20	0	52	142	1	1
9043	2801	2007-11-28 00:00:00	1056	\N	2	3	7	\N	2007-11-28 07:45:00	2007-11-28 12:00:00	311	432.14236232452083	56.5	0.2	4	106	40	146	15.205	\N	\N	\N	31.367999999999999	217.733	\N	522.70001	\N	186.36500000000001	2.8050000000000002	1.1862	\N	5.5026999999999999	0.074179999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.8029999999999999	1.0800000000000001	2.4390000000000001	3.6930000000000001	5.9691999999999998	4.5838999999999999	3.8858999999999999	3.4980000000000002	3.1101000000000001	2.3344	1.8089	1.4731000000000001	1.1373	0.97899999999999998	0.86329999999999996	0.77080000000000004	0.63200000000000001	0.125	0.0080000004	16	99.522003	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:18:16	151.40000000000001	15	0	40	146	1	1
9046	2801	2008-04-08 00:00:00	1056	\N	2	3	9	\N	2008-04-08 07:15:00	2008-04-08 11:40:00	341	490.69068238139135	56.810000000000002	0.22	7.6999998	105	32	137	8.2680000000000007	\N	\N	\N	30.324999999999999	218.423	\N	580.70001	\N	188.09899999999999	3.0870000000000002	1.2122999	\N	6.6631	0.081628000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.6779999999999999	0.98599999999999999	2.4849999999999999	3.9700000000000002	5.7229999999999999	4.3354999999999997	3.7999000000000001	3.4074	3.0148999999999999	2.2299000000000002	1.7569999999999999	1.4134	1.0698000000000001	0.92620000000000002	0.80179999999999996	0.70220000000000005	0.56169999999999998	0.125	0.0040000002	16	99.611	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:18:05	151.40000000000001	15	0	32	137	1	1
9045	2801	2008-03-04 00:00:00	1056	\N	2	3	8	\N	2008-03-04 09:15:00	2008-03-04 14:30:00	314	437.71839280612755	56.68	0.22	5.6999998	94	40	134	12.872999999999999	\N	\N	\N	30.762	218.13399999999999	\N	556.29999	\N	187.37200000000001	2.9689999999999999	1.1288	\N	6.4077999999999999	0.080048999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.8819999999999999	1.6379999999999999	2.351	2.8199999999999998	4.1558000000000002	3.3563999999999998	2.8872	2.3007	1.9038999999999999	1.5096000000000001	1.1153	0.91020000000000001	0.78339999999999999	0.71989999999999998	0.65649999999999997	0.60709999999999997	0.53539999999999999	0.25	0.050999999	16	99.972	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:18:10	151.40000000000001	15	0	40	134	1	1
9062	90	2007-04-04 00:00:00	1438	\N	2	3	45	\N	\N	\N	247	324.80377555359144	51.25	0.19	\N	82	43	125	9.2110000000000003	\N	\N	\N	11.683999999999999	157.208	\N	483.5	\N	145.523	3.323	0.9637	\N	6.1932	0.078697000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.0760000000000001	1.266	2.1869999999999998	2.754	3.9289000000000001	3.0649000000000002	2.4887999999999999	1.9544999999999999	1.8127	1.5293000000000001	1.2458	0.98119999999999996	0.83940000000000003	0.76859999999999995	0.69769999999999999	0.64100000000000001	0.55530000000000002	0.25	0.071000002	16	99.345001	4	0	1970-01-01 00:00:00	\N	2011-12-01 03:19:57	173.79999999999998	0	0	43	125	1	1
9141	88	2008-03-10 00:00:00	600	\N	2	3	52	\N	2008-03-10 09:30:00	2008-03-10 14:00:00	393	442.59741947753344	66.260000000000005	0.20999999	5.8000002	71	69	140	13.629	8.3119999999999994	22.123000000000001	34.838999999999999	41.301000000000002	203.792	741.71500000000003	499.10001	\N	162.49100000000001	3.0720000000000001	1.2723	0.65490001	6.3277999999999999	0.079547999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	4.3319999999999999	0.92100000000000004	3.3410000000000002	6.0090000000000003	9.9065999999999992	8.1045999999999996	6.9032	5.8323999999999998	5.0509000000000004	3.6368	2.5282	1.6891	1.0951	0.92490000000000006	0.81440000000000001	0.72609999999999997	0.60519999999999996	0.25	0.061999999	31.5	99.859001	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:04:14	106.40000000000001	40	40	69	140	1	1
9142	89	2008-03-06 00:00:00	185	\N	2	3	24	\N	2008-03-06 07:30:00	2008-03-06 12:00:00	460	581.99818151770137	60.189999999999998	0.22	14	92	70	162	23.196000000000002	19.045999999999999	49.805	59.646999999999998	34.927999999999997	216.06	751.495	613.70001	\N	181.13200000000001	3.3879999999999999	1.3607	0.66369998	7.3118999999999996	0.085510000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.359	1.1950000000000001	2.6190000000000002	3.5430000000000001	5.4656000000000002	3.9956	3.5653999999999999	3.0276000000000001	2.4899	1.7870999999999999	1.3960999999999999	1.0051000000000001	0.8196	0.72829999999999995	0.63690000000000002	0.5827	0.50439999999999996	0.125	0.0040000002	16	99.638	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:13:40	137.19999999999999	24	24	70	162	1	1
9201	88	2008-10-29 00:00:00	600	\N	2	3	54	\N	2008-10-29 07:00:00	2008-10-29 11:45:00	137	108.03559058113021	63.700000000000003	0.20999999	9.8999996	64	77	141	1.633	0.21199999999999999	1.355	8.7439999999999998	53.305999999999997	144.04599999999999	148.72800000000001	197.7	\N	90.739999999999995	2.1789999999999998	0.7841	0.50510001	4.4882	0.066993999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.232	1.8029999999999999	1.925	2.0659999999999998	2.8376999999999999	1.8625	1.5868	1.2422	0.98070000000000002	0.85070000000000001	0.72070000000000001	0.61580000000000001	0.56869999999999998	0.54510000000000003	0.52159999999999995	0.50280000000000002	0.41170000000000001	0.125	0.0070000002	10	99.769997	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:03:59	106.40000000000001	40	40	77	141	1	1
9647	88	2009-03-05 00:00:00	600	\N	2	3	56	\N	2009-03-05 07:20:00	2009-03-05 13:15:00	443	541.57196052605264	66.769999999999996	0.20999999	4.8000002	55	72	127	15.109	9.5850000000000009	38.094999999999999	49.027999999999999	33.677999999999997	217.87899999999999	1035.4380000000001	588.29999	\N	184.20099999999999	3.194	1.3207	0.68830001	6.5796999999999999	0.081115000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.8999999999999999	1.901	3.4449999999999998	4.0819999999999999	10.599299999999999	7.5890000000000004	5.9977999999999998	4.7023000000000001	3.6855000000000002	2.3117999999999999	1.5976999999999999	1.0771999999999999	0.86360000000000003	0.78359999999999996	0.70350000000000001	0.63949999999999996	0.56630000000000003	0.125	0.0020000001	16	96.309998	5	5	1970-01-01 00:00:00	\N	2011-12-01 03:03:34	106.40000000000001	30	30	72	127	1	1
9652	84	2009-03-26 00:00:00	579	\N	\N	\N	36	\N	2009-03-26 07:00:00	2009-03-26 15:00:00	404	492.08469000179304	76.390000000000001	0.20999999	\N	\N	\N	\N	\N	2.4220000000000002	15.281000000000001	21.645	22.294	193.57400000000001	983.07299999999998	601.70001	\N	171.28	3.5129999999999999	1.1733	0.59359998	7.2374999999999998	0.085072999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	5	1970-01-01 00:00:00	\N	2011-12-01 02:30:47	59.400000000000006	0	47	\N	\N	0	1
10069	86	2009-05-12 00:00:00	576	\N	2	3	61	\N	2009-05-12 07:00:00	2009-05-12 13:15:00	167	175.64496017061168	85.060000000000002	0.30000001	14	50	27	77	0.443	\N	\N	\N	-0.67200000000000004	105.77800000000001	\N	283.89999	\N	106.45099999999999	2.6669999999999998	0.88770002	\N	7.8479999999999999	0.088589000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.8400000000000001	0.98499999999999999	1.7509999999999999	2.419	3.3405999999999998	2.5863999999999998	2.0836000000000001	1.9244000000000001	1.8371999999999999	1.6629	1.4884999999999999	1.3142	1.1398999999999999	1.0527	0.94840000000000002	0.84399999999999997	0.6875	0.125	0.0080000004	10	99.288002	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:22:04	18.199999999999989	-14	0	27	77	1	0
10099	90	2009-04-29 00:00:00	1438	\N	2	3	54	\N	2009-04-29 10:00:00	2009-04-29 14:30:00	210	269.74047454772506	50.869999999999997	0.2	16.5	84	54	138	2.8559999999999999	\N	\N	\N	13.067	155.81	\N	428.79999	\N	142.74299999999999	3.004	0.90259999	\N	5.8933	0.076768000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.4390000000000001	1.1279999999999999	1.9379999999999999	2.8849999999999998	2.8591000000000002	1.9592000000000001	1.8331	1.6755	1.5179	1.2027000000000001	0.95199999999999996	0.81740000000000002	0.68279999999999996	0.61850000000000005	0.56479999999999997	0.52190000000000003	0.41689999999999999	0.125	0.035	16	99.728996	5	0	1970-01-01 00:00:00	\N	2011-12-01 03:19:00	173.79999999999998	15	0	54	138	1	0
10830	86	2009-10-28 00:00:00	576	\N	2	3	63	\N	2009-10-28 07:30:00	2009-10-28 12:10:00	171	181.2209906522184	85.069999999999993	0.30000001	11	55	33	88	0.26200000000000001	\N	\N	\N	-0.72799999999999998	105.80500000000001	\N	284.89999	\N	106.53400000000001	2.6749999999999998	0.91250002	\N	7.8712999999999997	0.088719999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.7270000000000001	1.1439999999999999	2.298	3.282	3.6364000000000001	2.7995000000000001	2.2414999999999998	1.9005000000000001	1.7482	1.4438	1.1393	0.89900000000000002	0.71279999999999999	0.62419999999999998	0.57199999999999995	0.53029999999999999	0.43990000000000001	0.125	0.032000002	10	99.058998	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:20:05	18.199999999999989	-17	0	33	88	1	0
10831	82	2009-10-29 00:00:00	577	\N	2	3	59	\N	2009-10-29 07:30:00	2009-10-29 13:15:00	170	179.82698303181672	76.680000000000007	0.2	11	45	19	64	0.318	\N	\N	\N	10.722	98.852999999999994	\N	285.5	\N	88.131	3.2389999999999999	0.90369999	\N	6.3558000000000003	0.079723000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	2.5150000000000001	0.98499999999999999	2.1440000000000001	3.3380000000000001	5.0944000000000003	3.9077000000000002	3.6396000000000002	3.3045	2.9693999999999998	2.2991999999999999	1.8371	1.5427	1.2484	1.1012	0.95799999999999996	0.85029999999999994	0.68879999999999997	0.25	0.044	16	99.906998	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:57:57	46.799999999999983	-42	0	19	64	1	0
10832	84	2010-03-09 00:00:00	579	\N	2	3	40	\N	2010-03-09 10:00:00	2010-03-09 15:10:00	291	326.19778317399312	75.379999999999995	0.2	2	63	64	127	3.0870000000000002	\N	\N	\N	26.125	171.88800000000001	\N	434.20001	\N	145.76300000000001	2.9790000000000001	1.0778	\N	5.8445	0.076449000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.2069999999999999	1.4470000000000001	2.0459999999999998	2.3889999999999998	6.4351000000000003	4.4728000000000003	3.7940999999999998	3.3809999999999998	2.968	2.1419000000000001	1.8174999999999999	1.5971	1.3768	1.2665999999999999	1.1564000000000001	1.0683	0.89659999999999995	0.125	0.0089999996	31.5	99.777	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:29:30	59.400000000000006	39	0	64	127	1	0
10833	84	2009-11-02 00:00:00	579	\N	2	3	39	\N	2009-11-02 10:45:00	2009-11-02 14:22:00	172	181.91799446241924	74.129999999999995	0.2	8.1999998	53	70	123	4.4500000000000002	\N	\N	\N	40.113999999999997	146.18000000000001	\N	286.29999	\N	106.066	2.6989999999999998	0.91180003	\N	5.2952000000000004	0.072767999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.756	1.345	1.8280000000000001	2.2069999999999999	3.4443000000000001	2.0337000000000001	1.8711	1.704	1.5368999999999999	1.2025999999999999	0.95950000000000002	0.85650000000000004	0.75349999999999995	0.70199999999999996	0.65049999999999997	0.60870000000000002	0.54490000000000005	0.125	0.0020000001	16	99.607002	5	0	1970-01-01 00:00:00	\N	2011-12-01 02:29:54	59.400000000000006	48	0	70	123	1	0
10851	82	2010-03-10 00:00:00	577	\N	2	3	60	\N	2010-03-10 07:00:00	2010-03-10 13:45:00	293	328.98579841479648	77.909999999999997	0.2	2	50	23	73	0.012999999999999999	\N	\N	\N	7.0720000000000001	104.056	\N	399.29999	\N	96.983999999999995	4.117	1.182	\N	8.0779999999999994	0.089878	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	3.133	1.018	2.1000000000000001	3.2000000000000002	5.8498000000000001	5.1539000000000001	4.6900000000000004	4.1101000000000001	3.7361	3.0844999999999998	2.4329999999999998	1.8980999999999999	1.5942000000000001	1.4422999999999999	1.2904	1.1688000000000001	0.96389999999999998	0.25	0.105	10	97.257004	5	0	1970-01-01 00:00:00	\N	2011-12-01 01:57:17	46.799999999999983	-38	0	23	73	1	0
11352	86	2011-03-01 00:00:00	576	\N	2	3	66	\N	2011-03-01 07:00:00	2011-03-01 12:00:00	225	241.86032213969148	85.489999999999995	0.28999999	2	21	20	41	0.0070000000000000001	\N	\N	\N	-1.7230000000000001	106.94799999999999	\N	330.20001	\N	108.67100000000001	3.0390000000000001	1.0509	\N	8.6443999999999992	0.092975000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	8.548	0.81100000000000005	2.7970000000000002	5.4500000000000002	20.9392	15.4293	13.703900000000001	11.5472	9.7406000000000006	7.9047000000000001	6.1260000000000003	4.7445000000000004	3.4958	2.9491000000000001	2.4024000000000001	1.9722	1.4504999999999999	0.5	0.65700001	16	85.322998	5	0	1970-01-01 00:00:00	\N	2012-04-23 12:02:22	18.199999999999989	-10	0	20	41	1	0
11353	86	2011-07-07 00:00:00	576	\N	2	3	67	\N	2011-07-07 08:30:00	2011-07-07 10:50:00	139	147.76480776257807	84.719999999999999	0.30000001	21	47	41	88	0.30299999999999999	\N	\N	\N	0.78000000000000003	104.657	\N	248.10001	\N	103.877	2.3889999999999998	0.85439998	\N	7.0297999999999998	0.083844000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.698	1.621	2.2029999999999998	2.5790000000000002	3.7686999999999999	2.7355999999999998	2.0468999999999999	1.8297000000000001	1.6496	1.2895000000000001	0.97560000000000002	0.85109999999999997	0.72670000000000001	0.66449999999999998	0.60629999999999995	0.56379999999999997	0.50009999999999999	0.125	0.02	10	99.222	5	0	1970-01-01 00:00:00	\N	2012-04-23 12:13:08	18.199999999999989	0	0	41	88	1	0
11384	85	2011-07-04 00:00:00	598	\N	2	3	56	\N	2011-07-04 13:15:00	2011-07-04 16:20:00	95	107.33858677092937	69.599999999999994	0.2	16	47	69	116	0.47799999999999998	\N	\N	\N	56.109999999999999	131.59	\N	174.60001	\N	75.480000000000004	2.3140000000000001	0.8818	\N	4.5393999999999997	0.067375000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	1.4910000000000001	1.298	2.0390000000000001	2.5680000000000001	3.2565	1.9936	1.8263	1.6172	1.4079999999999999	0.99660000000000004	0.85799999999999998	0.71940000000000004	0.60150000000000003	0.56140000000000001	0.5212	0.4793	0.38800000000000001	0.125	0.205	10	98.725998	5	0	1970-01-01 00:00:00	\N	2012-04-24 12:47:04	76.599999999999994	48	0	69	116	1	0
11385	85	2011-07-25 00:00:00	598	\N	2	3	57	\N	2011-07-25 11:30:00	2011-07-25 15:30:00	386	478.84161760797707	72.730000000000004	0.20999999	17	60	63	123	1.75	\N	\N	\N	37.149999999999999	229.73699999999999	\N	501.89999	\N	192.58699999999999	2.6059999999999999	1.3688	\N	5.3686999999999996	0.073271000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	0	6.9340000000000002	0.82699999999999996	3.5960000000000001	8.6940000000000008	16.427199999999999	13.3964	11.5783	9.5963999999999992	8.2752999999999997	5.8559999999999999	4.0968999999999998	2.9411	1.9011	1.5921000000000001	1.2831999999999999	1.036	0.67359999999999998	0.125	0.0070000002	31.5	99.595001	5	0	1970-01-01 00:00:00	\N	2012-04-24 12:50:09	76.599999999999994	41	0	63	123	1	0
\.


--
-- Data for Name: mpeilpunkt; Type: TABLE DATA; Schema: public; Owner: -
--

COPY mpeilpunkt (mpeilungid, punktnr, y, z) FROM stdin;
\.


--
-- Data for Name: mpeilung; Type: TABLE DATA; Schema: public; Owner: -
--

COPY mpeilung (mpeilungid, stationid, datum, km, bemerkung, lastupdated, oldapeilid) FROM stdin;
\.


--
-- Data for Name: siebanalyse; Type: TABLE DATA; Schema: public; Owner: -
--

COPY siebanalyse (siebanalyseid, sohlprobeid, istdigital, standort, dm, so, sk, u, d90, d84, d80, d75, d70, d60, d50, d40, d30, d25, d20, d16, d10, dmin, durchdmin, dmax, durchdmax, bemerkung) FROM stdin;
34	54	1	\N	22.741199999999999	8.1799999999999997	0.13800000000000001	48.209000000000003	56.304000000000002	49.568399999999997	45.078000000000003	39.521700000000003	34.503399999999999	24.466699999999999	16.331	9.7897999999999996	4.4543999999999997	1.4757	0.88360000000000005	0.74080000000000001	0.50749999999999995	0.10000000000000001	0.18700001	63	95.964996	\N
35	56	1	\N	30.838899999999999	4.1980000000000004	0.26000000000000001	30.68	66.275800000000004	59.755899999999997	56.164400000000001	51.6751	47.185699999999997	37.984299999999998	27.889800000000001	18.0609	9.5395000000000003	7.0377000000000001	4.8680000000000003	3.3908	1.2381	0.10000000000000001	0.28099999	63	87.612999	\N
36	66	1	\N	13.0534	6.8730000000000002	0.221	32.741999999999997	34.294800000000002	24.285299999999999	19.3992	17.3002	15.2012	11.003299999999999	7.5221999999999998	4.7022000000000004	2.3033999999999999	1.3190999999999999	0.73099999999999998	0.5141	0.33610000000000001	0.063	0.19499999	63	96.661003	\N
37	65	1	\N	29.325299999999999	3.1379999999999999	0.51200000000000001	10.237	63.853200000000001	56.243899999999996	51.304900000000004	45.131100000000004	39.393999999999998	32.217199999999998	25.040500000000002	18.3871	12.968299999999999	10.259	7.6855000000000002	5.7129000000000003	3.1471	0.10000000000000001	0.059999999	63	89.472	\N
38	75	1	\N	16.280999999999999	6.4889999999999999	0.19	29.079999999999998	37.805799999999998	33.627299999999998	30.8416	27.359500000000001	23.877300000000002	17.510999999999999	11.8956	7.6589999999999998	3.7869000000000002	1.5980000000000001	0.9325	0.79869999999999997	0.60219999999999996	0.063	0.024	40	93.151001	\N
39	76	1	\N	17.220300000000002	4.8730000000000002	0.27300000000000002	20.582999999999998	38.490499999999997	34.238700000000001	31.4041	27.861000000000001	24.317799999999998	18.162299999999998	13.458399999999999	9.0014000000000003	5.2944000000000004	3.5369999999999999	1.9351	1.4417	0.88239999999999996	0.063	0.022	40	92.129997	\N
40	83	1	\N	28.260899999999999	3.2789999999999999	0.35899999999999999	13.942	56.252699999999997	52.204300000000003	49.505400000000002	46.131700000000002	42.758099999999999	35.008499999999998	26.565899999999999	18.7423	13.084300000000001	10.2553	7.0022000000000002	4.8544999999999998	2.5110000000000001	0.063	0.115	40	65.912003	\N
41	85	1	\N	16.074400000000001	5.8010000000000002	0.251	23.504999999999999	38.396500000000003	33.385399999999997	30.044699999999999	25.8688	21.692900000000002	16.2209	11.481199999999999	7.4509999999999996	3.9422000000000001	2.3332999999999999	1.492	0.9919	0.69010000000000005	0.10000000000000001	0.017000001	40	91.919998	\N
42	86	1	\N	10.5191	4.8019999999999996	0.503	12.550000000000001	31.1934	18.294799999999999	15.7211	12.504	9.7315000000000005	7.3085000000000004	5.3730000000000002	3.7665000000000002	2.0425	1.4548000000000001	0.95750000000000002	0.79339999999999999	0.58240000000000003	0.063	0.025	40	92.635002	\N
43	88	1	\N	18.787800000000001	4.0659999999999998	0.17899999999999999	27.071000000000002	35.899799999999999	33.439599999999999	31.799499999999998	29.749400000000001	27.699300000000001	23.5991	19.429200000000002	14.7593	10.089399999999999	7.0568	4.1143999999999998	2.0228999999999999	0.87170000000000003	0.063	0.018999999	20	51.222	\N
44	89	1	\N	17.7194	5.5609999999999999	0.113	39.664000000000001	35.431899999999999	32.691099999999999	30.863900000000001	28.579799999999999	26.2958	21.727799999999998	17.476199999999999	13.4171	8.9944000000000006	5.8299000000000003	2.7888000000000002	1.0571999999999999	0.54779999999999995	0.063	0.023	20	56.217999	\N
45	91	1	\N	26.760999999999999	1.6160000000000001	0.70899999999999996	2.9460000000000002	39.0017	37.258400000000002	36.096200000000003	34.643500000000003	33.1907	30.2852	27.3797	24.4742	21.5687	20.116	16.937000000000001	14.273999999999999	10.279500000000001	0.10000000000000001	0.059	40	93.435997	\N
46	94	1	\N	16.300000000000001	7.3029999999999999	0.13200000000000001	33.948999999999998	37.197299999999998	33.170299999999997	30.485600000000002	27.1297	23.773800000000001	17.717300000000002	12.5024	8.1975999999999996	4.7130999999999998	2.5535999999999999	0.87749999999999995	0.62190000000000001	0.52190000000000003	0.10000000000000001	0.017999999	40	94.176003	\N
47	90	1	\N	21.123200000000001	5.117	0.083000000000000004	43.796999999999997	36.7318	34.770899999999997	33.4636	31.829499999999999	30.195399999999999	26.927199999999999	23.658999999999999	20.390799999999999	14.3278	11.1065	4.9076000000000004	1.3282	0.61480000000000001	0.063	0.037	20	38.804001	\N
48	93	1	\N	17.006799999999998	3.738	0.32600000000000001	13.103999999999999	35.700899999999997	31.953499999999998	29.455100000000002	26.3322	23.209399999999999	18.3538	14.967599999999999	11.5814	7.8345000000000002	5.7934999999999999	3.7545999999999999	2.2867999999999999	1.4006000000000001	0.063	0.017000001	40	96.883003	\N
50	98	1	\N	15.712300000000001	3.2530000000000001	0.433	12.19	33.764200000000002	30.0227	27.528300000000002	24.410399999999999	21.2925	17.358699999999999	14.0268	10.694900000000001	7.3311000000000002	5.6551	3.9956999999999998	2.8376999999999999	1.4239999999999999	0.063	0.018999999	20	67.927002	\N
51	96	1	\N	22.517299999999999	3.1339999999999999	0.313	21.433	43.0426	37.856999999999999	35.941699999999997	33.547499999999999	31.153300000000002	26.364999999999998	21.576699999999999	16.887699999999999	12.2475	9.8872999999999998	6.2878999999999996	3.8544	1.2301	0.063	0.033	40	88.474998	\N
52	100	1	\N	21.087800000000001	2.024	0.76400000000000001	3.7959999999999998	37.044499999999999	34.369	32.5854	30.355899999999998	28.126300000000001	23.667300000000001	19.432400000000001	16.236000000000001	13.0395	11.4413	9.8242999999999991	8.3923000000000005	6.2351999999999999	0.063	0.039999999	40	96.627998	\N
53	101	1	\N	23.222999999999999	1.929	0.80000000000000004	4.0750000000000002	39.511099999999999	36.781100000000002	34.961100000000002	32.686100000000003	30.411000000000001	25.861000000000001	21.311	17.697299999999998	14.4625	12.8451	11.2278	9.8795999999999999	6.3459000000000003	0.10000000000000001	0.022	40	91.074997	\N
54	103	1	\N	14.2765	4.2080000000000002	0.309	15.994999999999999	33.185200000000002	28.074400000000001	24.667100000000001	20.408100000000001	18.524699999999999	15.2616	11.9984	8.6097000000000001	5.0396999999999998	3.4487999999999999	2.1122000000000001	1.5852999999999999	0.95409999999999995	0.10000000000000001	0.017000001	40	98	\N
55	104	1	\N	14.253500000000001	7.5499999999999998	0.17000000000000001	31.536000000000001	36.338000000000001	31.344100000000001	28.014900000000001	23.853300000000001	19.819600000000001	14.947800000000001	10.0761	4.5888	0.88529999999999998	0.71879999999999999	0.60050000000000003	0.54990000000000006	0.47399999999999998	0.10000000000000001	0.022	40	94.400002	\N
56	105	1	\N	18.474	2.8370000000000002	0.52000000000000002	10.382	36.814300000000003	33.255200000000002	30.882400000000001	27.916399999999999	24.950399999999998	19.468299999999999	16.254899999999999	13.041399999999999	9.7941000000000003	7.8712999999999997	5.8967999999999998	4.1321000000000003	1.8752	0.063	0.101	40	95.370003	\N
57	106	1	\N	16.2669	3.5190000000000001	0.35399999999999998	13.641999999999999	34.468400000000003	31.1494	28.936800000000002	26.1709	23.405100000000001	18.5745	14.866300000000001	11.158099999999999	6.9123000000000001	4.9467999999999996	3.4350999999999998	2.5148999999999999	1.3614999999999999	0.063	0.061999999	20	63.844002	\N
58	110	1	\N	16.072900000000001	5.1680000000000001	0.22600000000000001	25.724	36.298200000000001	32.1218	29.337399999999999	25.856999999999999	22.3766	17.2516	13.0783	8.9657	5.1413000000000002	3.4036	1.8757999999999999	1.2024999999999999	0.67059999999999997	0.063	0.044	40	95.318001	\N
59	111	1	\N	22.0395	3.3149999999999999	0.28000000000000003	17.327999999999999	40.326000000000001	37.243600000000001	35.360900000000001	33.0075	30.6541	25.947399999999998	21.240600000000001	16.5852	11.9481	9.3480000000000008	5.5404999999999998	3.3896000000000002	1.4974000000000001	0.063	0.02	40	89.856003	\N
60	113	1	\N	14.785299999999999	5.8529999999999998	0.309	21.643999999999998	38.346200000000003	31.2103	26.452999999999999	20.506399999999999	18.0307	13.725300000000001	9.5884	6.5327999999999999	3.6871	2.2953000000000001	1.3443000000000001	0.91090000000000004	0.6341	0.063	0.030999999	40	91.390999	\N
61	114	1	\N	10.345599999999999	5.125	0.65100000000000002	13.444000000000001	29.549099999999999	23.278500000000001	19.479500000000002	16.463899999999999	13.4482	8.6082999999999998	5.6303000000000001	3.5541	2.0417000000000001	1.5684	1.1116999999999999	0.88619999999999999	0.64029999999999998	0.063	0.079999998	20	80.862999	\N
62	118	1	\N	19.6066	4.133	0.38800000000000001	14.522	47.181600000000003	38.781799999999997	35.444299999999998	31.272400000000001	27.1004	19.3611	15.074199999999999	10.7873	6.4002999999999997	4.6227999999999998	3.2275999999999998	2.2705000000000002	1.3331999999999999	0.063	0.033	40	85.459999	\N
63	119	1	\N	19.706299999999999	2.7440000000000002	0.41499999999999998	10.935	36.747199999999999	34.130699999999997	32.386299999999999	30.2058	28.025400000000001	23.6645	19.2974	14.897500000000001	10.4977	8.3134999999999994	6.1462000000000003	4.5320999999999998	2.1640000000000001	0.063	0.017999999	40	97.459	\N
64	161	1	\N	16.2134	6.8609999999999998	0.11899999999999999	33.393000000000001	36.031599999999997	32.246200000000002	29.7226	26.568200000000001	23.413699999999999	17.986999999999998	13.6005	9.3628999999999998	5.7648000000000001	3.6309999999999998	0.9103	0.68489999999999995	0.53859999999999997	0.10000000000000001	0.056000002	40	96.290001	\N
65	162	1	\N	20.436699999999998	2.7400000000000002	0.60699999999999998	25.295000000000002	41.780200000000001	36.711599999999997	34.162999999999997	30.9772	27.791399999999999	21.419899999999998	17.192599999999999	13.580299999999999	9.9704999999999995	8.3133999999999997	6.6562999999999999	4.8895	0.8468	0.10000000000000001	0.022	40	89.161003	\N
66	163	1	\N	15.460900000000001	4.2290000000000001	0.27200000000000002	20.882999999999999	34.002600000000001	30.404199999999999	28.005199999999999	25.006499999999999	22.0078	17.519100000000002	13.7896	10.0601	6.1127000000000002	4.2984	2.7128000000000001	1.6998	0.83889999999999998	0.20000000000000001	0.109	20	66.652	\N
67	170	1	\N	15.0091	4.6539999999999999	0.22500000000000001	22.085000000000001	33.489600000000003	29.583300000000001	26.979099999999999	23.7239	20.468699999999998	16.828700000000001	13.4114	9.9932999999999996	6.1429	4.2156000000000002	2.1448999999999998	1.3656999999999999	0.76200000000000001	0.20000000000000001	0.086999997	20	69.279999	\N
68	171	1	\N	14.767300000000001	6.5819999999999999	0.14699999999999999	30.181000000000001	34.369	30.1175	27.283100000000001	23.740100000000002	20.197099999999999	16.0183	11.922800000000001	8.3491999999999997	5.1600000000000001	3.0815000000000001	0.97929999999999995	0.69510000000000005	0.53069999999999995	0.10000000000000001	0.056000002	40	97.946999	\N
69	178	1	\N	12.084199999999999	7.7469999999999999	0.307	30.036000000000001	33.583199999999998	27.9801	24.244599999999998	19.7456	16.948399999999999	11.354100000000001	6.5172999999999996	2.8031999999999999	0.76219999999999999	0.58919999999999995	0.52080000000000004	0.4662	0.378	0.063	0.072999999	40	96.871002	\N
70	176	1	\N	14.4016	5.0590000000000002	0.316	19.074000000000002	34.672899999999998	30.120799999999999	27.085999999999999	23.2925	19.6995	15.149100000000001	10.598599999999999	6.8116000000000003	3.7555000000000001	2.3098000000000001	1.5921000000000001	1.1768000000000001	0.79420000000000002	0.10000000000000001	0.050000001	40	97.021004	\N
71	174	1	\N	22.203600000000002	1.7709999999999999	0.86099999999999999	3.0219999999999998	37.023000000000003	34.630099999999999	33.0349	31.040800000000001	29.046700000000001	25.058599999999998	21.070399999999999	17.905899999999999	15.0435	13.612399999999999	12.1812	11.036199999999999	8.2929999999999993	0.063	0.07	40	97.464996	\N
72	175	1	\N	15.3134	3.1429999999999998	0.499	11.548999999999999	33.941200000000002	28.6447	25.113700000000001	20.6999	18.766200000000001	15.833500000000001	12.9008	9.9695	7.1615000000000002	5.7377000000000002	4.2824999999999998	2.8988999999999998	1.3709	0.063	0.052999999	40	96.863998	\N
73	177	1	\N	15.7798	4.5720000000000001	0.219	31.036999999999999	34.1648	30.663699999999999	28.329599999999999	25.411999999999999	22.494499999999999	17.9344	14.326599999999999	10.7187	6.7563000000000004	4.9206000000000003	2.9775999999999998	1.4669000000000001	0.57779999999999998	0.10000000000000001	0.050000001	20	65.724998	\N
74	186	1	\N	15.3101	6.9980000000000002	0.13400000000000001	34.18	35.384	31.9099	29.593900000000001	26.698899999999998	23.803899999999999	18.0672	12.4328	6.9076000000000004	3.0960999999999999	1.4713000000000001	0.84419999999999995	0.65149999999999997	0.52859999999999996	0.20000000000000001	0.094999999	40	97.972	\N
75	187	1	\N	13.4641	3.1600000000000001	0.47399999999999998	10.622	30.766300000000001	25.226099999999999	21.532599999999999	19.009499999999999	17.526700000000002	14.561199999999999	11.595700000000001	8.6443999999999992	5.7929000000000004	4.5319000000000003	3.3815	2.5257000000000001	1.3709	0.10000000000000001	0.046	20	78.339996	\N
76	191	1	\N	19.261399999999998	2.206	0.66400000000000003	5.7270000000000003	35.430900000000001	32.689500000000002	30.861899999999999	28.577300000000001	26.2928	21.723700000000001	18.186	15.273199999999999	12.360300000000001	10.9039	8.9431999999999992	6.7146999999999997	3.7932999999999999	0.10000000000000001	0.064000003	20	56.227001	\N
77	188	1	\N	19.261399999999998	2.206	0.66400000000000003	5.7270000000000003	35.430900000000001	32.689500000000002	30.861899999999999	28.577300000000001	26.2928	21.723700000000001	18.186	15.273199999999999	12.360300000000001	10.9039	8.9431999999999992	6.7146999999999997	3.7932999999999999	0.10000000000000001	0.064000003	20	56.227001	\N
78	189	1	\N	18.8583	8.3149999999999995	0.080000000000000002	64.311999999999998	42.221299999999999	36.8249	34.249299999999998	31.029800000000002	27.810300000000002	21.371300000000002	15.7011	10.239100000000001	5.2252999999999998	2.8485	0.9718	0.53259999999999996	0.33229999999999998	0.063	0.25299999	40	88.931	\N
79	198	1	\N	28.610399999999998	5.1399999999999997	0.107	45.920000000000002	54.374099999999999	49.198599999999999	45.7483	41.435299999999998	38.469200000000001	33.880400000000002	29.291599999999999	24.7029	20.114100000000001	15.0932	9.8689999999999998	1.8619000000000001	0.73780000000000001	0.10000000000000001	0.059999999	40	73.335999	\N
80	164	1	\N	13.231999999999999	5.6950000000000003	0.28000000000000003	23.042000000000002	33.161299999999997	28.321899999999999	25.095700000000001	21.062899999999999	18.323599999999999	13.7707	9.3933999999999997	5.9496000000000002	3.1882999999999999	1.9320999999999999	1.2031000000000001	0.87339999999999995	0.59760000000000002	0.063	0.013	40	98.478996	\N
81	166	1	\N	19.360299999999999	4.4790000000000001	0.27200000000000002	20.437999999999999	43.199199999999998	37.179900000000004	34.607100000000003	31.390999999999998	28.174900000000001	21.742699999999999	15.9099	10.299799999999999	5.6727999999999996	3.8767999999999998	2.6867999999999999	1.8532999999999999	1.0638000000000001	0.063	0.015	40	88.384003	\N
82	165	1	\N	13.445499999999999	5.6849999999999996	0.23999999999999999	25.247	32.755600000000001	28.408899999999999	25.511099999999999	21.8889	18.953800000000001	14.581200000000001	10.208600000000001	7.0034999999999998	3.9401999999999999	2.4278	1.3546	0.87890000000000001	0.57750000000000001	0.20000000000000001	0.102	20	72.392998	\N
83	167	1	\N	18.120200000000001	2.6200000000000001	0.61599999999999999	6.0019999999999998	36.082299999999996	32.689700000000002	30.428000000000001	27.600899999999999	24.773800000000001	19.447900000000001	15.9026	12.357200000000001	8.9369999999999994	7.351	5.8444000000000003	4.7637	3.2400000000000002	0.20000000000000001	0.027000001	40	96.929001	\N
84	173	1	\N	18.444600000000001	5.3079999999999998	0.46000000000000002	14.237	50.180799999999998	42.4893	37.361600000000003	30.952000000000002	24.542400000000001	16.7821	11.7981	6.8140999999999998	3.5457999999999998	2.0103	1.7275	1.508	1.1787000000000001	2	24.966999	20	66.457001	\N
85	172	1	\N	15.597300000000001	3.488	0.56299999999999994	8.8970000000000002	42.089799999999997	29.543700000000001	21.179600000000001	18.6873	17.207599999999999	14.248200000000001	11.2889	8.3294999999999995	5.5903999999999998	4.4611000000000001	3.3319000000000001	2.4283999999999999	1.6013999999999999	2	14.103	20	79.435997	\N
86	179	1	\N	14.5814	7.2030000000000003	0.14699999999999999	30.573	35.506999999999998	30.552700000000002	27.2498	23.121300000000002	19.487200000000001	15.2834	11.079599999999999	6.9946000000000002	3.3187000000000002	1.0259	0.70320000000000005	0.58879999999999999	0.49990000000000001	0.10000000000000001	0.016000001	40	95.441002	\N
87	182	1	\N	9.5117999999999991	3.476	0.81999999999999995	7.0570000000000004	19.1617	16.895900000000001	15.385400000000001	13.497299999999999	11.6091	7.8329000000000004	5.3677000000000001	3.7982999999999998	2.2288999999999999	1.8300000000000001	1.5900000000000001	1.3979999999999999	1.1100000000000001	2	28.541	20	92.220001	\N
88	180	1	\N	20.007100000000001	2.645	1.0580000000000001	4.5019999999999998	48.773099999999999	40.236899999999999	34.546100000000003	27.432700000000001	20.319199999999999	17.425899999999999	14.7928	12.159700000000001	9.5265000000000004	8.2100000000000009	6.8933999999999997	5.7523999999999997	3.871	2	4.033	20	69.776001	\N
89	181	1	\N	22.243400000000001	5.0609999999999999	0.308	16.183	52.815899999999999	46.705399999999997	42.631799999999998	37.539700000000003	32.447699999999998	22.2636	16.628299999999999	12.292899999999999	7.9576000000000002	5.6519000000000004	2.8975	1.8231999999999999	1.3756999999999999	2	18.371	20	57.777	\N
90	183	1	\N	11.685	6.641	0.16800000000000001	27.690000000000001	30.1447	24.2315	20.289400000000001	18.2407	16.371600000000001	12.6334	8.9100999999999999	5.3940000000000001	2.3934000000000002	0.97299999999999998	0.61170000000000002	0.54949999999999999	0.45619999999999999	0.10000000000000001	0.018999999	20	79.706001	\N
91	184	1	\N	11.685	6.641	0.16800000000000001	27.690000000000001	30.1447	24.2315	20.289400000000001	18.2407	16.371600000000001	12.6334	8.9100999999999999	5.3940000000000001	2.3934000000000002	0.97299999999999998	0.61170000000000002	0.54949999999999999	0.45619999999999999	0.10000000000000001	0.018999999	20	79.706001	\N
92	185	1	\N	17.724299999999999	3.5819999999999999	0.28000000000000003	28.09	35.280099999999997	32.4482	30.560199999999998	28.200199999999999	25.840299999999999	21.1204	17.1311	13.369300000000001	9.4011999999999993	6.5316999999999998	3.9878999999999998	2.5295000000000001	0.75190000000000001	0.040000000000000001	0.037999999	20	57.625999	\N
93	192	1	\N	14.129099999999999	2.7690000000000001	0.43099999999999999	8.1760000000000002	34.558599999999998	19.769500000000001	18.722999999999999	17.414899999999999	16.1068	13.490600000000001	10.8744	8.2582000000000004	5.7332999999999998	4.6067999999999998	3.4802	2.5790000000000002	1.6500999999999999	2	13.43	20	84.880997	\N
94	193	1	\N	19.421600000000002	3.246	0.81599999999999995	7	49.225299999999997	40.9604	35.450499999999998	28.563099999999999	21.675799999999999	17.181000000000001	13.971500000000001	10.7621	7.5526	6.0378999999999996	4.8433999999999999	3.8877000000000002	2.4542999999999999	2	8.0979996	20	68.782997	\N
95	194	1	\N	15.5573	2.577	0.58299999999999996	6.8280000000000003	32.444800000000001	27.9117	24.889600000000002	21.111999999999998	19.126999999999999	16.6526	14.1783	11.703900000000001	8.9896999999999991	7.3674999999999997	5.6715	4.2013999999999996	2.4388999999999998	0.040000000000000001	0.014	20	73.528	\N
96	196	1	\N	21.351700000000001	2.968	0.89400000000000002	6.1829999999999998	51.049500000000002	43.879199999999997	39.098999999999997	33.123800000000003	27.148599999999998	18.747599999999998	15.630699999999999	12.5138	9.3969000000000005	7.8384	6.2792000000000003	4.9802999999999997	3.032	2	6.822	20	64.017998	\N
97	151	1	\N	20.994	4.7130000000000001	0.31	25.193999999999999	50.348399999999998	42.7575	38.594299999999997	34.7333	30.872399999999999	23.150500000000001	16.296299999999999	10.040100000000001	6.0359999999999996	4.3529	2.9495	1.9248000000000001	0.91890000000000005	0.040000000000000001	0.025	40	81.82	\N
98	150	1	\N	14.6968	4.9039999999999999	0.31	21.187999999999999	34.565100000000001	30.248100000000001	27.370000000000001	23.772400000000001	20.174900000000001	15.5945	11.0792	7.5499000000000001	4.6566999999999998	3.3157000000000001	1.9842	1.2575000000000001	0.73599999999999999	0.040000000000000001	0.016000001	40	97.554001	\N
99	159	1	\N	17.156099999999999	2.7330000000000001	0.55000000000000004	7.4219999999999997	34.777299999999997	31.643699999999999	29.5547	26.943300000000001	24.332000000000001	19.359999999999999	15.607100000000001	11.8543	8.3498999999999999	6.7190000000000003	5.3067000000000002	4.2373000000000003	2.6082999999999998	0.20000000000000001	0.037999999	20	61.705002	\N
100	160	1	\N	23.219999999999999	1.8879999999999999	0.68400000000000005	4.1379999999999999	38.140999999999998	35.864699999999999	34.347200000000001	32.450299999999999	30.5534	26.759699999999999	22.965900000000001	19.171800000000001	15.3766	13.478999999999999	11.5814	10.0633	6.4664000000000001	0.20000000000000001	0.02	40	94.900002	\N
101	199	1	\N	15.058199999999999	7.8289999999999997	0.56899999999999995	24.484999999999999	45.261000000000003	36.342300000000002	31.520299999999999	25.492899999999999	19.664999999999999	12.1096	6.1520999999999999	3.109	1.1876	0.86890000000000001	0.69169999999999998	0.59289999999999998	0.49459999999999998	0.063	0.034000002	40	87.033997	\N
102	200	1	\N	11.6698	7.6769999999999996	0.56100000000000005	22.207000000000001	34.823599999999999	27.845700000000001	23.1938	18.5154	15.2217	9.1062999999999992	4.8442999999999996	0.98880000000000001	0.6179	0.56599999999999995	0.51400000000000001	0.47239999999999999	0.41010000000000002	0.10000000000000001	0.033	40	94.450996	\N
103	201	1	\N	18.483799999999999	2.4079999999999999	0.59599999999999997	6.9550000000000001	35.156599999999997	32.250500000000002	30.313099999999999	27.891400000000001	25.4697	20.626300000000001	17.3553	14.3179	11.2805	9.6435999999999993	7.3705999999999996	5.5636999999999999	2.9659	0.063	0.037999999	20	58.707001	\N
104	202	1	\N	13.3728	5.5579999999999998	0.442	20.640999999999998	34.523499999999999	29.567599999999999	26.2636	22.133600000000001	18.630800000000001	12.9659	8.0052000000000003	4.7336	2.6076999999999999	1.8165	1.3197000000000001	0.95709999999999995	0.62819999999999998	0.063	0.134	40	96.629997	\N
105	205	1	\N	17.080300000000001	4.7800000000000002	0.61499999999999999	11.446	48.0916	39.146500000000003	33.183199999999999	25.728899999999999	19.477499999999999	14.9627	10.447900000000001	6.1302000000000003	4.0411000000000001	2.9965999999999999	1.9843999999999999	1.7136	1.3071999999999999	2	20.23	20	71.156998	\N
106	203	1	\N	18.5578	4.8680000000000003	0.49299999999999999	12.461	49.817300000000003	41.907600000000002	36.634500000000003	30.043199999999999	23.451799999999999	16.715199999999999	12.2652	7.8151999999999999	4.6642000000000001	3.4241000000000001	2.1840000000000002	1.7682	1.3413999999999999	2	19.257999	20	67.382004	\N
107	204	1	\N	18.891400000000001	5.1669999999999998	0.40999999999999998	13.977	50.210900000000002	42.537500000000001	37.421900000000001	31.0273	24.6328	17.219999999999999	12.860900000000001	8.5017999999999994	4.5548000000000002	2.7915999999999999	1.8341000000000001	1.5932999999999999	1.2321	2	22.754999	20	66.377998	\N
108	208	1	\N	22.749199999999998	3.6469999999999998	0.375	21.446999999999999	50.7087	43.3339	39.147199999999998	35.835700000000003	32.5242	25.9011	19.415800000000001	14.057	8.9444999999999997	6.7717999999999998	4.7843999999999998	3.2581000000000002	1.2077	0.10000000000000001	0.017000001	40	81.288002	\N
109	209	1	\N	18.706299999999999	4.1420000000000003	0.20000000000000001	26.981999999999999	36.195	33.374200000000002	31.4937	29.143000000000001	26.792300000000001	22.091000000000001	18.0016	14.4023	10.803000000000001	7.9050000000000002	4.2130999999999998	1.9451000000000001	0.81869999999999998	0.10000000000000001	0.057999998	40	98.093002	\N
110	210	1	\N	13.257999999999999	6.3529999999999998	0.23000000000000001	26.428000000000001	33.041800000000002	28.866900000000001	26.083600000000001	22.604500000000002	19.364000000000001	14.3041	9.4760000000000009	6.0298999999999996	3.1137999999999999	1.7362	0.93369999999999997	0.71530000000000005	0.54120000000000001	0.10000000000000001	0.033	20	71.257004	\N
111	213	1	\N	21.786100000000001	4.8360000000000003	0.34899999999999998	13.909000000000001	52.340600000000002	45.944899999999997	41.681199999999997	36.351399999999998	31.021699999999999	20.362300000000001	16.075299999999999	12.012600000000001	7.9497999999999998	5.8754	3.6149	1.9642999999999999	1.4639	2	16.427999	20	59.66	\N
112	214	1	\N	22.98	4.867	0.313	16.079000000000001	53.223100000000002	47.356900000000003	43.446199999999997	38.557699999999997	33.6693	23.892399999999999	17.402200000000001	13.0861	8.7700999999999993	6.6120000000000001	4.0766	1.9995000000000001	1.486	2	16.004999	20	56.019001	\N
113	219	1	\N	18.670200000000001	3.6299999999999999	0.752	8.6199999999999992	49.002499999999998	40.604100000000003	35.005099999999999	28.0063	21.0076	16.5809	12.896599999999999	9.2123000000000008	5.8810000000000002	4.8811999999999998	3.8814000000000002	3.0815000000000001	1.9235	2	10.591	20	69.279999	\N
114	220	1	\N	18.220099999999999	3.8039999999999998	0.61599999999999999	9.8819999999999997	47.929400000000001	38.887	32.858699999999999	25.323399999999999	19.523199999999999	16.2743	13.025499999999999	9.7766000000000002	6.5277000000000003	5.1319999999999997	3.7736000000000001	2.6867999999999999	1.6469	2	13.472	20	71.468002	\N
115	215	1	\N	18.693000000000001	3.8759999999999999	0.54600000000000004	12.141	47.335799999999999	38.612099999999998	34.3964	29.1267	23.856999999999999	17.4695	13.478400000000001	9.5418000000000003	6.0461	4.6539000000000001	3.4302999999999999	2.5708000000000002	1.4389000000000001	0.063	0.103	40	85.317001	\N
116	217	1	\N	16.8886	3.4140000000000001	0.41399999999999998	15.635	35.991199999999999	31.787800000000001	28.985600000000002	25.482800000000001	21.979900000000001	17.689900000000002	14.4697	11.249599999999999	7.8151000000000002	6.0301	4.2453000000000003	2.7280000000000002	1.1314	0.20000000000000001	0.054000001	40	95.722	\N
117	216	1	\N	18.297000000000001	2.649	0.55100000000000005	8.6980000000000004	35.870800000000003	32.582000000000001	30.389500000000002	27.648800000000001	24.908200000000001	19.6752	16.569500000000001	13.463699999999999	10.357900000000001	8.4345999999999997	6.4004000000000003	4.6429999999999998	2.262	0.20000000000000001	0.11	40	97.532997	\N
118	221	1	\N	16.866199999999999	2.6930000000000001	0.57499999999999996	6.6689999999999996	34.565300000000001	30.718299999999999	28.153700000000001	24.947900000000001	21.742000000000001	17.909600000000001	15.039300000000001	12.169	9.0864999999999991	7.2169999999999996	5.4965999999999999	4.2351999999999999	2.6857000000000002	0.063	0.086000003	40	98.475998	\N
119	223	1	\N	21.124099999999999	1.9470000000000001	0.67400000000000004	5.3570000000000002	36.2562	34.009900000000002	32.5124	30.6404	28.7685	25.024699999999999	21.280899999999999	17.738700000000001	14.3012	12.5825	10.863799999999999	8.9739000000000004	4.6715999999999998	0.20000000000000001	0.16	20	46.578999	\N
120	224	1	\N	12.482200000000001	5.6669999999999998	0.25900000000000001	20.998999999999999	31.8704	25.701699999999999	21.589200000000002	18.604700000000001	16.585000000000001	12.5456	8.9062000000000001	5.9892000000000003	3.1373000000000002	1.6513	0.94430000000000003	0.80030000000000001	0.59740000000000004	0.20000000000000001	0.094999999	40	97.906998	\N
121	222	1	\N	21.9267	4.2160000000000002	0.30199999999999999	20.899999999999999	50.157600000000002	42.452100000000002	38.558799999999998	35.112099999999998	31.665299999999998	24.771799999999999	18.3142	12.837199999999999	7.6805000000000003	5.4756999999999998	3.6318000000000001	2.3883999999999999	1.1853	0.063	0.139	40	82.091003	\N
122	231	1	\N	13.2669	4.4009999999999998	1.0389999999999999	9.3330000000000002	40.795200000000001	27.4724	19.707100000000001	17.399999999999999	15.0928	10.4786	6.1246	4.2664999999999997	2.4083999999999999	1.8619000000000001	1.6154999999999999	1.4184000000000001	1.1228	2	27.802	20	80.635002	\N
123	230	1	\N	17.867100000000001	3.641	0.68400000000000005	9.1170000000000009	47.424100000000003	38.078499999999998	31.848099999999999	24.060199999999998	19.213799999999999	15.929	12.6442	9.3594000000000008	6.1398999999999999	4.9728000000000003	3.8056999999999999	2.8721000000000001	1.7471000000000001	2	12.264	20	72.392998	\N
124	233	1	\N	15.313800000000001	4.6909999999999998	0.20999999999999999	26.216000000000001	33.759599999999999	30.0154	27.519200000000001	24.399000000000001	21.2788	17.332799999999999	13.978199999999999	10.6236	6.1745000000000001	3.9468999999999999	2.1890000000000001	1.3637999999999999	0.66110000000000002	0.040000000000000001	0.045000002	20	67.950996	\N
125	237	1	\N	14.4908	6.2080000000000002	0.21099999999999999	25.562999999999999	35.275100000000002	30.226500000000001	26.860800000000001	22.653700000000001	19.205300000000001	14.900700000000001	10.596	7.0240999999999998	3.9923000000000002	1.9894000000000001	0.94399999999999995	0.7843	0.58289999999999997	0.20000000000000001	0.037999999	40	95.614998	\N
126	238	1	\N	11.611599999999999	7.6550000000000002	0.161	34.905999999999999	31.098199999999999	25.757100000000001	22.196400000000001	18.896899999999999	16.719200000000001	12.363799999999999	8.3977000000000004	4.7823000000000002	0.60870000000000002	0.54830000000000001	0.4879	0.43959999999999999	0.35420000000000001	0.063	0.086000003	20	77.532997	\N
127	61	1	\N	14.394600000000001	6.6360000000000001	0.16600000000000001	28.271000000000001	34.601700000000001	29.954999999999998	26.857099999999999	22.9849	19.516200000000001	15.293900000000001	11.0716	7.4043999999999999	4.0792999999999999	1.7905	0.87109999999999999	0.68030000000000002	0.54100000000000004	0.10000000000000001	0.013	40	96.971001	\N
128	62	1	\N	24.4757	2.605	0.996	6.7460000000000004	53.462400000000002	47.739800000000002	43.924700000000001	39.155900000000003	34.387099999999997	24.849499999999999	18.362300000000001	15.0307	11.699	10.033200000000001	8.3673000000000002	7.0347	3.6836000000000002	2	7.5580001	20	54.915001	\N
129	64	1	\N	18.338100000000001	5.2460000000000004	0.41999999999999998	14.058999999999999	49.695900000000002	41.713500000000003	36.3919	29.739799999999999	23.087800000000001	16.639800000000001	12.263999999999999	7.8882000000000003	3.9432999999999998	2.0935999999999999	1.7372000000000001	1.5158	1.1836	2	24.747	20	67.679001	\N
130	63	1	\N	17.0395	3.198	0.82199999999999995	6.5789999999999997	45.490499999999997	34.984699999999997	27.980899999999998	19.862200000000001	18.302800000000001	15.183999999999999	12.065300000000001	8.9465000000000003	6.0190000000000001	5.0913000000000004	4.1635	3.4214000000000002	2.3081	2	8.3400002	20	75.442001	\N
131	240	1	\N	12.2874	5.3449999999999998	0.187	24.600999999999999	29.750499999999999	23.6008	19.843599999999999	18.236899999999999	16.630299999999998	13.4169	10.2036	7.1571999999999996	4.1909999999999998	2.6972999999999998	1.4443999999999999	0.82599999999999996	0.5454	0.063	0.02	20	80.487	\N
132	244	1	\N	15.1685	8.9269999999999996	0.39700000000000002	45.238	39.801699999999997	35.106000000000002	31.9756	28.0625	24.1495	15.734500000000001	6.2374000000000001	1.3781000000000001	0.67689999999999995	0.57320000000000004	0.4995	0.4405	0.3478	0.063	0.13600001	40	90.252998	\N
133	250	1	\N	22.3461	3.181	0.76600000000000001	7.7590000000000003	52.268900000000002	45.830300000000001	41.537799999999997	36.1723	30.806699999999999	20.075700000000001	16.4634	12.9017	9.3399000000000001	7.5590999999999999	5.8255999999999997	4.5303000000000004	2.5872999999999999	2	8.1859999	20	59.929001	\N
134	251	1	\N	19.273700000000002	4.7110000000000003	0.43099999999999999	12.208	49.9617	42.1387	36.923400000000001	30.404299999999999	23.885100000000001	17.3734	13.6319	9.8902999999999999	6.1677	4.5304000000000002	2.8931	1.8991	1.4232	2	17.273001	20	67.019997	\N
135	253	1	\N	11.1915	5.0739999999999998	0.185	23.244	26.400600000000001	19.5852	18.302299999999999	16.698799999999999	15.0952	11.8881	8.9768000000000008	6.4888000000000003	4.2733999999999996	2.9129999999999998	1.4015	0.76060000000000005	0.51149999999999995	0.10000000000000001	0.046999998	20	85.292999	\N
136	254	1	\N	11.9459	4.3959999999999999	0.307	16.297000000000001	29.274699999999999	22.839500000000001	19.537600000000001	17.828299999999999	16.119	12.7004	9.3773999999999997	6.4138000000000002	4.0441000000000003	2.8094000000000001	1.7531000000000001	1.1819	0.77929999999999999	0.20000000000000001	0.12	20	81.352997	\N
137	258	1	\N	10.9049	6.4279999999999999	0.34699999999999998	21.427	30.309999999999999	24.496099999999998	20.620100000000001	17.871300000000002	15.430099999999999	10.547700000000001	6.4718999999999998	3.5895999999999999	1.1566000000000001	0.85850000000000004	0.68999999999999995	0.59279999999999999	0.49230000000000002	0.20000000000000001	0.14	20	79.360001	\N
138	260	1	\N	10.890000000000001	5.5460000000000003	0.20599999999999999	21.123000000000001	27.802199999999999	20.483599999999999	18.665800000000001	16.814699999999998	14.9635	11.261100000000001	8.1310000000000002	5.4044999999999996	2.5339	1.1129	0.82189999999999996	0.66600000000000004	0.53310000000000002	0.10000000000000001	0.033	20	83.603996	\N
139	261	1	\N	11.6714	4.2530000000000001	0.28000000000000003	14.651999999999999	28.534199999999998	20.416599999999999	18.805399999999999	17.1875	15.569599999999999	12.3339	9.0762	5.7987000000000002	2.9948000000000001	1.923	1.4818	1.1288	0.84179999999999999	0.10000000000000001	0.057	40	98.474998	\N
140	262	1	\N	13.4947	3.9830000000000001	0.434	14.398999999999999	32.950000000000003	27.3188	23.564699999999998	19.560099999999998	17.729900000000001	14.0694	10.408899999999999	6.2203999999999997	3.7608000000000001	3.0139	2.2669999999999999	1.7219	0.97709999999999997	0.063	0.20299999	40	97.512001	\N
141	265	1	\N	11.5136	4.0640000000000001	0.28100000000000003	14.891999999999999	27.5745	20.119199999999999	18.770199999999999	17.1952	15.620100000000001	12.470000000000001	9.3331	6.2565	3.8391999999999999	2.4300999999999999	1.6367	1.2182999999999999	0.83740000000000003	0.10000000000000001	0.017000001	20	83.903999	\N
142	267	1	\N	14.75	2.3740000000000001	0.53400000000000003	6.1520000000000001	35.6922	19.937000000000001	18.9438	17.702300000000001	16.460699999999999	13.9777	11.4946	9.0115999999999996	6.5285000000000002	5.4386999999999999	4.3830999999999998	3.5387	2.2719999999999998	2	8.7119999	20	84.253998	\N
143	270	1	\N	11.7745	3.7090000000000001	0.32000000000000001	16.186	26.6403	19.304300000000001	18.097100000000001	16.588200000000001	15.0792	12.061299999999999	9.1943000000000001	6.6524999999999999	4.3411	3.2071999999999998	2.0746000000000002	1.403	0.74519999999999997	0.10000000000000001	0.018999999	40	97.432999	\N
144	276	1	\N	11.3032	5.6280000000000001	0.19600000000000001	22.396999999999998	29.1267	22.602699999999999	19.4559	17.762499999999999	16.068999999999999	12.682	9.0749999999999993	4.6105999999999998	1.4031	0.94620000000000004	0.81699999999999995	0.7137	0.56620000000000004	0.10000000000000001	0.023	20	81.606003	\N
145	279	1	\N	8.7012	5.0819999999999999	0.78800000000000003	12.090999999999999	23.078700000000001	17.355799999999999	15.0848	12.2462	9.6661000000000001	6.4661999999999997	3.8473999999999999	2.2080000000000002	1.2712000000000001	0.9466	0.79400000000000004	0.67190000000000005	0.53480000000000005	0.040000000000000001	0.19599999	40	97.378998	\N
146	285	1	\N	13.6882	5.577	0.191	25.991	32.887500000000003	27.441400000000002	23.810700000000001	19.728000000000002	18.031400000000001	14.638199999999999	11.244999999999999	7.7013999999999996	4.1948999999999996	2.5832999999999999	1.4131	0.88229999999999997	0.56320000000000003	0.10000000000000001	0.02	40	97.835999	\N
147	288	1	\N	10.0344	4.6719999999999997	0.42699999999999999	15.037000000000001	26.631	19.529399999999999	17.7193	15.456799999999999	13.1942	9.1806999999999999	6.3951000000000002	4.3921999999999999	2.3193999999999999	1.6637	1.1799999999999999	0.89490000000000003	0.61050000000000004	0.040000000000000001	0.039000001	20	85.040001	\N
148	294	1	\N	16.6617	3.661	0.308	22.693000000000001	34.696800000000003	31.514900000000001	29.393699999999999	26.742100000000001	24.090499999999999	19.164200000000001	15.509	11.8538	7.6280000000000001	5.4813999999999998	3.6850000000000001	2.3519000000000001	0.84450000000000003	0.10000000000000001	0.02	20	62.286999	\N
149	296	1	\N	22.863	2.4329999999999998	0.89700000000000002	5.0830000000000002	58.390000000000001	38.224899999999998	35.0321	31.0412	27.0502	19.6431	16.585799999999999	13.5284	10.471	9.0164000000000009	7.5946999999999996	6.4573999999999998	3.8643000000000001	0.040000000000000001	0.061999999	63	90.946999	\N
150	300	1	\N	12.812900000000001	6.4909999999999997	0.16600000000000001	26.134	32.168900000000001	26.136900000000001	22.115600000000001	18.9495	17.1355	13.5076	9.8889999999999993	6.5411999999999999	2.7829000000000002	1.1724000000000001	0.79379999999999995	0.62039999999999995	0.51690000000000003	0.10000000000000001	0.022	40	97.790001	\N
151	303	1	\N	12.0617	6.0039999999999996	0.25800000000000001	23.434999999999999	31.312899999999999	26.1006	22.625699999999998	19.142299999999999	16.973600000000001	12.636200000000001	8.5603999999999996	5.2443999999999997	2.5720999999999998	1.4933000000000001	0.9002	0.72409999999999997	0.53920000000000001	0.10000000000000001	0.016000001	20	76.976997	\N
152	308	1	\N	8.4343000000000004	5.2960000000000003	0.37	14.712	19.986599999999999	16.9953	15.001099999999999	12.5084	10.015700000000001	7.3894000000000002	5.2794999999999996	3.5672999999999999	1.9561999999999999	1.2287999999999999	0.79010000000000002	0.60599999999999998	0.50229999999999997	0.10000000000000001	0.022	20	90.027	\N
153	309	1	\N	12.721399999999999	2.7869999999999999	0.64800000000000002	7.0069999999999997	29.278199999999998	22.845199999999998	19.578399999999998	18.012699999999999	16.446999999999999	13.3157	10.1843	7.7563000000000004	5.5429000000000004	4.5701999999999998	3.6393	2.9420999999999999	1.9003000000000001	0.040000000000000001	0.033	20	81.346001	\N
154	311	1	\N	14.6983	6.4669999999999996	0.13200000000000001	32.027000000000001	33.645000000000003	29.832000000000001	27.289999999999999	24.112500000000001	20.934999999999999	16.644100000000002	12.709199999999999	8.8749000000000002	5.2606000000000002	3.3368000000000002	1.389	0.71330000000000005	0.51970000000000005	0.10000000000000001	0.013	20	68.528999	\N
155	316	1	\N	14.6548	3.4329999999999998	0.72499999999999998	8.8369999999999997	35.838700000000003	29.0243	24.481400000000001	19.591100000000001	17.651700000000002	13.7729	9.9305000000000003	7.3837999999999999	5.1166999999999998	4.0865999999999998	3.1796000000000002	2.4630999999999998	1.5585	0.20000000000000001	0.044	40	93.664001	\N
156	320	1	\N	10.006	5.5629999999999997	0.25700000000000001	20.137	25.165500000000002	19.0839	17.628699999999998	15.8096	13.990500000000001	10.3523	6.7709999999999999	4.1699999999999999	2.0196999999999998	1.2371000000000001	0.80789999999999995	0.61660000000000004	0.5141	0.10000000000000001	0.024	20	86.517998	\N
157	323	1	\N	12.664099999999999	5.7240000000000002	0.46700000000000003	18.158000000000001	34.212000000000003	27.849499999999999	23.607800000000001	19.123799999999999	16.381799999999998	10.8978	7.1196000000000002	4.4638999999999998	2.5192000000000001	1.7250000000000001	1.091	0.84989999999999999	0.60019999999999996	0.10000000000000001	0.014	40	95.458	\N
158	325	1	\N	10.696099999999999	4.5380000000000003	0.29699999999999999	15.593	26.8749	19.730799999999999	18.317499999999999	16.550999999999998	14.7844	11.251300000000001	7.9759000000000002	4.8909000000000002	2.1610999999999998	1.6443000000000001	1.2384999999999999	0.95809999999999995	0.72160000000000002	0.040000000000000001	0.017000001	20	84.762001	\N
159	327	1	\N	11.651300000000001	4.3769999999999998	0.28399999999999997	16.167000000000002	28.521899999999999	21.635000000000002	19.154499999999999	17.513300000000001	15.872	12.589399999999999	9.2743000000000002	5.9696999999999996	3.5903999999999998	2.5537999999999998	1.6797	1.1294999999999999	0.77869999999999995	0.10000000000000001	0.057999998	20	82.575996	\N
160	328	1	\N	19.508500000000002	2.3490000000000002	0.73099999999999998	6.2869999999999999	37.677599999999998	33.888100000000001	31.361699999999999	28.203800000000001	25.0459	19.476800000000001	16.875	14.273199999999999	11.6713	10.3704	8.1786999999999992	6.1416000000000004	3.0979999999999999	0.063	0.223	40	93.677002	\N
161	339	1	\N	8.4835999999999991	2.331	0.874	4.1550000000000002	17.372199999999999	14.8912	13.2371	11.169600000000001	9.6897000000000002	8.2607999999999997	6.8319999999999999	5.5861999999999998	4.4490999999999996	3.8683999999999998	3.2418	2.7404999999999999	1.9879	0.20000000000000001	0.022	20	96.355003	\N
162	343	1	\N	2.4392	2.843	1.2729999999999999	4.1440000000000001	5.6628999999999996	4.0212000000000003	3.5973000000000002	3.0838999999999999	2.5705	1.7703	1.2534000000000001	0.89370000000000005	0.68520000000000003	0.60250000000000004	0.54410000000000003	0.49730000000000002	0.42720000000000002	0.20000000000000001	0.067000002	10	96.530998	\N
163	344	1	\N	8.2980999999999998	5.173	1.208	9.5259999999999998	25.4648	18.587800000000001	16.066299999999998	12.9145	9.7911999999999999	5.3041	3.2692000000000001	1.9234	1.1996	0.93910000000000005	0.80330000000000001	0.6946	0.55679999999999996	0.20000000000000001	0.055	20	86.239998	\N
164	345	1	\N	1.7492000000000001	2.3820000000000001	1.329	3.137	3.7315	3.0579999999999998	2.609	2.0478000000000001	1.835	1.4743999999999999	1.1136999999999999	0.88949999999999996	0.72809999999999997	0.64739999999999998	0.58489999999999998	0.53900000000000003	0.46999999999999997	0.20000000000000001	0.1	10	99.599998	\N
165	346	1	\N	3.2924000000000002	2.3919999999999999	0.64600000000000002	5.6989999999999998	6.1516999999999999	5.3358999999999996	4.7920999999999996	4.1123000000000003	3.7883	3.2812000000000001	2.7740999999999998	2.2669999999999999	1.7343	1.4537	1.173	0.93220000000000003	0.57579999999999998	0.20000000000000001	0.1	10	97.797997	\N
205	58	1	\N	21.488099999999999	5.7629999999999999	0.81899999999999995	21.568000000000001	56.907499999999999	50.408499999999997	46.075899999999997	40.6601	33.889299999999999	19.978100000000001	9.6655999999999995	5.6079999999999997	3.4670000000000001	2.6692	1.9191	1.5177	0.92630000000000001	0.040000000000000001	0.030999999	63	95.625	\N
206	73	1	\N	22.1219	4.1559999999999997	0.21299999999999999	25.312999999999999	41.727800000000002	37.037199999999999	34.946399999999997	32.332999999999998	29.7195	24.4925	19.311199999999999	14.4091	9.4939	6.9778000000000002	4.4108000000000001	2.1440999999999999	0.96760000000000002	0.063	0.011	63	94.084	\N
207	74	1	\N	24.824400000000001	2.4380000000000002	0.56399999999999995	6.4219999999999997	49.820500000000003	41.9129	38.661000000000001	36.034199999999998	33.407299999999999	28.153700000000001	22.899999999999999	17.9664	13.4274	11.1579	8.8811999999999998	7.0537999999999998	4.3842999999999996	0.10000000000000001	0.032000002	40	82.549004	\N
208	67	1	\N	14.6937	3.9710000000000001	0.41299999999999998	20.370999999999999	34.045900000000003	29.418299999999999	26.333200000000001	22.476800000000001	19.304400000000001	15.415800000000001	11.527100000000001	8.2576000000000001	5.5172999999999996	4.2854999999999999	2.9323999999999999	1.8652	0.75680000000000003	0.20000000000000001	0.050999999	40	97.720001	\N
209	68	1	\N	36.3185	4.1429999999999998	0.27700000000000002	23.084	74.073400000000007	70.517499999999998	68.146900000000002	65.183599999999998	60.665300000000002	42.918399999999998	32.345300000000002	23.184000000000001	14.265599999999999	9.8923000000000005	6.2431000000000001	4.1090999999999998	1.8593	0.10000000000000001	0.044	63	71.316002	\N
210	69	1	\N	39.152299999999997	2.8820000000000001	0.46800000000000003	12.053000000000001	74.279600000000002	70.847399999999993	68.559299999999993	65.699100000000001	62.570799999999998	47.327599999999997	35.927999999999997	28.0867	20.2453	16.087900000000001	11.9147	8.5272000000000006	3.9266000000000001	0.10000000000000001	0.030999999	63	70.281998	\N
211	70	1	\N	19.420000000000002	4.673	0.27200000000000002	18.068000000000001	39.8279	35.555599999999998	32.707500000000003	29.147300000000001	25.5871	19.042400000000001	14.595700000000001	10.148899999999999	5.4317000000000002	3.5181	2.0348999999999999	1.6283000000000001	1.0539000000000001	0.20000000000000001	0.044	63	93.656998	\N
212	71	1	\N	29.768899999999999	4.3959999999999999	0.25	20.266999999999999	66.728099999999998	58.4726	52.797400000000003	45.703400000000002	39.3752	33.001399999999997	26.627500000000001	20.253699999999998	13.1119	9.1926000000000005	4.4854000000000003	3.0257999999999998	1.6284000000000001	0.10000000000000001	0.0089999996	63	87.191002	\N
213	81	1	\N	16.696000000000002	3.4260000000000002	0.44700000000000001	10.513	36.019100000000002	32.084000000000003	29.460599999999999	26.1814	22.902100000000001	17.856300000000001	14.011200000000001	10.166	6.3700000000000001	4.8273000000000001	3.5385	2.7342	1.6983999999999999	0.040000000000000001	0.048999999	40	96.07	\N
214	84	1	\N	26.761800000000001	2.919	0.46200000000000002	12.477	54.4191	49.270600000000002	45.838299999999997	41.547899999999998	37.910299999999999	31.372199999999999	24.834099999999999	18.635100000000001	13.398	10.779500000000001	8.0266999999999999	5.7816999999999998	2.5145	0.10000000000000001	0.027000001	40	73.195999	\N
215	87	1	\N	16.441400000000002	3.3740000000000001	0.40000000000000002	13.968	34.708399999999997	31.5334	29.416799999999999	26.771000000000001	24.1252	19.056000000000001	14.7737	10.491400000000001	6.9299999999999997	5.3365999999999998	3.8431999999999999	2.7692000000000001	1.3643000000000001	0.040000000000000001	0.101	20	62.203999	\N
216	92	1	\N	21.988700000000001	2.7909999999999999	0.38500000000000001	9.1850000000000005	39.197200000000002	36.476300000000002	34.662300000000002	32.3949	30.127400000000002	25.592500000000001	21.057600000000001	16.815300000000001	12.661899999999999	10.5853	7.0251000000000001	4.6841999999999997	2.7864	0.040000000000000001	0.017999999	40	91.769997	\N
217	77	1	\N	22.795200000000001	1.992	0.64500000000000002	7.5910000000000002	38.387300000000003	36.005600000000001	34.417700000000004	32.433	30.4482	26.4786	22.5091	18.6221	14.877000000000001	13.0044	11.1318	9.0728000000000009	3.4883000000000002	0.040000000000000001	0.017000001	40	94.063004	\N
218	97	1	\N	18.652200000000001	3.6309999999999998	0.30499999999999999	13.388999999999999	36.9801	33.596299999999999	31.340399999999999	28.520499999999998	25.700600000000001	20.0608	16.761700000000001	13.488099999999999	10.214499999999999	7.6510999999999996	4.5770999999999997	2.5478000000000001	1.4983	0.040000000000000001	0.021	40	95.355003	\N
219	95	1	\N	20.883700000000001	5.7990000000000004	0.065000000000000002	46.880000000000003	36.694200000000002	34.710700000000003	33.388300000000001	31.735399999999998	30.0825	26.776700000000002	23.4709	20.164999999999999	13.8086	10.5502	3.3999999999999999	1.0323	0.57120000000000004	0.040000000000000001	0.037	20	39.500999	\N
220	102	1	\N	16.260400000000001	2.6389999999999998	0.60099999999999998	7.3689999999999998	33.719200000000001	29.950800000000001	27.438500000000001	24.298100000000002	21.157699999999998	17.590199999999999	14.635899999999999	11.6815	8.6585999999999999	7.1018999999999997	5.5458999999999996	4.3018999999999998	2.387	0.040000000000000001	0.017999999	20	68.156998	\N
221	107	1	\N	18.939599999999999	3.536	0.34699999999999998	14.663	38.125799999999998	34.710000000000001	32.432899999999997	29.586400000000001	26.739899999999999	21.047000000000001	16.6585	12.564	8.3133999999999997	6.0789999999999997	4.0228999999999999	2.7768000000000002	1.4354	0.040000000000000001	0.039999999	40	93.292	\N
222	112	1	\N	15.628399999999999	4.8780000000000001	0.45500000000000002	17.041	39.695999999999998	33.111199999999997	28.721299999999999	23.234000000000002	19.0747	14.5679	10.061199999999999	6.7302999999999997	3.9049	2.8376999999999999	1.871	1.3913	0.85489999999999999	0.10000000000000001	0.027000001	40	90.277	\N
223	116	1	\N	17.621600000000001	6.4580000000000002	0.13800000000000001	34.067999999999998	38.537100000000002	34.844900000000003	32.383499999999998	29.306699999999999	26.229900000000001	20.0763	14.531499999999999	9.1087000000000007	4.6643999999999997	2.4357000000000002	1.1054999999999999	0.83540000000000003	0.58930000000000005	0.10000000000000001	0.017000001	40	92.376999	\N
224	117	1	\N	17.395800000000001	6.3410000000000002	0.32700000000000001	22.841000000000001	46.8309	38.186599999999999	34.100700000000003	28.993300000000001	23.885899999999999	16.379999999999999	10.5374	6.6470000000000002	3.4912999999999998	2.0655999999999999	1.3617999999999999	0.94969999999999999	0.71709999999999996	0.040000000000000001	0.016000001	40	85.775002	\N
225	121	1	\N	17.8139	6.2750000000000004	0.125	58.637	37.880200000000002	34.423999999999999	32.119799999999998	29.2395	26.359300000000001	20.5989	15.5198	10.5198	5.5597000000000003	3.4304999999999999	1.6654	0.87409999999999999	0.3513	0.040000000000000001	0.017000001	40	93.68	\N
226	120	1	\N	13.1058	5.9619999999999997	0.34999999999999998	21.373000000000001	34.488500000000002	28.3323	24.228100000000001	19.559100000000001	17.051600000000001	12.0366	8.0289000000000001	5.1387	2.8565	1.8301000000000001	1.0044	0.79720000000000002	0.56320000000000003	0.040000000000000001	0.017000001	40	95.372002	\N
227	124	1	\N	18.491399999999999	4.1820000000000004	0.28499999999999998	23.515999999999998	38.559199999999997	35.076599999999999	32.754899999999999	29.852699999999999	26.950600000000001	21.1463	15.7202	10.3872	6.2229999999999999	4.7407000000000004	3.2326999999999999	2.0057	0.8992	0.040000000000000001	0.017000001	40	92.482002	\N
228	125	1	\N	15.6945	4.0030000000000001	0.28499999999999998	17.591999999999999	33.9925	30.388100000000001	27.985099999999999	24.981300000000001	21.977599999999999	17.683800000000002	14.231	10.7783	6.7217000000000002	4.7778	3.0556000000000001	1.8964000000000001	1.0052000000000001	0.040000000000000001	0.021	20	66.708	\N
229	126	1	\N	12.652699999999999	5.5179999999999998	0.25600000000000001	29.774999999999999	31.693000000000001	26.7088	23.385999999999999	19.6267	17.6067	13.566599999999999	9.5640000000000001	5.9809000000000001	3.5011000000000001	2.4603999999999999	1.5165	0.87729999999999997	0.4556	0.040000000000000001	0.041999999	20	75.924004	\N
230	127	1	\N	10.5984	4.4509999999999996	0.94999999999999996	10.800000000000001	29.9512	21.873200000000001	18.665500000000002	16.107800000000001	13.5501	8.5942000000000007	5.0423999999999998	3.1661999999999999	1.897	1.6137999999999999	1.3306	1.1040000000000001	0.79579999999999995	0.040000000000000001	0.048999999	40	97.463997	\N
231	128	1	\N	19.9023	2.6640000000000001	0.51200000000000001	10.553000000000001	37.663600000000002	34.645299999999999	32.633099999999999	30.117799999999999	27.602499999999999	22.571899999999999	18.174800000000001	14.4405	10.706099999999999	8.6813000000000002	6.5606	4.8808999999999996	2.1387999999999998	0.10000000000000001	0.016000001	40	94.643997	\N
232	129	1	\N	13.3161	4.0750000000000002	0.52300000000000002	14.545999999999999	33.683999999999997	26.189599999999999	21.193300000000001	18.3218	16.247199999999999	12.098100000000001	8.8910999999999998	6.6479999999999997	4.5575000000000001	3.4841000000000002	2.3611	1.5772999999999999	0.83169999999999999	0.10000000000000001	0.017000001	40	95.056999	\N
233	130	1	\N	20.4739	4.1399999999999997	0.22800000000000001	25.945	41.728299999999997	37.213900000000002	35.065600000000003	32.380200000000002	29.694800000000001	24.324000000000002	18.835799999999999	12.8627	7.3322000000000003	5.1769999999999996	3.4173	2.1715	0.9375	0.040000000000000001	0.041000001	40	89.188004	\N
234	131	1	\N	19.145700000000001	7.5510000000000002	0.16600000000000001	46.366999999999997	49.427	41.283200000000001	37.387300000000003	33.110500000000002	28.8338	20.2803	13.412000000000001	7.1902999999999997	2.9984000000000002	1.7592000000000001	1.1186	0.72409999999999997	0.43740000000000001	0.040000000000000001	0.083999999	40	83.055	\N
235	132	1	\N	21.035499999999999	4.7519999999999998	0.247	32.210000000000001	48.8613	40.378100000000003	37.257599999999996	33.584000000000003	29.910399999999999	22.563199999999998	17.113900000000001	12.6815	7.8760000000000003	5.4044999999999996	3.2898999999999998	1.7882	0.70050000000000001	0.040000000000000001	0.044	40	83.733002	\N
236	133	1	\N	19.435700000000001	6.4610000000000003	0.16	32.613999999999997	47.457000000000001	38.985999999999997	35.612400000000001	31.395499999999998	27.178599999999999	19.365500000000001	15.1023	10.8392	6.2333999999999996	3.9169999999999998	1.7432000000000001	0.93389999999999995	0.59379999999999999	0.040000000000000001	0.034000002	40	85.202003	\N
237	134	1	\N	15.0449	6.6920000000000002	0.27600000000000002	28.84	38.533900000000003	32.631599999999999	28.6968	23.778199999999998	19.392099999999999	14.1479	9.2895000000000003	5.9547999999999996	3.1187999999999998	1.8202	0.96240000000000003	0.72860000000000003	0.49059999999999998	0.040000000000000001	0.048999999	40	91.489998	\N
238	135	1	\N	19.146599999999999	3.6819999999999999	0.42199999999999999	13.416	42.280999999999999	36.619	33.858400000000003	30.407699999999998	26.957000000000001	20.055599999999998	15.307600000000001	10.5771	6.6852	5.0381999999999998	3.6082999999999998	2.7004000000000001	1.4948999999999999	0.10000000000000001	0.017999999	40	88.899002	\N
239	136	1	\N	13.5374	6.6219999999999999	0.28799999999999998	25.567	36.7226	29.265899999999998	24.294799999999999	19.3035	17.048300000000001	12.5379	8.2300000000000004	4.6944999999999997	1.9346000000000001	1.3451	0.88649999999999995	0.6673	0.4904	0.040000000000000001	0.033	40	92.637001	\N
240	137	1	\N	35.892499999999998	8.3309999999999995	0.053999999999999999	85.007999999999996	72.334500000000006	67.735200000000006	64.668999999999997	59.932499999999997	54.499000000000002	43.632100000000001	34.918500000000002	27.285799999999998	19.201599999999999	10.414999999999999	2.6714000000000002	0.97589999999999999	0.51329999999999998	0.040000000000000001	0.090000004	63	77.822998	\N
241	138	1	\N	28.236000000000001	8.2070000000000007	0.16	52.866	70.410700000000006	64.656999999999996	59.311199999999999	51.193300000000001	43.075400000000002	30.8415	19.6707	11.534599999999999	5.4577999999999998	3.5022000000000002	1.8875999999999999	0.95989999999999998	0.58340000000000003	0.040000000000000001	0.081	63	82.272003	\N
242	139	1	\N	18.998699999999999	5.4470000000000001	0.56399999999999995	22.076000000000001	50.367600000000003	42.788200000000003	38.292400000000001	33.530099999999997	28.767800000000001	19.297499999999999	10.4572	5.8246000000000002	3.3782000000000001	2.5573000000000001	1.8402000000000001	1.4420999999999999	0.87409999999999999	0.040000000000000001	0.016000001	40	81.792999	\N
243	141	1	\N	20.7941	6.9569999999999999	0.13900000000000001	44.124000000000002	51.334800000000001	44.335599999999999	39.792900000000003	36.137900000000002	32.482799999999997	25.172799999999999	17.123200000000001	6.8994	2.1453000000000002	1.6287	1.2162999999999999	0.91610000000000003	0.57050000000000001	0.040000000000000001	0.033	40	80.282997	\N
244	142	1	\N	16.5016	6.6079999999999997	0.091999999999999998	35.832999999999998	34.767400000000002	31.627800000000001	29.534700000000001	26.918399999999998	24.302099999999999	19.357399999999998	15.7438	12.1303	7.3242000000000003	4.2248000000000001	1.0139	0.72430000000000005	0.54020000000000001	0.040000000000000001	0.024	20	61.778	\N
245	143	1	\N	18.101400000000002	5.9930000000000003	0.27400000000000002	22.690000000000001	47.178100000000001	38.6145	34.827100000000002	30.0929	25.358599999999999	17.670300000000001	12.303100000000001	7.7157999999999998	3.8782000000000001	2.1543999999999999	1.5077	1.0751999999999999	0.77880000000000005	0.040000000000000001	0.017000001	40	85.462997	\N
246	144	1	\N	14.944900000000001	4.4039999999999999	0.41999999999999998	17.521999999999998	35.4176	30.595400000000001	27.380500000000001	23.361999999999998	19.6358	15.1777	10.7195	7.4946000000000002	4.8087	3.5619999999999998	2.3073999999999999	1.5777000000000001	0.86619999999999997	0.10000000000000001	0.016000001	40	95.702003	\N
247	145	1	\N	28.879000000000001	4.7430000000000003	0.192	36.595999999999997	60.492400000000004	55.250900000000001	51.756599999999999	47.388800000000003	43.020899999999997	34.682899999999997	26.555099999999999	18.490500000000001	10.6891	7.25	4.2256999999999998	2.4563000000000001	0.94769999999999999	0.040000000000000001	0.018999999	63	92.871002	\N
248	146	1	\N	26.0366	5.048	0.23200000000000001	37.438000000000002	59.644399999999997	52.478400000000001	47.701099999999997	41.729500000000002	37.223199999999999	29.4053	21.587499999999999	14.626300000000001	8.1967999999999996	5.5308000000000002	3.4401999999999999	2.0590999999999999	0.78539999999999999	0.040000000000000001	0.017000001	63	92.809998	\N
249	329	1	\N	19.4512	1.8	1.0629999999999999	2.6600000000000001	35.331499999999998	31.911200000000001	29.631	26.7807	23.930399999999999	19.335899999999999	17.197099999999999	15.058400000000001	12.919600000000001	11.850199999999999	10.780900000000001	9.8498999999999999	7.2683999999999997	0.10000000000000001	0.014	40	98.190002	\N
250	330	1	\N	13.365600000000001	2.0899999999999999	0.57899999999999996	4.601	25.833300000000001	19.597000000000001	18.740600000000001	17.670200000000001	16.599699999999999	14.4588	12.3179	10.177	7.8986999999999998	6.7534000000000001	5.5195999999999996	4.4863	3.1423999999999999	0.40000000000000002	0.127	20	85.882004	\N
251	331	1	\N	16.030799999999999	1.883	0.86599999999999999	3.109	31.3979	25.113600000000002	20.924099999999999	19.1983	18.224799999999998	16.277899999999999	14.3309	12.383900000000001	10.436999999999999	9.3161000000000005	8.0753000000000004	7.0826000000000002	5.2351000000000001	0.40000000000000002	0.061999999	40	98.212997	\N
252	332	1	\N	9.0289000000000001	3.0979999999999999	0.48599999999999999	9.4819999999999993	18.291799999999999	16.349299999999999	15.0543	13.435600000000001	11.8169	9.2578999999999994	7.5666000000000002	5.8658000000000001	4.1364999999999998	3.2212999999999998	2.2966000000000002	1.7034	0.97640000000000005	0.40000000000000002	1.429	20	95.277	\N
253	335	1	\N	3.9828000000000001	4.2039999999999997	3.581	5.6970000000000001	11.039999999999999	8.1784999999999997	6.7398999999999996	5.3102	4	2.4022999999999999	1.028	0.627	0.55859999999999999	0.52439999999999998	0.49009999999999998	0.4627	0.42170000000000002	0.20000000000000001	0.071999997	20	98.057999	\N
254	334	1	\N	4.0932000000000004	3.2200000000000002	2.0649999999999999	3.7069999999999999	10.245799999999999	8.0146999999999995	6.6406999999999998	5.3612000000000002	4.1901000000000002	2.5558999999999998	1.7318	1.3168	0.96719999999999995	0.89780000000000004	0.82840000000000003	0.77280000000000004	0.6895	0.40000000000000002	0.551	20	98.747002	\N
255	336	1	\N	16.755099999999999	2.673	0.53600000000000003	11.537000000000001	33.952300000000001	30.323699999999999	27.904599999999999	24.880700000000001	21.8569	18.159199999999998	15.5029	12.846500000000001	10.190200000000001	8.2256	6.1342999999999996	4.2454999999999998	1.5740000000000001	0.040000000000000001	0.02	20	66.93	\N
256	337	1	\N	10.0562	2.6739999999999999	0.50900000000000001	8.7710000000000008	18.666899999999998	17.1492	16.1374	14.8726	13.607799999999999	11.0783	8.9873999999999992	7.2224000000000004	5.3258000000000001	4.3053999999999997	3.2523	2.3988	1.2629999999999999	0.40000000000000002	1.08	20	95.269997	\N
257	338	1	\N	13.493	3.181	0.46400000000000002	13.391999999999999	30.632000000000001	25.011199999999999	21.263999999999999	18.921800000000001	17.4451	14.4918	11.538500000000001	8.8338999999999999	6.3997999999999999	5.0385	3.6425000000000001	2.4714999999999998	1.0821000000000001	0.40000000000000002	0.72600001	20	78.651001	\N
258	340	1	\N	17.4221	1.913	0.93899999999999995	3.145	33.672499999999999	28.585799999999999	25.194700000000001	20.9557	19.2563	17.335899999999999	15.4155	13.495100000000001	11.5747	10.6145	9.3201000000000001	7.8094999999999999	5.5129000000000001	0.063	0.050000001	40	97.463997	\N
259	341	1	\N	6.0091999999999999	2.3279999999999998	0.78100000000000003	5.1150000000000002	12.788500000000001	9.4291	8.6439000000000004	7.6623999999999999	6.6809000000000003	5.5332999999999997	4.5820999999999996	3.6957	2.9114	2.5192000000000001	2.1271	1.7393000000000001	1.0818000000000001	0.20000000000000001	0.043000001	20	97.996002	\N
260	342	1	\N	4.3154000000000003	3.2450000000000001	1.024	5.6319999999999997	9.4690999999999992	6.7161	5.7146999999999997	4.7685000000000004	3.9123999999999999	2.9788999999999999	2.0455000000000001	1.5135000000000001	1.0022	0.87139999999999995	0.74160000000000004	0.63780000000000003	0.52900000000000003	0.40000000000000002	2.727	20	96.142998	\N
261	99	1	\N	13.7019	5.8730000000000002	0.27700000000000002	21.882999999999999	34.650599999999997	28.952999999999999	25.154599999999999	20.406600000000001	17.984000000000002	13.5745	9.3699999999999992	6.0822000000000003	3.149	1.7607999999999999	0.98750000000000004	0.83930000000000005	0.62029999999999996	0.063	0.024	40	95.633003	\N
262	108	1	\N	20.907	4.1699999999999999	0.27100000000000002	24.582999999999998	46.275799999999997	38.579599999999999	36.051499999999997	32.891399999999997	29.731200000000001	23.411000000000001	17.766200000000001	12.9133	8.2136999999999993	5.9945000000000004	3.871	2.2183000000000002	0.95230000000000004	0.063	0.023	40	86.247002	\N
263	122	1	\N	17.8139	6.2750000000000004	0.125	58.637	37.880200000000002	34.423999999999999	32.119799999999998	29.2395	26.359300000000001	20.5989	15.5198	10.5198	5.5597000000000003	3.4304999999999999	1.6654	0.87409999999999999	0.3513	0.040000000000000001	0.017000001	40	93.68	\N
264	140	1	\N	13.5345	7.4420000000000002	4.3410000000000002	9.0899999999999999	48.628900000000002	40.0062	30.904599999999999	19.753799999999998	13.876300000000001	5.1500000000000004	2.5802999999999998	1.6315	1.097	0.9274	0.8135	0.72240000000000004	0.5665	0.040000000000000001	0.021	40	83.996002	\N
265	153	1	\N	18.3141	7.343	0.078	39.173000000000002	37.292900000000003	33.874200000000002	31.595099999999999	28.746099999999998	25.897200000000002	20.199400000000001	16.5395	12.9534	9.0551999999999992	6.3773	2.3580999999999999	0.62829999999999997	0.51559999999999995	0.040000000000000001	0.035999998	40	94.750999	\N
266	154	1	\N	20.704999999999998	3.9020000000000001	0.36899999999999999	19.898	47.857300000000002	39.424300000000002	36.585599999999999	33.037199999999999	29.488800000000001	22.391999999999999	16.628599999999999	11.543100000000001	7.4394	5.6622000000000003	3.9838	2.5899000000000001	1.1253	0.040000000000000001	0.017000001	40	84.810997	\N
267	155	1	\N	19.3245	4.8200000000000003	0.254	26.692	44.898299999999999	37.731200000000001	34.976199999999999	31.532299999999999	28.0885	21.200900000000001	15.5467	10.152900000000001	5.2553000000000001	3.5935999999999999	2.3849	1.6244000000000001	0.79430000000000001	0.040000000000000001	0.016000001	40	87.293999	\N
268	157	1	\N	16.3309	9.984	25.827000000000002	13.877000000000001	53.865200000000002	48.384399999999999	44.730499999999999	40.1631	22.550599999999999	6.093	0.9536	0.74150000000000005	0.59340000000000004	0.55479999999999996	0.51619999999999999	0.4854	0.43909999999999999	0.040000000000000001	0.030999999	40	74.820999	\N
269	169	1	\N	6.3346	6.7430000000000003	7.3010000000000002	6.5449999999999999	20.870699999999999	15.6837	12.57	9.0127000000000006	6.1387	1.8843000000000001	0.86080000000000001	0.60819999999999996	0.49390000000000001	0.43680000000000002	0.38300000000000001	0.34499999999999997	0.28789999999999999	0.040000000000000001	0.033	20	89.544998	\N
270	195	1	\N	16.2942	2.7309999999999999	0.56999999999999995	9.6660000000000004	34.257899999999999	29.5854	26.470400000000001	22.576699999999999	19.559200000000001	16.952999999999999	14.3467	11.740500000000001	8.8983000000000008	7.2401	5.4817999999999998	3.9674	1.7538	0.040000000000000001	0.011	40	97.374001	\N
271	263	1	\N	13.9954	3.1459999999999999	0.49299999999999999	11.403	31.709800000000001	26.735600000000002	23.419499999999999	19.7331	18.208200000000001	15.1586	12.1089	9.0617999999999999	6.0712999999999999	4.8263999999999996	3.6158000000000001	2.7018	1.3293999999999999	0.063	0.035	20	75.875	\N
272	259	1	\N	11.136100000000001	6.4269999999999996	0.22	23.606999999999999	29.6022	23.363499999999998	19.6816	17.601299999999998	15.521000000000001	11.360300000000001	7.7591999999999999	4.8346999999999998	2.0152000000000001	0.89600000000000002	0.62190000000000001	0.56559999999999999	0.48120000000000002	0.10000000000000001	0.052000001	20	80.764999	\N
273	252	1	\N	9.8190000000000008	5.476	0.36799999999999999	16.396999999999998	27.1371	19.776299999999999	17.794699999999999	15.3177	12.8407	8.7363	5.9532999999999996	4.0007999999999999	1.7704	0.97250000000000003	0.79859999999999998	0.65939999999999999	0.53280000000000005	0.063	0.079000004	20	84.450996	\N
274	242	1	\N	10.9854	4.9089999999999998	0.183	21.286000000000001	25.9331	19.4696	18.279199999999999	16.7911	15.303100000000001	12.327	9.2720000000000002	5.9119999999999999	2.7099000000000002	1.6458999999999999	0.97870000000000001	0.80779999999999996	0.57909999999999995	0.063	0.033	20	85.781998	\N
275	235	1	\N	21.521999999999998	3.8759999999999999	0.21099999999999999	29.648	39.519500000000001	36.684800000000003	34.795000000000002	32.4328	30.070599999999999	25.3462	20.621700000000001	16.307600000000001	12.0556	9.8390000000000004	5.1954000000000002	2.4422999999999999	0.85489999999999999	0.063	0.18700001	40	91.016998	\N
276	225	1	\N	11.582599999999999	6.4640000000000004	0.32900000000000001	19.946000000000002	32.245699999999999	24.999099999999999	20.167999999999999	17.567699999999999	15.0657	10.0619	6.7454999999999998	3.8990999999999998	1.0228999999999999	0.84730000000000005	0.6915	0.59830000000000005	0.50439999999999996	0.20000000000000001	0.103	40	96.419998	\N
277	218	1	\N	13.6838	6.6779999999999999	0.17100000000000001	28.102	33.249899999999997	29.1998	26.499700000000001	23.124700000000001	19.828199999999999	15.197900000000001	10.567500000000001	6.9322999999999997	3.7927	1.105	0.81179999999999997	0.65480000000000005	0.54079999999999995	0.20000000000000001	0.033	20	70.371002	\N
278	211	1	\N	16.017099999999999	5.9299999999999997	0.17699999999999999	28.786000000000001	35.978299999999997	32.052199999999999	29.434799999999999	26.163	22.891300000000001	17.433199999999999	12.834199999999999	8.7559000000000005	5.5667999999999997	4.0552000000000001	1.843	0.91159999999999997	0.60560000000000003	0.063	0.050000001	40	96.146004	\N
279	206	1	\N	22.749199999999998	3.6469999999999998	0.375	21.446999999999999	50.7087	43.3339	39.147199999999998	35.835700000000003	32.5242	25.9011	19.415800000000001	14.057	8.9444999999999997	6.7717999999999998	4.7843999999999998	3.2581000000000002	1.2077	0.10000000000000001	0.017000001	40	81.288002	\N
280	243	1	\N	18.762899999999998	6.452	0.23200000000000001	30.334	48.5486	39.918599999999998	36.069400000000002	31.257899999999999	26.446400000000001	18.2256	12.850199999999999	8.1811000000000007	4.8215000000000003	3.3224999999999998	1.8062	0.95909999999999995	0.6008	0.10000000000000001	0.033	40	84.084999	\N
281	333	1	\N	7.7256999999999998	3.8919999999999999	0.38800000000000001	14.042	17.195599999999999	14.8916	13.355600000000001	11.435600000000001	9.7691999999999997	7.9401000000000002	6.1390000000000002	4.5822000000000003	3.1147999999999998	2.4077999999999999	1.6452	0.98309999999999997	0.56540000000000001	0.40000000000000002	2.757	20	97.303001	\N
7126	17245	1	\N	8.8467000000000002	5.5750000000000002	0.62	13.737	24.913399999999999	20.2972	17.219799999999999	14.261699999999999	11.7164	7.2887000000000004	4.6254999999999997	2.2521	1.0872999999999999	0.89059999999999995	0.75860000000000005	0.65300000000000002	0.53059999999999996	0.125	0.022	31.5	98.560997	\N
7275	1110	1	\N	57.937800000000003	2.2749999999999999	0.33900000000000002	7.6619999999999999	93.527500000000003	89.644000000000005	87.055000000000007	83.818700000000007	80.582499999999996	74.109999999999999	67.637500000000003	57.436999999999998	37.815100000000001	29.1569	22.581	17.3203	9.6722999999999999	0.125	0.34400001	63	42.834999	\N
7276	1111	1	\N	23.7606	6.6299999999999999	0.33900000000000002	31.396999999999998	64.064999999999998	52.752600000000001	45.565899999999999	36.582700000000003	29.674399999999999	21.2654	13.6577	8.1798000000000002	4.6135999999999999	3.0525000000000002	1.7565	1.2000999999999999	0.67730000000000001	0.125	0.50700003	63	89.704002	\N
7277	1112	1	\N	54.209699999999998	4.1769999999999996	0.19400000000000001	32.722000000000001	99.234300000000005	91.953900000000004	87.100399999999993	81.033500000000004	74.9666	62.822600000000001	49.956499999999998	37.090400000000002	23.189699999999998	15.857799999999999	9.2614999999999998	5.2716000000000003	1.9198999999999999	0.125	0.21699999	100	90.630997	\N
7278	1113	1	\N	30.487100000000002	5.9660000000000002	0.33800000000000002	25.006	80.078000000000003	68.124799999999993	60.763100000000001	52.928600000000003	45.094099999999997	30.114699999999999	19.6541	11.0124	5.5609000000000002	3.9222000000000001	2.7601	1.9137	1.2042999999999999	0.125	0.046	63	81.428001	\N
7279	1114	1	\N	38.491599999999998	8.3260000000000005	0.087999999999999995	89.316000000000003	86.874099999999999	78.998599999999996	73.7483	67.185299999999998	60.428199999999997	46.229999999999997	32.031799999999997	20.9862	11.132	7.3097000000000003	4.2728000000000002	1.1395999999999999	0.51759999999999995	0.125	0.2	63	71.810997	\N
7280	1115	1	\N	28.236499999999999	10.23	0.088999999999999996	62.228000000000002	73.378900000000002	59.954599999999999	54.157499999999999	46.911000000000001	39.664499999999997	27.903199999999998	19.6663	12.472099999999999	6.1520999999999999	3.9054000000000002	0.86180000000000001	0.57289999999999996	0.44840000000000002	0.125	0.064000003	63	86.100998	\N
7281	1116	1	\N	24.113499999999998	7.431	0.096000000000000002	49.106000000000002	54.012500000000003	48.619900000000001	45.024900000000002	40.531100000000002	36.037399999999998	28.054400000000001	21.0959	14.3095	8.3094999999999999	5.8186999999999998	3.4630000000000001	0.88060000000000005	0.57130000000000003	0.125	0.028000001	31.5	64.952003	\N
7282	1117	1	\N	18.1022	8.2789999999999999	0.17999999999999999	33.149999999999999	49.428800000000003	41.286000000000001	35.857500000000002	29.949100000000001	25.614799999999999	16.946300000000001	11.759	7.0382999999999996	2.6113	0.92730000000000001	0.71999999999999997	0.60229999999999995	0.51119999999999999	0.125	0.034000002	31.5	76.789001	\N
7283	1118	1	\N	35.727499999999999	2.407	0.66400000000000003	7.6849999999999996	71.695099999999996	60.418999999999997	56.893099999999997	52.485700000000001	48.078299999999999	39.263500000000001	30.819299999999998	25.111899999999999	19.404599999999999	16.550899999999999	13.204499999999999	10.433	5.1090999999999998	0.125	0.066	63	86.928001	\N
7284	1119	1	\N	19.654299999999999	4.585	0.35099999999999998	16.036999999999999	49.088200000000001	40.741100000000003	35.176400000000001	30.068100000000001	27.031099999999999	20.957100000000001	15.001300000000001	9.6065000000000005	5.2952000000000004	3.8502000000000001	2.7505000000000002	1.9381999999999999	1.3068	0.125	0.139	31.5	77.357002	\N
7285	1120	1	\N	18.560500000000001	4.5919999999999996	0.48399999999999999	13.315	51.880000000000003	34.672899999999998	29.2211	25.2834	21.345700000000001	14.750500000000001	10.8606	6.7070999999999996	3.9796999999999998	2.9927000000000001	2.0057999999999998	1.6447000000000001	1.1077999999999999	0.125	0.219	63	93.876999	\N
7286	1123	1	\N	16.3843	6.8479999999999999	0.16400000000000001	29.417999999999999	42.633499999999998	30.708400000000001	28.023199999999999	24.666599999999999	21.309999999999999	15.147399999999999	11.068099999999999	7.5034000000000001	4.4896000000000003	1.9789000000000001	0.91890000000000005	0.65490000000000004	0.51490000000000002	0.125	0.017999999	63	98.819	\N
7287	1124	1	\N	31.858899999999998	7.8570000000000002	0.21299999999999999	34.137	84.2928	74.868499999999997	68.585700000000003	59.779699999999998	48.628100000000003	29.459900000000001	20.6677	11.5181	4.0776000000000003	1.9724999999999999	1.5505	1.2129000000000001	0.86299999999999999	0.125	0.016000001	63	76.444	\N
7288	1125	1	\N	20.387	6.1159999999999997	0.38800000000000001	20.873999999999999	55.758099999999999	44.772399999999998	37.448599999999999	30.1068	26.128900000000002	18.173100000000002	11.756	6.1218000000000004	2.8068	1.8466	1.4857	1.1969000000000001	0.87060000000000004	0.125	0.015	63	93.955002	\N
7289	1126	1	\N	51.656100000000002	2.3799999999999999	0.44700000000000001	10.977	90.833600000000004	85.333699999999993	81.667199999999994	77.0839	72.500699999999995	63.334299999999999	53.628999999999998	43.903199999999998	34.177500000000002	28.236799999999999	20.9755	15.066800000000001	5.7698999999999998	0.125	0.097999997	63	59.634998	\N
7290	1127	1	\N	17.173999999999999	4.5670000000000002	0.34499999999999997	18.785	44.129199999999997	32.806800000000003	29.505299999999998	26.489899999999999	23.474399999999999	17.4436	12.2248	7.6562999999999999	4.5556999999999999	3.2997000000000001	2.0630999999999999	1.5727	0.92859999999999998	0.125	0.17	31.5	83.306999	\N
7291	1128	1	\N	33.301200000000001	2.1970000000000001	0.69599999999999995	9.4640000000000004	59.898400000000002	55.318600000000004	52.2654	48.448999999999998	44.6325	36.999600000000001	30.1876	25.492100000000001	20.796500000000002	18.448799999999999	16.100999999999999	11.460800000000001	3.9095	0.125	0.030999999	63	94.063004	\N
7292	1129	1	\N	20.732600000000001	4.0019999999999998	0.23899999999999999	17.228000000000002	47.184399999999997	37.695099999999996	31.4663	29.435400000000001	27.404499999999999	23.342600000000001	19.280799999999999	14.7189	7.9112	5.1704999999999997	3.4245000000000001	2.3540000000000001	1.3549	0.125	0.037	31.5	80.083	\N
7293	1130	1	\N	68.865300000000005	3.6709999999999998	0.25600000000000001	36.590000000000003	153.4427	125.50830000000001	106.8854	96.005899999999997	90.334199999999996	78.990799999999993	67.647400000000005	48.988700000000001	27.939900000000002	21.176600000000001	14.499499999999999	9.3160000000000007	2.1587999999999998	0.125	0.107	100	78.521004	\N
7294	1131	1	\N	15.014900000000001	6.3970000000000002	0.39000000000000001	23.367000000000001	43.125999999999998	31.383600000000001	28.2821	24.4053	20.528400000000001	13.515700000000001	7.8544	4.2755999999999998	1.7410000000000001	1.2373000000000001	0.90720000000000001	0.76690000000000003	0.57840000000000003	0.125	0.064999998	31.5	84.150002	\N
7295	1132	1	\N	26.091999999999999	3.1600000000000001	0.503	15.236000000000001	56.490699999999997	49.186599999999999	44.317300000000003	38.230600000000003	32.143900000000002	26.8569	21.954599999999999	17.052199999999999	12.0907	9.5350999999999999	6.6295000000000002	4.9246999999999996	1.7626999999999999	0.125	0.052000001	63	95.347	\N
7296	1133	1	\N	17.255099999999999	4.6619999999999999	0.23300000000000001	23.071000000000002	41.482399999999998	30.805700000000002	28.764800000000001	26.213699999999999	23.662600000000001	18.560300000000002	13.696300000000001	9.0878999999999994	5.1966000000000001	3.7216	1.9977	1.4176	0.80449999999999999	0.125	0.016000001	31.5	85.361	\N
7297	1134	1	\N	87.770099999999999	2.2890000000000001	0.73199999999999998	4.8019999999999996	172.55799999999999	156.09280000000001	145.11609999999999	131.39510000000001	117.6741	94.675600000000003	79.717100000000002	64.758600000000001	50.254399999999997	43.032499999999999	35.810699999999997	29.7941	19.715699999999998	0.125	0.032000002	100	63.558998	\N
7298	1135	1	\N	20.624199999999998	8.5150000000000006	0.113	46.552	52.873899999999999	43.455399999999997	37.176299999999998	30.644100000000002	27.5519	21.3675	15.1777	8.9238999999999997	3.8317000000000001	1.5974999999999999	0.82350000000000001	0.59930000000000005	0.45900000000000002	0.125	0.44600001	63	96.450996	\N
7299	1136	1	\N	20.1035	2.9740000000000002	0.375	11.865	44.260300000000001	33.016399999999997	30.214400000000001	28.1998	26.185300000000002	22.156199999999998	18.127099999999999	13.915100000000001	9.3871000000000002	6.6883999999999997	4.9894999999999996	3.7330999999999999	1.8673	0.125	0.02	31.5	83.191002	\N
7300	1137	1	\N	14.090199999999999	4.1790000000000003	0.442	12.259	30.910799999999998	27.407900000000001	25.072700000000001	22.153600000000001	19.234500000000001	14.112500000000001	9.8628999999999998	5.5781000000000001	3.2988	2.4676999999999998	1.8476999999999999	1.5690999999999999	1.1512	0.125	0.035999998	31.5	91.009003	\N
7301	1138	1	\N	78.785700000000006	2.3959999999999999	1.163	5.1470000000000002	169.46100000000001	151.13759999999999	138.9221	123.65260000000001	108.3831	77.696100000000001	58.488700000000001	49.8459	41.203099999999999	36.881700000000002	32.560299999999998	26.327999999999999	15.095599999999999	0.125	0.068999998	100	67.254997	\N
7302	1139	1	\N	21.861000000000001	6.0039999999999996	0.42399999999999999	23.648	58.887500000000003	48.447400000000002	41.487299999999998	32.787199999999999	27.807600000000001	19.1404	12.395	6.9859999999999998	3.7442000000000002	2.6768999999999998	1.7941	1.3439000000000001	0.80940000000000001	0.125	0.078000002	63	92.362999	\N
7303	1140	1	\N	30.404800000000002	1.843	1.1020000000000001	2.6160000000000001	57.127800000000001	50.136200000000002	45.475099999999998	39.648699999999998	33.822299999999998	29.017299999999999	25.916699999999999	22.816099999999999	19.715499999999999	18.165199999999999	16.614899999999999	14.765499999999999	11.092599999999999	0.125	0.063000001	63	95.039001	\N
7304	1141	1	\N	22.0718	2.5470000000000002	0.52100000000000002	7.6909999999999998	46.795400000000001	37.072600000000001	31.291799999999999	29.436199999999999	27.5806	23.869399999999999	20.158200000000001	16.446999999999999	12.5495	10.587999999999999	7.8658000000000001	5.7137000000000002	3.1034000000000002	0.125	0.18799999	31.5	80.560997	\N
7305	1142	1	\N	17.1782	5.9800000000000004	0.16700000000000001	25.635000000000002	43.7425	32.188000000000002	29.5031	26.7622	24.0213	18.5395	13.167899999999999	7.8566000000000003	3.6739000000000002	1.7329000000000001	1.0802	0.90010000000000001	0.72319999999999995	0.125	0.011	31.5	83.642998	\N
7306	1143	1	\N	12.015000000000001	5.0599999999999996	0.44600000000000001	14.622	28.898	24.686499999999999	21.878799999999998	18.369199999999999	15.3263	11.1799	7.3085000000000004	4.7957999999999998	2.6002000000000001	1.7696000000000001	1.284	0.96419999999999995	0.76459999999999995	0.125	0.024	31.5	93.707001	\N
7307	1144	1	\N	25.914300000000001	2.9460000000000002	0.46100000000000002	15.907	53.501100000000001	47.801699999999997	44.002099999999999	39.252600000000001	34.5032	28.408200000000001	23.887	19.3659	14.4946	11.549099999999999	8.2356999999999996	5.5076999999999998	1.7859	0.125	0.024	31.5	66.837997	\N
7308	1145	1	\N	15.4636	6.7549999999999999	0.192	35.253999999999998	40.005800000000001	30.148199999999999	27.797999999999998	24.860399999999998	21.922699999999999	16.0474	10.174899999999999	5.6097000000000001	2.4359999999999999	1.5173000000000001	0.9244	0.66069999999999995	0.45519999999999999	0.125	0.033	31.5	86.301003	\N
7309	1146	1	\N	14.6135	2.9729999999999999	1.0740000000000001	5.6399999999999997	33.016500000000001	27.746099999999998	25.013100000000001	21.596900000000002	18.180599999999998	12.930899999999999	9.0055999999999994	6.2397999999999998	4.9880000000000004	4.3621999999999996	3.7029999999999998	3.1389999999999998	2.2928999999999999	0.125	0.054000001	31.5	89.494003	\N
7310	1147	1	\N	13.071999999999999	3.3980000000000001	1.1539999999999999	6.6449999999999996	31.395199999999999	26.073599999999999	22.5259	18.0913	14.7445	9.9955999999999996	7.1412000000000004	5.4379	4.2157	3.5392999999999999	2.8273000000000001	2.2576999999999998	1.5042	0.125	0.117	31.5	90.117996	\N
7313	1148	1	\N	27.870100000000001	6.1639999999999997	0.090999999999999998	58.305	56.016100000000002	51.825800000000001	49.032200000000003	45.540300000000002	42.048299999999998	35.064399999999999	27.815200000000001	20.289300000000001	12.6442	8.6024999999999991	4.391	1.3640000000000001	0.60140000000000005	0.125	0.35600001	31.5	54.896	\N
7314	1149	1	\N	15.504200000000001	7.7000000000000002	0.17899999999999999	37.906999999999996	42.722700000000003	31.203299999999999	28.653099999999998	25.465299999999999	22.2775	15.902100000000001	9.5690000000000008	4.4866000000000001	1.1877	0.79800000000000004	0.59850000000000003	0.52629999999999999	0.41949999999999998	0.125	0.017000001	31.5	84.464996	\N
7315	1152	1	\N	21.968299999999999	3.8319999999999999	0.39600000000000002	16.286999999999999	51.039700000000003	43.863500000000002	39.079300000000003	33.099200000000003	29.440999999999999	23.819700000000001	18.198499999999999	13.2477	8.5555000000000003	6.1094999999999997	4.5343999999999998	2.9866999999999999	1.4624999999999999	0.125	0.068000004	31.5	73.663002	\N
7316	1153	1	\N	11.7744	2.8319999999999999	1.153	5.0369999999999999	28.5366	21.203299999999999	16.314499999999999	14.427199999999999	12.7691	9.5713000000000008	6.9725000000000001	5.4611999999999998	4.3296000000000001	3.7446999999999999	3.1332	2.6438999999999999	1.9004000000000001	0.125	0.022	31.5	92.425003	\N
7317	1154	1	\N	11.324299999999999	6.6189999999999998	0.47899999999999998	23.533999999999999	28.471800000000002	25.209599999999998	23.034700000000001	20.316199999999998	17.5977	11.8378	5.5038999999999998	1.6879999999999999	0.8931	0.75449999999999995	0.62390000000000001	0.57550000000000001	0.503	0.125	0.017000001	31.5	95.57	\N
7318	1155	1	\N	11.376899999999999	6.5460000000000003	0.34200000000000003	24.311	28.072900000000001	24.961200000000002	22.886800000000001	20.293800000000001	17.700800000000001	12.381600000000001	6.5235000000000003	2.3563999999999998	0.93820000000000003	0.78569999999999995	0.63319999999999999	0.58250000000000002	0.50929999999999997	0.125	0.0099999998	31.5	96.608002	\N
7319	17356	1	\N	2.4418000000000002	1.542	1.079	1.802	1.2838000000000001	0.89890000000000003	0.81389999999999996	0.70760000000000001	0.62560000000000004	0.59340000000000004	0.56110000000000004	0.52880000000000005	0.49120000000000003	0.45069999999999999	0.41020000000000001	0.37790000000000001	0.32929999999999998	0.125	0.029999999	31.5	97.019997	\N
7320	1156	1	\N	24.111999999999998	2.9710000000000001	0.42099999999999999	34.561999999999998	50.846600000000002	43.554600000000001	38.693300000000001	32.616599999999998	29.990300000000001	26.2912	22.592099999999999	18.893000000000001	14.6083	11.4153	7.7157	4.9352	0.76070000000000004	0.125	0.022	31.5	74.081001	\N
7321	1157	1	\N	10.732799999999999	5.3840000000000003	0.38700000000000001	18.417000000000002	26.971900000000002	22.269500000000001	19.134499999999999	15.614100000000001	13.6854	9.8568999999999996	6.6468999999999996	4.5313999999999997	2.0918000000000001	1.4777	0.96340000000000003	0.76819999999999999	0.53520000000000001	0.125	0.046999998	31.5	95.778	\N
7322	1158	1	\N	12.193300000000001	6.3440000000000003	0.36599999999999999	24.747	29.595199999999998	25.741499999999998	23.1724	19.960999999999999	16.749600000000001	11.428100000000001	6.7089999999999996	4.0932000000000004	1.7222999999999999	1.2729999999999999	0.88139999999999996	0.63959999999999995	0.46179999999999999	0.125	0.0080000004	31.5	92.966003	\N
7323	1159	1	\N	12.594200000000001	4.8890000000000002	0.379	17.946999999999999	28.916699999999999	25.5518	23.308599999999998	20.5046	17.700500000000002	12.9594	8.4890000000000008	5.0156000000000001	2.9100999999999999	1.9823999999999999	1.4750000000000001	1.0690999999999999	0.72209999999999996	0.125	0.0089999996	31.5	94.606003	\N
7324	1160	1	\N	15.8813	6.6210000000000004	0.113	32.710000000000001	30.367000000000001	27.2255	25.1311	22.513100000000001	19.895199999999999	15.232799999999999	12.236599999999999	8.9338999999999995	4.7996999999999996	2.0916000000000001	0.93720000000000003	0.621	0.4657	0.125	0.132	63	96.288002	\N
7325	1161	1	\N	16.528400000000001	6.9119999999999999	0.070000000000000007	41.832999999999998	31.2212	28.913399999999999	27.3749	25.451699999999999	23.528500000000001	19.682200000000002	15.8134	11.440200000000001	4.6393000000000004	1.7943	0.86750000000000005	0.60519999999999996	0.47049999999999997	0.125	0.015	31.5	90.724998	\N
7326	17357	1	\N	1.1511	1.9890000000000001	1.639	1.895	2.0217000000000001	1.3354999999999999	0.96579999999999999	0.79459999999999997	0.629	0.57679999999999998	0.52459999999999996	0.47070000000000001	0.4153	0.3876	0.35980000000000001	0.3377	0.3044	0.125	0.021	16	99.337997	\N
7327	1162	1	\N	24.161899999999999	2.294	0.63900000000000001	5.6950000000000003	49.886699999999998	39.7744	33.032800000000002	30.119599999999998	28.432300000000001	25.057600000000001	21.683	18.308299999999999	14.5862	12.3491	10.112	7.5560999999999998	4.3997999999999999	0.125	0.045000002	63	97.780998	\N
7328	1163	1	\N	10.5764	4.0999999999999996	2.2999999999999998	4.5990000000000002	30.2544	21.146599999999999	15.426399999999999	10.720700000000001	7.4363000000000001	4.7645999999999997	3.4007999999999998	2.3946000000000001	1.7753000000000001	1.5905	1.4056999999999999	1.2579	1.0361	0.125	0.017000001	63	97.698997	\N
7329	1164	1	\N	37.241100000000003	3.7719999999999998	0.40699999999999997	17.808	83.731499999999997	73.159099999999995	66.110900000000001	59.232399999999998	53.4084	41.760300000000001	30.3963	21.132100000000001	13.196199999999999	10.053100000000001	7.0004999999999997	5.1433	2.3451	0.125	0.41299999	100	99.233002	\N
7330	1165	1	\N	21.585000000000001	4.141	0.52200000000000002	15.589	54.375900000000001	43.6023	36.419899999999998	30.039999999999999	26.809899999999999	20.349699999999999	14.5715	10.199	6.2424999999999997	5.0411000000000001	3.7917000000000001	2.5421999999999998	1.3053999999999999	0.125	0.026000001	63	94.803001	\N
7331	1166	1	\N	6.4313000000000002	5.6639999999999997	2.2229999999999999	10.231	20.963100000000001	15.2468	12.911	9.9917999999999996	7.2910000000000004	3.98	1.8053999999999999	0.94999999999999996	0.62729999999999997	0.57550000000000001	0.52370000000000005	0.4753	0.38900000000000001	0.125	0.017999999	16	85.290001	\N
7332	1167	1	\N	6.4278000000000004	4.968	2.6059999999999999	8.4610000000000003	20.468699999999998	14.910500000000001	12.6745	9.8918999999999997	7.3863000000000003	3.9464000000000001	1.8592	1.1400999999999999	0.85770000000000002	0.76939999999999997	0.68100000000000005	0.60409999999999997	0.46639999999999998	0.125	0.021	16	85.948997	\N
7333	1168	1	\N	4.3141999999999996	3.7440000000000002	2.073	4.1920000000000002	12.2582	7.4920999999999998	5.6920999999999999	4.2889999999999997	3.1484999999999999	1.8064	1.3895999999999999	0.9869	0.78559999999999997	0.68500000000000005	0.59540000000000004	0.53439999999999999	0.43090000000000001	0.125	0.048999999	31.5	98.862	\N
7334	1169	1	\N	3.9302000000000001	3.218	1.3340000000000001	5.0759999999999996	9.6587999999999994	6.6738	5.6821999999999999	4.7313999999999998	3.8592	2.6391	1.7959000000000001	1.3673	0.96709999999999996	0.85189999999999999	0.73670000000000002	0.64449999999999996	0.51990000000000003	0.125	0.022	16	95.830002	\N
7335	1170	1	\N	19.7759	5.5469999999999997	0.28599999999999998	28	50.266599999999997	42.626600000000003	37.533200000000001	31.317299999999999	27.829599999999999	20.853999999999999	14.361599999999999	8.9906000000000006	4.8371000000000004	3.4068999999999998	2.0474000000000001	1.3855999999999999	0.74480000000000002	0.125	0.0089999996	31.5	75.262001	\N
7336	1171	1	\N	9.5934000000000008	5.5060000000000002	0.68700000000000006	12.855	26.4711	21.457899999999999	18.1158	14.607200000000001	11.7852	7.2850999999999999	4.7019000000000002	2.5226000000000002	1.3041	0.95430000000000004	0.81730000000000003	0.7077	0.56669999999999998	0.125	0.0070000002	31.5	96.018997	\N
7337	1172	1	\N	58.1417	2.0150000000000001	0.71599999999999997	4.5119999999999996	97.727199999999996	90.022900000000007	84.886600000000001	78.466300000000004	72.046000000000006	60.675199999999997	52.808300000000003	44.941299999999998	37.074399999999997	33.140999999999998	27.571899999999999	22.1799	13.4474	0.125	0.025	100	91.769997	\N
7338	1173	1	\N	9.7507000000000001	7.0869999999999997	0.33900000000000002	27.728000000000002	26.188600000000001	22.3567	19.802099999999999	16.608899999999998	14.348599999999999	10.2676	5.4207999999999998	1.6220000000000001	0.65490000000000004	0.56569999999999998	0.495	0.4451	0.37030000000000002	0.125	0.017999999	31.5	98.317001	\N
7339	1176	1	\N	13.050000000000001	6.8639999999999999	0.219	28.658999999999999	30.6067	26.960899999999999	24.5303	21.492100000000001	18.453900000000001	13.1775	8.3895	4.1641000000000004	1.119	0.84140000000000004	0.65439999999999998	0.57230000000000003	0.45979999999999999	0.125	0.0060000001	31.5	91.470001	\N
7340	1177	1	\N	11.724600000000001	6.8230000000000004	0.29499999999999998	26.390000000000001	29.168399999999998	25.183499999999999	22.526900000000001	19.206199999999999	15.9237	11.5006	6.7930000000000001	2.7949000000000002	0.91649999999999998	0.73680000000000001	0.59999999999999998	0.54100000000000004	0.43580000000000002	0.125	0.013	31.5	93.511002	\N
7341	17358	1	\N	0.60350000000000004	1.5429999999999999	0.98399999999999999	1.883	0.9264	0.83679999999999999	0.77710000000000001	0.70250000000000001	0.62939999999999996	0.58819999999999995	0.54690000000000005	0.50570000000000004	0.44350000000000001	0.41070000000000001	0.37790000000000001	0.35170000000000001	0.31240000000000001	0.125	0.023	2	99.766998	\N
7342	1178	1	\N	13.788600000000001	6.2249999999999996	0.14199999999999999	28.064	29.7807	27.046399999999998	25.223400000000002	22.944800000000001	20.6662	16.108899999999998	11.527100000000001	5.7150999999999996	1.5450999999999999	0.95050000000000001	0.81020000000000003	0.69789999999999996	0.57399999999999995	0.125	0.013	31.5	93.773003	\N
7343	1179	1	\N	14.1113	6.1849999999999996	0.17100000000000001	27.891999999999999	30.703600000000002	27.699000000000002	25.695900000000002	23.192	20.688099999999999	15.689299999999999	10.8201	5.3802000000000003	1.7109000000000001	0.99990000000000001	0.84660000000000002	0.72399999999999998	0.5625	0.125	0.018999999	31.5	91.589996	\N
7344	1180	1	\N	3.5790000000000002	2.1230000000000002	1.2090000000000001	2.9390000000000001	7.2934999999999999	5.8998999999999997	5.4627999999999997	4.9165000000000001	4.3700999999999999	3.4138000000000002	2.5274000000000001	1.9003000000000001	1.6539999999999999	1.5308999999999999	1.4077999999999999	1.3092999999999999	1.1616	0.125	0.017000001	10	96.371002	\N
7345	1181	1	\N	4.0959000000000003	2.113	1.042	2.9209999999999998	8.5742999999999991	6.1805000000000003	5.6643999999999997	5.0193000000000003	4.3741000000000003	3.5293000000000001	2.8662999999999998	2.2033	1.7962	1.6492	1.5022	1.3846000000000001	1.2081999999999999	0.125	0.0099999998	16	98.324997	\N
7346	1182	1	\N	1.7782	2.4870000000000001	1.355	3.3490000000000002	3.8348	2.6583999999999999	1.9752000000000001	1.7818000000000001	1.5884	1.2016	0.91820000000000002	0.74739999999999995	0.59360000000000002	0.53539999999999999	0.47689999999999999	0.42970000000000003	0.35880000000000001	0.125	0.037	16	99.536003	\N
7347	1183	1	\N	10.2766	6.7469999999999999	1.4610000000000001	14.863	28.819500000000001	24.161200000000001	21.055700000000002	17.1737	13.5318	6.2930999999999999	2.9628999999999999	1.5611999999999999	0.92420000000000002	0.74339999999999995	0.59850000000000003	0.53069999999999995	0.4234	0.125	0.017000001	31.5	93.453003	\N
7348	1184	1	\N	6.9100999999999999	5.327	0.66000000000000003	14.032	18.797999999999998	14.664199999999999	13.257	11.497999999999999	9.6922999999999995	5.8483999999999998	3.3877000000000002	1.5797000000000001	0.84850000000000003	0.66639999999999999	0.57340000000000002	0.51670000000000005	0.4168	0.125	0.023	16	87.796997	\N
7349	1185	1	\N	5.7428999999999997	5.117	2.5099999999999998	9.0050000000000008	15.717700000000001	13.0708	11.3062	9.0402000000000005	6.6866000000000003	3.6396000000000002	1.6123000000000001	0.94089999999999996	0.71040000000000003	0.61119999999999997	0.54910000000000003	0.49919999999999998	0.4042	0.125	0.033	31.5	99.690002	\N
7350	1186	1	\N	3.3649	2.298	1.3360000000000001	3.4969999999999999	6.7816000000000001	5.7415000000000003	5.2915000000000001	4.7290999999999999	4.1665999999999999	3.1543000000000001	2.1617000000000002	1.764	1.4822	1.3411999999999999	1.2002999999999999	1.0875999999999999	0.90200000000000002	0.125	0.027000001	16	99.742996	\N
7351	1187	1	\N	3.7244000000000002	2.1800000000000002	0.86499999999999999	3.52	7.3322000000000003	5.9699	5.5708000000000002	5.0720000000000001	4.5731000000000002	3.6850000000000001	2.9447999999999999	2.2046000000000001	1.7467999999999999	1.5718000000000001	1.3968	1.2567999999999999	1.0468	0.125	0.021	16	99.546997	\N
7352	1188	1	\N	33.017800000000001	8.452	0.19600000000000001	59.066000000000003	84.835099999999997	75.736099999999993	69.670100000000005	61.974200000000003	53.4482	36.3964	20.218599999999999	10.100300000000001	4.5900999999999996	2.7679	1.6069	1.0602	0.61619999999999997	0.125	0.19	63	75.601997	\N
7353	1189	1	\N	6.1871	4.3490000000000002	1.871	6.0979999999999999	16.4849	11.566000000000001	8.8300999999999998	6.1276000000000002	5.0058999999999996	3.2357	1.9442999999999999	1.4294	0.95699999999999996	0.8276	0.69810000000000005	0.61150000000000004	0.53059999999999996	0.125	0.094999999	31.5	96.644997	\N
7354	1190	1	\N	12.518700000000001	7.1310000000000002	0.20300000000000001	30.805	29.717099999999999	26.020499999999998	23.556100000000001	20.4756	17.395099999999999	12.6671	8.0931999999999995	4.4200999999999997	1.2624	0.77759999999999996	0.58389999999999997	0.51170000000000004	0.41120000000000001	0.125	0.017999999	31.5	92.893997	\N
7355	1191	1	\N	13.035600000000001	6.2910000000000004	0.11799999999999999	29.678000000000001	28.227599999999999	25.126999999999999	23.059999999999999	20.476199999999999	17.892499999999998	14.2987	11.6143	8.1806000000000001	4.0544000000000002	1.8499000000000001	0.89780000000000004	0.63500000000000001	0.48180000000000001	0.125	0.037	31.5	96.333	\N
7356	17359	1	\N	1.4635	1.4810000000000001	0.98099999999999998	1.7929999999999999	0.95340000000000003	0.7107	0.62090000000000001	0.59830000000000005	0.57569999999999999	0.53039999999999998	0.48449999999999999	0.43730000000000002	0.3901	0.36649999999999999	0.34289999999999998	0.3241	0.29580000000000001	0.125	0.016000001	16	97.220001	\N
7357	1193	1	\N	7.3586	4.9269999999999996	0.98499999999999999	9.6039999999999992	21.617100000000001	15.238799999999999	13.0486	10.310700000000001	8.2402999999999995	5.0796000000000001	3.1160999999999999	1.7849999999999999	1.0881000000000001	0.89019999999999999	0.74339999999999995	0.62770000000000004	0.52890000000000004	0.125	0.02	31.5	98.111	\N
7358	17360	1	\N	0.97770000000000001	1.974	1.5369999999999999	2.0070000000000001	1.7344999999999999	1.4216	1.2130000000000001	0.97960000000000003	0.8679	0.64470000000000005	0.58079999999999998	0.5282	0.46629999999999999	0.43009999999999998	0.39379999999999998	0.36480000000000001	0.32119999999999999	0.25	0.178	10	99.332001	\N
7359	1194	1	\N	20.2502	7.1210000000000004	0.17599999999999999	36.561999999999998	54.633899999999997	40.094299999999997	31.228999999999999	28.240600000000001	25.252199999999998	19.275400000000001	13.4396	7.9227999999999996	3.6564000000000001	1.8560000000000001	1.125	0.79059999999999997	0.5272	0.125	0.050999999	63	93.452003	\N
7360	1195	1	\N	8.2857000000000003	6.0620000000000003	0.65900000000000003	18.709	23.575199999999999	17.226099999999999	14.924899999999999	13.0329	11.141	6.4600999999999997	3.5007000000000001	1.6103000000000001	0.8821	0.69510000000000005	0.55630000000000002	0.46879999999999999	0.3453	0.125	0.23800001	31.5	97.488998	\N
7361	1196	1	\N	14.605499999999999	6.5979999999999999	0.080000000000000002	40.009999999999998	28.847300000000001	26.6707	25.2197	23.405899999999999	21.592099999999999	17.964500000000001	14.321999999999999	10.661799999999999	5.4459	3.3955000000000002	1.3089	0.61260000000000003	0.44900000000000001	0.125	0.021	31.5	97.313004	\N
7362	1197	1	\N	7.0064000000000002	6.702	1.7669999999999999	13.702	22.857399999999998	17.671800000000001	14.7067	11.5763	8.6166999999999998	4.6502999999999997	1.9838	0.82520000000000004	0.53129999999999999	0.47439999999999999	0.4294	0.39340000000000003	0.33939999999999998	0.125	0.022	16	82.066002	\N
7363	1198	1	\N	18.231400000000001	2.165	0.67000000000000004	5.2999999999999998	30.855799999999999	28.651800000000001	27.182500000000001	25.3459	23.5093	19.835999999999999	16.162800000000001	13.568099999999999	11.0235	9.6179000000000006	7.6643999999999997	6.1112000000000002	3.7425000000000002	0.125	0.015	31.5	91.753998	\N
7364	1199	1	\N	12.1165	3.927	0.35299999999999998	13.608000000000001	27.101500000000001	23.577400000000001	21.227900000000002	18.2911	15.6929	12.8994	10.106	6.8658999999999999	4.3117999999999999	3.0712000000000002	1.9275	1.5290999999999999	0.94789999999999996	0.125	0.048	31.5	97.488998	\N
7365	1200	1	\N	12.773	7.8419999999999996	0.27700000000000002	32.162999999999997	32.617899999999999	27.467500000000001	24.6035	21.023499999999999	17.4436	11.874700000000001	6.6561000000000003	2.2323	0.64539999999999997	0.56559999999999999	0.49809999999999999	0.4466	0.36919999999999997	0.125	0.013	31.5	89.632004	\N
7366	1201	1	\N	10.647	7.0899999999999999	0.33600000000000002	27.565000000000001	27.627600000000001	23.858899999999998	21.346499999999999	18.2059	15.306800000000001	10.6485	5.806	1.8607	0.66600000000000004	0.58109999999999995	0.52529999999999999	0.47460000000000002	0.38629999999999998	0.125	0.027000001	31.5	96.165001	\N
7367	17361	1	\N	0.91949999999999998	1.597	1.046	1.9039999999999999	0.9587	0.8538	0.78390000000000004	0.69650000000000001	0.62390000000000001	0.57340000000000002	0.52290000000000003	0.46939999999999998	0.4133	0.38529999999999998	0.35720000000000002	0.33479999999999999	0.30120000000000002	0.125	0.02	16	99.240997	\N
7368	1202	1	\N	11.006500000000001	7.218	0.33300000000000002	24.059000000000001	28.758800000000001	24.174099999999999	21.117599999999999	17.297000000000001	14.1974	9.1785999999999994	5.8038999999999996	3.0316999999999998	0.91739999999999999	0.62119999999999997	0.52629999999999999	0.46400000000000002	0.38150000000000001	0.125	0.041999999	31.5	93.586998	\N
7369	1203	1	\N	10.763500000000001	6.9359999999999999	0.19800000000000001	27.163	27.0153	22.700700000000001	19.824300000000001	16.2288	14.237	10.471500000000001	7.3616000000000001	4.4630999999999998	1.4477	0.66569999999999996	0.53959999999999997	0.47189999999999999	0.38550000000000001	0.125	0.030999999	31.5	96.236	\N
7370	1204	1	\N	2.9224000000000001	2.5529999999999999	1.464	2.8969999999999998	6.2144000000000004	4.9353999999999996	4.0827	3.4712000000000001	2.8978000000000002	1.9282999999999999	1.5979000000000001	1.2675000000000001	0.97089999999999999	0.89459999999999995	0.81830000000000003	0.75719999999999998	0.66559999999999997	0.125	0.022	16	98.738998	\N
7371	1205	1	\N	8.4095999999999993	4.4550000000000001	0.67900000000000005	10.507999999999999	23.118400000000001	18.089500000000001	15.383699999999999	13.3392	11.294600000000001	7.5754000000000001	4.9272999999999998	3.0236999999999998	1.7346999999999999	1.4072	1.0798000000000001	0.91159999999999997	0.72089999999999999	0.125	0.018999999	16	81.507004	\N
7372	1206	1	\N	15.7471	4.3380000000000001	0.54600000000000004	12.215999999999999	36.308100000000003	26.793700000000001	23.311699999999998	18.959199999999999	15.408200000000001	11.711	8.3592999999999993	5.6608000000000001	3.6396000000000002	2.4670999999999998	1.7526999999999999	1.4238	0.9587	0.125	0.035999998	63	93.294998	\N
7373	1207	1	\N	12.5565	4.0709999999999997	0.42899999999999999	13.055	28.370200000000001	24.745799999999999	22.329499999999999	19.309200000000001	16.288900000000002	12.751799999999999	9.2802000000000007	5.8905000000000003	3.8249	2.7187000000000001	1.8455999999999999	1.4928999999999999	0.9768	0.125	0.028999999	31.5	95.181	\N
7374	1208	1	\N	14.9343	6.8600000000000003	0.087999999999999995	37.978000000000002	30.023199999999999	27.6067	25.995699999999999	23.981999999999999	21.968299999999999	17.940799999999999	13.5807	8.5391999999999992	4.2434000000000003	1.9642999999999999	0.78029999999999999	0.58660000000000001	0.47239999999999999	0.125	0.018999999	31.5	93.667	\N
7375	1209	1	\N	9.1206999999999994	6.9960000000000004	0.47599999999999998	21.041	25.782599999999999	21.411999999999999	18.4983	15.1897	12.6096	7.6524999999999999	4.4385000000000003	1.5911999999999999	0.65680000000000005	0.56079999999999997	0.48670000000000002	0.4375	0.36370000000000002	0.125	0.037	31.5	97.848999	\N
7376	1210	1	\N	9.0473999999999997	7.1200000000000001	3.0249999999999999	13.843999999999999	27.156400000000001	22.325399999999998	19.104700000000001	15.181100000000001	11.601900000000001	5.0808999999999997	1.8028	0.89159999999999995	0.60970000000000002	0.54969999999999997	0.4894	0.44040000000000001	0.36699999999999999	0.125	0.028999999	31.5	95.394997	\N
7377	1211	1	\N	9.9108000000000001	7.1760000000000002	1.228	17.460000000000001	28.291899999999998	23.314299999999999	19.995899999999999	15.888299999999999	12.8398	6.5353000000000003	2.9316	1.0943000000000001	0.62390000000000001	0.56420000000000003	0.50449999999999995	0.45269999999999999	0.37430000000000002	0.125	0.023	31.5	93.866997	\N
7378	17362	1	\N	0.62660000000000005	1.5549999999999999	1.016	1.8580000000000001	0.93640000000000001	0.8125	0.72989999999999999	0.62929999999999997	0.60709999999999997	0.56269999999999998	0.51839999999999997	0.46779999999999999	0.4128	0.38540000000000002	0.3579	0.33589999999999998	0.3029	0.25	0.366	6.2999999999999998	99.674004	\N
7379	1212	1	\N	12.1069	5.9619999999999997	0.29299999999999998	21.648	29.0078	25.317	22.8565	19.780799999999999	16.705200000000001	12.337400000000001	7.8499999999999996	4.0925000000000002	1.4662999999999999	0.97370000000000001	0.82840000000000003	0.71220000000000006	0.56989999999999996	0.125	0.021	31.5	94.051003	\N
7380	1213	1	\N	10.5207	5.8109999999999999	0.433	18.379000000000001	27.1751	22.800999999999998	19.885000000000002	16.239899999999999	14.2096	10.3766	5.9629000000000003	2.6048	1.0447	0.89019999999999999	0.77080000000000004	0.67530000000000001	0.56459999999999999	0.125	0.02	31.5	95.932999	\N
7381	1214	1	\N	2.6802999999999999	2.9750000000000001	1.931	3.2719999999999998	6.8688000000000002	5.0312999999999999	4.0228000000000002	3.0356000000000001	2.0535000000000001	1.6138999999999999	1.2170000000000001	0.92820000000000003	0.76970000000000005	0.6905	0.6159	0.56830000000000003	0.49330000000000002	0.125	0.017000001	16	98.914001	\N
7382	1215	1	\N	3.3872	3.1379999999999999	1.6479999999999999	3.605	9.1121999999999996	5.9572000000000003	5.0377999999999998	3.9262000000000001	3.1657999999999999	1.9014	1.4789000000000001	1.0565	0.84550000000000003	0.75629999999999997	0.66710000000000003	0.60509999999999997	0.52749999999999997	0.125	0.011	16	97.498001	\N
7383	17363	1	\N	1.8392999999999999	2.387	1.8360000000000001	2.7120000000000002	4.3175999999999997	2.9746999999999999	2.1816	1.827	1.6152	1.1915	0.91949999999999998	0.77259999999999995	0.62780000000000002	0.58999999999999997	0.55210000000000004	0.52190000000000003	0.43930000000000002	0.125	0.068999998	16	99.570999	\N
7384	17364	1	\N	3.5667	3.5489999999999999	1.244	5.4699999999999998	9.5366	6.8089000000000004	5.6997999999999998	4.6580000000000004	3.7382	2.3167	1.7202	1.3603000000000001	1.0003	0.82120000000000004	0.64200000000000002	0.54059999999999997	0.42349999999999999	0.125	0.015	16	98.502998	\N
7385	17365	1	\N	8.2825000000000006	5.6669999999999998	0.67200000000000004	14.345000000000001	23.8569	18.789999999999999	15.6526	13.1579	10.6632	6.1826999999999996	4.0450999999999997	2.3309000000000002	1.4629000000000001	1.1295999999999999	0.80700000000000005	0.58520000000000005	0.43099999999999999	0.125	0.017000001	31.5	99.051003	\N
7386	1216	1	\N	0.96220000000000006	1.669	1.1639999999999999	2.1339999999999999	1.6142000000000001	1.1263000000000001	0.97130000000000005	0.91269999999999996	0.85409999999999997	0.73699999999999999	0.62549999999999994	0.57379999999999998	0.5222	0.49299999999999999	0.44379999999999997	0.40439999999999998	0.34539999999999998	0.125	0.02	10	99.492996	\N
7387	1217	1	\N	1.246	1.794	1.468	1.96	1.996	1.6705000000000001	1.4534	1.1820999999999999	0.98240000000000005	0.87549999999999994	0.76849999999999996	0.66159999999999997	0.59279999999999999	0.5665	0.54010000000000002	0.51910000000000001	0.4466	0.125	0.13500001	10	99.156998	\N
7388	1218	1	\N	1.2716000000000001	1.804	1.3149999999999999	2.1829999999999998	1.8956	1.5246	1.2773000000000001	0.99470000000000003	0.94320000000000004	0.84019999999999995	0.73719999999999997	0.63419999999999999	0.5716	0.54110000000000003	0.51070000000000004	0.46870000000000001	0.38490000000000002	0.125	0.1	10	97.912003	\N
7389	1219	1	\N	1.0377000000000001	1.5600000000000001	1.1659999999999999	1.978	1.6532	1.2277	0.99299999999999999	0.94899999999999995	0.90490000000000004	0.81679999999999997	0.72870000000000001	0.64049999999999996	0.58140000000000003	0.55379999999999996	0.52629999999999999	0.50419999999999998	0.41289999999999999	0.125	0.023	10	99.129997	\N
7390	1220	1	\N	2.8788	3.1459999999999999	0.871	5.8120000000000003	6.1924999999999999	5.2893999999999997	4.6872999999999996	3.9594999999999998	3.4922	2.5577000000000001	1.8015000000000001	1.3091999999999999	0.85809999999999997	0.66749999999999998	0.58209999999999995	0.53449999999999998	0.44009999999999999	0.125	0.018999999	16	99.529999	\N
7391	1221	1	\N	3.4173	3.1829999999999998	0.64800000000000002	6.2629999999999999	7.7297000000000002	5.9139999999999997	5.3756000000000004	4.7024999999999997	4.0294999999999996	3.1629999999999998	2.3071999999999999	1.6478999999999999	1.0985	0.86309999999999998	0.64949999999999997	0.58360000000000001	0.505	0.125	0.011	16	99.195999	\N
7392	1222	1	\N	10.493499999999999	5.407	0.158	24.472999999999999	24.387799999999999	19.800799999999999	16.742799999999999	15.0763	13.9298	11.636900000000001	9.2118000000000002	6.4572000000000003	4.1336000000000004	2.4264000000000001	1.2513000000000001	0.67720000000000002	0.47549999999999998	0.125	0.0099999998	31.5	99.303001	\N
7393	1223	1	\N	8.5953999999999997	5.6079999999999997	0.438	15.92	23.795200000000001	17.478100000000001	14.908099999999999	12.805099999999999	10.7021	7.1113999999999997	4.7084999999999999	2.3521000000000001	0.99890000000000001	0.80520000000000003	0.62209999999999999	0.55569999999999997	0.44669999999999999	0.125	0.0089999996	31.5	97.318001	\N
7394	1224	1	\N	6.6262999999999996	5.0549999999999997	0.623	12.573	17.532499999999999	13.992599999999999	12.354799999999999	10.307600000000001	8.5068000000000001	5.5385999999999997	3.5068000000000001	1.7911999999999999	0.96830000000000005	0.77800000000000002	0.61209999999999998	0.54769999999999996	0.4405	0.125	0.011	16	88.903	\N
7395	1225	1	\N	5.3720999999999997	3.9569999999999999	0.98399999999999999	7.1820000000000004	14.1098	11.054500000000001	9.2454999999999998	7.2899000000000003	5.8484999999999996	4.0195999999999996	2.8174000000000001	1.8226	1.2614000000000001	0.98919999999999997	0.83199999999999996	0.70620000000000005	0.55969999999999998	0.125	0.017999999	16	93.711998	\N
7396	1227	1	\N	5.2092000000000001	5.1029999999999998	1.7430000000000001	9.1630000000000003	15.0077	11.6873	9.5130999999999997	6.9537000000000004	5.5263	3.4123000000000001	1.7350000000000001	1.0029999999999999	0.67800000000000005	0.57630000000000003	0.49990000000000001	0.44890000000000002	0.37240000000000001	0.125	0.012	16	91.792999	\N
7397	1226	1	\N	5.7786999999999997	4.9100000000000001	0.57399999999999995	12.268000000000001	14.806100000000001	11.8012	9.8721999999999994	8.2883999999999993	6.7046000000000001	4.8791000000000002	3.1720000000000002	1.6201000000000001	0.80249999999999999	0.61319999999999997	0.54520000000000002	0.48959999999999998	0.3977	0.125	0.027000001	31.5	99.657997	\N
7398	1228	1	\N	5.5945	5.3810000000000002	0.48399999999999999	15.202999999999999	14.291	12.0383	10.5365	9.0363000000000007	7.6870000000000003	5.3529999999999998	3.2149999999999999	0.93810000000000004	0.56930000000000003	0.51219999999999999	0.45829999999999999	0.4158	0.35210000000000002	0.125	0.015	16	94.552002	\N
7399	1229	1	\N	5.5726000000000004	5.4420000000000002	0.67200000000000004	14.904999999999999	14.4108	12.207700000000001	10.738899999999999	9.1292000000000009	7.6718000000000002	5.2182000000000004	2.7368000000000001	0.91020000000000001	0.57299999999999995	0.50690000000000002	0.4536	0.41220000000000001	0.35010000000000002	0.125	0.0070000002	16	94.328003	\N
7400	1230	1	\N	2.0632999999999999	2.6859999999999999	2.0830000000000002	3.1829999999999998	5.2695999999999996	3.7218	3.0518999999999998	2.2143999999999999	1.8229	1.3469	0.95999999999999996	0.81240000000000001	0.66479999999999995	0.60409999999999997	0.55510000000000004	0.51590000000000003	0.42320000000000002	0.125	0.028000001	16	99.740997	\N
7401	1231	1	\N	3.2244999999999999	3.117	1.1839999999999999	4.694	8.1858000000000004	5.8662999999999998	5.1208	4.1889000000000003	3.5648	2.4733000000000001	1.73	1.2533000000000001	0.89580000000000004	0.78469999999999995	0.67359999999999998	0.60389999999999999	0.52690000000000003	0.125	0.032000002	16	99.308998	\N
7402	1232	1	\N	5.5834999999999999	4.6349999999999998	2.044	8.2710000000000008	14.9719	12.453200000000001	10.773999999999999	8.7387999999999995	6.7407000000000004	4.2115	1.8795999999999999	1.1857	0.84119999999999995	0.73270000000000002	0.62690000000000001	0.57979999999999998	0.50919999999999999	0.125	0.014	16	92.448997	\N
7403	1233	1	\N	6.0069999999999997	4.8419999999999996	2.0150000000000001	8.8360000000000003	15.684200000000001	13.380100000000001	11.843999999999999	9.9196000000000009	7.8917999999999999	4.4465000000000003	1.9463999999999999	1.1659999999999999	0.82440000000000002	0.71289999999999998	0.61560000000000004	0.5706	0.50319999999999998	0.125	0.0089999996	16	90.821999	\N
7404	1234	1	\N	9.7332000000000001	7.1970000000000001	0.72899999999999998	22.670000000000002	27.571300000000001	21.813700000000001	17.975300000000001	14.651999999999999	12.3606	7.7079000000000004	3.5487000000000002	1.2708999999999999	0.64900000000000002	0.55310000000000004	0.47520000000000001	0.42109999999999997	0.34000000000000002	0.125	0.15899999	31.5	94.094002	\N
7405	1235	1	\N	8.7470999999999997	6.8769999999999998	8.0839999999999996	6.2370000000000001	24.430700000000002	16.154	13.641	10.6076	6.9363000000000001	1.8411	0.82620000000000005	0.54900000000000004	0.44979999999999998	0.41110000000000002	0.3725	0.34160000000000001	0.29520000000000002	0.125	0.178	63	95.867996	\N
7406	1236	1	\N	14.7882	6.6449999999999996	0.122	36.279000000000003	30.559899999999999	27.6037	25.632999999999999	23.169499999999999	20.706	15.8248	11.916499999999999	7.9890999999999996	4.8505000000000003	3.2212999999999998	1.2669999999999999	0.62519999999999998	0.43619999999999998	0.125	0.012	31.5	91.907997	\N
7407	1237	1	\N	12.988799999999999	6.367	0.22	27.18	29.834499999999998	26.099900000000002	23.610199999999999	20.498000000000001	17.385899999999999	12.717499999999999	8.7318999999999996	5.5970000000000004	3.1627999999999998	1.7770999999999999	0.91849999999999998	0.64390000000000003	0.46789999999999998	0.125	0.030999999	31.5	92.676003	\N
7408	1238	1	\N	9.0896000000000008	5.4969999999999999	0.17299999999999999	22.428999999999998	21.914200000000001	15.8081	14.7126	13.343299999999999	11.974	9.3280999999999992	6.9212999999999996	4.9160000000000004	2.5886	1.2457	0.60950000000000004	0.5232	0.41589999999999999	0.125	0.024	31.5	98.588997	\N
7409	1239	1	\N	7.2564000000000002	4.9390000000000001	0.374	13.281000000000001	16.5291	13.774800000000001	12.212899999999999	10.2605	8.7735000000000003	6.1051000000000002	4.5603999999999996	2.9954999999999998	1.5206999999999999	0.9365	0.62719999999999998	0.56459999999999999	0.4597	0.125	0.014	31.5	98.528	\N
7410	1240	1	\N	11.3873	7.2060000000000004	0.191	28.605	28.069199999999999	23.1492	19.869199999999999	15.9002	14.1281	10.584	7.3433000000000002	4.9946000000000002	2.8206000000000002	1.4694	0.49630000000000002	0.44579999999999997	0.37	0.125	0.017000001	31.5	94.183998	\N
7411	1241	1	\N	12.789199999999999	6.6849999999999996	0.26700000000000002	25.661999999999999	31.262899999999998	26.5076	23.337399999999999	19.374600000000001	15.6999	11.655799999999999	7.6729000000000003	4.6677999999999997	1.6687000000000001	0.98960000000000004	0.74890000000000001	0.59309999999999996	0.45419999999999999	0.125	0.033	31.5	90.299004	\N
7412	1242	1	\N	6.9416000000000002	3.8399999999999999	0.46100000000000002	9.7690000000000001	15.253	13.291700000000001	11.9842	10.3499	9.0736000000000008	6.7161999999999997	5.1001000000000003	3.5142000000000002	1.8262	1.4582999999999999	1.0904	0.90129999999999999	0.6875	0.125	0.014	16	92.285004	\N
7413	1243	1	\N	7.2663000000000002	3.2999999999999998	0.70599999999999996	7.343	15.997400000000001	13.7102	12.1853	10.279299999999999	8.9288000000000007	6.4187000000000003	4.9454000000000002	3.6202999999999999	2.4870000000000001	1.9462999999999999	1.5644	1.2587999999999999	0.87409999999999999	0.125	0.039999999	16	90.007004	\N
7414	1244	1	\N	5.4897	4.8719999999999999	1.5229999999999999	9.1649999999999991	15.693199999999999	11.9091	9.5907999999999998	7.4878999999999998	5.8250999999999999	3.7126000000000001	1.9806999999999999	1.1449	0.71599999999999997	0.60209999999999997	0.5464	0.50170000000000003	0.40510000000000002	0.125	0.016000001	16	90.487	\N
7415	1245	1	\N	8.8571000000000009	6.2300000000000004	0.64500000000000002	15.202	25.4465	20.002800000000001	16.3736	13.3969	10.5602	6.3041	3.9988000000000001	2.0289000000000001	0.95699999999999996	0.69979999999999998	0.57530000000000003	0.51529999999999998	0.41470000000000001	0.125	0.024	31.5	96.671997	\N
7416	17366	1	\N	8.0465999999999998	6.0679999999999996	0.32900000000000001	19.015000000000001	22.010999999999999	15.8451	14.384499999999999	12.5588	10.733000000000001	6.8586	4.5533999999999999	2.7589000000000001	1.1698999999999999	0.60580000000000001	0.47689999999999999	0.4304	0.36070000000000002	0.125	0.014	31.5	98.802002	\N
7417	1247	1	\N	5.6806999999999999	5.4180000000000001	0.38800000000000001	15.122	14.436999999999999	11.866300000000001	10.1524	8.6396999999999995	7.1750999999999996	5.1883999999999997	3.5173000000000001	1.6934	0.60819999999999996	0.49609999999999999	0.4451	0.40429999999999999	0.34310000000000002	0.125	0.023	16	93.648003	\N
7418	17367	1	\N	1.0774999999999999	1.847	1.3109999999999999	2.2480000000000002	1.8831	1.5694999999999999	1.3604000000000001	1.099	0.96530000000000005	0.85370000000000001	0.74209999999999998	0.63039999999999996	0.56820000000000004	0.53720000000000001	0.50619999999999998	0.45989999999999998	0.37969999999999998	0.125	0.043000001	6.2999999999999998	99.200996	\N
7419	1250	1	\N	6.1135000000000002	4.5990000000000002	0.71699999999999997	10.092000000000001	15.100300000000001	12.924099999999999	11.4732	9.7026000000000003	8.1178000000000008	5.4161999999999999	3.3178999999999998	1.6483000000000001	0.93140000000000001	0.8105	0.68969999999999998	0.61099999999999999	0.53669999999999995	0.125	0.023	16	92.481003	\N
7420	1251	1	\N	4.9016999999999999	3.9750000000000001	0.92100000000000004	7.4109999999999996	12.964	9.4794999999999998	8.0404	6.2739000000000003	5.4702999999999999	3.8811	2.4851999999999999	1.6069	1.0043	0.84230000000000005	0.68230000000000002	0.59999999999999998	0.52370000000000005	0.125	0.016000001	16	94.664001	\N
7421	1248	1	\N	10.7081	4.8049999999999997	0.252	16.199000000000002	25.586099999999998	21.146999999999998	18.1876	15.476800000000001	14.196300000000001	11.635400000000001	8.7751999999999999	5.4977999999999998	2.0415000000000001	1.5684	1.1274999999999999	0.91590000000000005	0.71830000000000005	0.125	0.028000001	31.5	97.992996	\N
7422	1249	1	\N	9.1782000000000004	2.835	0.52500000000000002	6.5839999999999996	20.048300000000001	15.3482	14.2904	12.9682	11.646000000000001	9.3071999999999999	7.4720000000000004	5.8099999999999996	4.4539999999999997	3.6543999999999999	2.6084999999999998	1.9097999999999999	1.4137	0.125	0.39500001	16	86.464996	\N
7423	1252	1	\N	3.8517000000000001	4.2709999999999999	6.8460000000000001	2.4409999999999998	11.998699999999999	9.0282	7.5227000000000004	5.8201000000000001	4.4503000000000004	0.97950000000000004	0.80789999999999995	0.63629999999999998	0.57630000000000003	0.5484	0.52049999999999996	0.49490000000000001	0.40129999999999999	0.125	0.023	16	96.843002	\N
7424	1253	1	\N	3.9159999999999999	4.6660000000000004	1.278	10.531000000000001	10.0045	8.2933000000000003	7.1543000000000001	5.9802	5.1806999999999999	3.4782999999999999	1.5722	0.65010000000000001	0.49930000000000002	0.45700000000000002	0.4148	0.38100000000000001	0.33029999999999998	0.125	0.022	16	98.124001	\N
7425	17368	1	\N	0.95599999999999996	1.585	1.139	1.7909999999999999	1.6149	0.79800000000000004	0.62690000000000001	0.60019999999999996	0.57350000000000001	0.52010000000000001	0.47170000000000001	0.4264	0.38109999999999999	0.3584	0.3357	0.31759999999999999	0.29039999999999999	0.125	0.039000001	10	99.140999	\N
7426	1254	1	\N	4.9128999999999996	4.3259999999999996	0.94999999999999996	8.4819999999999993	13.4361	10.109999999999999	8.3946000000000005	6.2926000000000002	5.3573000000000004	3.6549999999999998	2.3974000000000002	1.5499000000000001	0.93999999999999995	0.75739999999999996	0.60540000000000005	0.5403	0.43090000000000001	0.125	0.024	16	94.625	\N
7427	1255	1	\N	4.4783999999999997	3.0670000000000002	0.89000000000000001	6.0949999999999998	11.261699999999999	7.9424999999999999	6.2068000000000003	5.3887999999999998	4.5707000000000004	3.5053999999999998	2.7458999999999998	1.9914000000000001	1.5121	1.2725	1.0328999999999999	0.84460000000000002	0.57509999999999994	0.125	0.024	16	96.393997	\N
7428	1256	1	\N	2.5899000000000001	2.7679999999999998	1.468	3.286	5.9013999999999998	4.4149000000000003	3.6730999999999998	2.9701	2.2671999999999999	1.6940999999999999	1.3165	0.97050000000000003	0.78800000000000003	0.69679999999999997	0.61650000000000005	0.57609999999999995	0.51559999999999995	0.125	0.028999999	16	98.661003	\N
7429	1257	1	\N	3.5539000000000001	3.0830000000000002	1.345	4.04	8.8557000000000006	5.9275000000000002	5.0403000000000002	3.964	3.3816000000000002	2.2168999999999999	1.6577999999999999	1.2373000000000001	0.90969999999999995	0.80600000000000005	0.70230000000000004	0.62360000000000004	0.54879999999999995	0.125	0.026000001	16	96.625999	\N
7430	1258	1	\N	12.9781	4.1870000000000003	0.35299999999999998	24.446999999999999	28.382100000000001	25.295400000000001	23.2376	20.665400000000002	18.0931	13.831899999999999	10.176500000000001	6.6007999999999996	4.3358999999999996	3.2894000000000001	2.2547000000000001	1.4431	0.56579999999999997	0.125	0.023	31.5	96.060997	\N
7431	1259	1	\N	11.039400000000001	7.7119999999999997	0.33400000000000002	24.312999999999999	29.750699999999998	24.154399999999999	20.4236	15.8622	13.184100000000001	8.3855000000000004	5.4234999999999998	3.4020999999999999	0.60509999999999997	0.49809999999999999	0.44700000000000001	0.40610000000000002	0.34489999999999998	0.125	0.039000001	31.5	91.875999	\N
7432	1260	1	\N	0.79769999999999996	1.6639999999999999	1.101	1.9710000000000001	1.2525999999999999	0.94320000000000004	0.87960000000000005	0.80020000000000002	0.72070000000000001	0.60299999999999998	0.54010000000000002	0.47910000000000003	0.4214	0.39250000000000002	0.36370000000000002	0.34060000000000001	0.30599999999999999	0.125	0.034000002	10	99.577003	\N
7433	1261	1	\N	1.7143999999999999	2.3410000000000002	1.51	2.6859999999999999	3.9424000000000001	2.1280999999999999	1.7931999999999999	1.5041	1.2149000000000001	0.89959999999999996	0.73970000000000002	0.60199999999999998	0.51259999999999994	0.46810000000000002	0.42370000000000002	0.38819999999999999	0.33489999999999998	0.25	0.44800001	16	99.299004	\N
7434	1262	1	\N	4.4173	3.8199999999999998	1.833	5.101	12.76	8.3760999999999992	6.3608000000000002	5.2476000000000003	4.1692	2.4140999999999999	1.6195999999999999	1.1185	0.84299999999999997	0.74019999999999997	0.63739999999999997	0.57410000000000005	0.4733	0.25	0.22499999	16	93.260002	\N
7435	1263	1	\N	5.4652000000000003	4.4249999999999998	1.712	7.7309999999999999	15.2883	10.369199999999999	8.3240999999999996	6.1638999999999999	5.2092000000000001	3.3075000000000001	1.7911999999999999	1.1126	0.7974	0.67600000000000005	0.58609999999999995	0.52959999999999996	0.42780000000000001	0.125	0.021	31.5	98.639999	\N
7436	17369	1	\N	1.3606	2.0539999999999998	1.837	2.2109999999999999	3.1303999999999998	1.7811999999999999	1.4632000000000001	1.0656000000000001	0.93779999999999997	0.78890000000000005	0.64000000000000001	0.58379999999999999	0.53420000000000001	0.50949999999999995	0.4662	0.4224	0.35680000000000001	0.125	0.034000002	10	98.521004	\N
7437	1264	1	\N	3.7934999999999999	4.8739999999999997	7.8150000000000004	6.2729999999999997	11.710100000000001	8.2565000000000008	6.2953000000000001	5.2828999999999997	4.2705000000000002	1.9407000000000001	0.60599999999999998	0.50019999999999998	0.4365	0.40479999999999999	0.373	0.34760000000000002	0.30940000000000001	0.125	0.025	16	96.161003	\N
7438	1265	1	\N	6.3113999999999999	5.6559999999999997	0.73499999999999999	12.295	19.392199999999999	13.6829	10.919700000000001	8.4245000000000001	6.2900999999999998	4.4199999999999999	2.8218000000000001	1.5430999999999999	0.72109999999999996	0.55579999999999996	0.47320000000000001	0.42770000000000002	0.35949999999999999	0.125	0.011	31.5	99.444	\N
7439	17370	1	\N	3.3386999999999998	3.7669999999999999	0.745	8.9299999999999997	8.0282	6.1428000000000003	5.6852999999999998	5.1134000000000004	4.5415000000000001	3.2461000000000002	1.8893	1.0364	0.62709999999999999	0.54930000000000001	0.47889999999999999	0.43280000000000002	0.36349999999999999	0.125	0.012	16	99.237999	\N
7440	17371	1	\N	4.8860999999999999	4.274	0.27400000000000002	12.659000000000001	10.7705	8.9306999999999999	8.0493000000000006	6.9476000000000004	6.0846	5.0395000000000003	3.9925999999999999	2.5840999999999998	1.371	0.89439999999999997	0.59660000000000002	0.48880000000000001	0.39810000000000001	0.125	0.023	16	97.785004	\N
7441	1268	1	\N	2.0666000000000002	2.7200000000000002	1.9630000000000001	2.8330000000000002	5.2320000000000002	3.3323	2.3487	1.8170999999999999	1.5617000000000001	1.0508999999999999	0.87439999999999996	0.73499999999999999	0.60470000000000002	0.55359999999999998	0.50239999999999996	0.45029999999999998	0.371	0.125	0.02	16	99.106003	\N
7442	1269	1	\N	3.0623	2.8740000000000001	1.018	5.4640000000000004	6.3200000000000003	5.3459000000000003	4.7065000000000001	3.9464000000000001	3.4847000000000001	2.5613000000000001	1.8436999999999999	1.4453	1.0468	0.89480000000000004	0.75729999999999997	0.64729999999999999	0.46879999999999999	0.125	0.097000003	16	99.087997	\N
7443	1270	1	\N	2.6431	3.1360000000000001	1.004	5.4160000000000004	5.9615	5.0160999999999998	4.3857999999999997	3.7421000000000002	3.2364999999999999	2.2254999999999998	1.5964	1.0769	0.77100000000000002	0.63660000000000005	0.56479999999999997	0.51000000000000001	0.41089999999999999	0.125	0.017999999	16	99.778999	\N
7444	1271	1	\N	3.0394999999999999	3.359	1.1020000000000001	5.5090000000000003	7.3720999999999997	5.5083000000000002	4.7354000000000003	3.8654999999999999	3.3026	2.1766999999999999	1.5619000000000001	1.0422	0.745	0.61770000000000003	0.54630000000000001	0.48820000000000002	0.39510000000000001	0.125	0.016000001	16	98.563004	\N
7445	1272	1	\N	7.7685000000000004	2.4180000000000001	0.76200000000000001	5.5679999999999996	15.0037	13.2935	12.1533	10.7281	9.5967000000000002	7.9478	6.2991999999999999	5.1792999999999996	4.0594000000000001	3.4274	2.7869000000000002	2.2745000000000002	1.4273	0.125	0.222	16	93.495003	\N
7446	1273	1	\N	8.5321999999999996	2.3140000000000001	0.624	6.351	15.2944	13.980499999999999	13.1045	12.009499999999999	10.9146	9.1346000000000007	7.6487999999999996	6.1814999999999998	4.8971999999999998	4.2549999999999999	3.4033000000000002	2.6114000000000002	1.4382999999999999	0.125	0.38800001	16	93.222	\N
7447	1274	1	\N	3.4605000000000001	3.202	1.383	4.6319999999999997	8.4957999999999991	6.1414999999999997	5.5631000000000004	4.8402000000000003	4.1172000000000004	2.4407999999999999	1.6311	1.1327	0.85540000000000005	0.75690000000000002	0.65839999999999999	0.59919999999999995	0.52700000000000002	0.125	0.025	16	98.069	\N
7448	1275	1	\N	7.0880000000000001	2.5579999999999998	0.72399999999999998	5.3070000000000004	14.4984	12.1434	10.573399999999999	9.3704999999999998	8.4810999999999996	6.7023999999999999	5.5777000000000001	4.6440999999999999	3.6034000000000002	2.9638	2.3241999999999998	1.8552999999999999	1.2628999999999999	0.125	0.018999999	16	93.825996	\N
7449	1276	1	\N	1.8658999999999999	2.831	2.875	2.331	5.4111000000000002	2.8681000000000001	1.7696000000000001	1.1735	0.92989999999999995	0.73199999999999998	0.59760000000000002	0.53080000000000005	0.46060000000000001	0.4239	0.38729999999999998	0.35799999999999998	0.314	0.125	0.025	16	99.128998	\N
7450	1277	1	\N	5.5843999999999996	4.4749999999999996	1.6819999999999999	7.7229999999999999	14.099500000000001	10.204800000000001	8.2134	6.0841000000000003	5.0598999999999998	3.1857000000000002	1.7584	0.98180000000000001	0.70809999999999995	0.60680000000000001	0.55289999999999995	0.50970000000000004	0.41249999999999998	0.125	0.0099999998	31.5	96.898003	\N
7451	1278	1	\N	19.340499999999999	8.3019999999999996	0.13600000000000001	44.927	51.761600000000001	38.364899999999999	30.9556	28.0138	25.071999999999999	19.188400000000001	12.5444	6.5763999999999996	3.5255999999999998	1.9240999999999999	0.77010000000000001	0.55659999999999998	0.42709999999999998	0.125	0.023	63	95.032997	\N
7452	1279	1	\N	5.9649999999999999	2.7090000000000001	0.68400000000000005	6.6479999999999997	12.057	8.6212	7.2340999999999998	6.0903	5.6356000000000002	4.7263000000000002	3.8490000000000002	3.0987	2.3483999999999998	1.9685999999999999	1.5274000000000001	1.1746000000000001	0.71089999999999998	0.125	0.052000001	31.5	97.778999	\N
7453	1280	1	\N	3.0724999999999998	3.012	0.876	5.4210000000000003	6.2457000000000003	5.5003000000000002	5.0033000000000003	4.3822000000000001	3.8166000000000002	2.8633000000000002	1.9509000000000001	1.4305000000000001	0.95409999999999995	0.82099999999999995	0.68799999999999994	0.60629999999999995	0.5282	0.125	0.024	16	99.235001	\N
7454	1281	1	\N	2.9066999999999998	3.0529999999999999	0.83999999999999997	6.0800000000000001	6.0647000000000002	5.3630000000000004	4.8952	4.3105000000000002	3.7728000000000002	2.8039000000000001	1.9173	1.4315	0.9657	0.81259999999999999	0.65949999999999998	0.57550000000000001	0.4612	0.125	0.018999999	16	99.758003	\N
7455	1282	1	\N	5.3442999999999996	1.7769999999999999	0.82799999999999996	2.7469999999999999	9.1411999999999995	7.9882999999999997	7.2196999999999996	6.2885	6.0186999999999999	5.4793000000000003	4.9398	4.4002999999999997	3.7711000000000001	3.3275000000000001	2.8837999999999999	2.5289000000000001	1.9944	0.125	0.032000002	16	99.446999	\N
7456	1283	1	\N	6.0441000000000003	2.093	0.68899999999999995	4.7370000000000001	11.095000000000001	9.4438999999999993	8.8870000000000005	8.1908999999999992	7.4947999999999997	6.1931000000000003	5.4389000000000003	4.6848000000000001	3.8862999999999999	3.2686000000000002	2.6509	2.1566999999999998	1.3072999999999999	0.125	0.030999999	16	98.983002	\N
7457	1284	1	\N	2.1732999999999998	2.9790000000000001	1.9039999999999999	4.0030000000000001	5.4854000000000003	4.3998999999999997	3.7538999999999998	3.0661999999999998	2.3784000000000001	1.6093	1.0704	0.81659999999999999	0.61990000000000001	0.57630000000000003	0.53259999999999996	0.49590000000000001	0.40200000000000002	0.125	0.014	16	99.828003	\N
7458	1285	1	\N	3.3216000000000001	3.4369999999999998	1.5349999999999999	4.8949999999999996	8.5602	5.8056000000000001	4.9356	3.9060000000000001	3.2334999999999998	1.9513	1.3635999999999999	0.91959999999999997	0.70860000000000001	0.61299999999999999	0.54620000000000002	0.49159999999999998	0.39860000000000001	0.125	0.016000001	16	96.949997	\N
7459	1286	1	\N	2.9935	3.1110000000000002	2.4740000000000002	3.4449999999999998	9.6896000000000004	4.8277000000000001	3.3999999999999999	2.0939000000000001	1.8048999999999999	1.3844000000000001	0.98640000000000005	0.82820000000000005	0.67000000000000004	0.6018	0.54469999999999996	0.49869999999999998	0.40189999999999998	0.125	0.014	16	97.019997	\N
7460	1287	1	\N	4.2572000000000001	4.2329999999999997	1.55	6.4240000000000004	12.690300000000001	8.2786000000000008	6.1018999999999997	5.0351999999999997	3.9773999999999998	2.4392999999999998	1.5708	0.98660000000000003	0.71850000000000003	0.60219999999999996	0.52029999999999998	0.46210000000000001	0.37969999999999998	0.125	0.035	16	94.094002	\N
7461	1288	1	\N	2.2909000000000002	2.5299999999999998	1.048	3.4940000000000002	5.0903	3.8843999999999999	3.4963000000000002	3.0112000000000001	2.5261	1.8429	1.4998	1.1567000000000001	0.88639999999999997	0.78190000000000004	0.6774	0.60699999999999998	0.52749999999999997	0.125	0.012	16	99.704002	\N
7462	1289	1	\N	2.0455999999999999	2.3610000000000002	1.3700000000000001	2.9990000000000001	4.5505000000000004	3.5846	3.1650999999999998	2.6406999999999998	2.1164000000000001	1.6693	1.2971999999999999	0.97240000000000004	0.83509999999999995	0.76649999999999996	0.69779999999999998	0.64290000000000003	0.55669999999999997	0.125	0.035	16	99.889999	\N
7463	1290	1	\N	2.5365000000000002	2.738	0.92200000000000004	4.4139999999999997	5.5613000000000001	4.5225	3.9182000000000001	3.5021	3.0859000000000001	2.2536	1.7208000000000001	1.3191999999999999	0.94710000000000005	0.81810000000000005	0.68910000000000005	0.60350000000000004	0.51060000000000005	0.125	0.011	10	98.112	\N
7464	1291	1	\N	2.4106999999999998	2.5339999999999998	0.98199999999999998	3.8799999999999999	5.1768000000000001	3.6354000000000002	3.3006000000000002	2.8822000000000001	2.4636999999999998	1.8295999999999999	1.4475	1.0654999999999999	0.82669999999999999	0.72219999999999995	0.62170000000000003	0.56599999999999995	0.47160000000000002	0.125	0.037	16	99.369003	\N
7465	1292	1	\N	1.7871999999999999	2.4889999999999999	1.7130000000000001	3.02	4.4309000000000003	2.9868000000000001	2.1021999999999998	1.8113999999999999	1.6035999999999999	1.1880999999999999	0.91690000000000005	0.76519999999999999	0.61980000000000002	0.57299999999999995	0.5262	0.48220000000000002	0.39340000000000003	0.125	0.081	16	99.684998	\N
7466	1293	1	\N	1.5726	1.9510000000000001	1.3979999999999999	2.1840000000000002	3.3368000000000002	2.1118999999999999	1.8665	1.6732	1.4798	1.0931	0.91569999999999996	0.80459999999999998	0.69359999999999999	0.63800000000000001	0.59130000000000005	0.55500000000000005	0.50060000000000004	0.125	0.033	16	99.793999	\N
7467	1294	1	\N	2.2441	2.6669999999999998	0.96899999999999997	4.3120000000000003	4.8954000000000004	3.8056999999999999	3.4575	3.0221	2.5868000000000002	1.8647	1.4495	1.0344	0.79300000000000004	0.68010000000000004	0.59099999999999997	0.53500000000000003	0.43240000000000001	0.125	0.037999999	16	99.639	\N
7468	1295	1	\N	2.2401	2.6680000000000001	1.847	3.0299999999999998	4.2098000000000004	3.0729000000000002	2.3923999999999999	1.8617999999999999	1.6051	1.0919000000000001	0.84730000000000005	0.6613	0.56469999999999998	0.52539999999999998	0.47910000000000003	0.43159999999999998	0.3604	0.125	0.041000001	31.5	98.728996	\N
7469	1296	1	\N	3.3092999999999999	3.6440000000000001	0.81200000000000006	8.0129999999999999	8.0403000000000002	6.0189000000000004	5.5252999999999997	4.9082999999999997	4.2911999999999999	3.0074000000000001	1.8331999999999999	1.0902000000000001	0.63160000000000005	0.56779999999999997	0.50519999999999998	0.45329999999999998	0.37530000000000002	0.125	0.02	16	99.234001	\N
7470	1298	1	\N	1.649	2.5720000000000001	1.6850000000000001	3.056	3.9401000000000002	2.9035000000000002	2.2124999999999999	1.8228	1.5878000000000001	1.1177999999999999	0.86970000000000003	0.69579999999999997	0.57689999999999997	0.53420000000000001	0.48780000000000001	0.439	0.36580000000000001	0.125	0.014	10	99.008003	\N
7471	1302	1	\N	2.8792	2.6139999999999999	0.84799999999999998	4.6070000000000002	5.8429000000000002	4.7477999999999998	4.0178000000000003	3.6648999999999998	3.3231000000000002	2.6395	1.9728000000000001	1.5517000000000001	1.1306	0.94679999999999997	0.80669999999999997	0.69469999999999998	0.57289999999999996	0.125	0.013	16	99.341003	\N
7472	1314	1	\N	1.9026000000000001	2.9790000000000001	1.8180000000000001	3.8650000000000002	4.6485000000000003	3.5099	2.9996999999999998	2.3620000000000001	1.8773	1.3096000000000001	0.874	0.61899999999999999	0.52739999999999998	0.48089999999999999	0.4335	0.39560000000000001	0.33879999999999999	0.125	0.039000001	16	99.629997	\N
7473	1315	1	\N	2.0739999999999998	2.9449999999999998	1.5349999999999999	4.1150000000000002	4.8384	3.5356000000000001	3.0325000000000002	2.4037000000000002	1.9125000000000001	1.4233	0.96899999999999997	0.73909999999999998	0.5635	0.50029999999999997	0.44879999999999998	0.40760000000000002	0.34589999999999999	0.125	0.075000003	16	99.237999	\N
7474	1316	1	\N	4.3436000000000003	2.7200000000000002	0.75800000000000001	5.4749999999999996	9.4838000000000005	7.4351000000000003	6.2297000000000002	5.7091000000000003	5.1886000000000001	4.1475999999999997	3.1400000000000001	2.1377999999999999	1.6206	1.4006000000000001	1.1807000000000001	1.0046999999999999	0.75760000000000005	0.125	0.018999999	16	98.375	\N
7475	1317	1	\N	3.1545999999999998	2.4180000000000001	1.2250000000000001	3.7200000000000002	6.2436999999999996	5.2885999999999997	4.6519000000000004	3.9281000000000001	3.5305	2.7353999999999998	1.9761	1.6574	1.3387	1.1794	1.0201	0.90480000000000005	0.73540000000000005	0.125	0.013	16	99.367996	\N
7476	1297	1	\N	3.3691	3.6669999999999998	0.95299999999999996	7.6029999999999998	8.4015000000000004	6.1882999999999999	5.6196000000000002	4.9086999999999996	4.1978	2.8893	1.7284999999999999	0.93059999999999998	0.60370000000000001	0.55669999999999997	0.50970000000000004	0.46029999999999999	0.38	0.125	0.028000001	16	98.644997	\N
7477	1299	1	\N	1.0569999999999999	1.9330000000000001	1.78	2.0830000000000002	1.9777	1.5922000000000001	1.3351999999999999	1.0139	0.91900000000000004	0.74960000000000004	0.61739999999999995	0.57440000000000002	0.53149999999999997	0.51000000000000001	0.47049999999999997	0.42620000000000002	0.3599	0.125	0.027000001	10	99.916	\N
7478	1304	1	\N	2.8300999999999998	2.9460000000000002	1.2709999999999999	3.8820000000000001	6.2896000000000001	5.1014999999999997	4.3094999999999999	3.5920999999999998	2.9986000000000002	1.9365000000000001	1.536	1.1355	0.86219999999999997	0.7581	0.65390000000000004	0.58789999999999998	0.49890000000000001	0.125	0.018999999	16	99.166	\N
7479	1305	1	\N	2.5830000000000002	2.8759999999999999	1.45	3.7429999999999999	5.9695	4.5906000000000002	3.8126000000000002	3.1574	2.5022000000000002	1.7426999999999999	1.3254999999999999	0.95960000000000001	0.77590000000000003	0.68410000000000004	0.60450000000000004	0.55489999999999995	0.46560000000000001	0.125	0.013	16	99.139999	\N
7480	1306	1	\N	1.4822	2.1379999999999999	1.4910000000000001	2.6579999999999999	3.3485999999999998	2.3531	1.9265000000000001	1.7301	1.5338000000000001	1.1411	0.90169999999999995	0.74819999999999998	0.61380000000000001	0.57850000000000001	0.54330000000000001	0.51500000000000001	0.42930000000000001	0.125	0.022	10	99.454002	\N
7481	1307	1	\N	2.4790999999999999	2.6829999999999998	1.411	3.3860000000000001	5.556	3.9782000000000002	3.5215999999999998	2.9508000000000001	2.3801000000000001	1.6992	1.2482	0.91400000000000003	0.72250000000000003	0.62860000000000005	0.58640000000000003	0.55259999999999998	0.50190000000000001	0.125	0.016000001	16	98.788002	\N
7482	1303	1	\N	2.7231999999999998	2.4910000000000001	1.054	3.4609999999999999	6.5022000000000002	3.7248999999999999	3.3401000000000001	2.8591000000000002	2.3780999999999999	1.7947	1.4563999999999999	1.1181000000000001	0.86870000000000003	0.76780000000000004	0.66690000000000005	0.60040000000000004	0.51849999999999996	0.125	0.017999999	16	97.970001	\N
7483	1310	1	\N	36.469099999999997	6.3479999999999999	0.084000000000000005	54.530000000000001	78.636899999999997	65.819100000000006	60.776499999999999	56.628799999999998	52.481000000000002	44.185600000000001	35.8902	25.874600000000001	14.017300000000001	8.2399000000000004	4.0267999999999997	1.6334	0.81030000000000002	0.125	0.023	63	82.68	\N
7484	1311	1	\N	14.730600000000001	6.5129999999999999	0.28799999999999998	25.513000000000002	41.189599999999999	30.3111	27.2576	23.4406	19.6236	13.4762	8.6649999999999991	4.6440999999999999	1.9229000000000001	1.2785	0.88149999999999995	0.71450000000000002	0.5282	0.125	0.11	31.5	85.556999	\N
7485	1312	1	\N	1.5367999999999999	2.1240000000000001	1.282	2.8660000000000001	3.4750000000000001	2.1892	1.8835	1.6967000000000001	1.5099	1.1363000000000001	0.91049999999999998	0.76949999999999996	0.62890000000000001	0.57940000000000003	0.52990000000000004	0.4854	0.39650000000000002	0.125	0.024	10	99.185997	\N
7486	1313	1	\N	2.0398999999999998	2.698	1.677	3.5009999999999999	4.5936000000000003	3.3452999999999999	2.7286999999999999	1.988	1.7685	1.3293999999999999	0.9577	0.78859999999999997	0.623	0.56689999999999996	0.51090000000000002	0.4597	0.37969999999999998	0.125	0.017000001	16	99.029999	\N
7487	17372	1	\N	2.0041000000000002	2.726	0.94499999999999995	4.468	4.4149000000000003	3.536	3.1387999999999998	2.6423000000000001	2.1457999999999999	1.6935	1.3343	0.98219999999999996	0.72499999999999998	0.61070000000000002	0.53700000000000003	0.47599999999999998	0.379	0.125	0.037	10	98.948997	\N
7488	17373	1	\N	2.8228	3.3290000000000002	1.23	4.7649999999999997	6.2622	5.4500999999999999	4.9086999999999996	4.2320000000000002	3.3685999999999998	1.883	1.4763999999999999	1.0698000000000001	0.78680000000000005	0.65810000000000002	0.56140000000000001	0.49180000000000001	0.3952	0.125	0.024	16	99.388	\N
7507	17392	1	\N	2.1160999999999999	2.5150000000000001	1.1839999999999999	3.2949999999999999	4.6924999999999999	3.6191	3.1905999999999999	2.6549999999999998	2.1193	1.6812	1.3225	0.98070000000000002	0.78979999999999995	0.69430000000000003	0.61319999999999997	0.57199999999999995	0.51019999999999999	0.125	0.056000002	16	99.822998	\N
7508	17393	1	\N	2.6979000000000002	2.9009999999999998	1.0369999999999999	4.3650000000000002	6.0519999999999996	4.9116999999999997	4.1515000000000004	3.6105	3.1472000000000002	2.2204999999999999	1.6627000000000001	1.2202	0.87849999999999995	0.75760000000000005	0.63680000000000003	0.58360000000000001	0.50870000000000004	0.125	0.018999999	16	99.823997	\N
7509	1336	1	\N	1.5195000000000001	1.978	1.097	2.6349999999999998	3.2057000000000002	2.2884000000000002	1.9411	1.8017000000000001	1.6621999999999999	1.3834	1.1046	0.91000000000000003	0.76600000000000001	0.69399999999999995	0.62439999999999996	0.5847	0.52510000000000001	0.125	0.014	10	99.913002	\N
7510	1337	1	\N	1.6859999999999999	2.3820000000000001	1.5329999999999999	3.1829999999999998	3.73	2.9476	2.4258999999999999	1.9350000000000001	1.7478	1.3732	0.99939999999999996	0.82440000000000002	0.64949999999999997	0.59660000000000002	0.55369999999999997	0.51939999999999997	0.43140000000000001	0.125	0.017999999	16	99.885002	\N
7511	1338	1	\N	3.6358000000000001	3.141	1.0609999999999999	5.1319999999999997	9.2533999999999992	6.0090000000000003	5.2321999999999997	4.2610999999999999	3.6446000000000001	2.6724999999999999	1.8573	1.3945000000000001	0.96109999999999995	0.82940000000000003	0.69769999999999999	0.60899999999999999	0.52080000000000004	0.125	0.026000001	16	97.421997	\N
7512	1339	1	\N	2.7772999999999999	2.9550000000000001	1.5549999999999999	3.871	6.3823999999999996	4.5846	3.7277	3.0425	2.3574000000000002	1.6788000000000001	1.2443	0.91020000000000001	0.70499999999999996	0.61639999999999995	0.56569999999999998	0.5252	0.43369999999999997	0.125	0.02	16	98.084	\N
7513	1340	1	\N	2.4079999999999999	2.3980000000000001	1.0189999999999999	3.556	3.944	3.1635	2.6432000000000002	1.9984999999999999	1.8602000000000001	1.5837000000000001	1.3071999999999999	1.0306999999999999	0.81279999999999997	0.70750000000000002	0.61019999999999996	0.55020000000000002	0.44540000000000002	0.125	0.016000001	16	97.682999	\N
7514	1341	1	\N	3.2372000000000001	2.4129999999999998	1.5620000000000001	2.6219999999999999	7.6943000000000001	4.1654999999999998	3.3035000000000001	2.3451	1.9147000000000001	1.6479999999999999	1.3813	1.1146	0.91769999999999996	0.84550000000000003	0.77339999999999998	0.71560000000000001	0.62849999999999995	0.125	0.041000001	16	94.969002	\N
7515	1342	1	\N	6.2434000000000003	3.23	0.79600000000000004	7.2990000000000004	14.9504	11.6083	9.6638999999999999	8.1532999999999998	6.6428000000000003	5.2328999999999999	4.0293000000000001	3.0754999999999999	2.1278999999999999	1.7441	1.3934	1.1129	0.71689999999999998	0.125	0.012	16	91.884003	\N
7516	1343	1	\N	5.6180000000000003	2.5139999999999998	0.91700000000000004	4.3410000000000002	12.67	9.3774999999999995	8.1686999999999994	6.6578999999999997	5.9085000000000001	4.8825000000000003	3.8955000000000002	3.1488	2.4020999999999999	2.0287999999999999	1.7236	1.4841	1.1248	0.125	0.02	16	94.914001	\N
7517	1344	1	\N	2.6978	2.7029999999999998	2.2229999999999999	2.8599999999999999	6.2862	4.2079000000000004	3.3904999999999998	2.4940000000000002	1.9036	1.474	1.0443	0.87990000000000002	0.74590000000000001	0.67900000000000005	0.61639999999999995	0.57599999999999996	0.51539999999999997	0.125	0.024	16	97.887001	\N
7518	1345	1	\N	4.7333999999999996	4.0940000000000003	2.6760000000000002	3.9369999999999998	14.3695	10.635300000000001	7.8745000000000003	5.4598000000000004	3.9731000000000001	2.1442999999999999	1.5881000000000001	1.1409	0.87990000000000002	0.7923	0.7046	0.63449999999999995	0.54459999999999997	0.125	0.021	16	92.620003	\N
7519	1346	1	\N	1.4722999999999999	1.929	1.3999999999999999	2.1429999999999998	3.1821999999999999	2.0985	1.8703000000000001	1.6827000000000001	1.4950000000000001	1.1196999999999999	0.9194	0.80110000000000003	0.68289999999999995	0.62629999999999997	0.5917	0.56410000000000005	0.52249999999999996	0.125	0.024	10	99.556	\N
7520	1347	1	\N	2.2307999999999999	2.3460000000000001	2.125	2.0310000000000001	5.0039999999999996	3.0827	2.1467000000000001	1.7828999999999999	1.5347	1.0383	0.90159999999999996	0.79500000000000004	0.68840000000000001	0.6351	0.59299999999999997	0.56030000000000002	0.51119999999999999	0.125	0.043000001	16	97.851997	\N
7521	1348	1	\N	2.1474000000000002	2.52	1.494	3.04	4.9016999999999999	3.673	3.2256	2.6665000000000001	2.1073	1.6167	1.1928000000000001	0.91169999999999995	0.74970000000000003	0.66869999999999996	0.60970000000000002	0.5786	0.53190000000000004	0.125	0.015	16	99.806	\N
7522	1349	1	\N	3.0158999999999998	2.4910000000000001	1.3859999999999999	3.04	5.7809999999999997	3.9943	3.4916	2.8633000000000002	2.2349000000000001	1.7137	1.3615999999999999	1.0096000000000001	0.85389999999999999	0.77869999999999995	0.7036	0.64349999999999996	0.56379999999999997	0.125	0.011	31.5	98.706001	\N
7523	1350	1	\N	16.244800000000001	8.1120000000000001	1.4219999999999999	21.748999999999999	64.565700000000007	30.4908	26.09	20.588899999999999	15.3179	8.0014000000000003	3.1524999999999999	0.96499999999999997	0.6694	0.58399999999999996	0.52129999999999999	0.46339999999999998	0.3679	0.125	0.398	63	89.557999	\N
7524	1351	1	\N	5.2515000000000001	6.665	13.851000000000001	2.4980000000000002	20.815899999999999	13.306800000000001	8.7637999999999998	4.2851999999999997	1.5829	0.64929999999999999	0.53649999999999998	0.45850000000000002	0.39229999999999998	0.35920000000000002	0.3261	0.29959999999999998	0.25990000000000002	0.125	0.889	31.5	98.095001	\N
7700	17501	0	\N	23.7881	5.2539999999999996	0.39200000000000002	22.108000000000001	59.812800000000003	50.724299999999999	44.665300000000002	37.0916	30.4849	22.7273	15.4246	9.5457000000000001	5.1124999999999998	3.5910000000000002	2.5706000000000002	1.8374999999999999	1.028	0.063	0.0040000002	63	92.103996	\N
7701	17502	0	\N	5.8239000000000001	5.3410000000000002	1.3360000000000001	10.151999999999999	17.802099999999999	13.3117	10.5382	8.4928000000000008	6.7085999999999997	3.7149999999999999	2.1564000000000001	1.0884	0.62660000000000005	0.57389999999999997	0.5212	0.46660000000000001	0.36599999999999999	0.063	0.022	20	92.588997	\N
7702	17503	0	\N	10.6046	6.7679999999999998	0.20599999999999999	32.271000000000001	27.792999999999999	19.505800000000001	17.148	14.8871	13.0639	9.4974000000000007	6.3503999999999996	2.9958999999999998	0.99539999999999995	0.63190000000000002	0.51439999999999997	0.42580000000000001	0.29430000000000001	0.125	1.743	31.5	92.455002	\N
7720	17520	0	\N	37.082900000000002	10.015000000000001	0.044999999999999998	98.241	84.628500000000003	75.405500000000004	69.256900000000002	62.013800000000003	56.709200000000003	46.100000000000001	35.4908	19.261900000000001	8.2866	3.6339999999999999	1.2101	0.75180000000000002	0.46929999999999999	0.063	0.011	63	75.93	\N
7721	17521	0	\N	1.7557	2.492	1.806	2.556	3.5975999999999999	1.9153	1.5278	1.0434000000000001	0.89439999999999997	0.66249999999999998	0.57179999999999997	0.50409999999999999	0.42309999999999998	0.3821	0.3412	0.30840000000000001	0.25929999999999997	0.063	0.011	20	98.639	\N
7722	17522	0	\N	18.454000000000001	6.2050000000000001	0.14499999999999999	29.824999999999999	48.111899999999999	29.9727	27.258900000000001	23.866599999999998	20.474299999999999	15.6342	12.667400000000001	9.5843000000000007	5.0616000000000003	2.7042000000000002	1.2181	0.77839999999999998	0.5242	0.063	0.0089999996	63	93.360001	\N
7723	17523	0	\N	24.140000000000001	1.958	1.054	3.2309999999999999	49.292499999999997	41.067999999999998	35.585000000000001	30.6723	28.6233	24.525500000000001	20.427600000000002	17.866199999999999	15.291499999999999	13.6568	12.022	10.7142	7.5896999999999997	0.063	0.0080000004	31.5	77.019997	\N
7724	17524	0	\N	22.4772	5.226	0.26900000000000002	32.526000000000003	53.070900000000002	47.113399999999999	43.1417	38.177100000000003	33.212600000000002	24.4085	17.393699999999999	12.061999999999999	7.2065999999999999	4.8764000000000003	2.9295	1.7249000000000001	0.75039999999999996	0.063	0.003	31.5	68.275002	\N
7725	17525	0	\N	23.112500000000001	1.845	0.55800000000000005	42.569000000000003	42.902000000000001	31.417100000000001	30.402899999999999	29.135000000000002	27.867100000000001	25.331399999999999	22.7957	20.260000000000002	17.709499999999998	16.433499999999999	13.1349	9.2334999999999994	0.59509999999999996	0.063	0.0020000001	31.5	84.327003	\N
7726	17526	0	\N	11.0473	2.7709999999999999	0.54500000000000004	9.1120000000000001	23.142700000000001	18.537600000000001	16.642199999999999	15.057399999999999	13.7643	11.178000000000001	9.0647000000000002	7.3471000000000002	5.4432999999999998	4.3459000000000003	3.2686000000000002	2.4142000000000001	1.2266999999999999	0.063	0.148	31.5	97.748001	\N
7727	17527	0	\N	10.3377	5.9930000000000003	0.14299999999999999	27.221	23.965	18.995699999999999	17.093	15.2654	13.9062	11.1877	8.3941999999999997	5.3426999999999998	2.4872999999999998	1.3879999999999999	0.68179999999999996	0.52900000000000003	0.41099999999999998	0.125	0.097999997	31.5	97.389999	\N
7728	17528	0	\N	28.114599999999999	4.798	0.221	51.417000000000002	59.247700000000002	53.594099999999997	49.825000000000003	45.113700000000001	40.4024	31.095300000000002	23.764700000000001	17.213699999999999	11.2075	8.0088000000000008	4.4027000000000003	2.3277000000000001	0.6048	0.063	0.0040000002	63	93.982002	\N
7729	17529	0	\N	3.9245999999999999	3.5339999999999998	1.367	5.1799999999999997	10.313700000000001	7.4653	5.923	4.5677000000000003	3.6905000000000001	2.6253000000000002	1.8069999999999999	1.3394999999999999	0.93069999999999997	0.80410000000000004	0.67749999999999999	0.5978	0.50680000000000003	0.125	0.0080000004	20	97.710999	\N
7730	17530	0	\N	5.5869999999999997	3.4529999999999998	1.9319999999999999	5.0309999999999997	15.2044	11.936299999999999	9.8370999999999995	8.0076000000000001	6.2186000000000003	3.8733	2.4868000000000001	1.7874000000000001	1.4597	1.2958000000000001	1.1319999999999999	1.0008999999999999	0.77000000000000002	0.125	0.039000001	20	95.982002	\N
7740	17540	0	\N	15.5534	2.641	0.505	9.6010000000000009	29.144200000000001	26.3856	24.546500000000002	22.247599999999998	19.965499999999999	16.8703	14.0564	11.352399999999999	8.5436999999999994	7.0869	5.3693	3.7827000000000002	1.7571000000000001	0.063	0.0070000002	31.5	95.124001	\N
7741	17541	0	\N	13.499000000000001	2.411	0.60399999999999998	6.0110000000000001	26.630700000000001	22.9634	20.5185	18.583100000000002	16.8767	14.4026	12.2529	10.103199999999999	7.7339000000000002	6.5437000000000003	5.1252000000000004	3.9502999999999999	2.3961000000000001	0.063	0.0070000002	31.5	97.967003	\N
7742	17542	0	\N	12.405200000000001	3.177	0.40200000000000002	13.923	26.319500000000001	22.208400000000001	19.648099999999999	17.383400000000002	15.5594	13.2949	11.0304	8.5422999999999991	5.7840999999999996	4.1886000000000001	3.0567000000000002	2.2010000000000001	0.95489999999999997	0.063	0.0060000001	31.5	97.560997	\N
7743	17543	0	\N	11.998200000000001	4.194	0.499	13.157999999999999	28.715299999999999	23.494800000000001	20.014399999999998	16.893799999999999	14.7889	11.3927	7.9263000000000003	4.7351999999999999	2.9314	2.2166999999999999	1.6907000000000001	1.3355999999999999	0.86580000000000001	0.063	0.0099999998	31.5	93.199997	\N
7744	17544	0	\N	11.751200000000001	4.8630000000000004	0.183	21.914999999999999	26.014399999999998	21.5153	19.282800000000002	17.470800000000001	15.744899999999999	13.036199999999999	10.327500000000001	7.3051000000000004	3.609	2.1078999999999999	1.3324	0.90969999999999995	0.5948	0.063	0.003	31.5	97.316002	\N
7745	17545	0	\N	11.750999999999999	4.7930000000000001	0.249	17.573	27.013300000000001	22.703800000000001	19.8931	17.623899999999999	15.573600000000001	12.574299999999999	9.4868000000000006	5.8487	2.8671000000000002	1.8871	1.3795999999999999	0.98819999999999997	0.71560000000000001	0.063	0.0020000001	31.5	96.247002	\N
7746	17546	0	\N	11.0022	5.1479999999999997	0.13	26.812999999999999	22.495899999999999	18.811499999999999	17.611499999999999	16.111699999999999	14.8992	12.5205	10.1419	7.0488999999999997	3.5909	2.0411000000000001	1.0299	0.70979999999999999	0.46700000000000003	0.063	0.011	31.5	97.351997	\N
7747	17547	0	\N	5.9271000000000003	3.488	0.878	7.0620000000000003	14.148899999999999	11.5792	9.9194999999999993	8.6324000000000005	7.3452000000000002	5.0861000000000001	3.5424000000000002	2.5657000000000001	1.7519	1.4571000000000001	1.1623000000000001	0.95189999999999997	0.72019999999999995	0.063	0.015	31.5	99.367996	\N
7748	17548	0	\N	4.7628000000000004	4.524	3.2519999999999998	4.7789999999999999	14.582700000000001	9.9484999999999992	7.5335999999999999	4.7416999999999998	3.3275999999999999	1.8242	1.2194	0.86909999999999998	0.66359999999999997	0.59219999999999995	0.53600000000000003	0.48609999999999998	0.38169999999999998	0.063	0.0089999996	31.5	98.216003	\N
7749	17549	0	\N	7.3150000000000004	6.8010000000000002	0.68899999999999995	18.677	21.9633	17.719100000000001	15.307600000000001	11.9445	9.2170000000000005	5.6486000000000001	3.1381000000000001	1.5425	0.68149999999999999	0.50890000000000002	0.43690000000000001	0.3831	0.3024	0.063	0.056000002	20	87.941002	\N
7750	17550	0	\N	5.9391999999999996	4.7249999999999996	0.40300000000000002	16.027999999999999	14.2875	11.8697	10.2578	9.1844999999999999	8.2492999999999999	6.3788999999999998	3.9565999999999999	2.5059999999999998	1.3252999999999999	0.90400000000000003	0.64610000000000001	0.53169999999999995	0.39800000000000002	0.063	0.030999999	20	97.620003	\N
7751	17551	0	\N	1.109	2.3690000000000002	1.9550000000000001	2.3599999999999999	2.6434000000000002	1.4148000000000001	0.95630000000000004	0.72760000000000002	0.58730000000000004	0.47860000000000003	0.42720000000000002	0.37569999999999998	0.32419999999999999	0.29849999999999999	0.27279999999999999	0.25219999999999998	0.20280000000000001	0.063	0.037	10	98.794998	\N
7752	17552	0	\N	7.3150000000000004	6.8010000000000002	0.68899999999999995	18.677	21.9633	17.719100000000001	15.307600000000001	11.9445	9.2170000000000005	5.6486000000000001	3.1381000000000001	1.5425	0.68149999999999999	0.50890000000000002	0.43690000000000001	0.3831	0.3024	0.063	0.056000002	20	87.941002	\N
7753	17553	0	\N	7.1493000000000002	6.9669999999999996	1.28	17.968	21.964400000000001	17.507400000000001	15.101800000000001	12.324999999999999	9.6346000000000007	5.1288	2.2208000000000001	1.0208999999999999	0.57079999999999997	0.47349999999999998	0.4108	0.36070000000000002	0.28539999999999999	0.063	0.479	20	87.940002	\N
7760	17560	0	\N	14.0824	2.859	0.35099999999999998	14.476000000000001	27.1221	22.088999999999999	19.621700000000001	18.3689	17.116	14.9414	13.0327	11.124000000000001	8.5418000000000003	6.7683	4.1520000000000001	2.7027999999999999	1.0322	0.063	0.0070000002	31.5	95.219002	\N
7761	17561	0	\N	7.9721000000000002	2.669	0.72099999999999997	6.5380000000000003	16.2803	14.289899999999999	13.079499999999999	11.5665	10.0535	8.1684000000000001	6.3037999999999998	4.7732999999999999	3.4794999999999998	2.9533	2.427	2.0059999999999998	1.2493000000000001	0.063	0.0080000004	20	94.628998	\N
7762	17562	0	\N	12.3208	3.0899999999999999	0.495	8.6709999999999994	27.2286	20.345600000000001	18.090199999999999	15.7507	14.4412	11.8223	9.3597000000000001	7.2546999999999997	4.9173	3.7524000000000002	2.8517000000000001	2.1312000000000002	1.3633999999999999	0.063	0.0070000002	31.5	93.723	\N
7763	17563	0	\N	19.852599999999999	2.738	0.44900000000000001	8.3650000000000002	36.843200000000003	29.133400000000002	27.285699999999999	24.975999999999999	22.666399999999999	18.7806	15.889200000000001	12.8096	9.6447000000000003	7.6191000000000004	5.5477999999999996	3.8874	2.2450000000000001	0.125	0.063000001	63	94.292	\N
7764	17564	0	\N	18.388400000000001	2.2389999999999999	0.59199999999999997	6.8600000000000003	31.407800000000002	28.794899999999998	27.052900000000001	24.875499999999999	22.698	19.0962	16.720700000000001	14.108700000000001	11.3939	10.0364	7.7382999999999997	5.7431000000000001	2.7837999999999998	0.125	0.109	31.5	90.211998	\N
7765	17565	0	\N	17.886700000000001	2.4470000000000001	0.46600000000000003	11.055999999999999	30.6174	28.264199999999999	26.695399999999999	24.734400000000001	22.773399999999999	19.301100000000002	16.9147	14.222300000000001	11.3399	9.8162000000000003	7.2020999999999997	4.7206000000000001	1.7458	0.063	0.0060000001	31.5	92.25	\N
7767	17567	0	\N	1.2902	1.948	1.3899999999999999	2.3479999999999999	2.3298000000000001	1.7484999999999999	1.5461	1.2931999999999999	1.0403	0.88560000000000005	0.76119999999999999	0.63690000000000002	0.57040000000000002	0.53890000000000005	0.50739999999999996	0.4607	0.37719999999999998	0.125	0.142	10	98.921997	\N
7766	17566	0	\N	0.85170000000000001	1.5740000000000001	1.0800000000000001	1.9259999999999999	1.3796999999999999	0.9718	0.91830000000000001	0.85160000000000002	0.78480000000000005	0.6512	0.59419999999999995	0.55149999999999999	0.50890000000000002	0.47370000000000001	0.42849999999999999	0.39229999999999998	0.33810000000000001	0.125	0.016000001	10	99.732002	\N
7768	17568	0	\N	7.4706000000000001	6.1159999999999997	1.583	11.804	19.8613	15.3957	13.1837	10.418699999999999	7.9116	3.8100000000000001	2.0007000000000001	1.1625000000000001	0.70050000000000001	0.56420000000000003	0.4708	0.41160000000000002	0.32279999999999998	0.125	0.60500002	31.5	95.293999	\N
7769	17569	0	\N	11.3368	6.2110000000000003	1.125	16.629999999999999	27.346599999999999	21.898900000000001	18.8767	15.9415	13.3398	8.1677	3.3245	1.5042	0.87239999999999995	0.73409999999999997	0.61529999999999996	0.56759999999999999	0.49109999999999998	0.125	0.22499999	63	95.864998	\N
7770	17570	0	\N	9.4341000000000008	5.8079999999999998	0.69899999999999995	15.468	25.463999999999999	19.081	16.5288	14.2706	12.1975	8.1538000000000004	3.9297	1.8266	0.84630000000000005	0.62319999999999998	0.59119999999999995	0.56559999999999999	0.52710000000000001	0.125	0.116	31.5	95.037003	\N
7780	17580	0	\N	12.024100000000001	5.6859999999999999	0.23300000000000001	20.856000000000002	28.178899999999999	24.1113	21.3995	18.351500000000001	15.713699999999999	12.190099999999999	8.7788000000000004	5.6269	2.6112000000000002	1.3143	0.87970000000000004	0.74590000000000001	0.58450000000000002	0.063	0.0040000002	31.5	94.899002	\N
7781	17581	0	\N	13.3331	5.5839999999999996	0.17299999999999999	25.187000000000001	28.7988	26.044	24.2074	21.9117	19.608599999999999	15.1096	11.2212	7.1281999999999996	3.0390000000000001	1.7370000000000001	1.0394000000000001	0.83509999999999995	0.59989999999999999	0.063	0.0060000001	31.5	95.883003	\N
7782	17582	0	\N	13.6744	3.4199999999999999	0.24199999999999999	16.484000000000002	26.4283	22.710599999999999	20.232099999999999	19.022400000000001	17.965699999999998	15.8361	13.491899999999999	11.1477	8.0410000000000004	6.0431999999999997	3.4733000000000001	1.9415	0.9607	0.063	0.0080000004	31.5	98.184998	\N
7783	17583	0	\N	18.3993	6.8360000000000003	0.311	26.818999999999999	52.807200000000002	37.439	30.2043	26.350899999999999	22.497599999999998	15.542	9.8169000000000004	5.2885	2.0663999999999998	1.5108999999999999	0.99850000000000005	0.80120000000000002	0.57950000000000002	0.063	0.014	63	93.978996	\N
7784	17584	0	\N	9.5538000000000007	4.6769999999999996	1.0369999999999999	10.08	27.756599999999999	17.800699999999999	14.7249	11.823	9.3646999999999991	6.0328999999999997	3.7381000000000002	2.5171999999999999	1.6086	1.2689999999999999	0.96160000000000001	0.81369999999999998	0.59850000000000003	0.063	0.17	31.5	91.833	\N
7785	17585	0	\N	2.0139999999999998	4.7389999999999999	8.7769999999999992	2.1200000000000001	7.2164000000000001	3.0017999999999998	1.5067999999999999	0.80769999999999997	0.51849999999999996	0.2374	0.21379999999999999	0.19020000000000001	0.16669999999999999	0.15490000000000001	0.1431	0.13370000000000001	0.112	0.063	1.306	16	95.334	\N
7824	17624	0	\N	1.6331	2.1339999999999999	1.371	2.8959999999999999	3.4224000000000001	2.4512	1.9593	1.7914000000000001	1.6234999999999999	1.2877000000000001	0.98080000000000001	0.84619999999999995	0.71160000000000001	0.64429999999999998	0.58440000000000003	0.53800000000000003	0.4446	0.063	0.23999999	10	98.862	\N
7821	17621	0	\N	1.3493999999999999	1.8660000000000001	1.161	2.5470000000000002	2.4733000000000001	1.8837999999999999	1.7598	1.6049	1.45	1.1402000000000001	0.93669999999999998	0.82110000000000005	0.70550000000000002	0.64780000000000004	0.5887	0.54090000000000005	0.44769999999999999	0.063	0.072999999	10	99.427002	\N
7823	17623	0	\N	1.6942999999999999	2.1059999999999999	1.2709999999999999	2.9350000000000001	3.3136000000000001	2.2223000000000002	1.9012	1.7234	1.5456000000000001	1.1899999999999999	0.93610000000000004	0.79879999999999995	0.66149999999999998	0.60019999999999996	0.54510000000000003	0.501	0.40539999999999998	0.063	0.081	20	99.686996	\N
7825	17625	0	\N	1.4874000000000001	2.069	1.2509999999999999	2.5640000000000001	2.8094000000000001	1.8411	1.6556999999999999	1.4238999999999999	1.1921999999999999	0.92449999999999999	0.79549999999999998	0.66659999999999997	0.56850000000000001	0.52559999999999996	0.47670000000000001	0.43020000000000003	0.36049999999999999	0.063	0.266	10	97.538002	\N
7826	17626	0	\N	2.1962999999999999	2.3959999999999999	1.196	3.0960000000000001	4.0461999999999998	3.4466000000000001	3.0714000000000001	2.6023000000000001	2.1333000000000002	1.6839	1.3154999999999999	0.97619999999999996	0.81040000000000001	0.72750000000000004	0.64459999999999995	0.60060000000000002	0.54400000000000004	0.063	0.1	16	98.528999	\N
7827	17627	0	\N	7.0114999999999998	4.6619999999999999	0.504	12.913	15.9297	13.626899999999999	12.091699999999999	10.172700000000001	8.8774999999999995	6.4104000000000001	4.1170999999999998	2.6040999999999999	1.4530000000000001	0.99509999999999998	0.78920000000000001	0.62709999999999999	0.49640000000000001	0.125	0.015	31.5	98.733002	\N
7828	17628	0	\N	7.7095000000000002	3.1549999999999998	0.64700000000000002	7.9409999999999998	15.755100000000001	13.3727	11.7845	9.8920999999999992	8.8249999999999993	6.6909000000000001	5.2698999999999998	4.0087999999999999	2.8673999999999999	2.2970999999999999	1.7542	1.3435999999999999	0.84260000000000002	0.063	0.029999999	31.5	97.543999	\N
7841	17641	0	\N	3.9125999999999999	3.8889999999999998	0.374	9.827	9.0492000000000008	7.2523	6.2005999999999997	5.5944000000000003	4.9882	3.8517999999999999	3.0501	2.2484000000000002	1.2496	0.80489999999999995	0.56530000000000002	0.47949999999999998	0.39200000000000002	0.063	0.116	16	99.610001	\N
7842	17642	0	\N	7.7435999999999998	4.8940000000000001	0.25900000000000001	18.364000000000001	17.103200000000001	14.9009	13.7676	12.350899999999999	10.9343	8.3277999999999999	5.9801000000000002	4.2712000000000003	2.6663000000000001	1.8613999999999999	0.99519999999999997	0.622	0.45350000000000001	0.063	0.041999999	20	95.569	\N
7844	17644	0	\N	5.5612000000000004	2.9580000000000002	0.77000000000000002	6.2679999999999998	13.2219	9.8795999999999999	8.8360000000000003	7.5316000000000001	6.2644000000000002	4.9898999999999996	3.8048000000000002	2.9302999999999999	2.0558999999999998	1.7157	1.3896999999999999	1.1289	0.79610000000000003	0.063	0.033	20	97.570999	\N
7845	17645	0	\N	11.7006	3.3279999999999998	0.26100000000000001	16.651	21.8752	18.900400000000001	17.942	16.7441	15.577500000000001	13.3469	11.116199999999999	8.2162000000000006	4.9676999999999998	3.6347	2.5171000000000001	1.7060999999999999	0.80159999999999998	0.063	1.779	31.5	97.238998	\N
7846	17646	0	\N	2.9902000000000002	3.5600000000000001	2.5489999999999999	4.2770000000000001	8.4680999999999997	5.7046999999999999	4.3883000000000001	3.3668999999999998	2.5384000000000002	1.5985	1.0037	0.79979999999999996	0.61250000000000004	0.55679999999999996	0.50109999999999999	0.45019999999999999	0.37369999999999998	0.063	0.121	20	98.871002	\N
7847	17647	0	\N	6.1039000000000003	4.1900000000000004	0.75600000000000001	9.4079999999999995	15.5726	12.8809	11.086399999999999	9.2550000000000008	7.8102	5.3547000000000002	3.5352000000000001	2.0638999999999998	1.3573	1.0214000000000001	0.85650000000000004	0.73380000000000001	0.56920000000000004	0.063	0.108	20	96.024002	\N
7848	17648	0	\N	2.4843999999999999	3.085	2.4470000000000001	2.7989999999999999	7.1566999999999998	3.8195999999999999	2.7227000000000001	1.8415999999999999	1.5066999999999999	0.95909999999999995	0.79139999999999999	0.62649999999999995	0.53539999999999999	0.48899999999999999	0.44019999999999998	0.4012	0.34260000000000002	0.063	0.154	20	98.637001	\N
7849	17649	0	\N	3.6602999999999999	4.242	1.2310000000000001	7.601	9.9914000000000005	7.6475	6.1787000000000001	5.0768000000000004	3.9847999999999999	2.6484999999999999	1.625	0.95689999999999997	0.65400000000000003	0.55549999999999999	0.47610000000000002	0.42509999999999998	0.34839999999999999	0.063	0.0099999998	20	99.320999	\N
7850	17650	0	\N	6.7320000000000002	4.3140000000000001	0.60799999999999998	10.566000000000001	16.555399999999999	13.1853	11.015499999999999	9.1841000000000008	7.8798000000000004	5.6227999999999998	3.9197000000000002	2.4586000000000001	1.4327000000000001	1.0192000000000001	0.84150000000000003	0.70860000000000001	0.53220000000000001	0.063	0.025	31.5	98.257004	\N
7851	17651	0	\N	6.0380000000000003	3.9980000000000002	1.5329999999999999	6.3730000000000002	14.347099999999999	9.4527999999999999	7.7180999999999997	5.8680000000000003	4.6196000000000002	3.0474000000000001	1.9092	1.3852	0.93240000000000001	0.80469999999999997	0.67700000000000005	0.59130000000000005	0.47820000000000001	0.063	0.043000001	31.5	94.986	\N
7852	17652	0	\N	8.3298000000000005	2.4889999999999999	0.56100000000000005	6.6029999999999998	15.5806	14.1686	13.2273	12.050599999999999	10.874000000000001	9.0732999999999997	7.5991	6.1200000000000001	4.6041999999999996	3.8264999999999998	2.9714999999999998	2.2875000000000001	1.3741000000000001	0.063	0.068000004	20	97.288002	\N
7853	17653	0	\N	16.613399999999999	1.8129999999999999	1.002	2.4489999999999998	30.066500000000001	25.319400000000002	22.154699999999998	19.394200000000001	18.063700000000001	15.6241	13.949400000000001	12.2746	10.5999	9.6874000000000002	8.5853000000000002	7.7035999999999998	6.3810000000000002	0.063	0.094999999	31.5	91.811996	\N
7854	17654	0	\N	7.4089	5.0110000000000001	0.94599999999999995	10.414	21.275400000000001	15.314	12.912599999999999	9.9494000000000007	8.2477	5.2205000000000004	3.1421999999999999	1.7549999999999999	0.98960000000000004	0.85009999999999997	0.71050000000000002	0.60980000000000001	0.50129999999999997	0.063	0.126	31.5	97.707001	\N
7855	17655	0	\N	7.2085999999999997	5.7619999999999996	0.41799999999999998	16.225000000000001	20.500699999999998	15.3619	13.2277	10.559799999999999	8.8952000000000009	6.1539000000000001	4.1234000000000002	2.3599000000000001	0.98740000000000006	0.71650000000000003	0.53610000000000002	0.46260000000000001	0.37930000000000003	0.063	0.152	20	89.544998	\N
7856	17656	0	\N	2.3138999999999998	2.6859999999999999	1.5229999999999999	3.0049999999999999	6.4935	2.7143000000000002	1.9095	1.6717	1.4339	0.98540000000000005	0.81889999999999996	0.65249999999999997	0.48899999999999999	0.44869999999999999	0.40839999999999999	0.37619999999999998	0.32790000000000002	0.063	0.021	20	98.344002	\N
7857	17657	0	\N	1.5844	2.4390000000000001	1.772	2.7069999999999999	3.4980000000000002	1.9246000000000001	1.6201000000000001	1.2394000000000001	0.9637	0.7681	0.59279999999999999	0.48230000000000001	0.41610000000000003	0.38300000000000001	0.34989999999999999	0.32350000000000001	0.2838	0.063	0.38	20	99.069	\N
7858	17658	0	\N	2.9432999999999998	3.3620000000000001	1.9199999999999999	4.2350000000000003	8.5652000000000008	5.2640000000000002	3.8715000000000002	3.0773999999999999	2.2833999999999999	1.6076999999999999	1.1302000000000001	0.86209999999999998	0.67249999999999999	0.5917	0.52239999999999998	0.46579999999999999	0.37969999999999998	0.063	0.0080000004	20	99.416	\N
7859	17659	0	\N	10.603400000000001	6.117	0.13900000000000001	29.184999999999999	24.776700000000002	20.742699999999999	19.186800000000002	17.782599999999999	16.378399999999999	12.8338	9.0904000000000007	5.2789999999999999	2.2526999999999999	0.97719999999999996	0.62909999999999999	0.5544	0.43969999999999998	0.063	0.045000002	20	82.894997	\N
7860	17660	0	\N	2.8201000000000001	3.9860000000000002	6.1449999999999996	2.468	9.7125000000000004	5.2923	3.3031000000000001	1.8692	1.3225	0.74339999999999995	0.53559999999999997	0.46060000000000001	0.40749999999999997	0.38090000000000002	0.3543	0.33310000000000001	0.30120000000000002	0.063	0.081	20	97.773003	\N
7861	17661	0	\N	4.3757000000000001	4.6900000000000004	1.288	9.1099999999999994	12.8232	8.8560999999999996	7.3616999999999999	5.7960000000000003	4.6281999999999996	2.8997999999999999	1.6637999999999999	0.9355	0.62560000000000004	0.53669999999999995	0.4587	0.40260000000000001	0.31830000000000003	0.063	0.063000001	20	96.734001	\N
7862	17662	0	\N	5.3448000000000002	5.3010000000000002	0.70799999999999996	12.465	14.6936	11.5114	9.6353000000000009	8.0501000000000005	6.4649000000000001	4.3056000000000001	2.5817999999999999	1.2962	0.65010000000000001	0.51429999999999998	0.45250000000000001	0.40970000000000001	0.34539999999999998	0.063	0.032000002	20	95.844002	\N
7863	17663	0	\N	8.7988999999999997	5.5540000000000003	0.14899999999999999	23.219000000000001	18.8705	16.395800000000001	15.1873	13.8508	12.5144	9.8681000000000001	7.6448999999999998	5.4272999999999998	3.0766	1.5545	0.60129999999999995	0.53159999999999996	0.42499999999999999	0.063	0.050000001	20	92.737999	\N
7864	17664	0	\N	8.8806999999999992	3.254	0.44600000000000001	11.891999999999999	17.9756	15.4444	14.319599999999999	12.913500000000001	11.5075	9.0825999999999993	7.1052	5.3308999999999997	3.7000000000000002	2.8934000000000002	2.0867	1.4589000000000001	0.76370000000000005	0.063	0.030999999	31.5	98.445999	\N
7865	17665	0	\N	9.3534000000000006	2.5289999999999999	0.52700000000000002	7.0110000000000001	17.885100000000001	15.563800000000001	14.675800000000001	13.5657	12.4556	10.2355	8.4748000000000001	6.7686000000000002	4.9790999999999999	4.0686	3.1604999999999999	2.4340999999999999	1.4599	0.063	0.075000003	20	94.527	\N
7866	17666	0	\N	13.2476	1.6950000000000001	0.75800000000000001	5.6239999999999997	23.192900000000002	19.259499999999999	17.885999999999999	16.1691	15.4582	14.2561	13.0541	11.8521	10.6501	10.048999999999999	8.2394999999999996	6.7060000000000004	2.5347	0.063	0.127	20	86.155998	\N
7867	17667	0	\N	2.6572	2.3479999999999999	1.48	2.7160000000000002	6.6990999999999996	3.8243	3.1642000000000001	2.3391999999999999	1.9152	1.6272	1.3391999999999999	1.0511999999999999	0.88670000000000004	0.81779999999999997	0.749	0.69389999999999996	0.59899999999999998	0.063	0.063000001	20	99.327003	\N
7868	17668	0	\N	8.2088000000000001	5.3739999999999997	0.89300000000000002	12.35	23.662400000000002	18.309799999999999	15.410500000000001	12.806100000000001	10.201599999999999	6.1600999999999999	3.6055000000000001	1.9659	1.2281	0.93600000000000005	0.76819999999999999	0.6341	0.49880000000000002	0.063	0.050999999	31.5	98.348	\N
7869	17669	0	\N	2.1116000000000001	2.8599999999999999	1.1479999999999999	4.5460000000000003	4.2093999999999996	3.4718	3.0859999999999999	2.6036999999999999	2.1215000000000002	1.5956999999999999	1.1331	0.82720000000000005	0.60499999999999998	0.53810000000000002	0.47360000000000002	0.42459999999999998	0.35099999999999998	0.125	0.15899999	16	97.754997	\N
7870	17670	0	\N	1.0317000000000001	1.4490000000000001	1.046	1.663	1.0781000000000001	0.62060000000000004	0.57899999999999996	0.52700000000000002	0.49130000000000001	0.45500000000000002	0.41870000000000002	0.38250000000000001	0.34620000000000001	0.3281	0.30990000000000001	0.2954	0.27360000000000001	0.125	0.322	16	98.469002	\N
7871	17671	0	\N	3.6135999999999999	3.2429999999999999	3.1139999999999999	2.9889999999999999	11.142200000000001	6.2274000000000003	4.3646000000000003	3.0625	1.99	1.5390999999999999	1.0881000000000001	0.89770000000000005	0.77049999999999996	0.70689999999999997	0.64339999999999997	0.59209999999999996	0.51500000000000001	0.063	0.103	20	96.227997	\N
7876	17676	0	\N	7.3666999999999998	4.9359999999999999	0.46899999999999997	16.344000000000001	17.141400000000001	14.6723	13.3666	11.734400000000001	10.1023	7.6634000000000002	4.3391999999999999	2.6905000000000001	1.4252	0.95009999999999994	0.74360000000000004	0.60229999999999995	0.46889999999999998	0.063	0.022	31.5	99.019997	\N
7877	17677	0	\N	8.6725999999999992	3.448	0.52100000000000002	12.423	18.783300000000001	16.169799999999999	15.0524	13.74	12.4275	9.7552000000000003	6.4985999999999997	4.3583999999999996	2.9506000000000001	2.3159000000000001	1.7531000000000001	1.3599000000000001	0.78520000000000001	0.125	0.0089999996	20	92.792999	\N
7878	17678	0	\N	10.5444	4.3689999999999998	0.46300000000000002	13.942	26.563500000000001	18.251000000000001	15.8169	13.873699999999999	11.9305	8.6928999999999998	6.1364999999999998	4.0568999999999997	2.5263	1.8433999999999999	1.3302	0.95599999999999996	0.62350000000000005	0.063	0.012	31.5	92.449997	\N
7879	17679	0	\N	3.6709999999999998	4.6509999999999998	2.819	5.7919999999999998	11.662100000000001	7.9577	6.1032999999999999	4.5263	3.4028999999999998	1.8249	1.0189999999999999	0.63080000000000003	0.4909	0.44690000000000002	0.40300000000000002	0.36780000000000002	0.31509999999999999	0.063	0.447	20	98.448997	\N
7880	17680	0	\N	0.7571	1.657	1.276	1.748	0.99109999999999998	0.82350000000000001	0.71189999999999998	0.60840000000000005	0.55620000000000003	0.48099999999999998	0.43980000000000002	0.3987	0.35749999999999998	0.33689999999999998	0.31630000000000003	0.29980000000000001	0.27510000000000001	0.063	0.0060000001	10	99.416	\N
7881	17681	0	\N	31.4969	11.013	0.042999999999999997	92.361999999999995	76.298599999999993	62.588900000000002	58.363700000000001	53.0822	47.800699999999999	37.2376	27.560099999999998	16.7441	2.9664000000000001	0.99319999999999997	0.62439999999999996	0.51600000000000001	0.4032	0.063	0.014	63	84.389	\N
7900	17700	0	\N	4.6558999999999999	3.6240000000000001	2.169	4.2850000000000001	13.6938	9.4002999999999997	7.4036	5.4813000000000001	4.0136000000000003	2.6240999999999999	1.7614000000000001	1.3264	0.95699999999999996	0.87090000000000001	0.78469999999999995	0.71579999999999999	0.61240000000000006	0.063	0.119	20	95.289001	\N
7901	17701	0	\N	7.9592999999999998	3.4039999999999999	0.51700000000000002	8.8770000000000007	17.75	15.022500000000001	13.7529	12.165900000000001	10.578799999999999	8.2613000000000003	6.1393000000000004	4.0721999999999996	2.5396000000000001	1.9033	1.5663	1.2967	0.93059999999999998	0.063	0.102	20	93.754997	\N
7902	17702	0	\N	5.8071999999999999	2.3980000000000001	0.93799999999999994	3.9409999999999998	12.6082	9.7954000000000008	8.9330999999999996	7.8552	6.7774000000000001	5.3884999999999996	4.2176999999999998	3.3935	2.6484000000000001	2.2757999999999998	1.9273	1.7033	1.3673	0.063	0.02	20	97.801003	\N
7903	17703	0	\N	3.6907999999999999	4.181	1.5149999999999999	7.7599999999999998	9.7370999999999999	8.0706000000000007	6.9596	5.7602000000000002	4.7319000000000004	2.9636	1.5683	0.84660000000000002	0.59999999999999998	0.55510000000000004	0.51019999999999999	0.46179999999999999	0.38190000000000002	0.063	0.003	20	99.691002	\N
7904	17704	0	\N	4.1387	3.6160000000000001	1.0269999999999999	6.5049999999999999	9.9114000000000004	8.0724	6.8464	5.7413999999999996	4.8734000000000002	3.4033000000000002	2.2023999999999999	1.4572000000000001	0.93149999999999999	0.81720000000000004	0.70289999999999997	0.61729999999999996	0.5232	0.063	0.071999997	20	98.32	\N
7905	17705	0	\N	4.8194999999999997	3.891	1.0149999999999999	7.1269999999999998	12.603	8.9116	7.4173999999999998	5.8939000000000004	4.8832000000000004	3.3780999999999999	2.2736000000000001	1.5541	0.98060000000000003	0.83109999999999995	0.68169999999999997	0.5887	0.47399999999999998	0.063	0.018999999	31.5	99.125999	\N
7906	17706	0	\N	5.8701999999999996	3.8889999999999998	0.97899999999999998	7.9160000000000004	14.132300000000001	11.177300000000001	9.5913000000000004	8.3215000000000003	7.0518000000000001	4.7869999999999999	2.9041000000000001	1.6979	1.0646	0.92000000000000004	0.81940000000000002	0.73899999999999999	0.6048	0.063	0.063000001	31.5	98.227997	\N
7907	17707	0	\N	1.5085999999999999	2.7210000000000001	3.5049999999999999	1.7350000000000001	4.5134999999999996	2.3485999999999998	0.99280000000000002	0.62639999999999996	0.58640000000000003	0.50639999999999996	0.46110000000000001	0.41880000000000001	0.3765	0.3553	0.3342	0.31719999999999998	0.2918	0.125	0.0080000004	16	99.199997	\N
7908	17708	0	\N	4.3339999999999996	4.9320000000000004	1.1379999999999999	10.611000000000001	12.480499999999999	9.2882999999999996	8.0403000000000002	6.4802	5.4268999999999998	3.5226000000000002	1.7655000000000001	0.62339999999999995	0.49840000000000001	0.45679999999999998	0.41520000000000001	0.38190000000000002	0.33200000000000002	0.125	0.0060000001	20	98.610001	\N
7909	17709	0	\N	1.7609999999999999	3.2389999999999999	3.9780000000000002	2.1040000000000001	5.4010999999999996	3.6677	2.8174000000000001	1.8021	0.98939999999999995	0.65649999999999997	0.56769999999999998	0.5	0.43730000000000002	0.40600000000000003	0.37469999999999998	0.34960000000000002	0.312	0.125	0.0099999998	10	98.264	\N
7910	17710	0	\N	4.5965999999999996	4.2729999999999997	0.56899999999999995	9.7089999999999996	11.9374	9.0976999999999997	7.9085000000000001	6.4218999999999999	5.5399000000000003	3.9228999999999998	2.8220999999999998	1.7302	0.87280000000000002	0.67090000000000005	0.56430000000000002	0.49830000000000002	0.40410000000000001	0.125	0.0089999996	20	98.356003	\N
7911	17711	0	\N	4.0289000000000001	3.8130000000000002	0.56499999999999995	8.7620000000000005	9.3414999999999999	7.9089	6.9538000000000002	5.9931999999999999	5.3150000000000004	3.9632000000000001	2.7583000000000002	1.5024999999999999	0.81989999999999996	0.67589999999999995	0.59040000000000004	0.54379999999999995	0.45229999999999998	0.125	0.023	16	97.425003	\N
7920	17720	0	\N	1.7195	2.036	1.306	2.6200000000000001	3.4737	2.6009000000000002	2.0190000000000001	1.8562000000000001	1.7085999999999999	1.4134	1.1181000000000001	0.92559999999999998	0.80159999999999998	0.73960000000000004	0.67759999999999998	0.62760000000000005	0.53939999999999999	0.125	0.041999999	10	98.750999	\N
7921	17721	0	\N	8.4629999999999992	5.7930000000000001	2.5920000000000001	14.01	23.2653	18.5886	16.8611	14.498799999999999	12.0017	6.2176	1.9931000000000001	1.296	0.86029999999999995	0.73880000000000001	0.62129999999999996	0.55389999999999995	0.44379999999999997	0.125	0.029999999	31.5	96.889	\N
7922	17722	0	\N	0.60799999999999998	1.5649999999999999	0.96799999999999997	1.954	0.93340000000000001	0.85619999999999996	0.80479999999999996	0.74039999999999995	0.67610000000000003	0.60109999999999997	0.55589999999999995	0.51080000000000003	0.44700000000000001	0.41210000000000002	0.37730000000000002	0.34939999999999999	0.30769999999999997	0.125	0.46000001	2	99.924004	\N
7923	17723	0	\N	0.99880000000000002	1.5760000000000001	0.91700000000000004	2.2519999999999998	1.4810000000000001	0.998	0.95830000000000004	0.90880000000000005	0.85929999999999995	0.76019999999999999	0.66110000000000002	0.58889999999999998	0.52890000000000004	0.49809999999999999	0.4446	0.40179999999999999	0.33760000000000001	0.125	0.37799999	16	99.664001	\N
7924	17724	0	\N	1.8384	2.3220000000000001	1.5509999999999999	2.8090000000000002	3.8953000000000002	3.1328999999999998	2.6246	1.9968999999999999	1.8141	1.4486000000000001	1.083	0.89480000000000004	0.75880000000000003	0.69069999999999998	0.62419999999999998	0.58079999999999998	0.51580000000000004	0.125	0.0080000004	16	99.818001	\N
7925	17725	0	\N	6.3368000000000002	4.4569999999999999	1.365	7.8339999999999996	15.862299999999999	11.944800000000001	9.6236999999999995	7.7817999999999996	6.0629999999999997	3.7789999999999999	2.294	1.4728000000000001	0.93220000000000003	0.81140000000000001	0.69059999999999999	0.60129999999999995	0.4824	0.125	0.003	31.5	96.689003	\N
7926	17726	0	\N	11.607799999999999	7.274	11.907999999999999	3.327	57.902299999999997	20.917899999999999	8.7340999999999998	3.7109000000000001	1.9944999999999999	1.1214999999999999	0.83340000000000003	0.63980000000000004	0.53300000000000003	0.48280000000000001	0.43419999999999997	0.39539999999999997	0.33710000000000001	0.125	0.108	63	90.496002	\N
7927	17727	0	\N	1.4292	2.556	1.4379999999999999	3.1709999999999998	3.3586999999999998	2.3083	1.8875999999999999	1.6366000000000001	1.3855999999999999	0.95350000000000001	0.75290000000000001	0.5847	0.4758	0.43209999999999998	0.38829999999999998	0.35320000000000001	0.30070000000000002	0.125	0.27599999	10	99.057999	\N
7928	17728	0	\N	3.6953	4.2590000000000003	0.37	11.500999999999999	8.8385999999999996	7.3413000000000004	6.3430999999999997	5.7347000000000001	5.1493000000000002	3.9786999999999999	2.8319999999999999	1.5367	0.5766	0.4929	0.44390000000000002	0.4047	0.34589999999999999	0.125	0.029999999	10	94.653999	\N
7929	17729	0	\N	4.6132999999999997	3.919	0.92800000000000005	7.46	12.3988	9.1332000000000004	7.8036000000000003	6.2148000000000003	5.3208000000000002	3.6726000000000001	2.4192999999999998	1.5802	0.97650000000000003	0.83069999999999999	0.68479999999999996	0.59470000000000001	0.49230000000000002	0.125	0.030999999	20	97.999001	\N
7930	17730	0	\N	2.1501999999999999	2.008	1.0469999999999999	2.7229999999999999	3.6922999999999999	2.7976000000000001	2.2010999999999998	1.9186000000000001	1.8070999999999999	1.5841000000000001	1.361	1.1379999999999999	0.93440000000000001	0.84840000000000004	0.76239999999999997	0.69359999999999999	0.58179999999999998	0.125	0.014	16	98.431	\N
7931	17731	0	\N	1.6888000000000001	2.5379999999999998	1.7330000000000001	2.758	3.8536000000000001	2.4413	1.8620000000000001	1.5375000000000001	1.2129000000000001	0.89180000000000004	0.73070000000000002	0.59689999999999999	0.50870000000000004	0.4627	0.4163	0.37909999999999999	0.32340000000000002	0.125	0.102	16	99.022003	\N
7932	17732	0	\N	13.804600000000001	9.4939999999999998	0.58099999999999996	26.692	47.164299999999997	37.662799999999997	31.192900000000002	17.136800000000001	13.5794	8.8016000000000005	5.2069000000000001	2.1193	0.8276	0.59289999999999998	0.47660000000000002	0.41789999999999999	0.32979999999999998	0.125	0.35299999	31.5	80.108002	\N
7933	17733	0	\N	7.3235000000000001	3.234	0.46400000000000002	9.234	15.176399999999999	13.42	12.249000000000001	10.785299999999999	9.5938999999999997	7.8417000000000003	6.0949	4.3887	2.8313000000000001	2.0745	1.6204000000000001	1.2835000000000001	0.84919999999999995	0.125	0.02	20	96.179001	\N
7934	17734	0	\N	13.7661	5.6130000000000004	0.37	19.713999999999999	31.048300000000001	27.870799999999999	25.752500000000001	23.104600000000001	20.456700000000001	12.952199999999999	8.1601999999999997	5.1356999999999999	2.7204000000000002	1.7593000000000001	1.1223000000000001	0.88460000000000005	0.65700000000000003	0.125	0.050000001	31.5	90.852997	\N
7935	17735	0	\N	1.8158000000000001	2.3100000000000001	1.7969999999999999	2.4449999999999998	3.3999999999999999	1.8443000000000001	1.5328999999999999	1.1435999999999999	0.93940000000000001	0.74739999999999995	0.59540000000000004	0.50649999999999995	0.4385	0.40529999999999999	0.37209999999999999	0.34549999999999997	0.30570000000000003	0.125	0.153	20	99.245003	\N
7936	17736	0	\N	0.87980000000000003	1.9079999999999999	1.2649999999999999	2.302	1.6954	1.2906	1.0207999999999999	0.93320000000000003	0.86199999999999999	0.71970000000000001	0.60129999999999995	0.52390000000000003	0.45190000000000002	0.41710000000000003	0.38229999999999997	0.35439999999999999	0.31269999999999998	0.125	0.146	6.2999999999999998	99.503998	\N
7937	17737	0	\N	5.3628999999999998	6.8250000000000002	15.141999999999999	2.903	21.138400000000001	15.5528	11.583299999999999	6.5384000000000002	2.8738000000000001	0.86180000000000001	0.58560000000000001	0.4819	0.42020000000000002	0.38940000000000002	0.35859999999999997	0.33389999999999997	0.2969	0.125	0.37799999	20	88.901001	\N
7938	17738	0	\N	1.4943	2.085	1.5900000000000001	2.1339999999999999	2.1379999999999999	1.4378	1.0463	0.91369999999999996	0.81840000000000002	0.629	0.54690000000000005	0.4743	0.41449999999999998	0.38450000000000001	0.35460000000000003	0.33069999999999999	0.29480000000000001	0.125	0.26800001	20	99.101997	\N
7939	17739	0	\N	1.306	1.9139999999999999	1.3100000000000001	2.2999999999999998	2.5091999999999999	1.7797000000000001	1.5754999999999999	1.3204	1.0651999999999999	0.91269999999999996	0.8125	0.71240000000000003	0.61439999999999995	0.5706	0.52669999999999995	0.48580000000000001	0.39679999999999999	0.125	0.0070000002	10	99.333	\N
7940	17740	0	\N	6.8079000000000001	4.9470000000000001	1.002	10.295999999999999	19.392199999999999	15.074199999999999	13.184900000000001	10.823399999999999	8.6532999999999998	5.1660000000000004	3.044	1.6832	0.96120000000000005	0.83640000000000003	0.71160000000000001	0.61609999999999998	0.50180000000000002	0.125	0.017000001	20	90.723999	\N
7941	17741	0	\N	4.4927999999999999	5.2910000000000004	7.6740000000000004	2.7010000000000001	17.3735	12.2614	7.8772000000000002	3.7157	1.9356	0.9869	0.83660000000000001	0.68630000000000002	0.57630000000000003	0.53339999999999999	0.48649999999999999	0.438	0.36530000000000001	0.125	0.059	20	94.297997	\N
7942	17742	0	\N	2.5512999999999999	3.855	4.9770000000000003	2.6280000000000001	9.0420999999999996	5.0956000000000001	3.1398000000000001	1.8091999999999999	1.2821	0.80289999999999995	0.59250000000000003	0.49270000000000003	0.43030000000000002	0.39910000000000001	0.3679	0.34289999999999998	0.30549999999999999	0.125	0.102	20	99.199997	\N
7943	17743	0	\N	2.4927999999999999	3.4420000000000002	2.2490000000000001	4.0410000000000004	7.1573000000000002	4.6218000000000004	3.6055000000000001	2.7726999999999999	1.9770000000000001	1.3409	0.89539999999999997	0.66990000000000005	0.53210000000000002	0.47770000000000001	0.42909999999999998	0.39019999999999999	0.33179999999999998	0.125	0.192	20	99.336998	\N
7945	17745	0	\N	1.4976	2.552	1.7470000000000001	2.722	3.7482000000000002	2.6331000000000002	1.9649000000000001	1.6688000000000001	1.3728	0.94069999999999998	0.78080000000000005	0.62490000000000001	0.53710000000000002	0.4924	0.44350000000000001	0.40439999999999998	0.34570000000000001	0.125	0.0070000002	10	99.723	\N
7946	17746	0	\N	1.7279	2.9529999999999998	2.6789999999999998	2.6400000000000001	5.0045999999999999	3.3292999999999999	2.4601999999999999	1.7402	1.2896000000000001	0.87429999999999997	0.68899999999999995	0.57740000000000002	0.50019999999999998	0.45789999999999997	0.41570000000000001	0.38190000000000002	0.33119999999999999	0.125	0.052999999	16	99.856003	\N
7947	17747	0	\N	1.4427000000000001	2.1789999999999998	1.651	2.3279999999999998	2.5272999999999999	1.6356999999999999	1.3223	0.98380000000000001	0.89270000000000005	0.71030000000000004	0.58399999999999996	0.50180000000000002	0.436	0.40329999999999999	0.3705	0.34439999999999998	0.30509999999999998	0.125	0.14399999	20	98.917999	\N
7948	17748	0	\N	6.4370000000000003	5.0259999999999998	0.29899999999999999	16.721	15.139699999999999	13.1455	11.816000000000001	10.1541	8.9748000000000001	6.7149999999999999	4.7820999999999998	3.1221999999999999	1.6414	0.97509999999999997	0.63060000000000005	0.52039999999999997	0.40160000000000001	0.125	0.373	20	97.982002	\N
7949	17749	0	\N	1.6371	2.6579999999999999	2.077	2.7210000000000001	4.3472999999999997	2.2885	1.7113	1.242	0.95099999999999996	0.74870000000000003	0.59730000000000005	0.5181	0.43740000000000001	0.39679999999999999	0.35630000000000001	0.32379999999999998	0.27510000000000001	0.125	1.59	10	96.661003	\N
7950	17750	0	\N	1.3408	2.0870000000000002	1.1919999999999999	2.863	2.9821	2.0442999999999998	1.8596999999999999	1.6708000000000001	1.482	1.1044	0.8972	0.75509999999999999	0.61799999999999999	0.56810000000000005	0.5181	0.46939999999999998	0.38579999999999998	0.125	0.015	10	99.926003	\N
7951	17751	0	\N	1.1566000000000001	2.0019999999999998	1.214	2.5409999999999999	2.1440999999999999	1.7843	1.6244000000000001	1.4245000000000001	1.2245999999999999	0.94179999999999997	0.80889999999999995	0.67610000000000003	0.57740000000000002	0.53700000000000003	0.49490000000000001	0.44519999999999998	0.37059999999999998	0.125	0.0099999998	10	99.908997	\N
7952	17752	0	\N	12.9696	6.7880000000000003	0.497	22.559999999999999	34.099200000000003	27.988800000000001	25.235299999999999	21.793399999999998	18.013300000000001	10.552	5.8507999999999996	3.1057000000000001	1.4164000000000001	0.94569999999999999	0.74909999999999999	0.60750000000000004	0.4677	0.125	0.057	31.5	89.100998	\N
7953	17753	0	\N	3.8498000000000001	4.2910000000000004	0.60499999999999998	10.194000000000001	9.5081000000000007	7.7534999999999998	6.5837000000000003	5.6843000000000004	4.9204999999999997	3.5230999999999999	2.3235000000000001	1.2163999999999999	0.64349999999999996	0.54759999999999998	0.4713	0.42099999999999999	0.34560000000000002	0.125	0.16599999	20	99.605003	\N
7954	17754	0	\N	2.6816	2.7970000000000002	0.92000000000000004	4.7229999999999999	5.9744999999999999	4.7584	3.9794	3.5792999999999999	3.1791999999999998	2.3788999999999998	1.7734000000000001	1.343	0.94910000000000005	0.82389999999999997	0.69869999999999999	0.60809999999999997	0.50360000000000005	0.125	0.148	10	97.583	\N
7955	17755	0	\N	2.1288	2.492	0.997	3.7360000000000002	4.6292999999999997	3.7160000000000002	3.3948	2.9931999999999999	2.5916000000000001	1.8944000000000001	1.4933000000000001	1.0923	0.8548	0.76049999999999995	0.66620000000000001	0.59840000000000004	0.5071	0.125	0.0060000001	10	99.616997	\N
7956	17756	0	\N	1.6735	2.419	1.7769999999999999	2.944	3.8008000000000002	2.9864999999999999	2.4436	1.9198999999999999	1.6884999999999999	1.2259	0.92610000000000003	0.78180000000000005	0.63749999999999996	0.59030000000000005	0.54590000000000005	0.51039999999999996	0.4163	0.125	0.208	10	99.391998	\N
7957	17757	0	\N	49.749699999999997	2.121	0.55300000000000005	42.945	87.403700000000001	79.8459	74.807299999999998	68.509200000000007	62.623800000000003	56.618400000000001	50.612900000000003	44.607399999999998	38.601900000000001	35.599200000000003	32.596499999999999	17.7529	1.3184	0.125	0.0099999998	63	70.625999	\N
7958	17758	0	\N	0.72970000000000002	1.847	1.079	2.5129999999999999	0.998	0.84130000000000005	0.73680000000000001	0.62209999999999999	0.57850000000000001	0.49440000000000001	0.43840000000000001	0.38229999999999997	0.32619999999999999	0.29809999999999998	0.27010000000000001	0.24660000000000001	0.19670000000000001	0.125	1.364	10	99.391998	\N
7959	17759	0	\N	2.5059	2.2930000000000001	1.123	3.0049999999999999	5.3852000000000002	3.9477000000000002	3.5964999999999998	3.1576	2.7187000000000001	1.9423999999999999	1.6245000000000001	1.3066	0.99380000000000002	0.90700000000000003	0.82010000000000005	0.75070000000000003	0.64649999999999996	0.125	0.0089999996	20	99.570999	\N
7960	17760	0	\N	4.2865000000000002	2.6909999999999998	0.72999999999999998	5.2709999999999999	9.1397999999999993	7.8146000000000004	6.9310999999999998	6.0529000000000002	5.4763999999999999	4.3234000000000004	3.3984000000000001	2.5623	1.8254999999999999	1.5590999999999999	1.2927	1.0794999999999999	0.82020000000000004	0.125	0.0070000002	10	93.893997	\N
7961	17761	0	\N	3.1124000000000001	2.5089999999999999	0.95899999999999996	4.0640000000000001	6.4321000000000002	5.3459000000000003	4.6836000000000002	3.9386000000000001	3.5859999999999999	2.8807999999999998	2.1757	1.7000999999999999	1.3007	1.101	0.94230000000000003	0.84889999999999999	0.70889999999999997	0.125	0.0080000004	10	96.421997	\N
7962	17762	0	\N	8.1994000000000007	4.4619999999999997	0.64600000000000002	11.050000000000001	18.354600000000001	15.0373	13.370699999999999	11.2875	9.4582999999999995	6.6219999999999999	4.1929999999999996	2.3892000000000002	1.3833	0.99560000000000004	0.86199999999999999	0.75519999999999998	0.59930000000000005	0.125	0.027000001	31.5	95.209	\N
7966	17766	0	\N	2.2667000000000002	2.984	1.536	4.29	5.6425000000000001	4.1200000000000001	3.5737999999999999	2.9698000000000002	2.3656999999999999	1.6361000000000001	1.1143000000000001	0.84150000000000003	0.63859999999999995	0.57509999999999994	0.5151	0.46279999999999999	0.38140000000000002	0.125	0.023	10	97.267998	\N
7967	17767	0	\N	3.1711	3.3599999999999999	0.79200000000000004	6.391	7.5652999999999997	5.2843	4.3179999999999996	3.6966999999999999	3.2850000000000001	2.4617	1.7670999999999999	1.2367999999999999	0.78010000000000002	0.6099	0.52780000000000005	0.46810000000000002	0.38519999999999999	0.125	0.012	20	99.008003	\N
7968	17768	0	\N	4.9233000000000002	2.1880000000000002	0.95199999999999996	3.3999999999999999	9.8840000000000003	8.2302999999999997	7.1279000000000003	6.1143000000000001	5.6492000000000004	4.7188999999999997	3.8542999999999998	3.2128999999999999	2.5716000000000001	2.2509000000000001	1.9399	1.7190000000000001	1.3876999999999999	0.125	0.028000001	16	98.265999	\N
7969	17769	0	\N	2.9491000000000001	3.0379999999999998	1.2689999999999999	4.2939999999999996	7.1832000000000003	5.2785000000000002	4.3589000000000002	3.6263999999999998	3.0832000000000002	1.9986999999999999	1.5423	1.0859000000000001	0.83799999999999997	0.73819999999999997	0.63839999999999997	0.57199999999999995	0.46539999999999998	0.125	0.0049999999	20	99.603996	\N
7973	17773	0	\N	3.4973000000000001	3.0659999999999998	0.995	5.6459999999999999	8.5579000000000001	5.7941000000000003	4.9287000000000001	3.9390000000000001	3.5083000000000002	2.6467999999999998	1.8946000000000001	1.4717	1.0488	0.88439999999999996	0.73409999999999997	0.61639999999999995	0.46879999999999999	0.125	0.015	20	98.523003	\N
7971	17771	0	\N	3.367	2.5169999999999999	0.73099999999999998	5.2140000000000004	6.2488000000000001	5.0880999999999998	4.3143000000000002	3.8052999999999999	3.5169999999999999	2.9403000000000001	2.3635000000000002	1.8402000000000001	1.4077999999999999	1.1917	0.97550000000000003	0.80279999999999996	0.56399999999999995	0.125	0.0060000001	20	98.438004	\N
7972	17772	0	\N	2.0720000000000001	2.6469999999999998	1.107	4.1379999999999999	4.4970999999999997	3.5922999999999998	3.2189999999999999	2.7524000000000002	2.2858000000000001	1.7090000000000001	1.2894000000000001	0.93820000000000003	0.73880000000000001	0.6391	0.5675	0.51259999999999994	0.41299999999999998	0.125	0.0049999999	16	99.613998	\N
7974	17774	0	\N	2.1536	2.5430000000000001	1.0600000000000001	3.847	4.7119	3.6714000000000002	3.2873000000000001	2.8071999999999999	2.3271000000000002	1.7625	1.4023000000000001	1.0421	0.82889999999999997	0.73209999999999997	0.63519999999999999	0.56779999999999997	0.4582	0.125	0.018999999	16	99.578003	\N
7975	17775	0	\N	6.0461999999999998	2.6110000000000002	0.746	5.4480000000000004	13.8466	10.7752	9.4867000000000008	8.4542999999999999	7.4218000000000002	5.8224	4.7766000000000002	3.7624	2.8389000000000002	2.3771	1.9218	1.5806	1.0687	0.125	0.034000002	16	94.207001	\N
7977	17777	0	\N	2.7938000000000001	3.6160000000000001	0.61399999999999999	7.827	6.5923999999999996	5.4404000000000003	4.7876000000000003	3.9855	3.5682	2.7336	1.9204000000000001	1.2623	0.70020000000000004	0.53800000000000003	0.46079999999999999	0.41620000000000001	0.34920000000000001	0.125	0.021	10	98.532997	\N
7978	17778	0	\N	2.0367999999999999	2.8069999999999999	1.4390000000000001	4.0540000000000003	4.9423000000000004	3.6597	3.1905000000000001	2.6038999999999999	2.0173999999999999	1.5468	1.0868	0.84630000000000005	0.65690000000000004	0.58350000000000002	0.51870000000000005	0.46460000000000001	0.38159999999999999	0.125	0.0080000004	10	98.471001	\N
7489	17374	1	\N	1.8799999999999999	2.6760000000000002	0.89200000000000002	4.476	3.9603999999999999	3.4607000000000001	3.1276000000000002	2.7111000000000001	2.2947000000000002	1.7524	1.3691	0.98960000000000004	0.70599999999999996	0.60050000000000003	0.53690000000000004	0.48320000000000002	0.39150000000000001	0.063	0.018999999	10	99.884003	\N
7490	17375	1	\N	3.0002	3.0800000000000001	0.92700000000000005	5.4770000000000003	6.9245999999999999	5.2302999999999997	4.375	3.7107999999999999	3.2652999999999999	2.3744000000000001	1.7633000000000001	1.3551	0.95779999999999998	0.79569999999999996	0.63349999999999995	0.55120000000000002	0.4335	0.063	0.016000001	16	99.224998	\N
7491	17376	1	\N	3.4956999999999998	2.7010000000000001	1.1379999999999999	4.6180000000000003	7.9733999999999998	5.8764000000000003	5.2942	4.5663999999999998	3.8969999999999998	2.968	2.0390000000000001	1.6371	1.2583	1.0689	0.91379999999999995	0.8054	0.64280000000000004	0.063	0.017000001	16	98.957001	\N
7492	17377	1	\N	4.0080999999999998	2.6989999999999998	0.79700000000000004	5.1109999999999998	9.1424000000000003	6.3061999999999996	5.7805	5.1288999999999998	4.4774000000000003	3.4632000000000001	2.6160000000000001	1.8783000000000001	1.4325000000000001	1.2095	0.99060000000000004	0.86539999999999995	0.67759999999999998	0.063	0.033	16	98.004997	\N
7493	17378	1	\N	8.3176000000000005	4.9249999999999998	1.325	8.5280000000000005	24.692	19.273499999999999	15.7475	12.382099999999999	9.1792999999999996	5.2465999999999999	3.3995000000000002	1.9921	1.4219999999999999	1.137	0.91910000000000003	0.79449999999999998	0.61519999999999997	0.063	0.011	31.5	97.539001	\N
7494	17379	1	\N	4.8654000000000002	5.1200000000000001	1.5289999999999999	8.9600000000000009	15.994400000000001	9.7408999999999999	6.9927999999999999	5.4477000000000002	4.3799999999999999	2.7966000000000002	1.5384	0.76749999999999996	0.51619999999999999	0.4607	0.41120000000000001	0.3715	0.31209999999999999	0.063	0.31099999	16	90.004997	\N
7495	17380	1	\N	7.6273999999999997	5.7839999999999998	1.327	9.2629999999999999	24.1234	18.826599999999999	15.343999999999999	11.2341	7.4433999999999996	4.1464999999999996	2.8258999999999999	1.7544	1.0255000000000001	0.82640000000000002	0.63980000000000004	0.56269999999999998	0.4476	0.063	0.021	31.5	98.356003	\N
7496	17381	1	\N	5.3548	4.9459999999999997	3.1000000000000001	5.319	18.679400000000001	12.350300000000001	8.7436000000000007	5.6336000000000004	4.1455000000000002	2.1526000000000001	1.4181999999999999	0.92579999999999996	0.70599999999999996	0.61170000000000002	0.55230000000000001	0.50480000000000003	0.4047	0.063	0.027000001	31.5	99.535004	\N
7497	17382	1	\N	4.2432999999999996	3.0099999999999998	1.405	3.722	9.5556999999999999	5.3494000000000002	4.0602999999999998	3.4556	2.8900999999999999	1.9120999999999999	1.4994000000000001	1.0867	0.84450000000000003	0.746	0.64759999999999995	0.59030000000000005	0.51370000000000005	0.063	0.011	31.5	97.960999	\N
7498	17383	1	\N	9.3760999999999992	6.2370000000000001	1.0309999999999999	12.502000000000001	26.539999999999999	22.7775	20.269200000000001	17.133800000000001	13.501200000000001	6.0373999999999999	3.5969000000000002	1.9619	1.1983999999999999	0.89739999999999998	0.68379999999999996	0.58560000000000001	0.4829	0.063	0.012	31.5	97.910004	\N
7499	17384	1	\N	1.0851999999999999	1.7250000000000001	1.2909999999999999	2.1110000000000002	1.8113999999999999	1.4742	1.2495000000000001	0.99460000000000004	0.94610000000000005	0.84919999999999995	0.75219999999999998	0.65529999999999999	0.58450000000000002	0.55369999999999997	0.52290000000000003	0.49559999999999998	0.4022	0.063	0.023	10	99.569	\N
7500	17385	1	\N	1.9711000000000001	2.2490000000000001	1.7629999999999999	2.4660000000000002	4.1086999999999998	2.8620000000000001	2.0706000000000002	1.8225	1.6314	1.2493000000000001	0.95840000000000003	0.83879999999999999	0.71919999999999995	0.65939999999999999	0.60499999999999998	0.56569999999999998	0.50670000000000004	0.063	0.017999999	16	98.935997	\N
7501	17386	1	\N	2.3260999999999998	2.6930000000000001	0.98999999999999999	4.0359999999999996	5.2903000000000002	4.0237999999999996	3.6446999999999998	3.1878000000000002	2.7309000000000001	1.9168000000000001	1.5014000000000001	1.0861000000000001	0.80620000000000003	0.68389999999999995	0.59899999999999998	0.55459999999999998	0.47499999999999998	0.063	0.018999999	16	99.825996	\N
7502	17387	1	\N	2.4822000000000002	2.9119999999999999	1.76	4.0709999999999997	5.7382999999999997	4.3724999999999996	3.7431000000000001	3.1997	2.6562000000000001	1.7536	1.1315999999999999	0.80920000000000003	0.61209999999999998	0.5776	0.54310000000000003	0.51549999999999996	0.43070000000000003	0.063	0.015	16	99.081001	\N
7503	17388	1	\N	2.3561999999999999	2.6629999999999998	0.91600000000000004	4.2389999999999999	5.1353999999999997	3.9253999999999998	3.5937000000000001	3.1789999999999998	2.7644000000000002	1.9665999999999999	1.54	1.1133999999999999	0.82050000000000001	0.69820000000000004	0.6028	0.55349999999999999	0.46400000000000002	0.063	0.021	16	99.470001	\N
7504	17389	1	\N	2.5556000000000001	2.6160000000000001	1.0249999999999999	3.8479999999999999	5.5822000000000003	4.4584000000000001	3.8643000000000001	3.4270999999999998	2.9897999999999998	2.1154000000000002	1.6834	1.3187	0.97119999999999995	0.85709999999999997	0.74299999999999999	0.65169999999999995	0.54969999999999997	0.063	0.017999999	16	99.834999	\N
7505	17390	1	\N	1.7032	2.2429999999999999	1.611	2.633	3.8256000000000001	2.7363	2.0101	1.8178000000000001	1.6335999999999999	1.2650999999999999	0.96099999999999997	0.82199999999999995	0.68300000000000005	0.62	0.5776	0.54379999999999995	0.48049999999999998	0.063	0.015	16	99.807999	\N
7506	17391	1	\N	2.3298999999999999	2.6659999999999999	2.1619999999999999	3.0390000000000001	5.54	3.7181999999999999	3.0836999999999999	2.2905000000000002	1.8403	1.3364	0.9486	0.79390000000000005	0.63919999999999999	0.59489999999999998	0.55500000000000005	0.52310000000000001	0.43980000000000002	0.063	0.018999999	16	98.987999	\N
\.


--
-- Data for Name: slotrechte; Type: TABLE DATA; Schema: public; Owner: -
--

COPY slotrechte (slotrechteid, messungid, uferabst, tsand, tschweb, fv, vm, tiefe, vsohle, bemerkung, uferablinks) FROM stdin;
8225	2033	10	5.5419999999999998	49.451000000000001	2.5	1.0871	2.2999999999999998	0.84299999	\N	10
8226	2033	29	11.282	90.838999999999999	4.375	1.4584	3	1.104	\N	29
8227	2033	48	40.186	131.23699999999999	4.6399999	1.406	3.2999999999999998	1.072	\N	48
8228	2033	69	28.568000000000001	128.55000000000001	5.6259999	1.4806	3.7999999999999998	1.307	\N	69
8229	2033	89	17.146999999999998	134.221	5.6570001	1.4141999	4	0.92799997	\N	89
8055	2032	14	6.0960000000000001	64.003	2.2490001	1.1243	2	0.88599998	\N	14
8056	2032	25	9.5220000000000002	90.837000000000003	3.027	1.2108001	2.5	0.90399998	\N	25
8057	2032	45	46.567999999999998	164.89699999999999	4.066	1.3552999	3	0.92799997	\N	45
8058	2032	75	32.119	173.559	5.1739998	1.4374	3.6000000000000001	0.935	\N	75
8059	2032	85	17.321999999999999	166.48500000000001	5.2719998	1.3178999	4	0.86000001	\N	85
7613	2030	14	23.774000000000001	331.70100000000002	5.3610001	1.1169	4.7999999999999998	0.75	\N	14
7614	2030	24	40.889000000000003	512.85900000000004	8.5129995	1.6693	5.0999999999999996	1.3	\N	24
7615	2030	44	95.599000000000004	707.81500000000005	10.851	1.9376	5.5999999999999996	1.35	\N	44
7616	2030	54	271.85300000000001	965.40800000000002	12.027	2.0383999	5.9000000000000004	1.55	\N	54
7617	2030	94	82.887	982.97199999999998	13.605	2.0931001	6.5	1.33	\N	94
7608	2029	14	3.5819999999999999	44.966000000000001	2.2	1.0001	2.2000000000000002	0.62	\N	14
7609	2029	35	5.6609999999999996	53.981999999999999	3.115	1.198	2.6000000000000001	0.74000001	\N	35
7610	2029	44	8.6669999999999998	70.420000000000002	3.5020001	1.2507	2.7999999999999998	0.83999997	\N	44
7611	2029	73	11.276999999999999	95.936000000000007	4.6329999	1.3238	3.5	0.77999997	\N	73
7612	2029	84	9.1199999999999992	97.055999999999997	4.473	1.209	3.7000000000000002	0.83999997	\N	84
7603	2028	16	24.091000000000001	226.65899999999999	3.2490001	0.92809999	3.5	0.34999999	\N	16
7604	2028	26	72.945999999999998	541.46500000000003	6.9219999	1.4729	4.7000000000000002	0.91000003	\N	26
7605	2028	52	122.235	908.92600000000004	9.4560003	1.8542	5.0999999999999996	1.24	\N	52
7606	2028	83	218.27000000000001	870.351	11.446	1.8763	6.0999999999999996	1.03	\N	83
7607	2028	93	156.876	798.90999999999997	12.081	1.8032	6.7000000000000002	0.85000002	\N	93
7598	2027	22	1.597	10.148	1.109	0.8527	1.3	0.61000001	\N	22
7599	2027	31	2.3130000000000002	12.957000000000001	1.372	0.91479999	1.5	0.68000001	\N	31
7600	2027	41	3.7519999999999998	16.654	1.725	0.90789998	1.8999999999999999	0.56	\N	41
7601	2027	71	9.0869999999999997	32.115000000000002	2.7349999	1.0519	2.6000000000000001	0.69	\N	71
7602	2027	81	5.1929999999999996	26.878	2.8699999	0.92570001	3.1000000000000001	0.41	\N	81
7597	2026	37	9.4770000000000003	73.266999999999996	5.2090001	1.3708	3.7999999999999998	1.1	\N	37
7592	2025	20	5.5410000000000004	56.738	3.723	1.0063	3.7000000000000002	0.64999998	\N	20
7593	2025	40	9.6449999999999996	90.129000000000005	5.7420001	1.4005001	4.0999999999999996	1	\N	40
7594	2025	59	15.276	121.746	6.9629998	1.5137	4.5999999999999996	1.1	\N	59
7595	2025	80	22.863	157.005	9.3649998	1.8009	5.2000000000000002	0.99000001	\N	80
7596	2025	100	14.047000000000001	126.664	7.5250001	1.2754	5.9000000000000004	0.63999999	\N	100
7589	2024	36	1.8999999999999999	22.68	1.031	0.85939997	1.2	0.68000001	\N	36
7590	2024	56	6.4550000000000001	44.798999999999999	1.748	0.8739	2	0.5	\N	56
7591	2024	76	3.6480000000000001	38.459000000000003	1.711	0.90060002	1.8999999999999999	0.60000002	\N	76
7588	2023	70	2.6040000000000001	25.077999999999999	1.0599999	0.75700003	1.3999999999999999	0.38999999	nur eine Lotrechte; kein Abstand angegeben, daher geschätzt	70
7587	2022	70	2.7919999999999998	32.531999999999996	1.243	0.88819999	1.3999999999999999	0.63999999	nur eine Lotrechte, keine Angabe zum Abstand, daher geschätzt	70
7582	2021	18	5.0060000000000002	32.479999999999997	2.9100001	1.1639	2.5	0.62	\N	18
7583	2021	37	6.6669999999999998	40.606000000000002	3.7920001	1.2641	3	0.63	\N	37
7584	2021	48	12.247	39.468000000000004	4.296	1.3426	3.2000000000000002	0.75	\N	48
7585	2021	78	10.813000000000001	54.706000000000003	5.6409998	1.3759	4.0999999999999996	0.61000001	\N	78
7586	2021	88	11.492000000000001	58.173999999999999	5.421	1.2046	4.5	0.46000001	\N	88
7573	2020	20	8.859	8.859	2.605	1.1325999	2.2999999999999998	0.57999998	\N	20
7574	2020	30	12.393000000000001	12.393000000000001	3.3210001	1.23	2.7000000000000002	0.66000003	\N	30
7575	2020	40	17.239000000000001	17.239000000000001	3.595	1.284	2.7999999999999998	0.83999997	\N	40
7576	2020	50	27.143999999999998	27.143999999999998	3.826	1.1957	3.2000000000000002	0.68000001	\N	50
7577	2020	61	47.863	47.863	4.0510001	1.1574	3.5	0.86000001	\N	61
7578	2020	70	32.604999999999997	32.604999999999997	4.5190001	1.2553	3.6000000000000001	0.72000003	\N	70
7579	2020	81	20.532	20.532	4.8309999	1.2714	3.7999999999999998	0.56	\N	81
7580	2020	90	16.350000000000001	16.350000000000001	4.6630001	1.227	3.7999999999999998	0.63	\N	90
7581	2020	100	6.194	6.194	2.526	0.97140002	2.6000000000000001	0.68000001	\N	100
7564	2019	8	4.5369999999999999	4.5369999999999999	1.693	0.94029999	1.8	0.51999998	\N	8
7565	2019	17	5.4509999999999996	5.4509999999999996	1.784	0.84939998	2.1000000000000001	0.50999999	\N	17
7566	2019	26	8.0779999999999994	8.0779999999999994	2.3280001	1.0121	2.2999999999999998	0.38	\N	26
7567	2019	35	7.9050000000000002	7.9050000000000002	2.451	0.98040003	2.5	0.60000002	\N	35
7568	2019	44	10.327	10.327	2.753	1.0587	2.6000000000000001	0.74000001	\N	44
7569	2019	53	21.943999999999999	21.943999999999999	3.135	1.1197	2.7999999999999998	0.67000002	\N	53
7570	2019	63	25.292999999999999	25.292999999999999	3.6500001	1.1774	3.1000000000000001	0.63999999	\N	63
7571	2019	71	18.260999999999999	18.260999999999999	3.5309999	1.0700001	3.2999999999999998	0.66000003	\N	71
7572	2019	80	13.880000000000001	13.880000000000001	4.1020002	1.1719	3.5	0.69999999	\N	80
6653	2016	17	4.4900000000000002	31.384	1.035	0.86229998	1.2	0.63999999	\N	17
6654	2016	31	7.4240000000000004	50.978999999999999	1.5039999	0.94029999	1.6000000000000001	0.74000001	\N	31
6655	2016	41	8.8290000000000006	53.438000000000002	1.724	0.90740001	1.8999999999999999	0.52999997	\N	41
6656	2016	71	14.808	88.829999999999998	2.7679999	1.0647	2.6000000000000001	0.70999998	\N	71
6657	2016	81	15.327999999999999	81.581000000000003	2.4549999	0.87690002	2.7999999999999998	0.49000001	\N	81
6648	2014	17	1.835	16.800999999999998	0.91299999	0.91250002	1	0.75	\N	17
6649	2014	27	3.0760000000000001	19.524999999999999	1.256	0.89679998	1.3999999999999999	0.62	\N	27
6650	2014	37	3.9140000000000001	29.818000000000001	1.442	0.84799999	1.7	0.62	\N	37
6651	2014	58	8.3109999999999999	42.816000000000003	2.2160001	1.0073	2.2000000000000002	0.81	\N	58
6652	2014	77	7.173	46.301000000000002	2.8310001	1.0111001	2.7999999999999998	0.54000002	\N	77
6638	2012	19	3.0990000000000002	27.405999999999999	0.89600003	0.89639997	1	0.75	\N	19
6639	2012	39	6.25	79.400999999999996	1.563	0.97670001	1.6000000000000001	0.80000001	\N	39
6640	2012	58	11.247999999999999	100.57899999999999	2.391	1.0869	2.2000000000000002	0.75999999	\N	58
6641	2012	69	10.128	114.062	2.71	1.1781	2.2999999999999998	0.93000001	\N	69
6642	2012	79	7.4139999999999997	91.643000000000001	2.688	1.034	2.6000000000000001	0.63	\N	79
6663	2018	19	3.6509999999999998	37.145000000000003	1.373	0.9156	1.5	0.69	\N	19
6664	2018	33	5.2220000000000004	53.524000000000001	1.9220001	1.0118001	1.8999999999999999	0.62	\N	33
6665	2018	43	7.4429999999999996	58.530999999999999	2.217	1.0077	2.2000000000000002	0.74000001	\N	43
6666	2018	73	10.781000000000001	89.477999999999994	3.3280001	1.1476001	2.8999999999999999	0.77999997	\N	73
6667	2018	83	10.871	102.313	3.28	1.0579	3.1000000000000001	0.52999997	\N	83
6643	2013	21	13.98	88.664000000000001	3.7939999	1.3312	2.8500000000000001	0.98000002	\N	21
6644	2013	41	20.280000000000001	129.78399999999999	5.2189999	1.4701	3.5499999999999998	0.95999998	\N	41
6645	2013	51	52.042999999999999	176.97399999999999	5.6560001	1.4318	3.9500000000000002	0.85000002	\N	51
6646	2013	81	24.675999999999998	197.15100000000001	6.698	1.4721	4.5499999999999998	0.81	\N	81
6647	2013	91	29.489000000000001	235.62899999999999	6.8280001	1.4078	4.8499999999999996	0.69999999	v=0,7 wurde aus Diagramm geschätzt, da kein Messwert vorliegend	91
6632	2011	10	5.827	45.334000000000003	1.9680001	0.72899997	2.7000000000000002	0.2	\N	10
6633	2011	20	12.246	67.441000000000003	3.573	1.2321	2.8999999999999999	1	\N	20
6634	2011	39	26.187000000000001	122.81	4.9369998	1.4521	3.3999999999999999	0.89999998	\N	39
6635	2011	50	40.768000000000001	128.541	5.473	1.5202	3.6000000000000001	1.1	\N	50
6636	2011	81	16.710999999999999	133.24299999999999	6.8709998	1.5616	4.4000000000000004	1.2	\N	81
6637	2011	90	11.757999999999999	127.941	6.158	1.4663	4.2000000000000002	1	\N	90
6628	2010	11	8.8079999999999998	41.356999999999999	3.3299999	1.1101	3	0.67000002	\N	11
6629	2010	21	10.419	102.31	4.039	1.3693	2.9500000000000002	0.99000001	\N	21
6630	2010	51	31.509	193.05799999999999	5.5320001	1.5154999	3.6499999999999999	0.99000001	\N	51
6631	2010	91	15.036	127.446	5.8390002	1.1677999	5	0.69999999	\N	91
6658	2017	9	6.6189999999999998	69.343000000000004	3.29	0.99690002	3.2999999999999998	0.61000001	\N	9
6659	2017	38	11.465	65.340000000000003	3.2	1.3333	2.3999999999999999	0.91000003	\N	38
6660	2017	49	60.201999999999998	166.94900000000001	5.0570002	1.4046	3.6000000000000001	0.87	\N	49
6661	2017	78	18.032	147.643	6.2789998	1.336	4.7000000000000002	0.51999998	\N	78
6662	2017	89	16.181000000000001	132.25299999999999	6.046	1.1627001	5.2000000000000002	0.44	\N	89
6623	2009	12	4.6920000000000002	40.914000000000001	1.5039999	1.0024	1.5	0.81	\N	12
6624	2009	22	6.7080000000000002	53.704000000000001	1.9630001	1.0903	1.8	0.93000001	\N	22
6625	2009	42	14.536	81.524000000000001	2.517	1.1442	2.2000000000000002	0.88	\N	42
6626	2009	72	19.585000000000001	108.051	3.615	1.1477	3.1499999999999999	0.81999999	\N	72
6627	2009	82	17.254999999999999	117.09399999999999	3.608	1.1638	3.1000000000000001	0.56999999	\N	82
6618	2008	10	14.090999999999999	155.98500000000001	2.9660001	1.0228	2.8999999999999999	0.60000002	\N	10
6619	2008	40	31.68	274.03100000000001	5.4190001	1.4645	3.7000000000000002	0.87	\N	40
6620	2008	50	59.651000000000003	367.31200000000001	5.77	1.4794	3.8999999999999999	1.0700001	\N	50
6621	2008	80	45.555999999999997	364.93400000000003	7.2909999	1.5512	4.7000000000000002	1.11	\N	80
6622	2008	90	29.513999999999999	360.36599999999999	6.2740002	1.426	4.4000000000000004	0.85000002	\N	90
6614	2007	24	21.096	148.029	4.6389999	1.3644	3.3999999999999999	0.74000001	\N	24
6615	2007	44	40.896000000000001	248.03899999999999	4.9510002	1.3753999	3.6000000000000001	0.47999999	\N	44
6616	2007	62	103.172	378.94999999999999	6.3590002	1.5898	4	0.79000002	\N	62
6617	2007	92	25.652999999999999	325.18799999999999	5.7059999	1.1411999	5	0.62	\N	92
6609	2006	13	26.591000000000001	462.32299999999998	5.8169999	1.3849	4.2000000000000002	0.99000001	\N	13
6610	2006	33	51.509	541.577	8.1730003	1.7768	4.5999999999999996	1.12	\N	33
6611	2006	53	181.24199999999999	784.38699999999994	9.4759998	1.8223	5.2000000000000002	0.93000001	\N	53
6612	2006	73	144.042	1030.4580000000001	9.7200003	1.7356	5.5999999999999996	0.76999998	\N	73
6613	2006	93	61.503999999999998	795.91999999999996	9.9790001	1.5591	6.4000000000000004	0.68000001	\N	93
6603	2005	9	8.6099999999999994	64.233999999999995	2.2179999	0.9436	2.3500000000000001	0.56999999	\N	9
6604	2005	19	13.664999999999999	104.125	3.437	1.1648999	2.9500000000000002	0.64999998	\N	19
6605	2005	39	23.611000000000001	144.08199999999999	4.4640002	1.3325	3.3500000000000001	0.85000002	\N	39
6606	2005	49	49.564999999999998	177.98699999999999	5.152	1.4116	3.6499999999999999	0.81	\N	49
6607	2005	78	43.396999999999998	222.179	6.3579998	1.4617	4.3499999999999996	0.97000003	\N	78
6608	2005	89	30.875	185.67699999999999	6.1440001	1.3214	4.6500000000000004	0.80000001	\N	89
6599	2003	23	3.113	25.393000000000001	1.743	0.99629998	1.75	0.69	\N	23
6600	2003	43	6.5449999999999999	38.805	2.7320001	1.0714	2.5499999999999998	0.67000002	\N	43
6601	2003	63	14.766999999999999	66.555999999999997	3.4949999	1.1848	2.9500000000000002	0.69	\N	63
6602	2003	84	8.7200000000000006	65.769999999999996	3.404	0.93260002	3.6499999999999999	0.07	\N	84
6594	2002	20	3.726	45.639000000000003	1.263	0.9357	1.3500000000000001	0.64999998	\N	20
6595	2002	30	4.4009999999999998	45.652000000000001	1.285	0.9522	1.3500000000000001	0.64999998	\N	30
6596	2002	40	10.382999999999999	71.686999999999998	2.0309999	0.99070001	2.0499999999999998	0.55000001	\N	40
6597	2002	70	12.576000000000001	82.457999999999998	2.9549999	1.0944	2.7000000000000002	0.57999998	\N	70
6598	2002	80	8.7110000000000003	86.852000000000004	2.776	1.0282	2.7000000000000002	0.5	\N	80
6590	2001	13	7.7779999999999996	78.555999999999997	1.5140001	0.91769999	1.6499999999999999	0.64999998	\N	13
6591	2001	33	13.273	128.99600000000001	2.0350001	1.0437	1.95	0.81999999	\N	33
6592	2001	53	20.908999999999999	183.73500000000001	2.852	1.1184	2.5499999999999998	0.91000003	\N	53
6593	2001	82	19.510000000000002	168.68899999999999	3.404	1.0807	3.1499999999999999	0.70999998	\N	82
6585	2000	23	41.445	458.31	7.2090001	1.5337	4.7000000000000002	0.92000002	\N	23
6586	2000	43	63.704999999999998	624.88699999999994	9.0179996	1.8037	5	1.12	\N	43
6587	2000	53	175.559	792.97199999999998	9.3210001	1.7261	5.4000000000000004	0.75	\N	53
6588	2000	82	65.653999999999996	567.14999999999998	10.14	1.6623	6.0999999999999996	0.74000001	\N	82
6589	2000	92	58.054000000000002	617.40700000000004	9.6239996	1.604	6	0.83999997	\N	92
6580	1999	13	8.7910000000000004	185.233	3.141	1.1217999	2.7999999999999998	0.70999998	\N	13
6581	1999	33	8.9559999999999995	137.233	4.2010002	1.3128	3.2000000000000002	0.80000001	\N	33
6582	1999	53	32.555	161.65600000000001	4.9720001	1.3439	3.7000000000000002	0.69999999	\N	53
6583	1999	68	27.728999999999999	165.84	6.0159998	1.4324	4.2000000000000002	0.98000002	\N	68
6584	1999	88	13.875999999999999	170.667	6.5019999	1.4135	4.5999999999999996	1	\N	88
12200	8965	14	7.7430000000000003	62.398000000000003	3.1059999	0.88739997	3.5	0.043000001	\N	52
12199	8965	28	13.58	117.124	6.125	1.3611	4.5	0.62099999	\N	66
12198	8965	42	95.191000000000003	226.16499999999999	7.6409998	1.3644	5.5999999999999996	0.96899998	\N	80
12197	8965	56	96.941000000000003	205.25800000000001	6.2940001	1.1876	5.2999999999999998	0.63999999	\N	94
12196	8965	70	14.470000000000001	101.02	4.7080002	1.0017	4.7000000000000002	0.76499999	\N	108
11167	7783	7	1.5740000000000001	17.629000000000001	1.104	0.73610002	1.5	0.38100001	\N	57
11166	7783	18	4.5049999999999999	40.847999999999999	3.145	1.0144	3.1000000000000001	0.58700001	\N	68
11165	7783	33	16.899000000000001	72.674000000000007	4.8639998	1.2471	3.8999999999999999	0.88599998	\N	83
11164	7783	47	22.754000000000001	74.486000000000004	4.5960002	1.2096	3.7999999999999998	0.83600003	\N	97
11163	7783	61	5.8120000000000003	51.359000000000002	4.257	1.2519	3.3999999999999999	1.007	\N	111
11172	7781	12	4.2880000000000003	42.725999999999999	2.3829999	0.85110003	2.7999999999999998	0.45300001	\N	62
11171	7781	27	13.789999999999999	68.614999999999995	5.8579998	1.3313	4.4000000000000004	0.78500003	\N	77
11170	7781	41	31.033999999999999	165.95099999999999	8.0380001	1.5167	5.2999999999999998	1.16	\N	91
11169	7781	57	30.085000000000001	172.95400000000001	7.5890002	1.4318	5.2999999999999998	1.029	\N	107
11168	7781	72	15.787000000000001	142.584	6.2179999	1.3817	4.5	1.01	\N	122
11177	7264	10	0.96799999999999997	10.247	1.071	0.76499999	1.3999999999999999	0.64200002	\N	60
11176	7264	22	3.4390000000000001	26.425999999999998	2.7650001	0.98760003	2.7999999999999998	0.458	\N	72
11175	7264	32	16.777999999999999	50.594000000000001	4.1069999	1.1099	3.7000000000000002	0.86500001	\N	82
11174	7264	45	38.459000000000003	69.248000000000005	3.9100001	1.1171	3.5	0.778	\N	95
11173	7264	57	6.6390000000000002	43.591000000000001	4.4949999	1.0963	4.0999999999999996	0.85500002	\N	107
11162	6823	10	0.39900000000000002	4.9109999999999996	0.72399998	0.48280001	1.5	0.412	\N	50
11161	6823	19	1.8069999999999999	18.968	2.2539999	0.75139999	3	0.34999999	\N	59
11160	6823	32	5.4050000000000002	23.472999999999999	3.313	1.1044	3	0.903	\N	72
11159	6823	43	4.3460000000000001	19.225000000000001	2.8900001	1.0321	2.7999999999999998	0.76099998	\N	83
11158	6823	55	1.6000000000000001	15.823	2.6889999	0.9605	2.7999999999999998	0.76599997	\N	95
10950	8381	15	5.0750000000000002	44.631999999999998	2.2260001	0.89029998	2.5	0.70700002	\N	55
10949	8381	30	14.26	116.983	5.671	1.3189	4.2999999999999998	0.79400003	\N	70
10948	8381	44	32.658000000000001	187.92599999999999	8.0690002	1.4671	5.5	1.16	\N	84
10947	8381	59	35.871000000000002	187.72399999999999	7.2360001	1.4471	5	1.049	\N	99
10946	8381	75	40.228000000000002	155.04300000000001	6.2989998	1.3694	4.5999999999999996	1.066	\N	115
10952	6802	114	605.17600000000004	2263.0720000000001	14.191	1.8430001	7.7000000000000002	1.298	\N	114
10951	6802	137	125.39700000000001	756.65800000000002	5.5929999	0.82249999	6.7999999999999998	0.41499999	\N	137
8420	1961	69	1.389	6.4210000000000003	0.491	0.35069999	1.3999999999999999	0.33000001	\N	69
8421	1961	78	7.3099999999999996	28.561	1.6160001	0.62150002	2.6000000000000001	0.54000002	\N	78
8422	1961	89	27.108000000000001	61.253	2.4590001	0.94569999	2.6000000000000001	0.74000001	\N	89
8423	1961	98	13.802	44.628	2.141	0.85640001	2.5	0.44999999	\N	98
8424	1961	108	3.6949999999999998	29.951000000000001	1.904	0.79350001	2.3999999999999999	0.56	\N	108
10665	6761	13	2.6920000000000002	21.834	1.178	0.84140003	1.3999999999999999	0.69999999	\N	53
10664	6761	22	13.586	95.376000000000005	4.467	1.2762001	3.5	0.77999997	\N	62
10663	6761	32	69.021000000000001	152.59999999999999	4.0770001	1.1324	3.6000000000000001	1.03	\N	72
10662	6761	46	23.396000000000001	86.879999999999995	3.3829999	1.0251	3.2999999999999998	0.72000003	\N	86
10661	6761	58	12.135999999999999	95.260000000000005	3.2579999	1.0511	3.1000000000000001	0.72000003	\N	98
8215	1958	69	12.180999999999999	123.249	3.961	1.2002	3.2999999999999998	0.79000002	\N	69
8216	1958	83	31.300999999999998	282.12400000000002	8.9219999	1.5382	5.7999999999999998	0.81999999	\N	83
8217	1958	105	187.91300000000001	483.07400000000001	8.2580004	1.5014	5.5	1.14	\N	105
8218	1958	122	69.748000000000005	366.435	8.1569996	1.5994	5.0999999999999996	1.4400001	\N	122
8219	1958	140	15.459	133.99000000000001	3.204	0.7281	4.4000000000000004	0.51999998	\N	140
8065	1957	59	5.9850000000000003	74.129999999999995	2.45	1.1138	2.2000000000000002	0.63999999	\N	59
8066	1957	71	9.9640000000000004	133.648	4.1550002	1.2221	3.3999999999999999	0.71200001	\N	71
8067	1957	86	59.780000000000001	271.53500000000003	6.9359999	1.4758	4.7000000000000002	0.97000003	\N	86
8068	1957	103	55.851999999999997	246.81800000000001	6.5229998	1.4495	4.5	1.0700001	\N	103
8069	1957	117	23.398	177.887	5.4559999	1.3638999	4	1.147	\N	117
6845	1954	61	2.02	19.026	1.897	1.0536	1.8	0.95200002	\N	61
6846	1954	79	6.7830000000000004	67.906999999999996	6.0570002	1.4085	4.2999999999999998	1.0599999	\N	79
6847	1954	99	11.252000000000001	107.182	10.717	1.6746	6.4000000000000004	1.14	\N	99
6848	1954	119	52.704999999999998	169.63300000000001	9.7299995	1.6776	5.7999999999999998	1.29	\N	119
6849	1954	139	8.2449999999999992	82.138999999999996	6.0320001	1.1827	5.0999999999999996	0.56999999	\N	139
6841	1952	86	11.864000000000001	108.687	5.5139999	1.3128999	4.2000000000000002	0.85000002	\N	86
6842	1952	99	33.170000000000002	159.85499999999999	7.4850001	1.5594	4.7999999999999998	1.1900001	\N	99
6843	1952	115	52.128999999999998	149.40199999999999	6.0560002	1.4083	4.2999999999999998	1.0700001	\N	115
6844	1952	130	10.816000000000001	74.853999999999999	3.8469999	1.0993	3.5	0.94	\N	130
6836	1951	53	48.999000000000002	140.36799999999999	5.7579999	1.3085999	4.4000000000000004	0.46000001	\N	53
6837	1951	72	95.031000000000006	630.75999999999999	10.576	1.7058001	6.2000000000000002	0.94999999	\N	72
6838	1951	92	170.113	949.59699999999998	14.482	1.8331	7.9000000000000004	0.88	\N	92
6839	1951	112	219.47800000000001	906.39499999999998	11.903	1.7505	6.7999999999999998	1.03	\N	112
6840	1951	132	59.448999999999998	365.92000000000002	5.6199999	0.90640002	6.2000000000000002	0.56	\N	132
6831	1950	76	1.76	27.227	0.73400003	0.52420002	1.3999999999999999	0.37099999	\N	76
6832	1950	83	5.3689999999999998	85.066999999999993	2.115	0.7834	2.7000000000000002	0.23	\N	83
6833	1950	94	10.6	144.12200000000001	3.4790001	1.0543	3.2999999999999998	0.72000003	\N	94
6834	1950	107	8.0990000000000002	84.878	2.5650001	0.94999999	2.7000000000000002	0.69	\N	107
6835	1950	118	5.8070000000000004	68.605999999999995	1.987	0.86369997	2.2999999999999998	0.60000002	\N	118
6822	1948	71	6.827	51.786000000000001	2.405	1.002	2.3999999999999999	0.69999999	\N	71
6823	1948	86	13.675000000000001	132.68700000000001	5.777	1.313	4.4000000000000004	0.98000002	\N	86
6824	1948	101	24.094999999999999	199.82400000000001	7.875	1.5144	5.2000000000000002	1.17	\N	101
6825	1948	114	16.245000000000001	158.166	6.8779998	1.5286	4.5	1.27	\N	114
6826	1948	131	11.484	115.456	5.198	1.3678	3.7999999999999998	1.17	\N	131
6818	1947	74	2.8660000000000001	14.298999999999999	0.62300003	0.47929999	1.3	0.43000001	\N	74
6819	1947	80	4.282	25.802	1.238	0.72839999	1.7	0.51999998	\N	80
6820	1947	94	15.612	71.105000000000004	3.477	0.93989998	3.7000000000000002	0.75	\N	94
6821	1947	109	15.029	56.304000000000002	2.4719999	0.727	3.3999999999999999	0.56	\N	109
6813	1946	72	3.1150000000000002	3.1150000000000002	0.96799999	0.6451	1.5	0.40000001	\N	72
6814	1946	83	11.074	11.074	3.9579999	1.1309	3.5	0.80000001	\N	83
6815	1946	97	22.134	22.134	5.5970001	1.2165999	4.5999999999999996	0.85000002	\N	97
6816	1946	112	44.564	44.564	4.823	1.0718	4.5	0.75999999	\N	112
6817	1946	127	9.3780000000000001	9.3780000000000001	2.892	0.78149998	3.7000000000000002	0.57999998	\N	127
6850	1955	72	16.937999999999999	127.997	3.549	1.1447999	3.1000000000000001	0.92000002	\N	72
6851	1955	82	22.510999999999999	176.334	5.1290002	1.3498	3.7999999999999998	1	\N	82
6852	1955	102	52.256999999999998	397.74299999999999	11.596	1.6332	7.0999999999999996	0.62	\N	102
6853	1955	122	57.770000000000003	392.42700000000002	11.043	1.6732	6.5999999999999996	1.04	\N	122
6854	1955	142	68.040000000000006	285.803	8.1879997	1.3647	6	1.02	\N	142
6808	1945	80	4.5880000000000001	30.603000000000002	1.5190001	0.82090002	1.8500000000000001	0.50999999	\N	80
6809	1945	90	14.302	93.519000000000005	3.8729999	1.0612	3.6499999999999999	0.76999998	\N	90
6810	1945	100	24.989999999999998	90.789000000000001	3.8559999	1.0283	3.75	0.87	\N	100
6811	1945	110	22.701000000000001	99.073999999999998	3.6110001	0.98940003	3.6499999999999999	0.67000002	\N	110
6812	1945	120	6.851	64.162999999999997	3.0580001	0.9127	3.3500000000000001	0.73000002	\N	120
6803	1944	66	52.896999999999998	525.90800000000002	4.0380001	1.2235	3.2999999999999998	0.81	\N	66
6804	1944	81	106.544	894.351	7.7789998	1.6206	4.7999999999999998	1.24	\N	81
6805	1944	95	194.31200000000001	1239.643	10.355	1.6436	6.2999999999999998	1.24	\N	95
6806	1944	110	201.34800000000001	1275.9200000000001	9.1820002	1.5829999	5.7999999999999998	1.1900001	\N	110
6807	1944	125	174.661	1029.6990000000001	7.8920002	1.4349	5.5	1.15	\N	125
6827	1949	61	1.1080000000000001	6.2690000000000001	2.131	0.85219997	2.5	0.44	\N	61
6828	1949	81	2.1800000000000002	29.978000000000002	6.9489999	1.3899	5	0.83999997	\N	81
6829	1949	101	9.391	31.495999999999999	6.2179999	1.2819999	4.8499999999999996	0.64999998	\N	101
6830	1949	121	2.3279999999999998	8.8089999999999993	3.2780001	0.73650002	4.4500000000000002	0.49000001	\N	121
6799	1943	61	1.7829999999999999	23.353999999999999	0.764	0.7281	1.05	0.56	\N	61
6800	1943	77	8.4019999999999992	129.06100000000001	3.3199999	1.0711	3.1000000000000001	0.73000002	\N	77
6801	1943	98	21.125	249.88499999999999	6.0479999	1.3148	4.5999999999999996	0.97000003	\N	98
6802	1943	123	10.667999999999999	153.31399999999999	4.0359998	1.0907	3.7000000000000002	0.88	\N	123
6795	1942	65	7.6280000000000001	149.50399999999999	3.234	1.0107	3.2000000000000002	0.61000001	\N	65
6796	1942	93	24.091000000000001	387.01600000000002	9.3789997	1.5897	5.9000000000000004	1.17	\N	93
6797	1942	112	33.357999999999997	452.45400000000001	9.8039999	1.6073	6.0999999999999996	1.11	\N	112
6798	1942	137	11.584	185.964	3.9089999	0.71079999	5.5	0.12	\N	137
13162	9659	82	108.626	1202.5360000000001	13.143	1.6226	8.0999999999999996	0.884	\N	72
13161	9659	92	94.418000000000006	1071.768	10.89	1.5556999	7	1.387	\N	82
13160	9659	102	117.729	1431.1659999999999	13.768	1.6998	8.0999999999999996	0.64200002	\N	92
13159	9659	112	115.932	1351.1469999999999	12.836	1.7345001	7.4000000000000004	0.86400002	\N	102
13158	9659	122	106.501	1312.8219999999999	12.839	1.7118	7.5	0.50199997	\N	112
12916	8989	8	3.4460000000000002	22.591000000000001	2.1930001	0.68519998	3.2000000000000002	0.42500001	\N	58
12917	8989	18	10.602	44.578000000000003	3.6440001	0.95889997	3.7999999999999998	0.58899999	\N	68
12918	8989	28	10.884	41.307000000000002	3.4089999	1.0027	3.3999999999999999	0.69599998	\N	78
12919	8989	38	8.8599999999999994	39.426000000000002	3.329	1.0404	3.2000000000000002	0.80400002	\N	88
12920	8989	48	25.684999999999999	47.402999999999999	3.184	0.93650001	3.3999999999999999	0.67900002	\N	98
12205	8987	13	19.457999999999998	155.642	6.454	1.1952	5.4000000000000004	0.87400001	\N	63
12204	8987	26	50.432000000000002	197.77600000000001	6.6009998	1.2695	5.2000000000000002	0.56	\N	76
12203	8987	42	87.390000000000001	242.06299999999999	7.2659998	1.2975	5.5999999999999996	0.991	\N	92
12202	8987	58	89.111000000000004	289.387	7.5780001	1.3530999	5.5999999999999996	0.95899999	\N	108
12201	8987	74	25.132999999999999	121.05800000000001	4.8379998	0.86390001	5.5999999999999996	0.59100002	\N	124
11255	7803	7	3.7250000000000001	39.238999999999997	2.961	0.8003	3.7000000000000002	0.52600002	\N	57
11254	7803	18	7.0570000000000004	56.831000000000003	4.125	1.1148	3.7000000000000002	0.87400001	\N	68
11253	7803	32	24.344999999999999	76.771000000000001	4.2639999	1.1523	3.7000000000000002	0.80400002	\N	82
11252	7803	45	23.132999999999999	83.366	4.197	1.1343	3.7000000000000002	0.86699998	\N	95
11251	7803	58	15.156000000000001	70.730000000000004	4.4710002	1.2085	3.7000000000000002	0.92000002	\N	108
11245	7801	8	9.6370000000000005	111.059	4.3649998	0.99190003	4.4000000000000004	0.65600002	\N	58
11244	7801	23	28.545000000000002	176.559	7.3569999	1.3882	5.2999999999999998	1.01	\N	73
11243	7801	38	63.289999999999999	219.28100000000001	7.348	1.413	5.2000000000000002	1.068	\N	88
11242	7801	53	129.67500000000001	295.411	8.0179996	1.4578	5.5	0.91299999	\N	103
11241	7801	67	80.257000000000005	251.40299999999999	8.0649996	1.4663	5.5	0.91299999	\N	117
11250	7282	8	2.1869999999999998	21.837	2.2190001	0.71569997	3.1000000000000001	0.47	\N	53
11249	7282	20	4.766	24.483000000000001	3.0969999	0.9989	3.1000000000000001	0.75999999	\N	65
11248	7282	32	7.3419999999999996	34.576000000000001	3.0320001	1.0456001	2.8999999999999999	0.84500003	\N	77
11247	7282	45	9.6999999999999993	41.454999999999998	3.0799999	1.0267	3	0.72500002	\N	90
11246	7282	57	9.1270000000000007	46.710000000000001	3.6489999	1.0427001	3.5	0.69499999	\N	102
11465	8581	8	2.0179999999999998	22.093	2.349	0.73400003	3.2000000000000002	0.51599997	\N	58
11464	8581	18	7.3209999999999997	33.948	2.842	0.86129999	3.2999999999999998	0.57499999	\N	68
11463	8581	31	9.6280000000000001	30.236000000000001	2.5899999	0.86330003	3	0.49000001	\N	81
11462	8581	42	15.19	33.073999999999998	2.5339999	0.90509999	2.7999999999999998	0.64999998	\N	92
11461	8581	55	5.4889999999999999	25.370000000000001	2.5899999	0.92500001	2.7999999999999998	0.67799997	\N	105
10940	6742	14	23.788	205.637	4.8579998	1.0337	4.7000000000000002	0.84600002	\N	54
10939	6742	27	33.552	227.357	5.1529999	1.1203001	4.5999999999999996	0.875	\N	67
10938	6742	38	42.002000000000002	229.643	5.0630002	1.1252	4.5	0.829	\N	78
10937	6742	51	48.920999999999999	244.61000000000001	4.777	1.1109999	4.2999999999999998	0.74900001	\N	91
10936	6742	63	59.725999999999999	219.15199999999999	4.8979998	1.1391	4.2999999999999998	0.713	\N	103
7113	2120	79	9.1519999999999992	111.459	2.875	0.87120003	3.2999999999999998	0.31	\N	79
7114	2120	90	7.766	98.516000000000005	2.506	0.83520001	3	0.25999999	\N	90
7115	2120	140	6.3230000000000004	96.998000000000005	2.6960001	0.8987	3	0.52999997	\N	140
7106	2119	25	10.792999999999999	57.600999999999999	2.921	0.85909998	3.3999999999999999	0.60000002	\N	25
7107	2119	35	29.788	151.541	6.961	1.3134	5.2999999999999998	0.81	\N	35
7108	2119	65	37.003	159.74100000000001	7.1300001	1.3981	5.0999999999999996	0.37	\N	65
7109	2119	106	36.494	173.79400000000001	7.4710002	1.4367	5.2000000000000002	1.05	\N	106
7110	2119	146	35.320999999999998	151.70599999999999	6.8530002	1.2931	5.2999999999999998	0.80000001	\N	146
7101	2118	28	7.298	102.53100000000001	3.7219999	0.9077	4.0999999999999996	0.46000001	\N	28
7102	2118	58	17.556000000000001	134.42699999999999	4.8379998	1.1518	4.2000000000000002	0.50999999	\N	58
7103	2118	88	34.271999999999998	173.215	4.5760002	1.1440001	4	0.50999999	\N	88
7104	2118	98	24.414000000000001	158.71199999999999	4.9780002	1.3099999	3.7999999999999998	1	\N	98
7105	2118	138	12.765000000000001	151.99100000000001	4.5879998	1.2744	3.6000000000000001	0.83999997	\N	138
7096	2117	31	5.8399999999999999	31.719000000000001	1.8099999	0.75410002	2.3999999999999999	0.44999999	\N	31
7097	2117	51	8.5619999999999994	39.286000000000001	1.939	0.88129997	2.2000000000000002	0.86000001	\N	51
7098	2117	81	6.8049999999999997	34.823999999999998	1.571	0.78570002	2	0.56	\N	81
7099	2117	92	6.3170000000000002	47.008000000000003	1.712	0.85619998	2	0.75	\N	92
7100	2117	131	5.3140000000000001	33.581000000000003	1.6849999	0.67390001	2.5	0.54000002	\N	131
7094	2115	86	3.6600000000000001	15.673999999999999	1.415	0.7446	1.8999999999999999	0.49000001	\N	86
7095	2115	126	1.5660000000000001	13.935	1.28	0.85329998	1.5	0.77999997	\N	126
7089	2114	25	4.181	48.853000000000002	1.37	0.91339999	1.5	0.69	\N	25
7090	2114	65	4.6189999999999998	60.728999999999999	1.596	0.88669997	1.8	0.76999998	\N	65
7091	2114	75	5.5609999999999999	61.975000000000001	1.753	0.92250001	1.8999999999999999	0.74000001	\N	75
7092	2114	105	5.3799999999999999	50.670000000000002	1.705	0.8973	1.8999999999999999	0.70999998	\N	105
7093	2114	125	3.7650000000000001	54.972999999999999	1.525	0.89719999	1.7	0.79000002	\N	125
7146	2128	19	12.019	113.541	3.451	0.82179999	4.2000000000000002	0.56	\N	19
7147	2128	59	107.503	507.75	5.71	1.1896	4.7999999999999998	0.70999998	\N	59
7148	2128	99	65.986999999999995	352.79000000000002	6.1329999	1.2266999	5	0.86000001	\N	99
7149	2128	129	47.393999999999998	225.86699999999999	6.2290001	1.3252	4.7000000000000002	1	\N	129
7150	2128	139	34.345999999999997	227.54599999999999	6.256	1.331	4.7000000000000002	0.97000003	\N	139
7084	2113	30	3.347	43.642000000000003	2.2550001	0.95969999	2.3500000000000001	0.67000002	\N	30
7085	2113	50	9.2940000000000005	54.082999999999998	2.563	0.96700001	2.6499999999999999	0.73000002	\N	50
7086	2113	60	9.8350000000000009	63.377000000000002	2.513	0.91369998	2.75	0.67000002	\N	60
7087	2113	100	7.0019999999999998	51	2.523	0.9174	2.75	0.69999999	\N	100
7088	2113	140	6.367	50.213000000000001	1.957	0.9321	2.1000000000000001	0.67000002	\N	140
7079	2112	27	6.9459999999999997	75.040000000000006	2.22	0.92500001	2.3999999999999999	0.81	\N	27
7080	2112	50	8.8149999999999995	92.442999999999998	2.8039999	0.96700001	2.8999999999999999	0.74000001	\N	50
7081	2112	93	10.026	97.481999999999999	2.7030001	0.96539998	2.7999999999999998	0.75999999	\N	93
7082	2112	111	8.9499999999999993	96.260999999999996	2.54	0.90719998	2.7999999999999998	0.67000002	\N	111
7083	2112	138	10.262	95.296000000000006	2.375	0.91350001	2.6000000000000001	0.54000002	\N	138
7073	2111	22	10.255000000000001	170.11600000000001	3.227	1.0086	3.2000000000000002	0.85000002	\N	22
7074	2111	43	18.16	197.59200000000001	3.652	1.0434999	3.5	0.77999997	\N	43
7075	2111	63	20.834	213.095	3.9070001	1.0019	3.8999999999999999	0.70999998	\N	63
7076	2111	83	20.475999999999999	246.95699999999999	3.914	1.0301	3.7999999999999998	0.63999999	\N	83
7077	2111	105	15.051	243.25800000000001	3.809	1.0883	3.5	0.92000002	\N	105
7078	2111	124	15.459	223.851	4.277	1.0966001	3.8999999999999999	0.87	\N	124
7070	2110	20	7.6950000000000003	10.212999999999999	2.7620001	0.9206	3	0.69999999	\N	20
7071	2110	79	6.9119999999999999	8.6869999999999994	3.0699999	0.99049997	3.1000000000000001	0.76999998	\N	79
7072	2110	129	3.391	4.5990000000000002	2.174	0.98820001	2.2000000000000002	0.74000001	\N	129
7065	2109	24	6.4459999999999997	69.266000000000005	2.842	0.91670001	3.1000000000000001	0.72000003	\N	24
7066	2109	53	8.5980000000000008	67.543000000000006	3.1960001	0.96850002	3.2999999999999998	0.70999998	\N	53
7067	2109	83	9.2739999999999991	85.198999999999998	3.4319999	0.9806	3.5	0.73000002	\N	83
7068	2109	93	9.8829999999999991	71.238	3.4130001	0.94819999	3.6000000000000001	0.62	\N	93
7069	2109	132	6.4119999999999999	76.305999999999997	3.3989999	0.97119999	3.5	0.69999999	\N	132
7060	2108	16	3.9790000000000001	85.622	2.1340001	0.5927	3.6000000000000001	0.28	\N	16
7061	2108	61	5.6699999999999999	206.679	4.309	1.051	4.0999999999999996	0.83999997	\N	61
7062	2108	88	8.4359999999999999	146.94999999999999	3.6760001	1.0211	3.6000000000000001	0.85000002	\N	88
7063	2108	101	7.0860000000000003	169.91499999999999	3.447	1.0771	3.2000000000000002	0.87	\N	101
7064	2108	139	16.879000000000001	160.88499999999999	3.793	0.9982	3.7999999999999998	0.38	\N	139
7055	2107	18	5.3840000000000003	94.328999999999994	2.6270001	0.74010003	3.5499999999999998	0.34	\N	18
7056	2107	43	19.513999999999999	188.084	4.1059999	1.0396	3.9500000000000002	0.83999997	\N	43
7057	2107	68	26.922000000000001	193.80000000000001	3.9779999	1.0608	3.75	0.70999998	\N	68
7058	2107	105	17.335000000000001	180.06700000000001	3.882	1.0082999	3.8500000000000001	0.47999999	\N	105
7059	2107	130	7.6559999999999997	189.22999999999999	3.8210001	1.0190001	3.75	0.56999999	\N	130
7050	2106	63	2.8719999999999999	39.723999999999997	1.441	0.90069997	1.6000000000000001	0.60000002	\N	63
7051	2106	91	3.9590000000000001	37.424999999999997	1.5599999	0.8211	1.8999999999999999	0.67000002	\N	91
7052	2106	111	5.4969999999999999	43.026000000000003	1.7	0.77289999	2.2000000000000002	0.52999997	\N	111
7053	2106	143	10.032	48.314	1.743	0.75779998	2.2999999999999998	0.37	\N	143
7054	2106	173	3.8559999999999999	31.913	1.431	0.7949	1.8	0.49000001	\N	173
11392	8443	95	2.7519999999999998	55.841000000000001	1.378	0.72539997	1.8999999999999999	0.56	\N	115
11391	8443	115	1.359	29.332000000000001	0.63700002	0.53070003	1.2	0.48699999	\N	135
11315	7161	51	2.8700000000000001	16.477	2.507	0.9641	2.6000000000000001	0.68800002	\N	51
11314	7161	71	1.681	11.775	1.915	0.91189998	2.1000000000000001	0.80199999	\N	71
11313	7161	80	1.7	12.542999999999999	1.794	0.85430002	2.1000000000000001	0.72000003	\N	80
11312	7161	102	1.262	7.7240000000000002	1.104	0.73570001	1.5	0.59100002	\N	102
11311	7161	112	0.80900000000000005	7.7999999999999998	0.94599998	0.7274	1.3	0.66600001	\N	112
11000	8402	40	5.2370000000000001	54.311	6.6939998	1.4242001	4.7000000000000002	1.025	\N	50
10999	8402	59	24.109999999999999	53.776000000000003	4.4759998	1.1191	4	0.81699997	\N	69
10998	8402	80	50.765999999999998	74.216999999999999	3.1600001	1.0533	3	0.97100002	\N	90
10997	8402	99	59.222000000000001	81.239999999999995	2.494	0.80440003	3.1000000000000001	0.60600001	\N	109
10996	8402	120	17.762	31.795000000000002	1.914	0.76539999	2.5	0.59899998	\N	130
10735	7121	48	4.1390000000000002	35.295000000000002	2.1930001	0.91390002	2.3999999999999999	0.75999999	\N	58
10734	7121	68	4.8929999999999998	31.059999999999999	1.777	0.84619999	2.1000000000000001	0.61000001	\N	78
10733	7121	78	4.1950000000000003	30.928999999999998	1.722	0.81980002	2.1000000000000001	0.55000001	\N	88
10732	7121	89	4.3639999999999999	29.777999999999999	1.598	0.84100002	1.8999999999999999	0.68000001	\N	99
10731	7121	108	1.879	16.940999999999999	0.90799999	0.69840002	1.3	0.57999998	\N	118
10725	7101	39	13.949999999999999	156.196	3.4719999	1.085	3.2000000000000002	0.72500002	\N	59
10724	7101	50	43.328000000000003	176.43700000000001	3.1719999	0.9914	3.2000000000000002	0.671	\N	70
10723	7101	59	14.048999999999999	149.75800000000001	2.957	0.954	3.1000000000000001	0.611	\N	79
10722	7101	79	10.917999999999999	114.873	2.1700001	0.90399998	2.3999999999999999	0.68800002	\N	99
10721	7101	99	10.231999999999999	79.519000000000005	1.617	0.85119998	1.8999999999999999	0.68800002	\N	119
10715	7082	38	10.295	76.369	5.0170002	1.2544	4	1.04	\N	58
10714	7082	48	21.420000000000002	93.507999999999996	5.1339998	1.2835	4	0.83999997	\N	68
10713	7082	66	13.847	52.319000000000003	2.9579999	1.0955	2.7000000000000002	0.81999999	\N	86
10712	7082	77	11.664	47.189	2.6259999	1.0504	2.5	0.87	\N	97
10711	7082	108	6.1459999999999999	26.135999999999999	1.643	0.9127	1.8	0.73000002	\N	128
8195	2099	69	4.1289999999999996	76.399000000000001	2.506	0.92830002	2.7000000000000002	0.74000001	\N	69
8196	2099	79	6.6790000000000003	80.066999999999993	2.7320001	1.012	2.7000000000000002	0.75	\N	79
8197	2099	90	5.1159999999999997	51.649000000000001	2.168	0.90350002	2.3999999999999999	0.72000003	\N	90
8198	2099	130	4.3789999999999996	33.975000000000001	1.339	0.78780001	1.7	0.68000001	\N	130
8199	2099	139	1.641	23.116	0.93800002	0.7216	1.3	0.60000002	\N	139
8190	2097	68	17.885999999999999	250.28	8.1260004	1.4775	5.5	1.1900001	\N	68
8191	2097	99	33.460000000000001	200.79300000000001	5.7319999	1.3028001	4.4000000000000004	0.98000002	\N	99
8192	2097	108	32.933999999999997	198.47800000000001	5.3639998	1.2771	4.2000000000000002	1.02	\N	108
8193	2097	137	30.998000000000001	179.887	4.3629999	1.0907	4	0.82999998	\N	137
8194	2097	146	17.254000000000001	132.64400000000001	3.7160001	1.0929	3.3999999999999999	0.80000001	\N	146
8080	2096	38	10.564	161.822	4.9489999	1.2374001	4	0.30000001	\N	38
8081	2096	69	33.482999999999997	220.43700000000001	7.5469999	1.3976001	5.4000000000000004	1.08	\N	69
8082	2096	99	35.256	204.833	5.5209999	1.3145	4.2000000000000002	0.97000003	\N	99
8083	2096	129	28.890999999999998	165.53200000000001	4.3509998	1.145	3.7999999999999998	0.75999999	\N	129
8084	2096	159	6.4260000000000002	72.872	2.1229999	0.60659999	3.5	0.41999999	\N	159
7045	2093	33	4.3470000000000004	95.739999999999995	9.3330002	1.6667	5.5999999999999996	1.08	\N	33
7046	2093	52	26.559000000000001	148.001	13.169	1.7102	7.7000000000000002	0.83999997	\N	52
7047	2093	62	30.16	144.417	11.238	1.6773	6.7000000000000002	1.3200001	\N	62
7048	2093	103	211.71899999999999	339.43700000000001	8.1300001	1.4263	5.7000000000000002	0.14	\N	103
7049	2093	143	277.142	348.97699999999998	5.4029999	1.0806	5	0.37	\N	143
13148	9657	44	63.649999999999999	237.49100000000001	6.2919998	1.1871001	5.2999999999999998	0.40700001	\N	52
13149	9657	64	109.24299999999999	273.36099999999999	6.244	1.2487	5	0.90100002	\N	72
13150	9657	84	184.45400000000001	380.44600000000003	6.573	1.2640001	5.2000000000000002	0.44100001	\N	92
13151	9657	104	156.96700000000001	365.09399999999999	6.592	1.3454	4.9000000000000004	0.87699997	\N	112
13152	9657	124	98.603999999999999	335.60500000000002	6.7459998	1.3492	5	0.954	\N	132
12285	9081	42	0.82899999999999996	5.944	1.411	0.74269998	1.8999999999999999	0.565	\N	66
12284	9081	63	1.579	7.0640000000000001	1.423	0.7906	1.8	0.59100002	\N	87
12283	9081	84	1.651	7.5759999999999996	1.4119999	0.83050001	1.7	0.727	\N	108
12282	9081	105	1.5069999999999999	8.3439999999999994	1.506	0.75279999	2	0.56	\N	129
12281	9081	126	0.97299999999999998	7.702	1.378	0.8107	1.7	0.676	\N	150
12215	9066	19	4.6589999999999998	48.229999999999997	3.0439999	0.89529997	3.3999999999999999	0.442	\N	32
12214	9066	29	14.378	71.991	4.3509998	1.0878	4	0.43200001	\N	42
12213	9066	69	36.326000000000001	94.569999999999993	4.3010001	1.1317	3.7999999999999998	0.84299999	\N	82
12212	9066	79	28.632999999999999	95.769000000000005	4.3200002	1.1677001	3.7000000000000002	0.98100001	\N	92
12211	9066	119	9.9090000000000007	73.373999999999995	4.4070001	1.1016999	4	0.727	\N	132
11050	8023	32	9	68.119	3.184	0.90960002	3.5	0.62300003	\N	42
11049	8023	55	31.917000000000002	119.175	4.7589998	1.1332	4.2000000000000002	0.741	\N	65
11048	8023	81	30.707999999999998	116.663	4.3210001	1.1079	3.8999999999999999	0.85000002	\N	91
11047	8023	106	31.245000000000001	119.212	4.5110002	1.1279	4	0.787	\N	116
11046	8023	132	16.93	103.97499999999999	4.5500002	1.1973	3.7999999999999998	0.89899999	\N	142
11045	8021	30	3.1379999999999999	33.268999999999998	2.573	0.85759997	3	0.54100001	\N	40
11044	8021	56	9.5139999999999993	60.302999999999997	4.0019999	1.1118	3.6000000000000001	0.89300001	\N	66
11043	8021	81	16.782	68.215000000000003	4.151	1.1217999	3.7000000000000002	0.80400002	\N	91
11042	8021	106	16.602	79.534999999999997	4.4689999	1.1172	4	0.787	\N	116
11041	8021	131	11.279999999999999	74.201999999999998	4.2670002	1.1853	3.6000000000000001	0.78500003	\N	141
11055	7311	48	3	21.369	2.1329999	0.88859999	2.3999999999999999	0.61500001	\N	48
11054	7311	65	3.4129999999999998	20.454999999999998	2.0899999	0.8707	2.3999999999999999	0.55699998	\N	65
11053	7311	85	4.468	23.039999999999999	2.0669999	0.8987	2.2999999999999998	0.65200001	\N	85
11052	7311	105	2.4390000000000001	20.873999999999999	1.933	0.92040002	2.1000000000000001	0.71899998	\N	105
11051	7311	126	2.706	18.048999999999999	1.887	0.89859998	2.1000000000000001	0.66399997	\N	126
11065	7421	45	3.3620000000000001	38.805999999999997	2.1689999	0.90380001	2.3999999999999999	0.667	\N	45
11064	7421	66	4.7640000000000002	34.947000000000003	2.1300001	0.88749999	2.3999999999999999	0.611	\N	66
11063	7421	86	5.4690000000000003	37.904000000000003	1.962	0.93440002	2.1000000000000001	0.74599999	\N	86
11062	7421	106	4.9560000000000004	31.102	1.8839999	0.89709997	2.1000000000000001	0.38100001	\N	106
11061	7421	126	2.71	31.030000000000001	1.883	0.8969	2.1000000000000001	0.57700002	\N	126
11060	7224	40	1.321	12.185	2.0869999	0.90740001	2.2999999999999998	0.65399998	\N	40
11059	7224	50	1.706	19.556000000000001	2.1159999	0.96160001	2.2000000000000002	0.787	\N	50
11058	7224	80	2.8959999999999999	13.651	1.9960001	0.86769998	2.2999999999999998	0.52600002	\N	80
11057	7224	91	2.0880000000000001	13.051	1.936	0.84149998	2.2999999999999998	0.62199998	\N	91
11056	7224	119	1.4339999999999999	15.465	2.105	0.91540003	2.2999999999999998	0.60600001	\N	119
10925	7221	25	0	0	0	0	2.2999999999999998	0	\N	25
10924	7221	45	0	0	0	0	3.7999999999999998	0	\N	45
10923	7221	65	0	0	0	0	3.5	0	\N	65
10922	7221	94	0	0	0	0	3.7999999999999998	0	\N	94
10921	7221	129	0	0	0	0	3.7999999999999998	0	\N	129
10765	7201	37	0.90600000000000003	11.916	0.89300001	0.44639999	2	0.38	\N	37
10764	7201	58	2.8759999999999999	22.774999999999999	1.544	0.81239998	1.8999999999999999	0.60000002	\N	58
10763	7201	78	3.1059999999999999	21.259	1.505	0.79210001	1.8999999999999999	0.62	\N	78
10762	7201	98	3.2040000000000002	22.675000000000001	1.535	0.80779999	1.8999999999999999	0.56999999	\N	98
10761	7201	118	3.0539999999999998	24.245000000000001	1.477	0.73839998	2	0.44999999	\N	118
10750	7183	32	2.5459999999999998	40.761000000000003	1.347	0.74830002	1.8	0.53799999	\N	32
10749	7183	51	6.157	78.474999999999994	2.2950001	0.99779999	2.2999999999999998	0.74800003	\N	51
10748	7183	81	6.5860000000000003	67.787000000000006	2.2750001	0.9892	2.2999999999999998	0.79699999	\N	81
10747	7183	101	6.4589999999999996	87.975999999999999	2.2909999	0.91659999	2.5	0.273	\N	101
10746	7183	121	6.6180000000000003	98.936999999999998	2.3840001	0.99339998	2.3999999999999999	0.64899999	\N	121
10745	7181	32	1.429	23.576000000000001	2.039	0.81550002	2.5	0.43000001	\N	32
10744	7181	52	5.1139999999999999	40.228000000000002	3.1010001	1.0694	2.8999999999999999	0.70999998	\N	52
10743	7181	82	12.715999999999999	53.978999999999999	3.099	1.1478	2.7000000000000002	1.02	\N	82
10742	7181	92	11.631	49.552999999999997	3.079	1.0997	2.7999999999999998	0.88	\N	92
10741	7181	121	5.593	59.252000000000002	3.2260001	1.1947	2.7000000000000002	0.91000003	\N	121
8185	2133	40	2.2839999999999998	46.899000000000001	1.913	0.79699999	2.3999999999999999	0.58999997	\N	40
8186	2133	50	3.8969999999999998	42.948999999999998	1.988	0.90369999	2.2000000000000002	0.68000001	\N	50
8187	2133	78	4.069	33.673999999999999	1.7079999	0.94870001	1.8	0.82999998	\N	78
8188	2133	89	3.3660000000000001	39.588999999999999	1.849	0.92470002	2	0.79000002	\N	89
8189	2133	129	2.7709999999999999	42.588999999999999	1.921	0.9605	2	0.77999997	\N	129
8180	2131	46	23.541	113.974	4.8309999	1.0502	4.5999999999999996	0.65200001	\N	46
8181	2131	55	22.710000000000001	115.78100000000001	4.9169998	1.0688	4.5999999999999996	0.60100001	\N	55
8182	2131	85	24.282	114.98699999999999	4.552	1.0346	4.4000000000000004	0.81199998	\N	85
8183	2131	95	31.558	114.724	4.4910002	1.0694	4.2000000000000002	0.73199999	\N	95
8184	2131	125	11.747	95.234999999999999	4.2090001	1.0523	4	0.67400002	\N	125
8085	2130	13	2.9809999999999999	66.546999999999997	2.0880001	0.8351	2.5	0.67000002	\N	13
8086	2130	41	47.991999999999997	253.995	7.2119999	1.3113	5.5	0.93000001	\N	41
8087	2130	52	54.890999999999998	260.976	7.0479999	1.2814	5.5	0.69999999	\N	52
8088	2130	121	25.164000000000001	224.934	6.4980001	1.2995	5	0.81	\N	121
8089	2130	132	8.7579999999999991	145.02099999999999	4.8109999	1.0691	4.5	0.56999999	\N	132
7141	2126	46	0.746	21.166	1.984	0.73470002	2.7000000000000002	0.37	\N	46
7142	2126	56	3.3029999999999999	59.548999999999999	4.3449998	1.0104001	4.2999999999999998	0.61000001	\N	56
7143	2126	93	109.979	215.369	8.8339996	1.5498	5.7000000000000002	1.12	\N	93
7144	2126	133	131.67500000000001	276.71100000000001	9.7799997	1.6299	6	1.27	\N	133
7145	2126	174	11.769	92.775000000000006	6.349	1.2697999	5	0.79000002	\N	174
7136	2125	34	0.70199999999999996	12.73	1.471	0.66869998	2.2000000000000002	0.43000001	\N	34
7137	2125	58	3.7879999999999998	27.815000000000001	2.4070001	0.96270001	2.5	0.76999998	\N	58
7138	2125	84	19.727	49.026000000000003	2.4460001	0.97850001	2.5	0.80000001	\N	84
7139	2125	108	4.2670000000000003	37.981999999999999	2.562	0.9853	2.6000000000000001	0.75	\N	108
7140	2125	134	3.016	34.390000000000001	2.4449999	0.90539998	2.7000000000000002	0.16	\N	134
7131	2124	29	1.048	16.681999999999999	1.5369999	0.69840002	2.2000000000000002	0.34999999	\N	29
7132	2124	60	22.212	85.215000000000003	5.7049999	1.0971	5.2000000000000002	0.41999999	\N	60
7133	2124	89	32.847999999999999	101.771	5.415	1.2306	4.4000000000000004	0.81999999	\N	89
7134	2124	130	19.841000000000001	90.052000000000007	5.4850001	1.2756	4.2999999999999998	0.88999999	\N	130
7135	2124	140	12.539999999999999	78.269000000000005	5.46	1.2697001	4.2999999999999998	0.82999998	\N	140
7126	2123	34	3.4900000000000002	15.69	2.0009999	0.90960002	2.2000000000000002	0.68000001	\N	34
7127	2123	43	7.6879999999999997	19.597000000000001	2.0510001	0.93239999	2.2000000000000002	0.63	\N	43
7128	2123	74	15.843	28.634	2.3080001	0.85500002	2.7000000000000002	0.28999999	\N	74
7129	2123	84	9.4090000000000007	23.119	2.2409999	0.86210001	2.6000000000000001	0.47	\N	84
7130	2123	124	8.1799999999999997	20.789999999999999	2.2260001	0.82429999	2.7000000000000002	0.47	\N	124
7121	2122	51	7.0919999999999996	76.802999999999997	2.131	0.78930002	2.7000000000000002	0.63	\N	51
7122	2122	60	43.237000000000002	309.51999999999998	7.296	1.1581	6.2999999999999998	0.63	\N	60
7123	2122	100	186.26499999999999	590.173	9.1160002	1.4944	6.0999999999999996	0.66000003	\N	100
7124	2122	141	310.50099999999998	798.86400000000003	9.1280003	1.4262	6.4000000000000004	0.62	\N	141
7125	2122	180	68.454999999999998	443.43599999999998	8.6730003	1.4217	6.0999999999999996	0.79000002	\N	180
7116	2121	35	1.9690000000000001	16.795000000000002	1.8150001	0.82499999	2.2000000000000002	0.58999997	\N	35
7117	2121	45	4.7930000000000001	19.506	1.842	0.83740002	2.2000000000000002	0.60000002	\N	45
7118	2121	75	3.8540000000000001	21.722999999999999	1.666	0.79329997	2.1000000000000001	0.62	\N	75
7119	2121	85	4.1909999999999998	20.434999999999999	1.696	0.80769998	2.1000000000000001	0.64999998	\N	85
7120	2121	135	2.1099999999999999	13.103	1.447	0.85140002	1.7	0.52999997	\N	135
7111	2120	40	5.7910000000000004	73.992999999999995	2.5639999	0.88419998	2.8999999999999999	0.58999997	\N	40
7112	2120	49	7.9059999999999997	87.337999999999994	2.711	0.90350002	3	0.62	\N	49
6574	1998	8	5.9429999999999996	89.506	2.161	0.93970001	2.2999999999999998	0.56	\N	8
6575	1998	18	9.9149999999999991	130.43799999999999	3.319	1.1065	3	0.68000001	\N	18
6576	1998	37	15.548	202.85400000000001	4.5819998	1.3475	3.3999999999999999	0.89999998	\N	37
6577	1998	48	38.593000000000004	285.91699999999997	5.1090002	1.3444	3.7999999999999998	0.63	\N	48
6578	1998	78	20.545999999999999	271.27600000000001	6.467	1.3759	4.7000000000000002	0.86000001	\N	78
6579	1998	88	17.756	253.822	6.1479998	1.2809	4.7999999999999998	0.91000003	\N	88
6571	1996	11	45.271000000000001	294.11000000000001	5.5970001	1.5125999	3.7000000000000002	1.22	\N	11
6572	1996	51	130.661	497.315	7.4640002	1.5233999	4.9000000000000004	0.60000002	\N	51
6573	1996	91	49.731000000000002	666.75599999999997	8.3509998	1.5183001	5.5	0.23999999	\N	91
13140	9655	55	88.631	432.07900000000001	13.811	1.8415	7.5	1.08	\N	25
13141	9655	70	100.399	517.91399999999999	13.429	2.066	6.5	1.0829999	\N	40
13142	9655	100	237.80500000000001	549.10500000000002	13.223	2.0343001	6.5	1.286	\N	70
12901	8944	53	4.0899999999999999	32.290999999999997	2.816	1.1263	2.5	0.89099997	\N	18
12902	8944	73	8.3499999999999996	27.901	2.5309999	1.1505001	2.2000000000000002	0.57700002	\N	38
12903	8944	83	11.244999999999999	23.794	2.4349999	1.1069	2.2000000000000002	0.78299999	\N	48
12904	8944	93	7.1079999999999997	35.978999999999999	2.6300001	1.0958	2.3999999999999999	0.37200001	\N	58
12905	8944	103	7.1980000000000004	26.898	2.507	1.0901	2.2999999999999998	0.71200001	\N	68
12195	8942	59	9.5869999999999997	101.28400000000001	7.3280001	1.357	5.4000000000000004	0.80900002	\N	23
12193	8942	69	62.637	171.02199999999999	8.0810003	1.6162	5	1.251	\N	33
12194	8942	86	28.5	116.923	6.533	1.5935	4.0999999999999996	1.17	\N	50
12192	8942	99	25.777000000000001	117.81699999999999	6.6690001	1.5157	4.4000000000000004	0.91100001	\N	63
12191	8942	109	26.596	118.46899999999999	6.0359998	1.3719	4.4000000000000004	0.50400001	\N	73
11295	7763	56	2.4729999999999999	22.373999999999999	1.849	0.6164	3	0.391	\N	21
11294	7763	66	4.3019999999999996	41.057000000000002	3.138	1.0461	3	0.78299999	\N	31
11293	7763	78	8.5609999999999999	43.420000000000002	3.273	1.0227	3.2000000000000002	0.60299999	\N	43
11292	7763	96	5.9370000000000003	41.783000000000001	3.3740001	0.99229997	3.3999999999999999	0.71200001	\N	61
11291	7763	106	5.1500000000000004	41.923999999999999	3.3340001	0.95270002	3.5	0.66900003	\N	71
11290	6924	55	0	0	0	0	2.5	0	\N	20
11289	6924	65	0	0	0	0	2.7999999999999998	0	\N	30
11288	6924	81	0	0	0	0	3.1000000000000001	0	\N	46
11287	6924	95	0	0	0	0	3.2999999999999998	0	\N	60
11286	6924	105	0	0	0	0	3.2999999999999998	0	\N	70
10990	6921	9	4.1790000000000003	47.603999999999999	1.6569999	0.75330001	2.2000000000000002	0.51599997	\N	9
10989	6921	27	44.561	408.49000000000001	12.092	1.6794	7.2000000000000002	0.66900003	\N	27
10988	6921	49	94.585999999999999	467.30500000000001	13.624	1.8923	7.2000000000000002	1.409	\N	49
10987	6921	69	218.63900000000001	639.68499999999995	14.878	1.9322	7.7000000000000002	1.346	\N	69
10986	6921	88	159.30199999999999	511.82499999999999	12.228	1.6303999	7.5	0.43000001	\N	88
10625	6901	53	2.4860000000000002	18.251000000000001	1.192	0.49680001	2.3999999999999999	0.34299999	\N	18
10624	6901	73	6.9210000000000003	43.604999999999997	2.7609999	0.89050001	3.1000000000000001	0.42500001	\N	38
10623	6901	83	7.3620000000000001	40.155999999999999	2.543	0.90820003	2.7999999999999998	0.704	\N	48
10622	6901	93	7.1269999999999998	39.405000000000001	2.5120001	0.89719999	2.7999999999999998	0.741	\N	58
10621	6901	103	5.7050000000000001	39.186999999999998	2.5810001	0.86019999	3	0.67699999	\N	68
10610	6861	47	3.181	22.375	0.88700002	0.35479999	2.5	0.079999998	\N	12
10609	6861	57	15.801	82.594999999999999	3.0869999	0.77179998	4	0.23999999	\N	22
10608	6861	64	24.978000000000002	134.108	4.9169998	1.2292	4	0.77999997	\N	29
10607	6861	95	38.738999999999997	157.57400000000001	5.401	1.3173	4.0999999999999996	0.95999998	\N	60
10606	6861	106	23.564	129.54599999999999	4.6040001	1.2443	3.7000000000000002	0.95999998	\N	71
8220	1924	21	14.553000000000001	185.55099999999999	6.9559999	1.1993001	5.7999999999999998	0.76999998	\N	21
8221	1924	31	18.890999999999998	224.73400000000001	8.2030001	1.4143	5.7999999999999998	1.1	\N	31
8222	1924	41	41.719000000000001	268.452	8.8579998	1.4764	6	1.02	\N	41
8223	1924	71	167.15000000000001	394.584	8.474	1.4608999	5.7999999999999998	0.83999997	\N	71
8224	1924	81	40.732999999999997	256.41500000000002	7.1459999	1.2994	5.5	0.94999999	\N	81
8060	1923	13	4.6139999999999999	70.688000000000002	1.885	0.58899999	3.2000000000000002	0.315	\N	13
8061	1923	26	17.218	180.636	5.2459998	1.1162	4.7000000000000002	0.96100003	\N	26
8062	1923	42	45.243000000000002	230.745	6.0380001	1.2846	4.7000000000000002	0.90100002	\N	42
8063	1923	58	52.966999999999999	252.173	6.3579998	1.3527	4.7000000000000002	1.003	\N	58
8064	1923	72	32.847000000000001	209.11500000000001	5.7740002	1.2285	4.7000000000000002	0.852	\N	72
7645	1920	26	41.451999999999998	453.27800000000002	10.472	1.563	6.7000000000000002	1.05	\N	26
7646	1920	37	47.408999999999999	518.06299999999999	12.364	1.7173001	7.2000000000000002	1.09	\N	37
7647	1920	46	62.228999999999999	538.45899999999995	13.476	1.7501	7.7000000000000002	0.94999999	\N	46
7648	1920	76	247.99700000000001	784.702	14.001	1.9446	7.2000000000000002	1.37	\N	76
7649	1920	86	134.97900000000001	533.05399999999997	12.147	1.813	6.7000000000000002	1.21	\N	86
7640	1918	18	1.3029999999999999	16.302	0.76499999	0.36430001	2.1000000000000001	0.18000001	\N	18
7641	1918	27	6.0739999999999998	66.162999999999997	3.312	0.92000002	3.6000000000000001	0.56	\N	27
7642	1918	36	7.8620000000000001	87.216999999999999	4.0879998	1.0757999	3.7999999999999998	0.66000003	\N	36
7643	1918	67	19.315000000000001	86.475999999999999	3.4089999	0.92150003	3.7000000000000002	0.55000001	\N	67
7644	1918	77	10.023	76.635999999999996	3.293	0.86659998	3.7999999999999998	0.49000001	\N	77
7635	1917	10	9.1210000000000004	89.599999999999994	1.233	0.72509998	1.7	0.88999999	\N	10
7636	1917	36	136.97300000000001	1047.9349999999999	11.77	1.6815	7	0.85000002	\N	36
7637	1917	45	161.148	1027.2860000000001	12.683	1.7139	7.4000000000000004	1.26	\N	45
7638	1917	74	392.178	1245.2529999999999	11.962	1.6612999	7.2000000000000002	0.91000003	\N	74
7639	1917	85	233.88499999999999	1030.5599999999999	11.342	1.5975	7.0999999999999996	0.50999999	\N	85
7630	1916	24	2.355	25.984999999999999	1.1109999	0.46290001	2.3999999999999999	0.28999999	\N	24
7631	1916	36	4.3600000000000003	55.633000000000003	2.138	0.79170001	2.7000000000000002	0.58999997	\N	36
7632	1916	48	5.0430000000000001	55.463999999999999	2.1389999	0.79210001	2.7000000000000002	0.54000002	\N	48
7633	1916	60	4.7140000000000004	57.219000000000001	2.243	0.74760002	3	0.44	\N	60
7634	1916	73	4.3639999999999999	50.261000000000003	2.118	0.73019999	2.8999999999999999	0.55000001	\N	73
7625	1915	20	1.7250000000000001	11.278	1.072	0.4289	2.5	0.33000001	\N	20
7626	1915	28	3.762	32.18	1.946	0.69489998	2.7999999999999998	0.41999999	\N	28
7627	1915	43	3.9670000000000001	17.202000000000002	2.4289999	0.8994	2.7000000000000002	0.64999998	\N	43
7628	1915	58	4.4630000000000001	24.396999999999998	2.5220001	0.86970001	2.8999999999999999	0.5	\N	58
7629	1915	74	4.2919999999999998	25.949000000000002	2.349	0.7342	3.2000000000000002	0.56	\N	74
7621	1914	13	8.0139999999999993	71.180999999999997	3.059	0.65090001	4.7000000000000002	0.40000001	\N	13
7622	1914	31	10.994	121.11499999999999	5.2199998	1.0038	5.2000000000000002	0.76999998	\N	31
7623	1914	53	12.352	118.399	5.8520002	1.2452	4.7000000000000002	0.99000001	\N	53
7624	1914	73	5.9619999999999997	104.736	4.1960001	0.99910003	4.2000000000000002	0.88	\N	73
7620	1913	63	16.687000000000001	169.17699999999999	5.7620001	1.226	4.7000000000000002	1.03	\N	63
7619	1912	58	3.3069999999999999	40.097000000000001	1.942	0.71939999	2.7000000000000002	0.61000001	\N	58
7618	1911	76	21.876999999999999	228.46000000000001	4.2160001	1.0283	4.0999999999999996	0.69	\N	76
6785	1909	10	8	8	2.6530001	0.5528	4.7999999999999998	0.31999999	\N	10
6786	1909	25	11.178000000000001	11.178000000000001	4.1529999	0.84759998	4.9000000000000004	0.50999999	\N	25
6787	1909	40	14.26	14.26	4.5890002	0.9763	4.7000000000000002	0.60000002	\N	40
6788	1909	55	11.776	11.776	4.5289998	1.0533	4.2999999999999998	0.72000003	\N	55
6789	1909	70	9.6509999999999998	9.6509999999999998	3.1689999	0.85640001	3.7000000000000002	0.41	\N	70
6782	1908	47	9.5990000000000002	32.609000000000002	3.687	0.89920002	4.0999999999999996	0.67000002	\N	47
6783	1908	62	9.2509999999999994	37.609000000000002	3.194	0.86320001	3.7000000000000002	0.54000002	\N	62
6784	1908	77	4.4189999999999996	15.422000000000001	2.118	0.68309999	3.1000000000000001	0.50999999	\N	77
6779	1907	28	6.5910000000000002	32.149999999999999	2.2179999	0.58359998	3.7999999999999998	0.43000001	\N	28
6780	1907	42	9.3940000000000001	42.948	2.372	0.69770002	3.3999999999999999	0.68000001	\N	42
6781	1907	73	6.4900000000000002	37.520000000000003	2.1700001	0.7482	2.8999999999999999	0.61000001	\N	73
6790	1910	8	5.5	43.234999999999999	1.512	0.68739998	2.2000000000000002	0.44999999	\N	8
6791	1910	16	22.341000000000001	143.654	4.6220002	0.81800002	5.6500000000000004	0.34999999	\N	16
6792	1910	38	52.841000000000001	286.39499999999998	7.6690001	1.2469	6.1500000000000004	0.67000002	\N	38
6793	1910	53	50.914000000000001	264.60000000000002	7.5910001	1.3556	5.5999999999999996	0.98000002	\N	53
6794	1910	75	14.140000000000001	152.262	5.2259998	1.1239001	4.6500000000000004	0.83999997	\N	75
6774	1905	28	6.6959999999999997	47.692999999999998	2.4809999	0.5704	4.3499999999999996	0.38999999	\N	28
6775	1905	40	11.833	59.134999999999998	3.339	0.80470002	4.1500000000000004	0.60000002	\N	40
6776	1905	52	11.375	58.969000000000001	2.8640001	0.7252	3.9500000000000002	0.52999997	\N	52
6777	1905	64	8.5350000000000001	57.564999999999998	2.9059999	0.77499998	3.75	0.60000002	\N	64
6778	1905	76	5.3479999999999999	49.152000000000001	2.744	0.75160003	3.6499999999999999	0.49000001	\N	76
6763	1902	23	19.428000000000001	269.50799999999998	3.0880001	0.66399997	4.6500000000000004	0.46000001	\N	23
6764	1902	34	33.890000000000001	375.25299999999999	4.9959998	0.88429999	5.6500000000000004	0.81999999	\N	34
6765	1902	44	37.768000000000001	365.53899999999999	4.8779998	0.91180003	5.3499999999999996	0.69	\N	44
6766	1902	54	37.250999999999998	326.322	4.3299999	0.93110001	4.6500000000000004	0.62	\N	54
6767	1902	64	25.681000000000001	289.58699999999999	3.776	0.90990001	4.1500000000000004	0.69	\N	64
6768	1902	74	18.329999999999998	233.87	2.9449999	0.76499999	3.8500000000000001	0.63999999	\N	74
6769	1904	18	7.6699999999999999	60.262999999999998	1.345	0.67250001	2	0.36000001	\N	18
6770	1904	27	22.824000000000002	113.896	3.891	1.0809	3.6000000000000001	0.64999998	\N	27
6771	1904	38	31.109000000000002	194.33799999999999	4.915	1.2934	3.7999999999999998	0.89999998	\N	38
6772	1904	68	47.845999999999997	220.82400000000001	4.96	1.2399	4	0.81999999	\N	68
6773	1904	78	46.595999999999997	235.17500000000001	6.1329999	1.2266999	5	0.76999998	\N	78
6759	1901	21	7.0350000000000001	50.387999999999998	5.0700002	1.1142	4.5499999999999998	0.52999997	\N	21
6760	1901	41	18.091999999999999	80.233999999999995	6.8610001	1.3861001	4.9500000000000002	0.74000001	\N	41
6761	1901	57	30.834	80.75	6.7529998	1.3372999	5.0499999999999998	0.88	\N	57
6762	1901	81	14.836	78.992000000000004	5.954	1.1562001	5.1500000000000004	0.69999999	\N	81
6755	1900	19	1.9630000000000001	26.396999999999998	2.191	0.61720002	3.5499999999999998	0.14	\N	19
6756	1900	39	21.812000000000001	92.887	6.309	1.3866	4.5499999999999998	0.91000003	\N	39
6757	1900	59	20.013999999999999	80.495000000000005	5.9250002	1.2743	4.6500000000000004	0.81	\N	59
6758	1900	79	9.7010000000000005	74.147000000000006	5.2150002	1.1214	4.6500000000000004	0.52999997	\N	79
6750	1899	25	8.5169999999999995	103.17700000000001	3.1059999	0.87489998	3.5499999999999998	0.41999999	\N	25
6751	1899	36	14.208	127.10299999999999	4.1409998	1.1043	3.75	0.68000001	\N	36
6752	1899	50	22.908000000000001	143.77500000000001	4.401	1.1285	3.8999999999999999	0.67000002	\N	50
6753	1899	65	15.227	110.018	4.052	1.0524	3.8500000000000001	0.60000002	\N	65
6754	1899	75	14.720000000000001	96.534000000000006	4.2690001	1.0671999	4	0.72000003	\N	75
6746	1898	14	8.4930000000000003	95.768000000000001	1.942	0.79259998	2.4500000000000002	0.5	\N	14
6747	1898	33	67.873999999999995	515.16300000000001	8.3389997	1.4255	5.8499999999999996	0.81999999	\N	33
6748	1898	58	56.994	567.22699999999998	9.8559999	1.6026	6.1500000000000004	1.03	\N	58
6749	1898	83	43.850999999999999	448.56999999999999	7.7969999	1.3329	5.8499999999999996	0.94999999	\N	83
6742	1897	31	22.315999999999999	259.58199999999999	5.9790001	1.4234999	4.2000000000000002	0.69	\N	31
6743	1897	41	42.723999999999997	277.76499999999999	6.1789999	1.507	4.0999999999999996	0.79000002	\N	41
6744	1897	71	23.495999999999999	192.25399999999999	5.427	1.2333	4.4000000000000004	0.60000002	\N	71
6745	1897	80	19.856000000000002	230.39699999999999	5.3730001	1.2211	4.4000000000000004	0.98000002	\N	80
6740	1896	24	60.289000000000001	837.63300000000004	8.9219999	1.1223	7.9500000000000002	0.60000002	\N	24
6741	1896	99	61.491999999999997	873.50400000000002	6.5289998	0.9131	7.1500000000000004	0.74000001	\N	99
13130	9652	26	21.448	170.89699999999999	8.3970003	1.5549999	5.4000000000000004	0.71200001	\N	73
13129	9652	36	31.056999999999999	248.518	11.503	1.7168	6.7000000000000002	1.344	\N	83
13128	9652	46	32.822000000000003	240.81399999999999	11.332	1.7434	6.5	1.319	\N	93
13127	9652	56	33.093000000000004	221.68199999999999	10.559	1.676	6.2999999999999998	1.104	\N	103
13126	9652	66	45.530000000000001	218.119	9.4919996	1.556	6.0999999999999996	1.031	\N	113
12921	8968	11	1.8680000000000001	18.274000000000001	2.0120001	0.87470001	2.2999999999999998	0.63700002	\N	58
12922	8968	23	3.6709999999999998	42.807000000000002	4.4759998	1.2433	3.6000000000000001	0.87900001	\N	70
12923	8968	35	16.484999999999999	53.935000000000002	3.9389999	1.0941	3.6000000000000001	0.81699997	\N	82
12924	8968	47	6.5179999999999998	37.308	3.4170001	1.0051	3.3999999999999999	0.69300002	\N	94
12925	8968	59	3.1949999999999998	23.454000000000001	2.832	0.91350001	3.1000000000000001	0.63999999	\N	106
13131	9653	22	26.286999999999999	149.28299999999999	6.3390002	1.4087	4.5	0.76300001	\N	8
13132	9653	37	38.091000000000001	201.995	7.9590001	1.6935	4.7000000000000002	0.91600001	\N	23
13133	9653	52	52.729999999999997	225.566	10.087	1.9398	5.2000000000000002	1.322	\N	38
13134	9653	72	104.245	311.40199999999999	11.546	2.0256	5.7000000000000002	1.401	\N	58
13135	9653	92	68.668000000000006	236.94300000000001	11.831	1.9081	6.2000000000000002	0.89899999	\N	78
12911	8925	35	1.2290000000000001	5.181	0.44999999	0.4497	1	0.419	\N	18
12912	8925	45	1.127	10.667	1.033	0.79430002	1.3	0.461	\N	28
12913	8925	65	1.913	13.395	1.41	0.8294	1.7	0.57700002	\N	48
12914	8925	75	4.7409999999999997	21.207999999999998	2.438	1.016	2.3999999999999999	0.456	\N	58
12915	8925	85	6.3010000000000002	23.82	2.8540001	1.0977	2.6000000000000001	0.62099999	\N	68
12290	8923	27	5.8499999999999996	37.332999999999998	3.5580001	1.227	2.8999999999999999	0.80400002	\N	17
12289	8923	47	11.292	68.772999999999996	4.9260001	1.5394	3.2000000000000002	1.1619999	\N	37
12288	8923	57	22.945	82.965000000000003	5.184	1.4813	3.5	0.92500001	\N	47
12287	8923	72	77.146000000000001	147.184	6.507	1.5492001	4.2000000000000002	0.84799999	\N	62
12286	8923	87	16.321000000000002	87.287999999999997	6.9770002	1.5505	4.5	0.838	\N	77
11182	7721	33	1.115	13.381	1.082	0.9016	1.2	0.778	\N	13
11181	7721	43	1.663	17.974	1.388	0.99169999	1.3999999999999999	0.79400003	\N	23
11180	7721	53	2.3250000000000002	21.905000000000001	1.682	1.051	1.6000000000000001	0.81699997	\N	33
11179	7721	83	5.7380000000000004	27.864999999999998	3.073	1.2292	2.5	1.024	\N	63
11178	7721	93	4.5300000000000002	43.069000000000003	3.2850001	1.1733	2.7999999999999998	0.82300001	\N	73
11187	6964	32	0.39400000000000002	5.4470000000000001	0.84200001	0.93589997	0.90000000000000002	0.83999997	\N	12
11186	6964	42	1.252	14.738	1.401	1.0005	1.3999999999999999	0.84600002	\N	22
11185	6964	52	1.409	11.617000000000001	1.76	1.1001	1.6000000000000001	0.91600001	\N	32
11184	6964	80	4.6310000000000002	24.712	2.8410001	1.1364	2.5	0.852	\N	60
11183	6964	91	1.9830000000000001	17.744	2.8929999	1.1126	2.6000000000000001	0.80900002	\N	71
10957	6961	22	22.170000000000002	178.80600000000001	5.8249998	1.3547	4.2999999999999998	1.051	\N	22
10956	6961	41	38.863	221.31800000000001	8.7869997	1.8307	4.7999999999999998	1.517	\N	41
10955	6961	60	199.02699999999999	496.11200000000002	10.319	1.947	5.2999999999999998	1.346	\N	60
10954	6961	81	324.50599999999997	638.61300000000006	11.637	2.0064001	5.7999999999999998	1.216	\N	81
10953	6961	101	76.879000000000005	408.97300000000001	11.327	1.7979	6.2999999999999998	0.81900001	\N	101
10650	6942	28	2.3170000000000002	12.234999999999999	0.81599998	0.81569999	1	0.67900002	\N	28
10649	6942	39	1.9570000000000001	16.428000000000001	1.2029999	0.85890001	1.3999999999999999	0.66500002	\N	39
10648	6942	49	3.254	16.164000000000001	1.133	0.80900002	1.3999999999999999	0.62199998	\N	49
10647	6942	60	11.41	39.552	1.906	1.0031	1.8999999999999999	0.71600002	\N	60
10646	6942	72	9.2599999999999998	41.384	2.2190001	1.0569	2.1000000000000001	0.71600002	\N	72
10645	6941	26	24.972999999999999	210.745	4.776	1.4471999	3.2999999999999998	0.98100001	\N	11
10644	6941	36	33.661999999999999	175.16300000000001	5.7399998	1.5946	3.6000000000000001	1.123	\N	21
10643	6941	56	115.675	339.36599999999999	6.882	1.7204	4	1.141	\N	41
10642	6941	86	135.947	457.827	8.9350004	1.7869	5	1.133	\N	71
10641	6941	96	64.936000000000007	568.19200000000001	8.7950001	1.5991	5.5	0.81699997	\N	81
8205	2089	58	3.52	69.962000000000003	1.704	0.68180001	2.5	0.34	\N	58
8206	2089	67	5.6870000000000003	80.644000000000005	2.2379999	0.8951	2.5	0.75999999	\N	67
8207	2089	76	6.21	75.364999999999995	2.3180001	0.92729998	2.5	0.79000002	\N	76
8208	2089	108	5.899	83.674999999999997	2.451	0.81690001	3	0.63999999	\N	108
8209	2089	117	5.8869999999999996	80.670000000000002	2.4219999	0.80729997	3	0.58999997	\N	117
8200	2087	68	8.5280000000000005	103.004	3.5510001	0.84539998	4.2000000000000002	0.19	\N	68
8201	2087	78	19.024000000000001	219.93100000000001	7.2880001	1.4874001	4.9000000000000004	1.0700001	\N	78
8202	2087	98	46.673999999999999	237.90000000000001	6.9429998	1.3352	5.2000000000000002	0.5	\N	98
8203	2087	108	48.064999999999998	233.81	6.723	1.3446	5	1.05	\N	108
8204	2087	138	96.489999999999995	241.61699999999999	5.875	1.1749001	5	0.88999999	\N	138
8075	2086	58	10.622	143.11799999999999	4.4829998	1.1797	3.7999999999999998	0.787	\N	58
8076	2086	78	15.849	196.75700000000001	5.4899998	1.2768	4.2999999999999998	0.92799997	\N	78
8077	2086	88	26.981999999999999	196.95099999999999	5.4330001	1.2074	4.5	0.89899999	\N	88
8078	2086	117	144.001	315.899	5.5440001	1.1314	4.9000000000000004	0.625	\N	117
8079	2086	128	15.706	143.22800000000001	4.2329998	0.92019999	4.5999999999999996	0.80599999	\N	128
7030	2078	35	2.4990000000000001	39.664999999999999	2.901	0.9066	3.2000000000000002	0.63999999	\N	35
7031	2078	56	44.729999999999997	197.81	11.068	1.8144	6.0999999999999996	1.25	\N	56
7032	2078	81	47.643999999999998	168.989	9.2019997	1.5337	6	1.16	\N	81
7033	2078	105	124.878	255.55799999999999	9.0299997	1.6418	5.5	1.4299999	\N	105
7034	2078	131	69.789000000000001	149.27699999999999	6.3309999	1.4724	4.2999999999999998	1.27	\N	131
7025	2077	63	20.262	213.36500000000001	6.7340002	1.3204	5.0999999999999996	0.74000001	\N	63
7026	2077	84	35.960000000000001	212.20500000000001	6.171	1.3714	4.5	0.88	\N	84
7027	2077	94	44.744999999999997	211.04499999999999	5.552	1.2911	4.2999999999999998	0.67000002	\N	94
7028	2077	124	82.528000000000006	239.32499999999999	5.6950002	1.2117	4.7000000000000002	0.70999998	\N	124
7029	2077	134	34.503999999999998	137.06700000000001	3.8610001	0.9192	4.2000000000000002	0.69	\N	134
7020	2076	56	6.3280000000000003	78.247	3.3629999	0.80080003	4.2000000000000002	0.079999998	\N	56
7021	2076	66	11.071999999999999	139.53999999999999	7.6020002	1.5515	4.9000000000000004	1.08	\N	66
7022	2076	97	51.213999999999999	203.202	7.3889999	1.421	5.2000000000000002	0.77999997	\N	97
7023	2076	106	46.694000000000003	241.43700000000001	9.2080002	1.4851	6.2000000000000002	0.91000003	\N	106
7024	2076	153	10.025	39.576000000000001	1.715	0.34990001	4.9000000000000004	0.27000001	\N	153
7015	2075	63	3.718	72.251000000000005	1.924	0.76959997	2.5	0.47	\N	63
7016	2075	73	4.0629999999999997	79.909000000000006	1.877	0.85329998	2.2000000000000002	0.58999997	\N	73
7017	2075	83	4.5839999999999996	75.554000000000002	1.851	0.84140003	2.2000000000000002	0.60000002	\N	83
7018	2075	103	4.9740000000000002	80.313000000000002	1.899	0.79110003	2.3999999999999999	0.52999997	\N	103
7019	2075	123	5.5099999999999998	73.335999999999999	1.544	0.67129999	2.2999999999999998	0.55000001	\N	123
7010	2074	68	7.5389999999999997	82.694000000000003	2.293	0.6947	3.2999999999999998	0.43000001	\N	68
7011	2074	78	43.554000000000002	167.38399999999999	3.2520001	1.0491	3.1000000000000001	0.80000001	\N	78
7012	2074	88	44.125	149.34200000000001	3.6730001	1.1129	3.2999999999999998	0.87	\N	88
7013	2074	118	32.798999999999999	127.77	3.247	0.98409998	3.2999999999999998	0.76999998	\N	118
7014	2074	128	11.045	105.928	3.187	0.9659	3.2999999999999998	0.79000002	\N	128
7006	2073	55	76.105000000000004	389.82900000000001	11.02	1.5972	6.9000000000000004	0.67000002	\N	55
7007	2073	85	199.232	482.577	9.1599998	1.4312	6.4000000000000004	0.44999999	\N	85
7008	2073	114	272.93599999999998	502.81	8.7539997	1.6210999	5.4000000000000004	1.28	\N	114
7009	2073	145	87.057000000000002	211.87200000000001	4.9590001	0.84060001	5.9000000000000004	0.47999999	\N	145
7001	2072	39	7.8710000000000004	112.941	3.372	1.466	2.2999999999999998	1.1	\N	39
7002	2072	69	186.81	529.83100000000002	10.285	1.607	6.4000000000000004	0.68000001	\N	69
7003	2072	99	307.87400000000002	691.87099999999998	9.5539999	1.4928	6.4000000000000004	0.38	\N	99
7004	2072	108	362.62900000000002	712.64999999999998	9.3400002	1.5065	6.2000000000000002	0.28	\N	108
7005	2072	149	41.920000000000002	175.178	3.6989999	0.69800001	5.2999999999999998	0.50999999	\N	149
6996	2071	63	3.54	59.950000000000003	1.543	0.77139997	2	0.61000001	\N	63
6997	2071	72	3.7480000000000002	63.738999999999997	1.495	0.87959999	1.7	0.64999998	\N	72
6998	2071	82	3.375	59.670999999999999	1.431	0.84179997	1.7	0.60000002	\N	82
6999	2071	111	4.0979999999999999	64.067999999999998	1.556	0.8646	1.8	0.61000001	\N	111
7000	2071	121	3.3090000000000002	54.732999999999997	1.323	0.778	1.7	0.55000001	\N	121
6991	2070	63	10.427	76.691000000000003	1.976	0.85909998	2.2999999999999998	0.67000002	\N	63
6992	2070	73	5.3310000000000004	48.915999999999997	1.675	0.88169998	1.8999999999999999	0.64999998	\N	73
6993	2070	83	6.3470000000000004	46.744999999999997	1.668	0.8779	1.8999999999999999	0.63	\N	83
6994	2070	113	7.0010000000000003	57.719999999999999	1.8710001	0.8908	2.1000000000000001	0.51999998	\N	113
6995	2070	123	4.282	37.485999999999997	1.52	0.84429997	1.8	0.66000003	\N	123
7040	2081	60	6.3250000000000002	79.930000000000007	2.177	0.80620003	2.7000000000000002	0.63	\N	60
7041	2081	75	8.1080000000000005	79.161000000000001	1.948	0.88559997	2.2000000000000002	0.64999998	\N	75
7042	2081	90	9.0980000000000008	90.875	2.112	0.9181	2.2999999999999998	0.66000003	\N	90
7043	2081	105	10.036	75.975999999999999	1.9119999	0.86909997	2.2000000000000002	0.54000002	\N	105
7044	2081	120	7.7009999999999996	67.712999999999994	1.686	0.80269998	2.1000000000000001	0.57999998	\N	120
6987	2069	65	13.634	13.634	2.8010001	1.0003	2.7999999999999998	0.70999998	\N	65
6988	2069	85	18.494	18.494	2.612	1.0045	2.6000000000000001	0.69999999	\N	85
6989	2069	115	12.470000000000001	12.470000000000001	2.448	0.90679997	2.7000000000000002	0.72000003	\N	115
6990	2069	125	11.858000000000001	11.858000000000001	2.23	0.85780001	2.6000000000000001	0.64999998	\N	125
6982	2068	57	12.849	122.971	3.9070001	1.0281	3.7999999999999998	0.81	\N	57
6983	2068	77	10.4	99.349999999999994	3.447	1.149	3	0.82999998	\N	77
6984	2068	87	10.353	97.900000000000006	3.3099999	1.0677	3.1000000000000001	0.63999999	\N	87
6985	2068	117	8.7129999999999992	81.768000000000001	2.767	0.95410001	2.8999999999999999	0.81999999	\N	117
6986	2068	127	8.4329999999999998	73.965999999999994	2.918	1.1670001	2.5	1.09	\N	127
6977	2067	70	14.481999999999999	113.42	2.484	0.95560002	2.6000000000000001	0.69	\N	70
6978	2067	84	17.931000000000001	137.381	2.5710001	1.0713	2.3999999999999999	0.81	\N	84
6979	2067	98	19.728000000000002	180.809	2.5409999	1.0163	2.5	0.69	\N	98
6980	2067	112	18.402999999999999	131.81	2.494	0.99739999	2.5	0.51999998	\N	112
6981	2067	126	15.481999999999999	125.40900000000001	2.461	0.94669998	2.6000000000000001	0.74000001	\N	126
7035	2080	50	82.566000000000003	782.13699999999994	10.507	1.6677999	6.2999999999999998	1.14	\N	50
7036	2080	80	115.51000000000001	641.89200000000005	8.8149996	1.4218	6.2000000000000002	0.75	\N	80
7037	2080	110	108.887	629.76599999999996	8.4440002	1.5078	5.5999999999999996	1.05	\N	110
7038	2080	120	220.727	703.46400000000006	7.8860002	1.4338	5.5	0.92000002	\N	120
7039	2080	150	37.585999999999999	149.31200000000001	2.665	0.56699997	4.7000000000000002	0.46000001	\N	150
6973	2066	67	8.2940000000000005	71.25	3.036	1.0121	3	0.77999997	\N	67
6974	2066	87	5.8769999999999998	60.765000000000001	2.654	0.98280001	2.7000000000000002	0.74000001	\N	87
6975	2066	107	6.1230000000000002	57.164999999999999	2.5780001	0.95480001	2.7000000000000002	0.81	\N	107
6976	2066	127	10.279	56.347999999999999	2.4319999	0.90069997	2.7000000000000002	0.68000001	\N	127
6968	2065	56	3.4860000000000002	47.021999999999998	2.1259999	0.6857	3.1000000000000001	0.34	\N	56
6969	2065	76	15.574	149.74299999999999	6.5139999	1.3859	4.7000000000000002	0.69999999	\N	76
6970	2065	96	22.513000000000002	151.01499999999999	6.0840001	1.3226	4.5999999999999996	0.75999999	\N	96
6971	2065	116	66.816000000000003	178.535	5.6490002	1.202	4.7000000000000002	0.69999999	\N	116
6972	2065	136	38.201000000000001	118.55800000000001	5.1240001	1.1914999	4.2999999999999998	0.75999999	\N	136
6963	2064	64	3.0139999999999998	60.517000000000003	2.536	0.97539997	2.6000000000000001	0.70999998	\N	64
6964	2064	74	4.1150000000000002	49.335999999999999	2.74	1.0539	2.6000000000000001	0.72000003	\N	74
6965	2064	84	5.0090000000000003	86.947000000000003	2.773	0.9903	2.7999999999999998	0.75	\N	84
6966	2064	114	5.3920000000000003	30.847999999999999	2.286	0.81639999	2.7999999999999998	0.28	\N	114
6967	2064	123	3.5419999999999998	44.942	2.2639999	0.87089998	2.6000000000000001	0.58999997	\N	123
6958	2063	63	8.9510000000000005	238.83699999999999	4.75	1.1875	4	1.27	\N	63
6959	2063	73	8.1120000000000001	204.191	4.6430001	1.2217	3.7999999999999998	0.88999999	\N	73
6960	2063	83	8.8640000000000008	207.167	4.4050002	1.1592	3.7999999999999998	0.58999997	\N	83
6961	2063	112	28.199000000000002	174.84	3.8369999	1.0098	3.7999999999999998	0.41999999	\N	112
6962	2063	123	14.603999999999999	149.32300000000001	3.9960001	0.99900001	4	0.77999997	\N	123
6953	2062	58	16.056000000000001	241.79400000000001	5.3280001	1.2108001	4.4000000000000004	0.89999998	\N	58
6954	2062	80	18.190000000000001	310.21899999999999	5.8730001	1.3983001	4.2000000000000002	1.03	\N	80
6955	2062	90	20.643000000000001	291.51299999999998	5.9039998	1.4056	4.2000000000000002	0.97000003	\N	90
6956	2062	120	52.140999999999998	265.53100000000001	5.027	1.197	4.2000000000000002	0.36000001	\N	120
6957	2062	130	52.118000000000002	321.35199999999998	4.8460002	1.1539	4.2000000000000002	0.58999997	\N	130
6950	2061	74	6.8949999999999996	113.986	4.6750002	1.2302001	3.7999999999999998	0.77999997	\N	74
6951	2061	84	10.82	65.159999999999997	4.4429998	1.1691999	3.7999999999999998	0.41999999	\N	84
6952	2061	124	24.099	110.489	4.3870001	1.0968	4	0.76999998	\N	124
6945	2060	58	39.018999999999998	385.12900000000002	9.2379999	1.6496	5.5999999999999996	1.3099999	\N	58
6946	2060	68	82.465999999999994	521.18100000000004	9.0959997	1.5958	5.7000000000000002	1.11	\N	68
6947	2060	88	80.643000000000001	488.60300000000001	9.2180004	1.6461	5.5999999999999996	1.3200001	\N	88
6948	2060	98	98.149000000000001	510.16000000000003	9.3669996	1.6726	5.5999999999999996	1.36	\N	98
6949	2060	128	106.33799999999999	329.99200000000002	4.0300002	0.95959997	4.2000000000000002	1.05	\N	128
6940	2059	63	50.692	907.28200000000004	10.844	1.7632999	6.1500000000000004	1.46	\N	63
6941	2059	78	107.063	817.54499999999996	9.9399996	1.6163	6.1500000000000004	1.29	\N	78
6942	2059	108	125.95399999999999	817.59699999999998	9.9840002	1.5243	6.5499999999999998	0.85000002	\N	108
6943	2059	123	257.14499999999998	805.08199999999999	8.2320004	1.4316	5.75	0.33000001	\N	123
6944	2059	138	116.515	463.31700000000001	5.513	1.2674	4.3499999999999996	1.08	\N	138
13153	9658	34	44.627000000000002	221.018	5.296	1.3239	4	0.69599998	\N	50
13154	9658	54	96.620000000000005	329.24799999999999	7.757	1.4103	5.5	0.359	\N	70
13155	9658	74	114.467	363.87200000000001	6.8779998	1.3486	5.0999999999999996	0.94499999	\N	90
13156	9658	94	737.85699999999997	955.22000000000003	5.677	1.2078	4.7000000000000002	0.884	\N	110
13157	9658	114	134.751	317.88600000000002	5.0300002	1.1431	4.4000000000000004	0.83999997	\N	130
12906	9000	36	0.72299999999999998	5.4790000000000001	1.029	0.57160002	1.8	0.43900001	\N	65
12907	9000	56	13.061999999999999	21.885000000000002	1.793	0.94379997	1.8999999999999999	0.63700002	\N	85
12908	9000	76	5.726	14.664	1.574	0.8743	1.8	0.57200003	\N	105
12909	9000	96	6.1020000000000003	12.286	1.122	0.8017	1.3999999999999999	0.69099998	\N	125
12910	9000	106	1.663	4.9809999999999999	0.69800001	0.77579999	0.90000000000000002	0.66900003	\N	135
12230	9142	33	13.824	154.25899999999999	4.5679998	1.114	4.0999999999999996	0.56	\N	57
12229	9142	43	39.840000000000003	340.01600000000002	9.026	1.5835	5.7000000000000002	1.215	\N	67
12228	9142	73	117.917	324.221	7.1090002	1.4218	5	1.291	\N	97
12227	9142	83	140.62200000000001	359.00700000000001	6.7420001	1.3485	5	1.041	\N	107
12226	9142	123	211.15100000000001	417.00200000000001	4.349	1.0354	4.2000000000000002	0.75599998	\N	147
11310	7901	40	7.149	83.337999999999994	4.809	1.2997	3.7000000000000002	1.029	\N	55
11309	7901	59	17.209	75.456000000000003	3.7130001	1.0921	3.3999999999999999	0.514	\N	74
11308	7901	79	23.655000000000001	78.236000000000004	3.2490001	0.98449999	3.2999999999999998	0.56300002	\N	94
11307	7901	99	12.805999999999999	54.496000000000002	2.556	0.98299998	2.6000000000000001	0.708	\N	114
11306	7901	119	11.301	40.146999999999998	1.8710001	0.89090002	2.1000000000000001	0.71899998	\N	134
11305	7881	23	3.9289999999999998	57.771000000000001	2.3959999	1.0892	2.2000000000000002	0.204	\N	43
11304	7881	33	13.412000000000001	210.66999999999999	8.1000004	1.5	5.4000000000000004	0.91299999	\N	53
11303	7881	63	29.882000000000001	153.291	5.8790002	1.3362	4.4000000000000004	0.73400003	\N	83
11302	7881	73	30.155999999999999	137.39699999999999	5.3670001	1.2482001	4.2999999999999998	0.94400001	\N	93
11301	7881	114	14.539999999999999	94.870999999999995	3.79	1.1148	3.3999999999999999	0.75800002	\N	134
11300	7306	43	8.8599999999999994	35.652000000000001	2.967	0.98909998	3	0.63700002	\N	53
11299	7306	56	3.9199999999999999	27.488	2.438	0.93760002	2.6000000000000001	0.722	\N	66
11298	7306	73	4.0259999999999998	18.911999999999999	2.0650001	0.86019999	2.3999999999999999	0.71200001	\N	83
11297	7306	94	1.7569999999999999	13.047000000000001	1.503	0.8348	1.8	0.66600001	\N	104
11296	7306	115	2.2069999999999999	9.8919999999999995	1.001	0.76969999	1.3	0.60600001	\N	125
11395	8443	37	4.25	110.533	2.618	0.81809998	3.2000000000000002	0.54500002	\N	57
11394	8443	54	5.0670000000000002	107.18600000000001	2.52	0.9691	2.6000000000000001	0.77499998	\N	74
11393	8443	74	3.79	69.823999999999998	1.775	0.84509999	2.1000000000000001	0.70200002	\N	94
8425	1991	63	1.7649999999999999	14.379	1.0599999	0.3655	2.8999999999999999	0.30000001	\N	63
8426	1991	74	6.0970000000000004	34.837000000000003	2.1470001	0.7155	3	0.56999999	\N	74
8427	1991	86	16.588999999999999	50.456000000000003	2.52	0.89999998	2.7999999999999998	0.75	\N	86
8428	1991	98	7.5300000000000002	38.893999999999998	2.4130001	0.92799997	2.6000000000000001	0.75	\N	98
8429	1991	110	4.6500000000000004	40.700000000000003	2.576	0.95389998	2.7000000000000002	0.75999999	\N	110
8430	1992	57	17.529	71.349000000000004	4.9860001	1.0388	4.7999999999999998	0.79000002	\N	57
8431	1992	71	31.306000000000001	129.24000000000001	5.8660002	1.2221	4.7999999999999998	0.70999998	\N	71
8432	1992	85	73.405000000000001	198.28399999999999	5.8769999	1.2244	4.7999999999999998	0.79000002	\N	85
8433	1992	99	108.30500000000001	255.602	6.0419998	1.2587	4.7999999999999998	0.88999999	\N	99
8434	1992	113	14.259	98.134	3.845	0.75389999	5.0999999999999996	0.47999999	\N	113
8210	1990	58	5.9530000000000003	71.390000000000001	2.5739999	0.80419999	3.2000000000000002	0.46000001	\N	58
8211	1990	72	21.113	187.63399999999999	5.7880001	1.2582999	4.5999999999999996	0.86000001	\N	72
8212	1990	84	37.723999999999997	198.56	5.4819999	1.2459	4.4000000000000004	0.85000002	\N	84
8213	1990	97	61.271999999999998	215.25299999999999	5.2579999	1.2519	4.2000000000000002	0.88999999	\N	97
8214	1990	110	110.846	280.70999999999998	5.8899999	1.2805001	4.5999999999999996	1.08	\N	110
8070	1988	51	25.795999999999999	207.07400000000001	5.7610002	1.1079	5.2000000000000002	0.30599999	\N	51
8071	1988	66	58.283000000000001	244.339	6.4640002	1.3467	4.7999999999999998	0.91000003	\N	66
8072	1988	81	96.378	252.19	5.3639998	1.2191	4.4000000000000004	0.76599997	\N	81
8073	1988	95	56.948	266.93000000000001	5.9809999	1.2726001	4.7000000000000002	0.77700001	\N	95
8074	1988	111	29.489999999999998	237.58699999999999	6.6090002	1.247	5.2999999999999998	0.70499998	\N	111
6930	1985	45	3.7200000000000002	50.857999999999997	3.997	0.8883	4.5	0.41	\N	45
6931	1985	60	19.651	117.727	8.79	1.5422	5.7000000000000002	1.14	\N	60
6932	1985	74	27.635000000000002	132.13499999999999	8.915	1.564	5.7000000000000002	1.11	\N	74
6933	1985	92	10.269	117.843	9.7709999	1.6285	6	1.1799999	\N	92
6934	1985	106	12.679	118.148	10.758	1.6551	6.5	1.35	\N	106
6925	1983	56	2.5219999999999998	23.713999999999999	2.7449999	0.74199998	3.7000000000000002	0.41	\N	56
6926	1983	71	5.1550000000000002	47.265000000000001	5.1880002	1.1791	4.4000000000000004	0.73000002	\N	71
6927	1983	86	11.625999999999999	57.374000000000002	5.3779998	1.2806	4.2000000000000002	0.73000002	\N	86
6928	1983	101	8.0869999999999997	69.816000000000003	6.803	1.3339	5.0999999999999996	0.94	\N	101
6929	1983	116	3.3279999999999998	50.738	4.823	0.92750001	5.2000000000000002	0.49000001	\N	116
6920	1981	62	6.9669999999999996	28.401	2.2620001	0.75389999	3	0.54000002	\N	62
6921	1981	74	11.199	34.783000000000001	2.875	0.95840001	3	0.63999999	\N	74
6922	1981	85	9.7490000000000006	34.619	2.835	1.05	2.7000000000000002	0.75	\N	85
6923	1981	98	7.6040000000000001	32.877000000000002	2.7679999	1.0645	2.6000000000000001	0.72000003	\N	98
6924	1981	110	6.0430000000000001	32.631999999999998	3.0739999	0.99169999	3.1000000000000001	0.75999999	\N	110
6916	1980	66	5.5709999999999997	83.879999999999995	2.4319999	0.75999999	3.2000000000000002	0.41	\N	66
6917	1980	80	8.4990000000000006	88.513000000000005	2.2449999	0.89810002	2.5	0.63999999	\N	80
6918	1980	96	5.7949999999999999	87.004000000000005	2.312	1.0051	2.2999999999999998	0.69999999	\N	96
6919	1980	110	5.9649999999999999	93.480000000000004	2.4349999	0.90189999	2.7000000000000002	0.55000001	\N	110
6911	1979	57	6.2270000000000003	70.974999999999994	1.784	0.54070002	3.2999999999999998	0.25999999	\N	57
6912	1979	69	19.837	216.417	4.9899998	1.1605	4.2999999999999998	0.76999998	\N	69
6913	1979	84	19.420000000000002	214.09399999999999	4.941	1.3355	3.7000000000000002	1.05	\N	84
6914	1979	98	15.696999999999999	197.15199999999999	5.0079999	1.3534	3.7000000000000002	1.04	\N	98
6915	1979	114	14.288	204.535	5.3449998	1.2727	4.2000000000000002	0.77999997	\N	114
6908	1978	76	13.004	107.758	2.2679999	0.83999997	2.7000000000000002	0.63999999	\N	76
6909	1978	91	11.169	101.57899999999999	2.2850001	0.87900001	2.6000000000000001	0.72000003	\N	91
6910	1978	105	10.739000000000001	101.48699999999999	2.427	0.93360001	2.6000000000000001	0.72000003	\N	105
6904	1977	61	3.214	30.890999999999998	0.884	0.44190001	2	0.40000001	\N	61
6905	1977	76	12.83	66.712999999999994	2.3069999	0.88709998	2.6000000000000001	0.63999999	\N	76
6906	1977	81	12.112	71.611000000000004	2.4230001	0.96920002	2.5	0.87	\N	81
6907	1977	106	10.563000000000001	78.793000000000006	2.563	0.98589998	2.6000000000000001	0.75999999	\N	106
6899	1976	60	6.7080000000000002	52.682000000000002	1.41	0.56389999	2.5	0.40000001	\N	60
6900	1976	71	11.612	89.358999999999995	2.474	0.88370001	2.7999999999999998	0.70999998	\N	71
6901	1976	83	16.395	94.057000000000002	2.556	0.98299998	2.6000000000000001	0.73000002	\N	83
6902	1976	95	12.672000000000001	85.769000000000005	2.6630001	1.0244	2.6000000000000001	0.81999999	\N	95
6903	1976	107	14.140000000000001	91.847999999999999	2.779	0.99260002	2.7999999999999998	0.73000002	\N	107
6894	1975	56	9.6129999999999995	9.6129999999999995	2.506	0.83520001	3	0.58999997	\N	56
6895	1975	69	25.071000000000002	25.071000000000002	4.3610001	1.0903	4	0.75	\N	69
6896	1975	85	22.268000000000001	22.268000000000001	4.4990001	1.216	3.7000000000000002	0.93000001	\N	85
6897	1975	99	11.818	11.818	4.7290001	1.2781	3.7000000000000002	0.95999998	\N	99
6898	1975	114	8.2720000000000002	8.2720000000000002	4.5869999	1.1468	4	0.83999997	\N	114
6890	1974	57	4.1349999999999998	13.808	2.1500001	0.56580001	3.7999999999999998	0.30000001	\N	57
6891	1974	74	10.866	32.488	3.803	1.0565	3.6000000000000001	0.69999999	\N	74
6892	1974	89	9.2639999999999993	44.414000000000001	4	1.1765	3.3999999999999999	0.82999998	\N	89
6893	1974	110	5.5620000000000003	33.610999999999997	3.882	1.0491	3.7000000000000002	0.80000001	\N	110
6885	1973	66	14.715	90.370999999999995	3.3399999	0.92790002	3.6000000000000001	0.54000002	\N	66
6886	1973	76	15.472	92.186000000000007	3.8789999	1.1754	3.2999999999999998	0.81	\N	76
6887	1973	86	15.484	93.903000000000006	3.839	1.1996	3.2000000000000002	0.88999999	\N	86
6888	1973	97	13.789999999999999	105.69199999999999	3.799	1.2254	3.1000000000000001	0.77999997	\N	97
6889	1973	106	11.352	101.146	3.977	1.2427	3.2000000000000002	0.77999997	\N	106
6935	1986	49	43.261000000000003	372.45400000000001	7.1599998	1.2786	5.5999999999999996	0.66000003	\N	49
6936	1986	69	131.006	479.71699999999998	9.7700005	1.5757999	6.2000000000000002	1.2	\N	69
6937	1986	89	54.899999999999999	393.34500000000003	10.021	1.6428	6.0999999999999996	1.3	\N	89
6938	1986	119	27.177	371.149	7.006	1.251	5.5999999999999996	0.63	\N	119
6939	1986	139	6.6399999999999997	87.269000000000005	1.747	0.48519999	3.6000000000000001	0.33000001	\N	139
6880	1971	68	12.307	62.174999999999997	2.868	0.89609998	3.2000000000000002	0.62	\N	68
6881	1971	79	19.594999999999999	84.849999999999994	3.2690001	1.0216	3.2000000000000002	0.74000001	\N	79
6882	1971	90	24.117000000000001	103.551	3.402	1.1339999	3	0.80000001	\N	90
6883	1971	101	14.237	71.873000000000005	3.543	1.1808	3	0.81	\N	101
6884	1971	112	7.8760000000000003	54.393000000000001	3.434	1.1445	3	0.77999997	\N	112
6876	1970	66	153.05500000000001	1048.73	10.058	1.6223	6.2000000000000002	0.99000001	\N	66
6877	1970	81	180.63999999999999	1316.2159999999999	10.055	1.6759	6	1.27	\N	81
6878	1970	96	116.598	958.00300000000004	10.249	1.7082	6	1.5	\N	96
6879	1970	121	98.947999999999993	934.23000000000002	10.856	1.7509	6.2000000000000002	1.41	\N	121
6872	1969	54	36.061999999999998	165.98500000000001	7.4749999	1.3348	5.5999999999999996	0.69999999	\N	54
6873	1969	77	67.659999999999997	285.02100000000002	8.4259996	1.5604	5.4000000000000004	1.0599999	\N	77
6874	1969	92	41.136000000000003	282.58999999999997	8.6780005	1.607	5.4000000000000004	0.99000001	\N	92
6875	1969	107	31.529	220.78800000000001	7.9000001	1.5799	5	1.2	\N	107
6867	1968	69	4.5510000000000002	48.345999999999997	6.0640001	1.2632999	4.7999999999999998	0.88999999	\N	69
6868	1968	79	35.865000000000002	72.588999999999999	6.5650001	1.3968	4.7000000000000002	0.74000001	\N	79
6869	1968	89	76.941999999999993	179.92599999999999	6.7870002	1.4141001	4.7999999999999998	0.80000001	\N	89
6870	1968	101	11.089	83.251000000000005	7.098	1.4788001	4.7999999999999998	0.86000001	\N	101
6871	1968	121	0.95799999999999996	95.558000000000007	6.0380001	1.2075	5	0.34999999	\N	121
6863	1967	52	4.8760000000000003	84.540999999999997	1.53	0.63739997	2.3999999999999999	0.40000001	\N	52
6864	1967	69	19.427	261.10899999999998	5.2519999	1.3131	4	0.95999998	\N	69
6865	1967	93	16.629999999999999	253.054	5.2870002	1.4288	3.7000000000000002	1.14	\N	93
6866	1967	111	13.73	342.03199999999998	6.6110001	1.7866	3.7000000000000002	0.98000002	\N	111
6858	1966	56	10.253	174.84200000000001	2.944	0.84119999	3.5	0.50999999	\N	56
6859	1966	67	27.228999999999999	373.49299999999999	6.388	1.3036	4.9000000000000004	0.86000001	\N	67
6860	1966	83	52.923000000000002	442.08499999999998	6.9349999	1.4449	4.7999999999999998	0.88999999	\N	83
6861	1966	98	26.645	401.42899999999997	7.921	1.5232	5.2000000000000002	1.01	\N	98
6862	1966	114	24.399999999999999	347.983	7.1890001	1.4096	5.0999999999999996	0.83999997	\N	114
6855	1965	58	6.8689999999999998	54.807000000000002	4.598	1.0218	4.5	0.73000002	\N	58
6856	1965	88	7.8940000000000001	75.015000000000001	6.6100001	1.5023	4.4000000000000004	1.26	\N	88
6857	1965	117	3.387	71.290999999999997	5.0159998	1.2539999	4	0.94	\N	117
13101	9647	30	43.433	347.209	8.9650002	1.63	5.5	1.191	\N	60
13102	9647	45	71.978999999999999	337.51999999999998	7.73	1.5157	5.0999999999999996	1.085	\N	75
13103	9647	60	113.262	413.37700000000001	7.9239998	1.5238	5.2000000000000002	1.355	\N	90
13104	9647	70	183.89099999999999	471.03100000000001	8.0469999	1.4632	5.5	1.327	\N	100
13105	9647	80	133.464	481.983	8.8649998	1.5553	5.7000000000000002	1.08	\N	110
12296	9201	26	1.4319999999999999	13.747	1.396	0.60699999	2.2999999999999998	0.25	\N	66
12297	9201	46	2.339	17.353999999999999	1.876	0.85259998	2.2000000000000002	0.77100003	\N	86
12298	9201	66	2.1989999999999998	18.692	2.2309999	0.89249998	2.5	0.74400002	\N	106
12299	9201	76	2.4620000000000002	17.338000000000001	2.1389999	0.85579997	2.5	0.59200001	\N	116
12300	9201	86	4.859	17.992000000000001	2.2119999	0.85089999	2.6000000000000001	0.58399999	\N	126
12190	9141	16	4.6639999999999997	78.051000000000002	3.2060001	1.0686001	3	0.92500001	\N	56
12189	9141	25	24.347000000000001	163.96799999999999	6.9629998	1.3926001	5	1.066	\N	65
12188	9141	45	31.268999999999998	186.62799999999999	6.7979999	1.3595999	5	0.417	\N	85
12187	9141	55	32.808999999999997	174.94800000000001	6.7649999	1.353	5	0.97600001	\N	95
12186	9141	85	163.87100000000001	306.91000000000003	6.4759998	1.2454	5.2000000000000002	1.017	\N	125
11353	7861	33	5.4089999999999998	51.781999999999996	3.2539999	1.0496	3.1000000000000001	0.81900001	\N	53
11352	7861	43	3.105	40.831000000000003	3.23	1.1137	2.8999999999999999	0.86400002	\N	63
11351	7861	52	3.7869999999999999	42.566000000000003	3.349	1.1162	3	0.90799999	\N	72
11350	7861	73	4.1820000000000004	43.914000000000001	3.4130001	1.0664999	3.2000000000000002	0.79400003	\N	93
11349	7861	93	12.864000000000001	53.668999999999997	3.6730001	1.0495	3.5	0.82599998	\N	113
11348	7841	26	6.1959999999999997	100.852	4.572	1.27	3.6000000000000001	0.96600002	\N	51
11347	7841	36	10.429	139.93299999999999	6.2179999	1.4461	4.2999999999999998	1.034	\N	61
11346	7841	46	13.753	155.81299999999999	6.316	1.5039001	4.2000000000000002	1.245	\N	71
11345	7841	56	25.533999999999999	160.31899999999999	6.0869999	1.4847	4.0999999999999996	1.288	\N	81
11344	7841	96	137.14699999999999	266.13099999999997	6.441	1.4313999	4.5	1.228	\N	121
11385	8441	31	2.3540000000000001	28.895	2.497	0.9249	2.7000000000000002	0.76099998	\N	61
11384	8441	41	2.1360000000000001	25.893999999999998	2.4260001	0.93309999	2.6000000000000001	0.70700002	\N	71
11383	8441	51	4.1989999999999998	25.388999999999999	2.171	0.86849999	2.5	0.667	\N	81
11382	8441	71	4.5750000000000002	28.805	2.5309999	0.87279999	2.8999999999999999	0.71700001	\N	101
11381	8441	91	7.8140000000000001	39.631999999999998	2.9579999	0.92439997	3.2000000000000002	0.66900003	\N	121
11390	8442	30	0.81399999999999995	9.3989999999999991	2.154	0.9364	2.2999999999999998	0.73699999	\N	60
11389	8442	40	0.90100000000000002	9.1199999999999992	2.0710001	0.94150001	2.2000000000000002	0.671	\N	70
11388	8442	51	0.89900000000000002	9.5800000000000001	1.975	0.89770001	2.2000000000000002	0.73100001	\N	81
11387	8442	80	3.8879999999999999	20.503	2.431	0.86830002	2.7999999999999998	0.667	\N	110
11386	8442	90	4.665	20.707000000000001	1.957	0.85079998	2.2999999999999998	0.65399998	\N	120
11011	7021	37	6.5890000000000004	97.823999999999998	3.675	1.2249	3	0.889	\N	57
11010	7021	47	8.3559999999999999	104.214	3.4389999	1.2283	2.7999999999999998	0.97600001	\N	67
11009	7021	57	11.544	106.44	3.473	1.1576999	3	0.80000001	\N	77
11008	7021	88	47.640999999999998	155.11699999999999	3.536	1.04	3.3999999999999999	0.72899997	\N	108
11007	7021	98	18.893999999999998	118.90900000000001	3.5209999	1.006	3.5	0.69099998	\N	118
10687	7003	28	4.6219999999999999	36.869999999999997	1.757	0.76389998	2.2999999999999998	0.55000001	\N	68
10686	7003	47	6.8200000000000003	40.859999999999999	2.1059999	0.9156	2.2999999999999998	0.74000001	\N	87
10685	7003	58	3.1459999999999999	30.399000000000001	1.955	0.93089998	2.1000000000000001	0.76999998	\N	98
10684	7003	67	4.399	35.476999999999997	2.0869999	0.9073	2.2999999999999998	0.72000003	\N	107
10683	7003	88	28.443000000000001	61.795999999999999	2.279	0.78579998	2.8999999999999999	0.63	\N	128
10682	7001	82	12.776	57.194000000000003	3.5090001	1.0026	3.5	0.50999999	\N	112
10681	7001	92	21.988	65.173000000000002	3.335	0.95270002	3.5	0.68000001	\N	122
\.


--
-- Data for Name: sohlprobe; Type: TABLE DATA; Schema: public; Owner: -
--

COPY sohlprobe (sohlprobeid, sohltestid, probenahmeartid, tiefevon, tiefebis, beschreibung, lastupdated) FROM stdin;
54	61	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
55	62	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
56	63	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
57	65	2	0	0.20000000000000001	105 m rechts	2006-10-06 13:40:00
58	66	2	0	0.20000000000000001	105 m rechts	2006-10-06 13:40:00
59	67	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
60	68	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
61	69	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
62	70	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
63	71	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
64	72	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
65	73	2	0	0.20000000000000001	125 m rechts = mitte	2006-10-06 13:40:00
66	74	2	0	0.20000000000000001	165 m rechts	2006-10-06 13:40:00
67	75	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
68	76	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
69	77	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
70	78	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
71	79	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
72	80	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
73	81	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
74	82	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
75	83	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
76	84	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
77	85	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
78	86	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
79	87	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
80	88	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
81	89	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
82	90	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
83	91	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
84	93	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
85	94	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
86	95	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
87	97	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
88	98	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
89	99	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
90	100	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
91	101	2	0	0.20000000000000001	toniges Sohlmaterial bei Belgern	2006-10-06 13:40:00
92	102	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
93	103	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
94	104	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
95	105	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
96	106	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
97	107	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
98	108	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
99	109	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
100	110	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
101	111	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
102	112	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
103	113	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
104	114	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
105	115	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
106	116	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
107	117	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
108	118	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
109	119	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
110	120	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
111	121	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
112	122	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
113	123	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
114	124	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
115	125	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
116	126	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
117	127	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
118	128	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
119	129	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
120	130	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
121	131	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
122	132	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
123	133	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
124	134	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
125	135	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
126	136	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
127	137	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
128	138	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
129	139	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
130	140	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
131	141	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
132	142	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
133	143	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
134	144	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
135	145	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
136	146	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
137	148	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
138	149	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
139	150	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
140	151	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
141	152	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
142	153	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
143	154	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
144	155	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
145	156	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
146	157	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
147	158	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
148	159	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
149	160	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
150	161	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
151	162	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
152	163	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
153	164	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
154	165	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
155	166	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
156	167	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
157	168	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
158	169	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
159	170	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
160	171	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
161	172	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
162	173	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
163	174	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
164	175	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
165	176	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
166	177	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
167	178	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
168	180	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
169	181	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
170	182	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
171	183	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
172	184	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
173	185	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
174	186	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
175	187	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
176	188	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
177	189	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
178	190	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
179	191	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
180	192	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
181	193	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
182	194	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
183	195	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
184	196	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
185	197	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
186	198	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
187	199	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
188	200	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
189	201	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
190	202	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
191	203	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
192	204	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
193	205	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
194	206	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
195	207	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
196	208	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
197	209	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
198	210	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
199	211	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
200	212	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
201	213	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
202	214	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
203	215	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
204	216	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
205	217	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
206	218	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
207	219	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
208	220	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
209	221	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
210	222	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
211	223	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
212	224	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
213	225	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
214	226	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
215	227	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
216	228	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
217	229	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
218	230	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
219	231	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
220	232	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
221	233	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
222	234	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
223	235	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
224	236	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
225	237	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
226	238	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
227	239	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
228	240	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
229	241	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
230	242	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
231	243	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
232	244	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
233	245	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
234	246	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
235	247	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
236	248	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
237	249	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
238	250	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
239	251	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
240	252	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
241	253	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
242	254	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
243	255	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
244	256	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
245	257	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
246	258	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
247	259	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
248	260	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
249	261	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
250	262	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
251	263	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
252	264	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
253	265	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
254	266	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
255	267	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
256	268	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
257	269	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
258	270	2	0	0.20000000000000001	112 m rechts = links	2006-10-06 13:40:00
259	271	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
260	272	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
261	273	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
262	274	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
263	275	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
264	276	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
265	277	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
266	278	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
267	279	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
268	280	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
269	281	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
270	282	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
271	283	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
272	284	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
273	285	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
274	286	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
275	287	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
276	288	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
277	289	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
278	290	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
279	291	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
280	292	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
281	293	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
282	294	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
283	295	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
284	296	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
285	297	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
286	298	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
287	299	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
288	300	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
289	301	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
290	302	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
291	303	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
292	304	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
293	305	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
294	306	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
295	307	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
296	308	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
297	309	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
298	310	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
299	311	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
300	312	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
301	313	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
302	314	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
303	315	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
304	316	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
305	317	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
306	318	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
307	319	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
308	320	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
309	321	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
310	322	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
311	323	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
312	324	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
313	325	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
314	326	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
315	327	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
316	328	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
317	329	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
318	330	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
319	331	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
320	332	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
321	333	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
322	334	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
323	335	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
324	336	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
325	337	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
326	338	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
327	339	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
328	340	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
329	341	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
330	342	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
331	343	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
332	344	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
333	345	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
334	346	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
335	347	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
336	348	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
337	349	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
338	350	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
339	353	2	0	0.20000000000000001	60 m re = rechts	2006-10-06 13:40:00
340	354	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
341	357	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
342	358	2	0	0.20000000000000001	\N	2006-10-06 13:40:00
343	359	2	0	0.20000000000000001	112 m vom rechten Ufer	2006-10-06 13:40:00
344	360	2	0	0.20000000000000001	150 m re = links	2006-10-06 13:40:00
345	361	2	0	0.20000000000000001	200 m re = links	2006-10-06 13:40:00
346	362	2	0	0.20000000000000001	110 m re = rechts	2006-10-06 13:40:00
1110	1062	2	0	0.10000000000000001	Grobkies, wenig Steine	2007-11-15 15:17:36
1111	1062	2	0.10000000000000001	0.29999999999999999	Kies, schwach sandig	2007-11-15 15:17:36
1112	1063	2	0	0.10000000000000001	Kies und Steine	2007-11-15 15:17:36
1113	1063	2	0.10000000000000001	0.29999999999999999	Kies, sandig	2007-11-15 15:17:36
1114	1064	2	0	0.10000000000000001	Grobkies, mittelkiesig, schwach sandig	2007-11-15 15:17:36
1115	1064	2	0.10000000000000001	0.29999999999999999	Kies, sandig	2007-11-15 15:17:36
1116	1065	2	0	0.10000000000000001	Grobkies, mittelkiesig, wenig Steine	2007-11-15 15:17:36
1117	1065	2	0.10000000000000001	0.29999999999999999	Kies, sandig	2007-11-15 15:17:36
1118	1066	2	0	0.10000000000000001	Grobkies, mittelkiesig, wenig Steine	2007-11-15 15:17:36
1119	1066	2	0.10000000000000001	0.29999999999999999	Kies, schwach sandig	2007-11-15 15:17:36
1120	1067	2	0	0.10000000000000001	Grobkies, steinig	2007-11-15 15:17:36
1121	1067	2	0.10000000000000001	0.29999999999999999	Kies, sandig	2007-11-15 15:17:36
1122	1068	2	0	0.10000000000000001	Steine und Blöcke (Buhnen, keine Probe)	2007-11-21 13:48:18
1123	1068	2	0.10000000000000001	0.29999999999999999	Grobkies, mittelkiesig, schwach sandig	2007-11-15 15:17:36
1124	1069	2	0	0.10000000000000001	Grobkies, mittelkiesig, sandig (evtl. Geschiebe)	2007-11-15 15:17:36
1125	1069	2	0.10000000000000001	0.29999999999999999	Grobkies, mittel- und feinkiesig, sandig	2007-11-15 15:17:36
1126	1070	2	0	0.10000000000000001	Grobkies und Steine (leichter organischer Überzug)	2007-11-21 13:48:18
1127	1070	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein), schwach sandig	2007-11-15 15:17:36
1128	1071	2	0	0.10000000000000001	Grobkies, mittelkiesig	2007-11-15 15:17:36
1129	1071	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel), schwach feinkiesig, schwach sandig	2007-11-15 15:17:36
1130	1072	2	0	0.10000000000000001	Steine und Blöcke, grobkiesig	2007-11-21 13:48:18
1131	1072	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein), sandig	2007-11-15 15:17:36
1132	1073	2	0	0.10000000000000001	Kies (grob, mittel, fein)	2007-11-15 15:17:36
1133	1073	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein), schwach sandig	2007-11-15 15:17:36
1134	1074	2	0	0.10000000000000001	Steine und Blöcke, grobkiesig	2007-11-21 13:48:18
1135	1074	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein), schwach sandig	2007-11-15 15:17:36
1136	1075	2	0	0.10000000000000001	Grobkies, mittel- und feinkiesig	2007-11-15 15:17:36
1137	1075	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein), schwach sandig	2007-11-15 15:17:36
1138	1076	2	0	0.10000000000000001	Steine und Blöcke, grobkiesig (leichter organischer Überzug)	2007-11-21 13:48:18
1139	1076	2	0.10000000000000001	0.29999999999999999	Grobkies, mittel- und feinkiesig	2007-11-15 15:17:36
1140	1077	2	0	0.10000000000000001	Grobkies	2007-11-15 15:17:36
1141	1077	2	0.10000000000000001	0.29999999999999999	Grobkies, schwach mittelkiesig	2007-11-15 15:17:36
1142	1078	2	0	0.10000000000000001	Kies (grob, mittel, fein), stark sandig	2007-11-15 15:17:36
1143	1078	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein), stark sandig	2007-11-15 15:17:36
1144	1079	2	0	0.10000000000000001	Grobkies, mittel- und feinkiesig, schwach sandig	2007-11-15 15:17:36
1145	1079	2	0.10000000000000001	0.29999999999999999	Grobkies, mittel- und feinkiesig, sandig	2007-11-15 15:17:36
1146	1080	2	0	0.10000000000000001	Mittel- und Feinkies, schwach grobkiesig	2007-11-15 15:17:36
1147	1080	2	0.10000000000000001	0.29999999999999999	Mittel- und Feinkies, schwach grobkiesig	2007-11-15 15:17:36
1148	1081	2	0	0.10000000000000001	Grobkies, sandig	2007-11-15 15:17:36
1149	1081	2	0.10000000000000001	0.29999999999999999	Kies und Sand	2007-11-15 15:17:36
1150	1082	2	0	0.10000000000000001	Mittel- und Feinkies, schwach sandig	2007-11-15 15:17:36
1151	1082	2	0.10000000000000001	0.29999999999999999	Feinkies, mittelkiesig, sandig	2007-11-15 15:17:36
1152	1083	2	0	0.10000000000000001	Mittel- und Feinkies, grobkiesig	2007-11-15 15:17:36
1153	1083	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein)	2007-11-15 15:17:36
1154	1084	2	0	0.10000000000000001	Kies, sandig (Düne -> Geschiebe)	2007-11-21 13:48:18
1155	1084	2	0.10000000000000001	0.29999999999999999	Kies und Sand	2007-11-15 15:17:36
1156	1085	2	0	0.10000000000000001	Grobkies, mittel- und feinkiesig, schwach sandig	2007-11-15 15:17:36
1157	1085	2	0.10000000000000001	0.29999999999999999	Grobkies, mittel- und feinkiesig, schwach sandig	2007-11-15 15:17:36
1158	1086	2	0	0.10000000000000001	Kies (grob, mittel, fein), sandig (schwache Düne)	2007-11-21 13:48:18
1159	1086	2	0.10000000000000001	0.29999999999999999	Kies, schwach sandig	2007-11-15 15:17:36
1160	1087	2	0	0.10000000000000001	Kies (grob, mittel, fein), sandig (Düne -> Geschiebe)	2007-11-21 13:48:18
1161	1087	2	0.10000000000000001	0.29999999999999999	Kies, schwach sandig	2007-11-15 15:17:36
1162	1088	2	0	0.10000000000000001	Grobkies	2007-11-15 15:17:36
1163	1088	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein), schwach sandig	2007-11-15 15:17:36
1164	1089	2	0	0.10000000000000001	Grobkies und Steine, schwach mittelkiesig (leichter organischer Überzug)	2007-11-21 13:48:18
1165	1089	2	0.10000000000000001	0.29999999999999999	Grobkies, mittel- und feinkiesig, schwach steinig	2007-11-15 15:17:36
1166	1090	2	0	0.10000000000000001	Grobsand, kiesig, mittelsandig (schwache Düne ?)	2007-11-21 13:48:19
1167	1090	2	0.10000000000000001	0.29999999999999999	Grobsand und Feinkies, mittelkiesig	2007-11-15 15:17:36
1168	1091	2	0	0.10000000000000001	Kies (fein, mittel), stark sandig	2007-11-15 15:17:36
1169	1091	2	0.10000000000000001	0.29999999999999999	Kies (fein, mittel), stark sandig	2007-11-15 15:17:36
1170	1092	2	0	0.10000000000000001	Kies (grob, mittel), feinkiesig, sandig	2007-11-15 15:17:36
1171	1092	2	0.10000000000000001	0.29999999999999999	Mittelkies, schwach grobkiesig, feinkiesig, sandig	2007-11-15 15:17:36
1172	1093	2	0	0.10000000000000001	Steine und Grobkies	2007-11-15 15:17:36
1173	1093	2	0.10000000000000001	0.29999999999999999	Kies, sandig	2007-11-15 15:17:36
1174	1094	2	0	0.10000000000000001	Sohlschwelle: Wasserbausteine mit organischem Überzug, darunter Grobkies	2007-11-21 13:48:19
1175	1094	2	0.10000000000000001	0.29999999999999999	Grobkies	2007-11-15 15:17:36
1176	1095	2	0	0.10000000000000001	Sand, schwach kiesig (Düne -> Geschiebe)	2007-11-21 13:48:19
1177	1095	2	0.10000000000000001	0.29999999999999999	Kies, sandig	2007-11-15 15:17:36
1178	1096	2	0	0.10000000000000001	Sand, kiesig (evtl. Düne, stark mit Sohle durchmischt)	2007-11-21 13:48:19
1179	1096	2	0.10000000000000001	0.29999999999999999	Kies, stark sandig	2007-11-15 15:17:36
1180	1097	2	0	0.10000000000000001	Mittel- und Feinkies	2007-11-15 15:17:36
1181	1097	2	0.10000000000000001	0.29999999999999999	Mittel- und Feinkies	2007-11-15 15:17:36
1182	1098	2	0	0.10000000000000001	Sand, schwach kiesig	2007-11-15 15:17:36
1183	1098	2	0.10000000000000001	0.29999999999999999	Sand, schwach kiesig	2007-11-15 15:17:36
1184	1099	2	0	0.10000000000000001	Sand und Kies (mittel, fein), schwach grobkiesig	2007-11-15 15:17:36
1185	1099	2	0.10000000000000001	0.29999999999999999	Sand und Kies (mittel, fein), schwach grobkiesig	2007-11-15 15:17:36
1186	1100	2	0	0.10000000000000001	Mittel- und Feinkies, schwach sandig	2007-11-15 15:17:36
1187	1100	2	0.10000000000000001	0.29999999999999999	Mittel- und Feinkies, schwach sandig	2007-11-15 15:17:36
1188	1101	2	0	0.10000000000000001	Steine (evtl. Wasserbausteine, organischer Überzug) und Kies	2007-11-21 13:48:19
1189	1101	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein), sandig	2007-11-15 15:17:36
1190	1102	2	0	0.10000000000000001	Kies (grob, mittel, fein), sandig (Düne -> Geschiebe)	2007-11-21 13:48:19
1191	1102	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein), schwach sandig	2007-11-15 15:17:36
1192	1103	2	0	0.10000000000000001	Mittel- und Feinkies, sandig	2007-11-15 15:17:36
1193	1103	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein), sandig	2007-11-15 15:17:36
1194	1104	2	0	0.10000000000000001	Grobkies, schwach steinig (kein organischer Überzug), sandige Düne -> Geschiebe	2007-11-21 13:48:19
1195	1104	2	0.10000000000000001	0.29999999999999999	Grobkies, mittel- und feinkiesig, schwach sandig	2007-11-15 15:17:36
1196	1105	2	0	0.10000000000000001	Grobkies, schwach mittel- und feinkiesig, schwach sandig (Düne schwach zu erkennen, keine Probe der Düne)	2007-11-21 13:48:19
1197	1105	2	0.10000000000000001	0.29999999999999999	Sand, stark kiesig	2007-11-15 15:17:37
1198	1106	2	0	0.10000000000000001	Grobkies, schwach mittel- und feinkiesig	2007-11-15 15:17:37
1199	1106	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein)	2007-11-15 15:17:37
1200	1107	2	0	0.10000000000000001	Kies und Sand (sandige Düne -> Geschiebe)	2007-11-21 13:48:19
1201	1107	2	0.10000000000000001	0.29999999999999999	Grobkies, mittel- und feinkiesig, stark sandig	2007-11-15 15:17:37
1202	1108	2	0	0.10000000000000001	Kies und Sand (sandige Düne -> Geschiebe)	2007-11-21 13:48:19
1203	1108	2	0.10000000000000001	0.29999999999999999	Kies, schwach sandig	2007-11-15 15:17:37
1204	1109	2	0	0.10000000000000001	Mittel- und Feinkies, schwach grobkiesig, schwach sandig	2007-11-15 15:17:37
1205	1109	2	0.10000000000000001	0.29999999999999999	Kies, schwach sandig	2007-11-15 15:17:37
1206	1110	2	0	0.10000000000000001	Mittel- und Feinkies, stark grobkiesig	2007-11-15 15:17:37
1207	1110	2	0.10000000000000001	0.29999999999999999	Kies, schwach sandig	2007-11-15 15:17:37
1208	1111	2	0	0.10000000000000001	Grobkies, mittel- und feinkiesig, sandig (schwache Düne, keine Probe)	2007-11-21 13:48:19
1209	1111	2	0.10000000000000001	0.29999999999999999	Kies und Sand	2007-11-15 15:17:37
1210	1112	2	0	0.10000000000000001	Kies und Sand (mächtige Düne > 20 cm)	2007-11-21 13:48:19
1211	1112	2	0.10000000000000001	0.29999999999999999	Grobkies, mittel- und feinkiesig, sandig	2007-11-15 15:17:37
1212	1113	2	0	0.10000000000000001	Kies und Sand	2007-11-15 15:17:37
1213	1113	2	0.10000000000000001	0.29999999999999999	Kies, sandig	2007-11-15 15:17:37
1214	1114	2	0	0.10000000000000001	Mittel- und Feinkies, Sand	2007-11-15 15:17:37
1215	1114	2	0.10000000000000001	0.29999999999999999	Mittel- und Feinkies, sandig	2007-11-15 15:17:37
1216	1115	2	0	0.10000000000000001	Sand, feinkiesig	2007-11-15 15:17:37
1217	1115	2	0.10000000000000001	0.29999999999999999	Sand, feinkiesig	2007-11-15 15:17:37
1218	1116	2	0	0.10000000000000001	Sand, feinkiesig	2007-11-15 15:17:37
1219	1116	2	0.10000000000000001	0.29999999999999999	Sand, feinkiesig, schwach mittelkiesig	2007-11-15 15:17:37
1220	1117	2	0	0.10000000000000001	Mittel- und Feinkies, schwach sandig	2007-11-15 15:17:37
1221	1117	2	0.10000000000000001	0.29999999999999999	Mittel- und Feinkies, schwach sandig	2007-11-15 15:17:37
1222	1118	2	0	0.10000000000000001	Grobkies, mittelkiesig, schwach feinkiesig, schwach sandig	2007-11-15 15:17:37
1223	1118	2	0.10000000000000001	0.29999999999999999	Grobkies, mittel- und feinkiesig, schwach sandig	2007-11-15 15:17:37
1224	1119	2	0	0.10000000000000001	Kies (grob, mittel, fein), sandig	2007-11-15 15:17:37
1225	1119	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein), schwach sandig	2007-11-15 15:17:37
1226	1120	2	0	0.10000000000000001	Kies, stark sandig	2007-11-15 15:17:37
1227	1120	2	0.10000000000000001	0.29999999999999999	Mittel und Feinkies, stark sandig	2007-11-15 15:17:37
1228	1121	2	0	0.10000000000000001	Mittelkies, feinkiesig, sandig	2007-11-15 15:17:37
1229	1121	2	0.10000000000000001	0.29999999999999999	Mittel- und Feinkies, stark sandig	2007-11-15 15:17:37
1230	1122	2	0	0.10000000000000001	Feinkies und Sand, schwach mittelkiesig	2007-11-15 15:17:37
1231	1122	2	0.10000000000000001	0.29999999999999999	Mittel- und Feinkies, sandig	2007-11-15 15:17:37
1232	1123	2	0	0.10000000000000001	Mittel- und Feinkies, sandig	2007-11-15 15:17:37
1233	1123	2	0.10000000000000001	0.29999999999999999	Mittel- und Feinkies, sandig	2007-11-15 15:17:37
1234	1124	2	0	0.10000000000000001	Grobkies, mittel- und feinkiesig, sandig, Wasserbausteine mit organischem Überzug (HW-Schaden?)	2007-11-21 13:48:19
1235	1124	2	0.10000000000000001	0.29999999999999999	Sand, grob- und mittelkiesig, schwach feinkiesig	2007-11-15 15:17:37
1236	1125	2	0	0.10000000000000001	Grobkies + Sand, mittelkiesig	2007-11-15 15:17:37
1237	1125	2	0.10000000000000001	0.29999999999999999	Grob- u. Mittelkies, sandig	2007-11-15 15:17:37
1238	1126	2	0	0.10000000000000001	Sand und Grobkies, mittelkiesig	2007-11-15 15:17:37
1239	1126	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein), sandig	2007-11-15 15:17:37
1240	1127	2	0	0.10000000000000001	Sand, grob- und mittelkiesig	2007-11-15 15:17:37
1241	1127	2	0.10000000000000001	0.29999999999999999	Grobkies, mittel- und feinkiesig, sandig	2007-11-15 15:17:37
1242	1128	2	0	0.10000000000000001	Mittel- u. Feinkies, sandig, schwach grobkiesig	2007-11-15 15:17:37
1243	1128	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies, schwach sandig, schwach grobkiesig	2007-11-15 15:17:37
1244	1129	2	0	0.10000000000000001	Sand, mittelkiesig u. feinkiesig	2007-11-15 15:17:37
1245	1129	2	0.10000000000000001	0.29999999999999999	Grob- u. Mittelkies, sandig	2007-11-15 15:17:37
1246	1130	2	0	0.10000000000000001	Grob- und Mittelkies, sandig	2007-11-15 15:17:37
1247	1130	2	0.10000000000000001	0.29999999999999999	Grob- u. Mittelkies, sandig	2007-11-15 15:17:37
1248	1131	2	0	0.10000000000000001	Kies (grob, mittel, fein), schwach sandig	2007-11-15 15:17:37
1249	1131	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies, schwach sandig, schwach grobkiesig	2007-11-15 15:17:37
1250	1132	2	0	0.10000000000000001	Mittel- u. Feinkies, sandig, schwach grobkiesig schwache Düne	2007-11-21 13:48:19
1251	1132	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies, schwach sandig, schwach grobkiesig	2007-11-15 15:17:37
1252	1133	2	0	0.10000000000000001	Mittel- u. Feinkies, stark sandig Düne (ca. 10 - 15 cm)	2007-11-21 13:48:19
1253	1133	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies, stark sandig	2007-11-15 15:17:37
1254	1134	2	0	0.10000000000000001	Sand, fein- u. mittelkiesig, schwach grobkiesig	2007-11-15 15:17:37
1255	1134	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies, schwach sandig	2007-11-15 15:17:37
1256	1135	2	0	0.10000000000000001	Feinkies, mittelkiesig, sandig, schwach grobkiesig	2007-11-15 15:17:37
1257	1135	2	0.10000000000000001	0.29999999999999999	Feinkies, mittelkiesig, sandig	2007-11-15 15:17:37
1258	1136	2	0	0.10000000000000001	Grob- u. Mittelkies, feinkiesig	2007-11-15 15:17:37
1259	1136	2	0.10000000000000001	0.29999999999999999	Grob- u. Mittelkies, feinkiesig, schwach sandig	2007-11-15 15:17:37
1260	1137	2	0	0.10000000000000001	Sand (vielleicht Düne)	2007-11-21 13:48:19
1261	1137	2	0.10000000000000001	0.29999999999999999	Sand, feinkiesig	2007-11-15 15:17:37
1262	1138	2	0	0.10000000000000001	Sand, feinkiesig Düne (ca. 5 -  10 cm)	2007-11-21 13:48:19
1263	1138	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies, sandig	2007-11-15 15:17:37
1264	1139	2	0	0.10000000000000001	Sand, mittel- u. feinkiesig	2007-11-15 15:17:37
1265	1139	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies, sandig, schwach grobkiesig	2007-11-15 15:17:37
1266	1140	2	0	0.10000000000000001	Mittel- u. Feinkies, sandig viel "Kohle" obendrauf	2007-11-15 15:17:37
1267	1140	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies, schwach sandig	2007-11-15 15:17:37
1268	1141	2	0	0.10000000000000001	Mittel- u. Feinkies, stark sandig	2007-11-15 15:17:37
1269	1141	2	0.10000000000000001	0.29999999999999999	Feinkies, schwach sandig u. mittelkiesig	2007-11-15 15:17:37
1270	1142	2	0	0.10000000000000001	Feinkies, sandig, schwach mittelkiesig	2007-11-15 15:17:37
1271	1142	2	0.10000000000000001	0.29999999999999999	Feinkies, sandig, mittelkiesig	2007-11-15 15:17:37
1272	1143	2	0	0.10000000000000001	Mittelkies, feinkiesig, schwach grobkiesig	2007-11-15 15:17:37
1273	1143	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies	2007-11-15 15:17:37
1274	1144	2	0	0.10000000000000001	Mittel- u. Feinkies, sandig, schwach grobkiesig	2007-11-15 15:17:37
1275	1144	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies	2007-11-15 15:17:37
1276	1145	2	0	0.10000000000000001	Sand, mittel- u. feinkiesig (evtl. Düne)	2007-11-21 13:48:19
1277	1145	2	0.10000000000000001	0.29999999999999999	Sand + Feinkies, mittelkiesig	2007-11-15 15:17:37
1278	1146	2	0	0.10000000000000001	Grobkies, steinig, mittelkiesig	2007-11-15 15:17:37
1279	1146	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies, schwach grobkiesig	2007-11-15 15:17:37
1280	1147	2	0	0.10000000000000001	Mittel- u. Feinkies, sandig	2007-11-15 15:17:37
1281	1147	2	0.10000000000000001	0.29999999999999999	Feinkies, sandig, schwach mittelkiesig	2007-11-15 15:17:37
1282	1148	2	0	0.10000000000000001	Mittelkies, feinkiesig	2007-11-15 15:17:37
1283	1148	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies	2007-11-15 15:17:37
1284	1149	2	0	0.10000000000000001	Feinkies, schwach mittelkiesig, schwach sandig	2007-11-15 15:17:37
1285	1149	2	0.10000000000000001	0.29999999999999999	Feinkies, mittelkiesig, sandig	2007-11-15 15:17:37
1286	1150	2	0	0.10000000000000001	Feinkies, sandig schwach Düne (<3 cm)	2007-11-21 13:48:19
1287	1150	2	0.10000000000000001	0.29999999999999999	Feinkies, sandig, schwach grobkiesig	2007-11-15 15:17:37
1288	1151	2	0	0.10000000000000001	Mittel- u. Feinkies, schwach sandig	2007-11-15 15:17:37
1289	1151	2	0.10000000000000001	0.29999999999999999	Feinkies, mittelkiesig, schwach sandig	2007-11-15 15:17:37
1290	1152	2	0	0.10000000000000001	Feinkies, sandig (evtl. Düne)	2007-11-21 13:48:19
1291	1152	2	0.10000000000000001	0.29999999999999999	Feinkies, sandig	2007-11-15 15:17:37
1292	1153	2	0	0.10000000000000001	Sand, feinkiesig	2007-11-15 15:17:37
1293	1153	2	0.10000000000000001	0.29999999999999999	Sand, feinkiesig, schwach mittelkiesig	2007-11-15 15:17:37
1294	1154	2	0	0.10000000000000001	Feinkies, mittelkiesig, schwach sandig	2007-11-15 15:17:37
1295	1154	2	0.10000000000000001	0.29999999999999999	Feinkies + Sand	2007-11-15 15:17:37
1296	1155	2	0	0.10000000000000001	Mittelkies, feinkiesig u. sandig, schwach grobkiesig	2007-11-15 15:17:37
1297	1155	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies, schwach sandig	2007-11-15 15:17:37
1298	1156	2	0	0.10000000000000001	Sand, feinkiesig	2007-11-15 15:17:37
1299	1156	2	0.10000000000000001	0.29999999999999999	Sand, schwach feinkiesig	2007-11-15 15:17:37
1300	1157	2	0	0.10000000000000001	Ton -> Sohle des Elbedurchstichs bei 250 oder Grundschwellen	2007-11-15 15:17:37
1301	1157	2	0.10000000000000001	0.29999999999999999	Ton -> Sohle des Elbedurchstichs bei 250 oder Grundschwellen	2007-11-15 15:17:37
1302	1158	2	0	0.10000000000000001	Feinkies, mittelkiesig, schwach sandig	2007-11-15 15:17:37
1303	1158	2	0.10000000000000001	0.29999999999999999	Feinkies, schwach sandig	2007-11-15 15:17:37
1304	1159	2	0	0.10000000000000001	Mittel- u. Feinkies, sandig evtl. schwache Düne (< 3 cm)	2007-11-21 13:48:19
1305	1159	2	0.10000000000000001	0.29999999999999999	Mittel- u. Feinkies, sandig	2007-11-15 15:17:37
1306	1160	2	0	0.10000000000000001	Feinkies, schwach mittelkiesig, sandig	2007-11-15 15:17:37
1307	1160	2	0.10000000000000001	0.29999999999999999	Feinkies, schwach mittelkiesig, sandig	2007-11-15 15:17:37
1308	1161	2	0	0.10000000000000001	Feinkies + Sand, schwach mitteklkiesig	2007-11-15 15:17:37
1309	1161	2	0.10000000000000001	0.29999999999999999	Feinkies, sandig	2007-11-15 15:17:37
1310	1162	2	0	0.10000000000000001	Steine, grobkiesig, sandig (Düne?)	2007-11-21 13:48:19
1311	1162	2	0.10000000000000001	0.29999999999999999	Grobkies, mittel- u. feinkiesig, schwach sandig	2007-11-15 15:17:37
1312	1163	2	0	0.10000000000000001	Feinkies + Sand	2007-11-15 15:17:37
1313	1163	2	0.10000000000000001	0.29999999999999999	Feinkies + Sand	2007-11-15 15:17:37
1314	1164	2	0	0.10000000000000001	Feinkies, Sand, schwach mittelkiesig	2007-11-15 15:17:37
1315	1164	2	0.10000000000000001	0.29999999999999999	Sand, feinkiesig	2007-11-15 15:17:37
1316	1165	2	0	0.10000000000000001	Feinkies, mittelkiesig	2007-11-15 15:17:37
1317	1165	2	0.10000000000000001	0.29999999999999999	Feinkies, schwach mittelkiesig, schwach sandig	2007-11-15 15:17:37
1336	1175	2	0	0.10000000000000001	Grobsand, feinkiesig, schwach mittelkiesig	2007-11-15 15:17:38
1337	1175	2	0.10000000000000001	0.29999999999999999	Grobsand, feinkiesig	2007-11-15 15:17:38
1338	1176	2	0	0.10000000000000001	Feinkies, mittelkiesig, schwach sandig	2007-11-15 15:17:38
1339	1176	2	0.10000000000000001	0.29999999999999999	Sand und Feinkies, schwach mittelkiesig	2007-11-15 15:17:38
1340	1177	2	0	0.10000000000000001	Sand und Feinkies	2007-11-15 15:17:38
1341	1177	2	0.10000000000000001	0.29999999999999999	Kies (grob, mittel, fein), sandig	2007-11-15 15:17:38
1342	1178	2	0	0.10000000000000001	Kies (grob, mittel, fein), schwach sandig	2007-11-15 15:17:38
1343	1178	2	0.10000000000000001	0.29999999999999999	Mittel- und Feinkies, grobkiesig	2007-11-15 15:17:38
1344	1179	2	0	0.10000000000000001	Sand, fein- und mittelkiesig	2007-11-15 15:17:38
1345	1179	2	0.10000000000000001	0.29999999999999999	Fein- und Mittelkies, schwach grobkiesig, schwach sandig	2007-11-15 15:17:38
1346	1180	2	0	0.10000000000000001	Feinkies und Mittelkies, sandig	2007-11-15 15:17:38
1347	1180	2	0.10000000000000001	0.29999999999999999	Feinkies und Grobsand, schwach mittelkiesig	2007-11-15 15:17:38
1348	1181	2	0	0.10000000000000001	Feinkies, mittelkiesig, sandig	2007-11-15 15:17:38
1349	1181	2	0.10000000000000001	0.29999999999999999	Feinkies, grobsandig, mittelkiesig	2007-11-15 15:17:38
1350	1182	2	0	0.10000000000000001	Deckschicht aus Steinen, darunter Kies und Sand	2007-11-15 15:17:38
1351	1182	2	0.10000000000000001	0.29999999999999999	Sand (dunkel), schwach kiesig	2007-11-15 15:17:38
17245	10003	2	\N	\N	keine Angaben	2008-03-05 15:04:20
17356	1084	2	\N	\N	D¿ne	2008-03-05 15:04:23
17357	1087	2	\N	\N	D¿ne	2008-03-05 15:04:23
17358	1095	2	\N	\N	D¿ne	2008-03-05 15:04:23
17359	1102	2	\N	\N	D¿ne	2008-03-05 15:04:23
17360	1104	2	\N	\N	D¿ne	2008-03-05 15:04:23
17361	1107	2	\N	\N	D¿ne	2008-03-05 15:04:23
17362	1112	2	\N	\N	D¿ne	2008-03-05 15:04:24
17363	1114	2	\N	\N	D¿ne	2008-03-05 15:04:24
17364	10055	2	0	0.10000000000000001	\N	2008-03-05 15:04:24
17365	10055	2	0.10000000000000001	0.29999999999999999	\N	2008-03-05 15:04:24
17366	1130	2	0.10000000000000001	0.10000000000000001	\N	2008-03-05 15:04:24
17367	1129	2	\N	\N	D¿ne	2008-03-05 15:04:24
17368	1133	2	\N	\N	D¿ne	2008-03-05 15:04:24
17369	1138	2	\N	\N	D¿ne	2008-03-05 15:04:24
17370	8284	2	0	0.10000000000000001	\N	2008-03-05 15:04:24
17371	8284	2	0.10000000000000001	0.29999999999999999	\N	2008-03-05 15:04:24
17372	10056	2	0	0.10000000000000001	\N	2008-03-05 15:04:25
17373	10056	2	0.10000000000000001	0.29999999999999999	\N	2008-03-05 15:04:25
17378	1168	2	0	0.10000000000000001	Feinkies, sandig, schwach mittel- u. schwach grobkiesig	2011-06-20 13:30:07
17382	1170	2	0	0.10000000000000001	Mittel- und Feinkies, sandig, schwach grobkiesig	2011-06-20 13:32:47
17384	1171	2	0	0.10000000000000001	Sand und Feinkies, schwach mittelkiesig	2011-06-20 13:34:36
17385	1171	2	0.10000000000000001	0.29999999999999999	Sand und Feinkies	2011-06-20 13:35:09
17389	1173	2	0.10000000000000001	0.29999999999999999	Feinkies, sandig, schwach mittelkiesig	2011-06-20 13:37:28
17390	1174	2	0	0.10000000000000001	Feinkies, mittelkiesig, sandig	2011-06-20 13:38:41
17392	8286	2	0	0.10000000000000001	\N	2008-03-05 15:04:25
17393	8286	2	0.10000000000000001	0.29999999999999999	\N	2008-03-05 15:04:25
17501	10101	8	0	0.40000000000000002	\N	2008-09-03 00:00:00
17502	10101	8	0.40000000000000002	0.5	\N	2008-09-03 00:00:00
17503	10101	8	0.5	0.80000000000000004	\N	2008-09-03 00:00:00
17520	10120	8	0	0.10000000000000001	\N	2008-09-05 00:00:00
17521	10120	8	0.10000000000000001	0.40000000000000002	\N	2008-09-05 00:00:00
17522	10120	8	0.40000000000000002	0.69999999999999996	\N	2008-09-05 00:00:00
17523	10121	8	0	0.40000000000000002	\N	2008-09-05 00:00:00
17524	10122	8	0	0.40000000000000002	\N	2008-09-05 00:00:00
17525	10122	8	0.40000000000000002	1	\N	2008-09-05 00:00:00
17526	10123	8	0	0.55000000000000004	\N	2008-09-05 00:00:00
17527	10123	8	0.90000000000000002	1.5	\N	2008-09-05 00:00:00
17528	10123	8	0.55000000000000004	0.90000000000000002	\N	2008-09-05 00:00:00
17529	10124	8	0	0.5	\N	2008-09-05 00:00:00
17530	10124	8	0.5	1.1000000000000001	\N	2008-09-05 00:00:00
17540	10141	8	0	0.20000000000000001	\N	2008-11-19 00:00:00
17541	10141	8	0.20000000000000001	0.5	\N	2008-11-19 00:00:00
17542	10141	8	0.5	1.1000000000000001	\N	2008-11-19 00:00:00
17543	10142	8	0	0.20000000000000001	\N	2008-11-19 00:00:00
17544	10142	8	0.20000000000000001	0.5	\N	2008-11-19 00:00:00
17545	10142	8	0.5	1	\N	2008-11-19 00:00:00
17546	10142	8	1	1.5	\N	2008-11-19 00:00:00
17547	10143	8	0	0.29999999999999999	\N	2008-11-19 00:00:00
17548	10143	8	0.29999999999999999	1	\N	2008-11-19 00:00:00
17549	10144	8	0	0.29999999999999999	\N	2008-11-19 00:00:00
17550	10144	8	0.29999999999999999	0.5	\N	2008-11-19 00:00:00
17551	10144	8	0.5	0.75	\N	2008-11-19 00:00:00
17552	10144	8	0.75	1	\N	2008-11-19 00:00:00
17553	10145	8	0	1	\N	2008-11-19 00:00:00
17560	10160	8	0	0.34999999999999998	\N	2008-11-20 00:00:00
17561	10160	8	0.90000000000000002	1.5	\N	2008-11-20 00:00:00
17562	10160	8	0.34999999999999998	0.90000000000000002	\N	2008-11-20 00:00:00
17563	10161	8	0	0.20000000000000001	\N	2008-11-20 00:00:00
17564	10161	8	0.20000000000000001	0.5	\N	2008-11-20 00:00:00
17565	10161	8	0.5	1.2	\N	2008-11-20 00:00:00
17566	10162	8	0	0.25	\N	2008-11-20 00:00:00
17567	10162	8	0.25	0.5	\N	2008-11-20 00:00:00
17568	10162	8	0.5	0.69999999999999996	\N	2008-11-20 00:00:00
17569	10162	8	0.69999999999999996	1.5	\N	2008-11-20 00:00:00
17570	10163	8	0	0.59999999999999998	\N	2008-11-20 00:00:00
17580	10180	8	0	0.20000000000000001	\N	2008-11-21 00:00:00
17581	10180	8	0.20000000000000001	0.5	\N	2008-11-21 00:00:00
17582	10180	8	0.5	1.2	\N	2008-11-21 00:00:00
17583	10181	8	0	0.40000000000000002	\N	2008-11-21 00:00:00
17584	10181	8	0.40000000000000002	0.94999999999999996	\N	2008-11-21 00:00:00
17585	10181	8	0.94999999999999996	1	\N	2008-11-21 00:00:00
17624	10200	8	0.5	1	\N	2008-12-03 00:00:00
17621	10200	8	0	0.20000000000000001	\N	2008-12-03 00:00:00
17623	10200	8	0.20000000000000001	0.5	\N	2008-12-03 00:00:00
17625	10200	8	1	1.5	\N	2008-12-03 00:00:00
17626	10220	8	0	0.34999999999999998	\N	2008-12-03 00:00:00
17627	10220	8	0.34999999999999998	1	\N	2008-12-03 00:00:00
17628	10220	8	1	1.5	\N	2008-12-03 00:00:00
17641	10241	8	0	0.20000000000000001	\N	2008-12-04 00:00:00
17642	10241	8	0.20000000000000001	0.5	\N	2008-12-04 00:00:00
17644	10241	8	0.5	1	\N	2008-12-04 00:00:00
17645	10241	8	1	1.2	\N	2008-12-04 00:00:00
17646	10242	8	0	0.20000000000000001	\N	2008-12-04 00:00:00
17647	10242	8	0.20000000000000001	0.80000000000000004	\N	2008-12-04 00:00:00
17648	10242	8	0.80000000000000004	1	\N	2008-12-04 00:00:00
17649	10242	8	1	1.2	\N	2008-12-04 00:00:00
17650	10243	8	0	0.20000000000000001	\N	2008-12-04 00:00:00
17651	10243	8	0.20000000000000001	0.5	\N	2008-12-04 00:00:00
17652	10243	8	0.5	0.90000000000000002	\N	2008-12-04 00:00:00
17653	10243	8	0.90000000000000002	1.2	\N	2008-12-04 00:00:00
17654	10244	8	0	0.25	\N	2008-12-04 00:00:00
17655	10244	8	0.5	1	\N	2008-12-04 00:00:00
17656	10244	8	0.25	0.5	\N	2008-12-04 00:00:00
17657	10244	8	1	1.25	\N	2008-12-04 00:00:00
17658	10244	8	1.25	1.5	\N	2008-12-04 00:00:00
17659	10245	8	0	0.10000000000000001	\N	2008-12-04 00:00:00
17660	10245	8	0.10000000000000001	0.45000000000000001	\N	2008-12-04 00:00:00
17661	10245	8	0.45000000000000001	1	\N	2008-12-04 00:00:00
17662	10245	8	1.25	1.5	\N	2008-12-04 00:00:00
17663	10246	8	0	0.20000000000000001	\N	2008-12-04 00:00:00
17664	10246	8	0.20000000000000001	0.5	\N	2008-12-04 00:00:00
17665	10246	8	0.5	1	\N	2008-12-04 00:00:00
17666	10246	8	1	1.2	\N	2008-12-04 00:00:00
17667	10247	8	0	0.29999999999999999	\N	2008-12-04 00:00:00
17668	10247	8	0.29999999999999999	0.84999999999999998	\N	2008-12-04 00:00:00
17669	10247	8	0.84999999999999998	1	\N	2008-12-04 00:00:00
17670	10247	8	1	1.2	\N	2008-12-04 00:00:00
17671	10248	8	0	0.29999999999999999	\N	2008-12-04 00:00:00
17676	10255	8	0	0.20000000000000001	\N	2008-12-04 00:00:00
17677	10255	8	0.20000000000000001	0.5	\N	2008-12-04 00:00:00
17678	10255	8	0.5	0.80000000000000004	\N	2008-12-04 00:00:00
17679	10255	8	0.80000000000000004	0.90000000000000002	\N	2008-12-04 00:00:00
17680	10255	8	0.90000000000000002	1.3	\N	2008-12-04 00:00:00
17681	10255	8	1.3	1.5	\N	2008-12-04 00:00:00
17700	10260	8	0	0.20000000000000001	\N	2008-12-05 00:00:00
17701	10260	8	0.20000000000000001	0.55000000000000004	\N	2008-12-05 00:00:00
17702	10260	8	0.55000000000000004	1.2	\N	2008-12-05 00:00:00
17703	10261	8	0	0.20000000000000001	\N	2008-12-05 00:00:00
17704	10261	8	0.20000000000000001	0.5	\N	2008-12-05 00:00:00
17705	10261	8	0.5	1	\N	2008-12-05 00:00:00
17706	10261	8	1	1.5	\N	2008-12-05 00:00:00
17707	10262	8	0	0.14999999999999999	\N	2008-12-05 00:00:00
17708	10262	8	0.14999999999999999	0.25	\N	2008-12-05 00:00:00
17709	10262	8	0.25	0.40000000000000002	\N	2008-12-05 00:00:00
17710	10262	8	0.40000000000000002	1	\N	2008-12-05 00:00:00
17711	10262	8	1	1.5	\N	2008-12-05 00:00:00
17720	10280	8	0	0.34999999999999998	\N	2008-12-08 00:00:00
17721	10280	8	0.34999999999999998	0.40000000000000002	\N	2008-12-08 00:00:00
17722	10280	8	0.40000000000000002	0.75	\N	2008-12-08 00:00:00
17723	10280	8	0.75	1.2	\N	2008-12-08 00:00:00
17724	10281	8	0	0.34999999999999998	\N	2008-12-08 00:00:00
17725	10281	8	0.34999999999999998	0.80000000000000004	\N	2008-12-08 00:00:00
17726	10281	8	0.80000000000000004	1.3	\N	2008-12-08 00:00:00
17727	10281	8	1.3	1.5	\N	2008-12-08 00:00:00
17728	10282	8	0	0.25	\N	2008-12-08 00:00:00
17729	10282	8	0.25	0.65000000000000002	\N	2008-12-08 00:00:00
17730	10282	8	0.65000000000000002	0.84999999999999998	\N	2008-12-08 00:00:00
17731	10282	8	0.84999999999999998	1.3	\N	2008-12-08 00:00:00
17732	10282	8	1.3	1.5	\N	2008-12-08 00:00:00
17733	10283	8	0	0.40000000000000002	\N	2008-12-08 00:00:00
17734	10283	8	0.40000000000000002	0.59999999999999998	\N	2008-12-08 00:00:00
17735	10283	8	0.59999999999999998	0.75	\N	2008-12-08 00:00:00
17736	10283	8	0.75	0.90000000000000002	\N	2008-12-08 00:00:00
17737	10283	8	0.90000000000000002	0.94999999999999996	\N	2008-12-08 00:00:00
17738	10283	8	0.94999999999999996	1.2	\N	2008-12-08 00:00:00
17739	10284	8	0	0.34999999999999998	\N	2008-12-08 00:00:00
17740	10284	8	0.34999999999999998	0.59999999999999998	\N	2008-12-08 00:00:00
17741	10284	8	0.59999999999999998	0.84999999999999998	\N	2008-12-08 00:00:00
17742	10284	8	0.84999999999999998	1	\N	2008-12-08 00:00:00
17743	10284	8	1	1.3999999999999999	\N	2008-12-08 00:00:00
17745	10286	8	0	0.20000000000000001	\N	2008-12-08 00:00:00
17746	10286	8	0.20000000000000001	0.65000000000000002	\N	2008-12-08 00:00:00
17747	10286	8	0.65000000000000002	0.75	\N	2008-12-08 00:00:00
17748	10286	8	0.75	1.2	\N	2008-12-08 00:00:00
17749	10286	8	1.2	1.5	\N	2008-12-08 00:00:00
17750	10287	8	0	0.20000000000000001	\N	2008-12-08 00:00:00
17751	10287	8	0.20000000000000001	0.59999999999999998	\N	2008-12-08 00:00:00
17752	10287	8	0.59999999999999998	0.69999999999999996	\N	2008-12-08 00:00:00
17753	10287	8	0.69999999999999996	1	\N	2008-12-08 00:00:00
17754	10287	8	1	1.2	\N	2008-12-08 00:00:00
17755	10288	8	0	0.20000000000000001	\N	2008-12-08 00:00:00
17756	10288	8	0.20000000000000001	0.75	\N	2008-12-08 00:00:00
17757	10288	8	0.75	0.84999999999999998	\N	2008-12-08 00:00:00
17758	10288	8	0.84999999999999998	1.2	\N	2008-12-08 00:00:00
17759	10289	8	0	0.34999999999999998	\N	2008-12-08 00:00:00
17760	10289	8	0.34999999999999998	0.59999999999999998	\N	2008-12-08 00:00:00
17761	10289	8	0.59999999999999998	1	\N	2008-12-08 00:00:00
17762	10289	8	1	1.2	\N	2008-12-08 00:00:00
17766	10291	8	0	0.65000000000000002	\N	2008-12-08 00:00:00
17767	10291	8	0.65000000000000002	1	\N	2008-12-08 00:00:00
17768	10291	8	1	1.25	\N	2008-12-08 00:00:00
17769	10292	8	0	0.29999999999999999	\N	2008-12-08 00:00:00
17773	10293	8	0	0.10000000000000001	\N	2008-12-08 00:00:00
17771	10292	8	0.59999999999999998	1	\N	2008-12-08 00:00:00
17772	10292	8	0.29999999999999999	0.59999999999999998	\N	2008-12-08 00:00:00
17774	10293	8	0.10000000000000001	0.80000000000000004	\N	2008-12-08 00:00:00
17775	10293	8	0.80000000000000004	1.2	\N	2008-12-08 00:00:00
17777	10295	8	0	0.14999999999999999	\N	2008-12-08 00:00:00
17778	10295	8	0.14999999999999999	0.90000000000000002	\N	2008-12-08 00:00:00
17374	1166	2	0	0.10000000000000001	Feinkies + Sand	2011-06-20 13:25:32
17375	1166	2	0.10000000000000001	0.29999999999999999	Feinkies + Sand, schwach mittelkiesig	2011-06-20 13:26:14
17376	1167	2	0	0.10000000000000001	Feinkies + Grobsand, mittelkiesig	2011-06-20 13:27:01
17377	1167	2	0.10000000000000001	0.29999999999999999	Feinkies, schwach sandig, schwach mittelkiesig	2011-06-20 13:27:36
17379	1168	2	0.10000000000000001	0.29999999999999999	Feinkies, sandig, schwach mittelkiesig	2011-06-20 13:30:46
17380	1169	2	0	0.10000000000000001	Feinkies + Sand, mittelkiesig, schwach grobkiesig, schwache Düne? (< 3 cm)	2011-06-20 13:31:27
17381	1169	2	0.10000000000000001	0.29999999999999999	Sand, stark feinkiesig, schwach mittel- u. schwach grobkiesig	2011-06-20 13:32:07
17383	1170	2	0.10000000000000001	0.29999999999999999	Grobkies und Mittelkies, feinkiesig, schwach sandig	2011-06-20 13:33:32
17386	1172	2	0	0.10000000000000001	Feinkies, mittelkiesig, sandig	2011-06-20 13:35:47
17387	1172	2	0.10000000000000001	0.29999999999999999	Feinkies und Sand, mittelkiesig	2011-06-20 13:36:19
17388	1173	2	0	0.10000000000000001	Mittel- und Feinkies, sandig	2011-06-20 13:36:54
17391	1174	2	0.10000000000000001	0.29999999999999999	Sand und Feinkies, mittelkiesig	2011-06-20 13:39:16
\.


--
-- Data for Name: sohltest; Type: TABLE DATA; Schema: public; Owner: -
--

COPY sohltest (sohltestid, stationid, sondierungartid, archivid, datum, istnurjahr, km, abstand, abstistvonlinks, abstbezug, abstoffset, abstlinks, rechts, hoch, hoehe, bemerkung, sohlebeschreib, sondierungbeschreib, lastupdated) FROM stdin;
61	329	\N	\N	1993-12-16 00:00:00	0	3.5999999999999943	50	1	1	0	50	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
62	329	\N	\N	1993-12-16 00:00:00	0	3.5999999999999943	90	1	1	0	90	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
63	329	\N	\N	1993-12-16 00:00:00	0	3.5999999999999943	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
64	330	\N	\N	1993-12-16 00:00:00	0	6.5999999999999943	0	1	1	0	0	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
65	331	\N	\N	1993-03-24 00:00:00	0	9.5999999999999943	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2008-01-14 00:00:00
66	332	\N	\N	1995-01-12 00:00:00	0	16.599999999999994	125	1	1	0	125	\N	\N	\N	\N	\N	\N	2008-01-14 00:00:00
347	404	\N	\N	1995-02-22 00:00:00	0	79.599999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
348	405	\N	\N	1995-02-22 00:00:00	0	81.599999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
349	406	\N	\N	1995-02-22 00:00:00	0	85.599999999999994	95	1	1	0	95	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
350	407	\N	\N	1995-02-22 00:00:00	0	87.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
351	408	\N	\N	1993-03-25 00:00:00	0	90.099999999999994	0	1	1	0	0	\N	\N	\N	\N	Elstermündung	\N	2006-10-06 13:40:00
352	408	\N	\N	1995-02-22 00:00:00	0	90.099999999999994	0	1	1	0	0	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
353	409	\N	\N	1993-03-25 00:00:00	0	91.199999999999989	140	1	1	0	140	\N	\N	\N	\N	60 m re = rechts	\N	2006-10-06 13:40:00
354	410	\N	\N	1995-02-22 00:00:00	0	91.599999999999994	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
355	411	\N	\N	1995-02-22 00:00:00	0	95.599999999999994	0	1	1	0	0	\N	\N	\N	\N	Elster (Ort)	\N	2006-10-06 13:40:00
356	412	\N	\N	1995-02-24 00:00:00	0	109.59999999999999	0	1	1	0	0	\N	\N	\N	\N	Wittenberg	\N	2006-10-06 13:40:00
357	413	\N	\N	1995-02-24 00:00:00	0	111.59999999999999	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
358	413	\N	\N	1995-02-24 00:00:00	0	111.59999999999999	105	1	1	0	105	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
359	414	\N	\N	1993-03-26 00:00:00	0	137.59999999999999	100	1	1	0	100	\N	\N	\N	\N	112 m vom rechten Ufer	\N	2006-10-06 13:40:00
360	415	\N	\N	1993-03-26 00:00:00	0	147.59999999999999	45	1	1	0	45	\N	\N	\N	\N	150 m re = links	\N	2006-10-06 13:40:00
361	416	\N	\N	1993-03-26 00:00:00	0	151.59999999999999	50	1	1	0	50	\N	\N	\N	\N	200 m re = links	\N	2006-10-06 13:40:00
362	416	\N	\N	1993-03-26 00:00:00	0	151.59999999999999	155	1	1	0	155	\N	\N	\N	\N	110 m re = rechts	\N	2006-10-06 13:40:00
363	417	\N	\N	1994-11-01 00:00:00	0	166.59999999999999	0	1	1	0	0	\N	\N	\N	\N	Meßschiff "Elbegrund"	\N	2006-10-06 13:40:00
1062	856	\N	\N	2006-09-07 00:00:00	0	1.5999999999999943	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1063	856	\N	\N	2006-09-07 00:00:00	0	1.5999999999999943	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1064	856	\N	\N	2006-09-07 00:00:00	0	1.5999999999999943	160	1	1	0	160	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1065	857	\N	\N	2006-09-07 00:00:00	0	5.5999999999999943	40	1	1	0	40	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1066	857	\N	\N	2006-09-07 00:00:00	0	5.5999999999999943	75	1	1	0	75	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1067	857	\N	\N	2006-09-07 00:00:00	0	5.5999999999999943	95	1	1	0	95	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1068	858	\N	\N	2006-09-07 00:00:00	0	13.599999999999994	45	1	1	0	45	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1069	858	\N	\N	2006-09-07 00:00:00	0	13.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1070	858	\N	\N	2006-09-07 00:00:00	0	13.599999999999994	105	1	1	0	105	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1071	859	\N	\N	2006-09-07 00:00:00	0	18.199999999999989	45	1	1	0	45	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1072	859	\N	\N	2006-09-07 00:00:00	0	18.199999999999989	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1073	859	\N	\N	2006-09-07 00:00:00	0	18.199999999999989	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1074	860	\N	\N	2006-09-08 00:00:00	0	23.099999999999994	50	1	1	0	50	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1075	860	\N	\N	2006-09-08 00:00:00	0	23.099999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1076	860	\N	\N	2006-09-08 00:00:00	0	23.099999999999994	125	1	1	0	125	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1077	337	\N	\N	2006-09-08 00:00:00	0	25.599999999999994	78	1	1	0	78	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1078	337	\N	\N	2006-09-08 00:00:00	0	25.599999999999994	98	1	1	0	98	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1079	337	\N	\N	2006-09-08 00:00:00	0	25.599999999999994	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1080	346	\N	\N	2006-09-08 00:00:00	0	32.199999999999989	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1081	346	\N	\N	2006-09-08 00:00:00	0	32.199999999999989	138	1	1	0	138	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1082	346	\N	\N	2006-09-08 00:00:00	0	32.199999999999989	118	1	1	0	118	\N	\N	\N	\N	\N	\N	2008-01-14 00:00:00
1083	861	\N	\N	2006-09-08 00:00:00	0	35.900000000000006	47	1	1	0	47	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1179	890	\N	\N	2006-09-13 00:00:00	0	182.09999999999999	45	1	1	0	45	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1180	890	\N	\N	2006-09-13 00:00:00	0	182.09999999999999	90	1	1	0	90	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1181	890	\N	\N	2006-09-13 00:00:00	0	182.09999999999999	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1182	891	\N	\N	2006-09-13 00:00:00	0	182.29999999999998	35	1	1	0	35	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
8284	878	\N	\N	2006-09-12 00:00:00	0	119.59999999999999	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2007-11-15 15:20:59
8286	888	\N	\N	2006-09-13 00:00:00	0	173.79999999999998	72	1	1	0	72	\N	\N	\N	\N	\N	\N	2007-11-15 15:21:00
10003	2699	\N	\N	2006-09-01 00:00:00	0	59.099999999999994	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2008-03-05 15:04:20
10055	868	\N	\N	2006-09-11 00:00:00	0	76.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2008-03-05 15:04:24
10056	886	\N	\N	2006-09-13 00:00:00	0	156.59999999999999	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2011-06-20 10:45:42
10120	859	\N	\N	2007-09-12 00:00:00	0	18.199999999999989	70	1	0	0	70	\N	\N	\N	\N	\N	\N	2008-09-05 00:00:00
10101	859	\N	\N	2007-09-12 00:00:00	0	18.199999999999989	40	1	1	0	40	\N	\N	\N	\N	\N	\N	2008-09-03 00:00:00
10121	344	\N	\N	2007-09-12 00:00:00	0	31.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2008-09-05 00:00:00
10122	382	\N	\N	2007-09-12 00:00:00	0	45.599999999999994	40	1	1	0	40	\N	\N	\N	\N	\N	\N	2008-09-05 00:00:00
10123	382	\N	\N	2007-09-12 00:00:00	0	45.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2008-09-05 00:00:00
10124	382	\N	\N	2007-09-12 00:00:00	0	45.599999999999994	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2008-09-05 00:00:00
10141	865	\N	\N	2007-06-13 00:00:00	0	59.449999999999989	30	1	1	0	30	\N	\N	\N	\N	\N	\N	2008-11-19 00:00:00
10142	865	\N	\N	2007-06-13 00:00:00	0	59.449999999999989	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2008-11-19 00:00:00
10143	2900	\N	\N	2007-06-14 00:00:00	0	65.599999999999994	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2008-11-19 00:00:00
10144	2900	\N	\N	2007-06-14 00:00:00	0	65.599999999999994	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2008-11-19 00:00:00
10145	2900	\N	\N	2007-06-14 00:00:00	0	65.599999999999994	150	1	0	0	150	\N	\N	\N	\N	\N	\N	2008-11-19 00:00:00
10160	2921	\N	\N	2007-06-14 00:00:00	0	66.099999999999994	150	1	1	0	150	\N	\N	\N	\N	\N	\N	2008-11-20 00:00:00
10161	399	\N	\N	2007-06-14 00:00:00	0	66.599999999999994	150	1	1	0	150	\N	\N	\N	\N	\N	\N	2008-11-20 00:00:00
10162	2940	\N	\N	2007-06-14 00:00:00	0	67.549999999999983	50	1	1	0	50	\N	\N	\N	\N	\N	\N	2008-11-20 00:00:00
10163	2940	\N	\N	2007-06-14 00:00:00	0	67.549999999999983	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2008-11-20 00:00:00
10180	2940	\N	\N	2007-06-14 00:00:00	0	67.549999999999983	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2008-11-21 00:00:00
10181	2960	\N	\N	2007-06-15 00:00:00	0	69.099999999999994	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2008-11-21 00:00:00
10200	869	\N	\N	2007-06-18 00:00:00	0	82.099999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2008-12-03 00:00:00
10220	869	\N	\N	2007-06-18 00:00:00	0	82.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2008-12-03 00:00:00
10241	869	\N	\N	2007-06-18 00:00:00	0	82.099999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2008-12-04 00:00:00
10242	3000	\N	\N	2007-06-18 00:00:00	0	84	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2008-12-04 00:00:00
10243	870	\N	\N	2007-06-19 00:00:00	0	86.099999999999994	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2008-12-04 00:00:00
10291	3021	\N	\N	2007-06-21 00:00:00	0	141	50	1	1	0	50	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
10293	3021	\N	\N	2007-06-21 00:00:00	0	141	71	1	0	0	71	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
10295	3021	\N	\N	2007-06-21 00:00:00	0	141	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
10297	3022	\N	\N	2007-06-22 00:00:00	0	\N	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
13660	356	\N	\N	1996-09-18 00:00:00	0	\N	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2011-06-20 10:21:30
67	332	\N	\N	1996-09-23 00:00:00	0	16.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
68	332	\N	\N	1996-09-23 00:00:00	0	16.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
69	332	\N	\N	1996-09-23 00:00:00	0	16.599999999999994	125	1	1	0	125	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
70	332	\N	\N	1997-03-25 00:00:00	0	16.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
71	332	\N	\N	1997-03-25 00:00:00	0	16.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
72	332	\N	\N	1997-03-25 00:00:00	0	16.599999999999994	125	1	1	0	125	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
73	333	\N	\N	1993-03-24 00:00:00	0	17.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2008-01-14 00:00:00
74	333	\N	\N	1993-03-24 00:00:00	0	17.599999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2008-01-14 00:00:00
75	334	\N	\N	1995-01-12 00:00:00	0	18.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
76	334	\N	\N	1995-01-12 00:00:00	0	18.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
77	335	\N	\N	1995-01-12 00:00:00	0	20.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
78	335	\N	\N	1995-01-12 00:00:00	0	20.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
79	336	\N	\N	1995-01-12 00:00:00	0	24.599999999999994	75	1	1	0	75	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
80	337	\N	\N	1993-03-24 00:00:00	0	25.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
81	338	\N	\N	1995-01-11 00:00:00	0	27.599999999999994	55	1	1	0	55	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
82	338	\N	\N	1995-01-11 00:00:00	0	27.599999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
83	340	\N	\N	1996-02-22 00:00:00	0	29.599999999999994	50	1	1	0	50	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
84	340	\N	\N	1996-02-22 00:00:00	0	29.599999999999994	75	1	1	0	75	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
85	340	\N	\N	1996-02-22 00:00:00	0	29.599999999999994	95	1	1	0	95	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
86	340	\N	\N	1996-02-22 00:00:00	0	29.599999999999994	125	1	1	0	125	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
87	341	\N	\N	1996-02-22 00:00:00	0	30.099999999999994	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
88	341	\N	\N	1996-02-22 00:00:00	0	30.099999999999994	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
89	341	\N	\N	1996-02-22 00:00:00	0	30.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
90	341	\N	\N	1996-02-22 00:00:00	0	30.099999999999994	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
91	341	\N	\N	1996-02-22 00:00:00	0	30.099999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
92	342	\N	\N	1993-11-25 00:00:00	0	30.599999999999994	0	1	1	0	0	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
93	342	\N	\N	1996-02-22 00:00:00	0	30.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2011-06-20 12:54:55
94	342	\N	\N	1996-02-22 00:00:00	0	30.599999999999994	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
95	342	\N	\N	1996-02-22 00:00:00	0	30.599999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
96	342	\N	\N	1999-02-22 00:00:00	0	30.599999999999994	0	1	1	0	0	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
97	343	\N	\N	1996-02-22 00:00:00	0	31.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
98	343	\N	\N	1996-02-22 00:00:00	0	31.099999999999994	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
99	343	\N	\N	1996-02-22 00:00:00	0	31.099999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
100	344	\N	\N	1996-02-22 00:00:00	0	31.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2011-06-20 12:59:26
101	344	\N	\N	1996-02-22 00:00:00	0	31.599999999999994	80	1	1	0	80	\N	\N	\N	\N	toniges Sohlmaterial bei Belgern	\N	2006-10-06 13:40:00
102	344	\N	\N	1996-02-22 00:00:00	0	31.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
103	344	\N	\N	1996-02-22 00:00:00	0	31.599999999999994	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
104	344	\N	\N	1996-02-22 00:00:00	0	31.599999999999994	140	1	1	0	140	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
105	345	\N	\N	1996-02-22 00:00:00	0	31.799999999999983	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
106	345	\N	\N	1996-02-22 00:00:00	0	31.799999999999983	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
107	345	\N	\N	1996-02-22 00:00:00	0	31.799999999999983	105	1	1	0	105	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
108	345	\N	\N	1996-02-22 00:00:00	0	31.799999999999983	125	1	1	0	125	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
109	345	\N	\N	1996-02-22 00:00:00	0	31.799999999999983	145	1	1	0	145	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
110	346	\N	\N	1996-02-22 00:00:00	0	32.199999999999989	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
111	346	\N	\N	1996-02-22 00:00:00	0	32.199999999999989	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
112	346	\N	\N	1996-02-22 00:00:00	0	32.199999999999989	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
113	346	\N	\N	1996-02-22 00:00:00	0	32.199999999999989	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
114	346	\N	\N	1996-02-22 00:00:00	0	32.199999999999989	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
115	347	\N	\N	1996-02-22 00:00:00	0	32.400000000000006	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
116	347	\N	\N	1996-02-22 00:00:00	0	32.400000000000006	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
117	347	\N	\N	1996-02-22 00:00:00	0	32.400000000000006	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
118	347	\N	\N	1996-02-22 00:00:00	0	32.400000000000006	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
119	347	\N	\N	1996-02-22 00:00:00	0	32.400000000000006	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
120	348	\N	\N	1996-02-22 00:00:00	0	32.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
121	348	\N	\N	1996-02-22 00:00:00	0	32.599999999999994	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
122	348	\N	\N	1996-02-22 00:00:00	0	32.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
123	348	\N	\N	1996-02-22 00:00:00	0	32.599999999999994	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
124	348	\N	\N	1996-02-22 00:00:00	0	32.599999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
125	349	\N	\N	1996-02-21 00:00:00	0	32.799999999999983	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
126	349	\N	\N	1996-02-21 00:00:00	0	32.799999999999983	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
127	349	\N	\N	1996-02-21 00:00:00	0	32.799999999999983	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
128	349	\N	\N	1996-02-21 00:00:00	0	32.799999999999983	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
129	349	\N	\N	1996-02-21 00:00:00	0	32.799999999999983	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
130	350	\N	\N	1996-02-21 00:00:00	0	33	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2011-06-20 13:01:55
131	350	\N	\N	1996-02-21 00:00:00	0	33	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
132	350	\N	\N	1996-02-21 00:00:00	0	33	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
133	351	\N	\N	1996-02-21 00:00:00	0	33.199999999999989	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
134	351	\N	\N	1996-02-21 00:00:00	0	33.199999999999989	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
135	351	\N	\N	1996-02-21 00:00:00	0	33.199999999999989	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
136	351	\N	\N	1996-02-21 00:00:00	0	33.199999999999989	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
137	352	\N	\N	1996-02-21 00:00:00	0	33.400000000000006	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
138	352	\N	\N	1996-02-21 00:00:00	0	33.400000000000006	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
139	352	\N	\N	1996-02-21 00:00:00	0	33.400000000000006	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
140	352	\N	\N	1996-02-21 00:00:00	0	33.400000000000006	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
141	352	\N	\N	1996-02-21 00:00:00	0	33.400000000000006	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
142	353	\N	\N	1996-02-21 00:00:00	0	33.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
143	353	\N	\N	1996-02-21 00:00:00	0	33.599999999999994	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
144	353	\N	\N	1996-02-21 00:00:00	0	33.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
145	353	\N	\N	1996-02-21 00:00:00	0	33.599999999999994	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
146	353	\N	\N	1996-02-21 00:00:00	0	33.599999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
147	353	\N	\N	1996-09-18 00:00:00	0	33.599999999999994	0	1	1	0	0	\N	\N	\N	\N	Hydraulikgreifer zur Entnahme der Sohlproben	\N	2006-10-06 13:40:00
148	354	\N	\N	1996-02-21 00:00:00	0	33.799999999999983	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2011-06-20 13:03:57
149	354	\N	\N	1996-02-21 00:00:00	0	33.799999999999983	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
150	354	\N	\N	1996-02-21 00:00:00	0	33.799999999999983	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
151	354	\N	\N	1996-02-21 00:00:00	0	33.799999999999983	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
152	354	\N	\N	1996-02-21 00:00:00	0	33.799999999999983	140	1	1	0	140	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
153	355	\N	\N	1996-02-21 00:00:00	0	34	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
154	355	\N	\N	1996-02-21 00:00:00	0	34	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
155	355	\N	\N	1996-02-21 00:00:00	0	34	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
156	355	\N	\N	1996-02-21 00:00:00	0	34	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
157	355	\N	\N	1996-02-21 00:00:00	0	34	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
158	356	\N	\N	1996-03-18 00:00:00	0	34.099999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2011-06-20 10:22:05
159	356	\N	\N	1996-09-18 00:00:00	0	34.099999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
160	356	\N	\N	1996-09-18 00:00:00	0	34.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
161	356	\N	\N	1997-03-25 00:00:00	0	34.099999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
162	356	\N	\N	1997-03-25 00:00:00	0	34.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
163	356	\N	\N	1997-03-25 00:00:00	0	34.099999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
164	357	\N	\N	1996-02-21 00:00:00	0	34.199999999999989	50	1	1	0	50	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
165	357	\N	\N	1996-02-21 00:00:00	0	34.199999999999989	75	1	1	0	75	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
166	357	\N	\N	1996-02-21 00:00:00	0	34.199999999999989	90	1	1	0	90	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
167	357	\N	\N	1996-02-21 00:00:00	0	34.199999999999989	105	1	1	0	105	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
168	357	\N	\N	1996-02-21 00:00:00	0	34.199999999999989	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
169	357	\N	\N	1997-03-25 00:00:00	0	34.199999999999989	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
170	357	\N	\N	1997-03-25 00:00:00	0	34.199999999999989	90	1	1	0	90	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
171	357	\N	\N	1997-03-25 00:00:00	0	34.199999999999989	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
172	358	\N	\N	1996-02-21 00:00:00	0	34.400000000000006	50	1	1	0	50	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
173	358	\N	\N	1996-02-21 00:00:00	0	34.400000000000006	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
174	358	\N	\N	1996-02-21 00:00:00	0	34.400000000000006	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
175	358	\N	\N	1996-09-18 00:00:00	0	34.400000000000006	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
176	358	\N	\N	1997-03-25 00:00:00	0	34.400000000000006	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
177	359	\N	\N	1996-09-18 00:00:00	0	34.799999999999983	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
178	359	\N	\N	1997-03-25 00:00:00	0	34.799999999999983	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
179	360	\N	\N	1996-07-09 00:00:00	0	35	0	1	1	0	0	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
180	361	\N	\N	1996-02-20 00:00:00	0	35.099999999999994	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
181	361	\N	\N	1996-09-18 00:00:00	0	35.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
182	362	\N	\N	1996-02-20 00:00:00	0	35.599999999999994	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2011-06-20 10:24:15
183	362	\N	\N	1996-02-20 00:00:00	0	35.599999999999994	145	1	1	0	145	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
184	362	\N	\N	1997-03-25 00:00:00	0	35.599999999999994	95	1	1	0	95	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
185	362	\N	\N	1997-03-25 00:00:00	0	35.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
186	363	\N	\N	1996-02-20 00:00:00	0	36.099999999999994	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
187	363	\N	\N	1996-02-20 00:00:00	0	36.099999999999994	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
188	363	\N	\N	1996-02-20 00:00:00	0	36.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
189	363	\N	\N	1996-02-20 00:00:00	0	36.099999999999994	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
190	363	\N	\N	1996-02-20 00:00:00	0	36.099999999999994	140	1	1	0	140	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
191	363	\N	\N	1996-09-18 00:00:00	0	36.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
192	363	\N	\N	1997-03-25 00:00:00	0	36.099999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
193	363	\N	\N	1997-03-25 00:00:00	0	36.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
194	363	\N	\N	1997-03-25 00:00:00	0	36.099999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
195	364	\N	\N	1996-09-18 00:00:00	0	36.299999999999983	105	1	1	0	105	\N	\N	\N	\N	\N	\N	2008-01-14 00:00:00
196	364	\N	\N	1997-09-18 00:00:00	0	36.299999999999983	105	1	1	0	105	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
197	365	\N	\N	1996-09-19 00:00:00	0	36.799999999999983	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
198	366	\N	\N	1996-02-20 00:00:00	0	37.099999999999994	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
199	366	\N	\N	1996-02-20 00:00:00	0	37.099999999999994	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
200	366	\N	\N	1996-02-20 00:00:00	0	37.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2011-06-20 10:28:04
201	366	\N	\N	1996-02-20 00:00:00	0	37.099999999999994	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
202	366	\N	\N	1996-02-20 00:00:00	0	37.099999999999994	140	1	1	0	140	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
203	366	\N	\N	1997-02-20 00:00:00	0	37.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2011-06-20 10:28:48
204	366	\N	\N	1997-03-25 00:00:00	0	37.099999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
205	366	\N	\N	1997-03-25 00:00:00	0	37.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
206	367	\N	\N	1996-09-19 00:00:00	0	37.199999999999989	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
207	368	\N	\N	1996-09-19 00:00:00	0	37.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
208	368	\N	\N	1997-03-25 00:00:00	0	37.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2011-06-20 13:08:14
209	368	\N	\N	1997-03-25 00:00:00	0	37.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
210	369	\N	\N	1996-02-20 00:00:00	0	38.099999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
211	369	\N	\N	1996-02-20 00:00:00	0	38.099999999999994	90	1	1	0	90	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
212	369	\N	\N	1996-02-20 00:00:00	0	38.099999999999994	105	1	1	0	105	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
213	369	\N	\N	1996-02-20 00:00:00	0	38.099999999999994	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
214	369	\N	\N	1996-02-20 00:00:00	0	38.099999999999994	140	1	1	0	140	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
215	369	\N	\N	1997-03-25 00:00:00	0	38.099999999999994	75	1	1	0	75	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
216	369	\N	\N	1997-03-25 00:00:00	0	38.099999999999994	105	1	1	0	105	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
217	369	\N	\N	1997-03-25 00:00:00	0	38.099999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
218	370	\N	\N	1996-02-19 00:00:00	0	38.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2011-06-20 10:29:49
219	370	\N	\N	1996-02-19 00:00:00	0	38.599999999999994	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
220	370	\N	\N	1996-02-19 00:00:00	0	38.599999999999994	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
221	370	\N	\N	1996-02-19 00:00:00	0	38.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
222	370	\N	\N	1996-02-19 00:00:00	0	38.599999999999994	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
223	370	\N	\N	1996-02-19 00:00:00	0	38.599999999999994	140	1	1	0	140	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
224	370	\N	\N	1997-03-25 00:00:00	0	38.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
225	370	\N	\N	1997-03-25 00:00:00	0	38.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
226	370	\N	\N	1997-03-25 00:00:00	0	38.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
227	371	\N	\N	1996-02-19 00:00:00	0	39.099999999999994	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
228	371	\N	\N	1996-02-19 00:00:00	0	39.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
229	371	\N	\N	1996-02-19 00:00:00	0	39.099999999999994	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
230	371	\N	\N	1996-02-19 00:00:00	0	39.099999999999994	140	1	1	0	140	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
231	371	\N	\N	1997-03-25 00:00:00	0	39.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
232	371	\N	\N	1997-03-25 00:00:00	0	39.099999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
233	372	\N	\N	1996-02-19 00:00:00	0	39.599999999999994	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
234	372	\N	\N	1996-02-19 00:00:00	0	39.599999999999994	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
235	372	\N	\N	1996-02-19 00:00:00	0	39.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
236	372	\N	\N	1996-02-19 00:00:00	0	39.599999999999994	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
237	372	\N	\N	1996-02-19 00:00:00	0	39.599999999999994	140	1	1	0	140	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
238	372	\N	\N	1996-09-23 00:00:00	0	39.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
239	372	\N	\N	1996-09-23 00:00:00	0	39.599999999999994	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
240	372	\N	\N	1996-09-23 00:00:00	0	39.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
241	372	\N	\N	1997-03-25 00:00:00	0	39.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
242	372	\N	\N	1997-03-25 00:00:00	0	39.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
243	372	\N	\N	1997-03-25 00:00:00	0	39.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
244	373	\N	\N	1996-09-23 00:00:00	0	39.799999999999983	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
245	373	\N	\N	1996-09-23 00:00:00	0	39.799999999999983	95	1	1	0	95	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
246	373	\N	\N	1996-09-23 00:00:00	0	39.799999999999983	125	1	1	0	125	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
247	374	\N	\N	1996-02-19 00:00:00	0	40.099999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
248	374	\N	\N	1996-02-19 00:00:00	0	40.099999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
249	374	\N	\N	1996-02-19 00:00:00	0	40.099999999999994	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
250	374	\N	\N	1996-02-19 00:00:00	0	40.099999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
251	375	\N	\N	1996-09-23 00:00:00	0	40.400000000000006	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
252	375	\N	\N	1996-09-23 00:00:00	0	40.400000000000006	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
253	375	\N	\N	1996-09-23 00:00:00	0	40.400000000000006	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
254	376	\N	\N	1996-02-19 00:00:00	0	40.599999999999994	55	1	1	0	55	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
255	376	\N	\N	1996-02-19 00:00:00	0	40.599999999999994	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
256	376	\N	\N	1996-02-19 00:00:00	0	40.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
257	376	\N	\N	1996-02-19 00:00:00	0	40.599999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
258	376	\N	\N	1996-09-23 00:00:00	0	40.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
259	376	\N	\N	1996-09-23 00:00:00	0	40.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
260	376	\N	\N	1996-09-23 00:00:00	0	40.599999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
261	376	\N	\N	1997-03-25 00:00:00	0	40.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
262	376	\N	\N	1997-03-25 00:00:00	0	40.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
263	376	\N	\N	1997-03-25 00:00:00	0	40.599999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
264	377	\N	\N	1996-02-19 00:00:00	0	41.099999999999994	55	1	1	0	55	\N	\N	\N	\N	\N	\N	2011-06-20 13:11:42
265	377	\N	\N	1996-02-19 00:00:00	0	41.099999999999994	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
266	377	\N	\N	1996-02-19 00:00:00	0	41.099999999999994	95	1	1	0	95	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
267	378	\N	\N	1996-09-23 00:00:00	0	41.199999999999989	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
268	378	\N	\N	1996-09-23 00:00:00	0	41.199999999999989	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
269	378	\N	\N	1996-09-23 00:00:00	0	41.199999999999989	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
270	379	\N	\N	1993-03-24 00:00:00	0	41.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2007-11-27 00:00:00
271	379	\N	\N	1996-02-19 00:00:00	0	41.599999999999994	55	1	1	0	55	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
272	379	\N	\N	1996-02-19 00:00:00	0	41.599999999999994	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
273	379	\N	\N	1996-02-19 00:00:00	0	41.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
274	379	\N	\N	1996-02-19 00:00:00	0	41.599999999999994	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
275	379	\N	\N	1996-02-19 00:00:00	0	41.599999999999994	145	1	1	0	145	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
276	379	\N	\N	1996-09-23 00:00:00	0	41.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
277	379	\N	\N	1996-09-23 00:00:00	0	41.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
278	379	\N	\N	1997-03-25 00:00:00	0	41.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
279	379	\N	\N	1997-03-25 00:00:00	0	41.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
280	380	\N	\N	1996-09-23 00:00:00	0	43.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
281	381	\N	\N	1996-09-23 00:00:00	0	44.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
282	381	\N	\N	1996-09-23 00:00:00	0	44.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
283	381	\N	\N	1996-09-23 00:00:00	0	44.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
284	381	\N	\N	1997-03-25 00:00:00	0	44.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
285	381	\N	\N	1997-03-25 00:00:00	0	44.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
286	381	\N	\N	1997-03-25 00:00:00	0	44.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
287	382	\N	\N	1996-09-23 00:00:00	0	45.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
288	382	\N	\N	1996-09-23 00:00:00	0	45.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
289	382	\N	\N	1997-03-25 00:00:00	0	45.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
290	383	\N	\N	1996-09-24 00:00:00	0	47.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
291	383	\N	\N	1996-09-24 00:00:00	0	47.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
292	383	\N	\N	1996-09-24 00:00:00	0	47.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
293	383	\N	\N	1997-04-01 00:00:00	0	47.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
294	383	\N	\N	1997-04-01 00:00:00	0	47.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
295	383	\N	\N	1997-04-01 00:00:00	0	47.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
296	384	\N	\N	1996-09-24 00:00:00	0	48.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
297	384	\N	\N	1996-09-24 00:00:00	0	48.599999999999994	95	1	1	0	95	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
298	384	\N	\N	1996-09-24 00:00:00	0	48.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
299	385	\N	\N	1996-09-24 00:00:00	0	49.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
300	385	\N	\N	1996-09-24 00:00:00	0	49.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
301	385	\N	\N	1996-09-24 00:00:00	0	49.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
302	385	\N	\N	1997-04-01 00:00:00	0	49.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
303	385	\N	\N	1997-04-01 00:00:00	0	49.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
304	385	\N	\N	1997-04-01 00:00:00	0	49.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
305	386	\N	\N	1996-09-24 00:00:00	0	50.599999999999994	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
306	386	\N	\N	1996-09-24 00:00:00	0	50.599999999999994	95	1	1	0	95	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
307	387	\N	\N	1996-09-24 00:00:00	0	51.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
308	387	\N	\N	1996-09-24 00:00:00	0	51.599999999999994	95	1	1	0	95	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
309	388	\N	\N	1997-04-01 00:00:00	0	52	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
310	388	\N	\N	1997-04-01 00:00:00	0	52	90	1	1	0	90	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
311	388	\N	\N	1997-04-01 00:00:00	0	52	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
312	389	\N	\N	1996-09-24 00:00:00	0	52.599999999999994	105	1	1	0	105	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
313	389	\N	\N	1996-09-24 00:00:00	0	52.599999999999994	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
314	390	\N	\N	1996-09-24 00:00:00	0	53.599999999999994	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
315	390	\N	\N	1996-09-24 00:00:00	0	53.599999999999994	90	1	1	0	90	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
316	390	\N	\N	1996-09-24 00:00:00	0	53.599999999999994	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
317	390	\N	\N	1997-04-01 00:00:00	0	53.599999999999994	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
318	390	\N	\N	1997-04-01 00:00:00	0	53.599999999999994	90	1	1	0	90	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
319	390	\N	\N	1997-04-01 00:00:00	0	53.599999999999994	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
320	391	\N	\N	1996-09-24 00:00:00	0	54.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
321	392	\N	\N	1996-09-24 00:00:00	0	55.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
322	393	\N	\N	1996-09-24 00:00:00	0	56.599999999999994	75	1	1	0	75	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
323	393	\N	\N	1996-09-24 00:00:00	0	56.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
324	393	\N	\N	1996-09-24 00:00:00	0	56.599999999999994	125	1	1	0	125	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
325	393	\N	\N	1997-04-01 00:00:00	0	56.599999999999994	75	1	1	0	75	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
326	393	\N	\N	1997-04-01 00:00:00	0	56.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
327	393	\N	\N	1997-04-01 00:00:00	0	56.599999999999994	125	1	1	0	125	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
328	394	\N	\N	1996-09-24 00:00:00	0	57.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
329	395	\N	\N	1996-09-24 00:00:00	0	58.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
330	395	\N	\N	1996-09-24 00:00:00	0	58.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
331	396	\N	\N	1996-09-24 00:00:00	0	59.599999999999994	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
332	396	\N	\N	1996-09-24 00:00:00	0	59.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
333	396	\N	\N	1997-04-01 00:00:00	0	59.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2011-06-20 10:34:24
334	396	\N	\N	1997-04-01 00:00:00	0	59.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
335	397	\N	\N	1996-09-24 00:00:00	0	60.599999999999994	95	1	1	0	95	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
336	398	\N	\N	1996-09-24 00:00:00	0	61.599999999999994	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
337	398	\N	\N	1996-09-24 00:00:00	0	61.599999999999994	95	1	1	0	95	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
338	398	\N	\N	1996-09-24 00:00:00	0	61.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
339	399	\N	\N	1994-03-16 00:00:00	0	66.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
340	399	\N	\N	1994-03-16 00:00:00	0	66.599999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
341	399	\N	\N	1995-02-21 00:00:00	0	66.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
342	400	\N	\N	1995-02-21 00:00:00	0	69.599999999999994	105	1	1	0	105	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
343	401	\N	\N	1995-02-21 00:00:00	0	71.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
344	402	\N	\N	1995-02-21 00:00:00	0	73.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
345	403	\N	\N	1995-02-22 00:00:00	0	78.599999999999994	125	1	1	0	125	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
346	404	\N	\N	1995-02-22 00:00:00	0	79.599999999999994	75	1	1	0	75	\N	\N	\N	\N	\N	\N	2006-10-06 13:40:00
1084	861	\N	\N	2006-09-08 00:00:00	0	35.900000000000006	82	1	1	0	82	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1085	861	\N	\N	2006-09-08 00:00:00	0	35.900000000000006	102	1	1	0	102	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1086	379	\N	\N	2006-09-08 00:00:00	0	41.599999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1087	379	\N	\N	2006-09-08 00:00:00	0	41.599999999999994	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1088	379	\N	\N	2006-09-08 00:00:00	0	41.599999999999994	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1089	382	\N	\N	2006-09-08 00:00:00	0	45.599999999999994	44	1	1	0	44	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1090	382	\N	\N	2006-09-08 00:00:00	0	45.599999999999994	78	1	1	0	78	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1091	382	\N	\N	2006-09-08 00:00:00	0	45.599999999999994	98	1	1	0	98	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1092	862	\N	\N	2006-09-08 00:00:00	0	46.799999999999983	35	1	1	0	35	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1093	862	\N	\N	2006-09-08 00:00:00	0	46.799999999999983	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1094	862	\N	\N	2006-09-08 00:00:00	0	46.799999999999983	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1095	863	\N	\N	2006-09-11 00:00:00	0	52.099999999999994	45	1	1	0	45	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1096	863	\N	\N	2006-09-11 00:00:00	0	52.099999999999994	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1097	863	\N	\N	2006-09-11 00:00:00	0	52.099999999999994	85	1	1	0	85	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1098	864	\N	\N	2006-09-11 00:00:00	0	55	75	1	1	0	75	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1099	864	\N	\N	2006-09-11 00:00:00	0	55	95	1	1	0	95	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1100	864	\N	\N	2006-09-11 00:00:00	0	55	105	1	1	0	105	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1101	865	\N	\N	2006-09-11 00:00:00	0	59.449999999999989	30	1	1	0	30	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1102	865	\N	\N	2006-09-11 00:00:00	0	59.449999999999989	50	1	1	0	50	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1103	865	\N	\N	2006-09-11 00:00:00	0	59.449999999999989	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1104	866	\N	\N	2006-09-11 00:00:00	0	62.599999999999994	95	1	1	0	95	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1105	866	\N	\N	2006-09-11 00:00:00	0	62.599999999999994	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:36
1106	866	\N	\N	2006-09-11 00:00:00	0	62.599999999999994	150	1	1	0	150	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1107	867	\N	\N	2006-09-11 00:00:00	0	67.5	53	1	1	0	53	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1108	867	\N	\N	2006-09-11 00:00:00	0	67.5	73	1	1	0	73	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1109	867	\N	\N	2006-09-11 00:00:00	0	67.5	102	1	1	0	102	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1110	401	\N	\N	2006-09-11 00:00:00	0	71.599999999999994	75	1	1	0	75	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1111	401	\N	\N	2006-09-11 00:00:00	0	71.599999999999994	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1112	401	\N	\N	2006-09-11 00:00:00	0	71.599999999999994	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1113	868	\N	\N	2006-09-11 00:00:00	0	76.599999999999994	73	1	1	0	73	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1114	868	\N	\N	2006-09-11 00:00:00	0	76.599999999999994	93	1	1	0	93	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1115	869	\N	\N	2006-09-11 00:00:00	0	82.099999999999994	72	1	1	0	72	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1116	869	\N	\N	2006-09-11 00:00:00	0	82.099999999999994	92	1	1	0	92	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1117	869	\N	\N	2006-09-11 00:00:00	0	82.099999999999994	116	1	1	0	116	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1118	870	\N	\N	2006-09-11 00:00:00	0	86.099999999999994	83	1	1	0	83	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1119	870	\N	\N	2006-09-11 00:00:00	0	86.099999999999994	103	1	1	0	103	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1120	870	\N	\N	2006-09-11 00:00:00	0	86.099999999999994	132	1	1	0	132	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1121	871	\N	\N	2006-09-11 00:00:00	0	90	78	1	1	0	78	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1122	871	\N	\N	2006-09-11 00:00:00	0	90	101	1	1	0	101	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1123	871	\N	\N	2006-09-11 00:00:00	0	90	121	1	1	0	121	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1124	2379	\N	\N	2006-09-11 00:00:00	0	90.199999999999989	126	1	1	0	126	\N	\N	\N	\N	\N	\N	2007-11-16 09:37:10
1125	873	\N	\N	2006-09-11 00:00:00	0	94.599999999999994	75	1	1	0	75	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1126	873	\N	\N	2006-09-11 00:00:00	0	94.599999999999994	126	1	1	0	126	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1127	873	\N	\N	2006-09-11 00:00:00	0	94.599999999999994	146	1	1	0	146	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1128	874	\N	\N	2006-09-12 00:00:00	0	100.09999999999999	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1129	874	\N	\N	2006-09-12 00:00:00	0	100.09999999999999	107	1	1	0	107	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1130	874	\N	\N	2006-09-12 00:00:00	0	100.09999999999999	127	1	1	0	127	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1131	875	\N	\N	2006-09-12 00:00:00	0	106.40000000000001	50	1	1	0	50	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1132	875	\N	\N	2006-09-12 00:00:00	0	106.40000000000001	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1133	875	\N	\N	2006-09-12 00:00:00	0	106.40000000000001	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1134	876	\N	\N	2006-09-12 00:00:00	0	109.29999999999998	64	1	1	0	64	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1135	876	\N	\N	2006-09-12 00:00:00	0	109.29999999999998	84	1	1	0	84	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1136	876	\N	\N	2006-09-12 00:00:00	0	109.29999999999998	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1137	877	\N	\N	2006-09-12 00:00:00	0	113.59999999999999	57	1	1	0	57	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1138	877	\N	\N	2006-09-12 00:00:00	0	113.59999999999999	77	1	1	0	77	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1139	877	\N	\N	2006-09-12 00:00:00	0	113.59999999999999	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1140	878	\N	\N	2006-09-12 00:00:00	0	119.59999999999999	116	1	1	0	116	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1141	878	\N	\N	2006-09-12 00:00:00	0	119.59999999999999	134	1	1	0	134	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1142	878	\N	\N	2006-09-12 00:00:00	0	119.59999999999999	154	1	1	0	154	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1143	879	\N	\N	2006-09-12 00:00:00	0	124.59999999999999	42	1	1	0	42	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1144	879	\N	\N	2006-09-12 00:00:00	0	124.59999999999999	62	1	1	0	62	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1145	879	\N	\N	2006-09-12 00:00:00	0	124.59999999999999	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1146	880	\N	\N	2006-09-12 00:00:00	0	129.59999999999999	54	1	1	0	54	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1147	880	\N	\N	2006-09-12 00:00:00	0	129.59999999999999	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1148	880	\N	\N	2006-09-12 00:00:00	0	129.59999999999999	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1149	881	\N	\N	2006-09-12 00:00:00	0	134.59999999999999	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1150	881	\N	\N	2006-09-12 00:00:00	0	134.59999999999999	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1151	881	\N	\N	2006-09-12 00:00:00	0	134.59999999999999	150	1	1	0	150	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1152	882	\N	\N	2006-09-12 00:00:00	0	137.19999999999999	40	1	1	0	40	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1153	882	\N	\N	2006-09-12 00:00:00	0	137.19999999999999	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1154	882	\N	\N	2006-09-12 00:00:00	0	137.19999999999999	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1155	883	\N	\N	2006-09-12 00:00:00	0	141.59999999999999	45	1	1	0	45	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1156	883	\N	\N	2006-09-12 00:00:00	0	141.59999999999999	65	1	1	0	65	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1157	883	\N	\N	2006-09-12 00:00:00	0	141.59999999999999	112	1	1	0	112	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1158	415	\N	\N	2006-09-12 00:00:00	0	147.59999999999999	55	1	1	0	55	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1159	415	\N	\N	2006-09-12 00:00:00	0	147.59999999999999	75	1	1	0	75	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1160	415	\N	\N	2006-09-12 00:00:00	0	147.59999999999999	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1161	415	\N	\N	2006-09-13 00:00:00	0	147.59999999999999	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1162	884	\N	\N	2006-09-12 00:00:00	0	149.40000000000001	109	1	1	0	109	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1163	885	\N	\N	2006-09-12 00:00:00	0	151.20000000000002	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1164	885	\N	\N	2006-09-12 00:00:00	0	151.20000000000002	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1165	885	\N	\N	2006-09-12 00:00:00	0	151.20000000000002	115	1	1	0	115	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:37
1166	886	\N	\N	2006-09-13 00:00:00	0	156.59999999999999	140	1	1	0	140	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1167	886	\N	\N	2006-09-13 00:00:00	0	156.59999999999999	165	1	1	0	165	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1168	887	\N	\N	2006-09-13 00:00:00	0	161.09999999999999	90	1	1	0	90	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1169	887	\N	\N	2006-09-13 00:00:00	0	161.09999999999999	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1170	887	\N	\N	2006-09-13 00:00:00	0	161.09999999999999	160	1	1	0	160	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1171	417	\N	\N	2006-09-13 00:00:00	0	166.59999999999999	50	1	1	0	50	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1172	417	\N	\N	2006-09-13 00:00:00	0	166.59999999999999	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1173	417	\N	\N	2006-09-13 00:00:00	0	166.59999999999999	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1174	888	\N	\N	2006-09-13 00:00:00	0	173.79999999999998	52	1	1	0	52	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1175	888	\N	\N	2006-09-13 00:00:00	0	173.79999999999998	125	1	1	0	125	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1176	889	\N	\N	2006-09-13 00:00:00	0	178.09999999999999	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1177	889	\N	\N	2006-09-13 00:00:00	0	178.09999999999999	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
1178	889	\N	\N	2006-09-13 00:00:00	0	178.09999999999999	180	1	1	0	180	\N	\N	\N	\N	\N	\N	2007-11-15 15:17:38
10244	870	\N	\N	2007-06-19 00:00:00	0	86.099999999999994	105	1	1	0	105	\N	\N	\N	\N	\N	\N	2008-12-04 00:00:00
10245	870	\N	\N	2007-06-19 00:00:00	0	86.099999999999994	130	1	1	0	130	\N	\N	\N	\N	\N	\N	2008-12-04 00:00:00
10246	871	\N	\N	2007-06-19 00:00:00	0	90	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2008-12-04 00:00:00
10247	871	\N	\N	2007-06-19 00:00:00	0	90	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2008-12-04 00:00:00
10248	871	\N	\N	2007-06-19 00:00:00	0	90	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2008-12-04 00:00:00
10255	3004	\N	\N	2007-06-19 00:00:00	0	93.599999999999994	140	1	1	0	140	\N	\N	\N	\N	\N	\N	2008-12-04 00:00:00
10260	875	\N	\N	2007-06-19 00:00:00	0	106.40000000000001	55	1	1	0	55	\N	\N	\N	\N	\N	\N	2008-12-05 00:00:00
10261	875	\N	\N	2007-06-19 00:00:00	0	106.40000000000001	75	1	1	0	75	\N	\N	\N	\N	\N	\N	2008-12-05 00:00:00
10262	875	\N	\N	2007-06-19 00:00:00	0	106.40000000000001	105	1	1	0	105	\N	\N	\N	\N	\N	\N	2008-12-05 00:00:00
10280	877	\N	\N	2007-06-20 00:00:00	0	113.59999999999999	60	1	1	0	60	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
10281	877	\N	\N	2007-06-20 00:00:00	0	113.59999999999999	80	1	1	0	80	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
10282	877	\N	\N	2007-06-20 00:00:00	0	113.59999999999999	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
10283	878	\N	\N	2007-06-20 00:00:00	0	119.59999999999999	110	1	1	0	110	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
10284	878	\N	\N	2007-06-20 00:00:00	0	119.59999999999999	135	1	1	0	135	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
10286	878	\N	\N	2007-06-20 00:00:00	0	119.59999999999999	155	1	1	0	155	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
10287	880	\N	\N	2007-06-20 00:00:00	0	129.59999999999999	55	1	1	0	55	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
10288	880	\N	\N	2007-06-20 00:00:00	0	129.59999999999999	100	1	1	0	100	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
10289	880	\N	\N	2007-06-20 00:00:00	0	129.59999999999999	120	1	1	0	120	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
10292	3021	\N	\N	2007-06-21 00:00:00	0	141	70	1	1	0	70	\N	\N	\N	\N	\N	\N	2008-12-08 00:00:00
\.


--
-- Data for Name: sprobe; Type: TABLE DATA; Schema: public; Owner: -
--

COPY sprobe (slotrechteid, lfdnr, wprozpkt, wpkt, vpkt, csandpkt, cschwebpkt, sandtrieb, schwebtrieb) FROM stdin;
11287	1	0	0.29999999999999999	0	0.36199999999999999	2.782	0	0
11287	2	0	2	0	0.60199999999999998	3.0219999999999998	0	0
11287	3	0	2.6000000000000001	0	0.95799999999999996	3.1579999999999999	0	0
11287	4	0	3	0	0.93799999999999994	3.3580000000000001	0	0
11286	1	0	0.29999999999999999	0	0.36499999999999999	3.085	0	0
11286	2	0	2	0	0.47299999999999998	3.133	0	0
11286	3	0	2.6000000000000001	0	0.624	4.0839999999999996	0	0
11286	4	0	3	0	1.056	6.1559999999999997	0	0
10990	1	0	0.29999999999999999	0.99699998	2.4039999999999999	31.584	2.3969999999999998	31.489000000000001
10990	2	0	1.3	0.68300003	3.02	30.699999999999999	2.0630000000000002	20.968
10990	3	0	1.8	0.60799998	3.2290000000000001	30.309000000000001	1.9630000000000001	18.428000000000001
10990	4	0	1.8999999999999999	0.51599997	4.4800000000000004	33.399999999999999	2.3119999999999998	17.234000000000002
10989	1	0	0.29999999999999999	1.975	3.4420000000000002	34.682000000000002	6.798	68.497
10989	2	0	4.2999999999999998	1.767	3.8420000000000001	36.642000000000003	6.7889999999999997	64.745999999999995
10989	3	0	5.7999999999999998	1.559	4.2160000000000002	28.236000000000001	6.5730000000000004	44.020000000000003
10989	4	0	6.9000000000000004	0.66900003	4.5839999999999996	34.344000000000001	3.0670000000000002	22.975999999999999
10988	1	0	0.29999999999999999	2.171	4.2960000000000003	32.816000000000003	9.327	71.244
10988	2	0	4.2999999999999998	1.881	7.0529999999999999	34.232999999999997	13.266999999999999	64.391999999999996
10988	3	0	5.7999999999999998	1.767	9.1020000000000003	36.981999999999999	16.082999999999998	65.346999999999994
10988	4	0	6.9000000000000004	1.409	21.007000000000001	53.307000000000002	29.599	75.109999999999999
10987	1	0	0.29999999999999999	2.2290001	5.6849999999999996	33.484999999999999	12.672000000000001	74.638000000000005
10987	2	0	4.5999999999999996	1.9630001	17.103999999999999	47.183999999999997	33.575000000000003	92.622
10987	3	0	6.2000000000000002	1.702	31.914999999999999	61.454999999999998	54.319000000000003	104.596
10987	4	0	7.4000000000000004	1.346	19.169	48.189	25.800999999999998	64.861999999999995
10986	1	0	0.29999999999999999	2.0090001	7.2110000000000003	36.470999999999997	14.487	73.269999999999996
10986	2	0	4.5	1.714	13.073	41.033000000000001	22.407	70.331000000000003
10986	3	0	6	1.489	18.962	51.302	28.234000000000002	76.388999999999996
10986	4	0	7.2000000000000002	0.43000001	92.584000000000003	124.404	39.811	53.494
10625	1	0	0.29999999999999999	0.53200001	1.984	16.423999999999999	1.0549999999999999	8.7379999999999995
10625	2	0	1.3	0.59399998	2.3759999999999999	16.076000000000001	1.411	9.5489999999999995
10625	3	0	1.7	0.493	2.2120000000000002	17.192	1.091	8.4760000000000009
10625	4	0	2.1000000000000001	0.34299999	2.2440000000000002	17.524000000000001	0.77000000000000002	6.0110000000000001
10624	1	0	0.29999999999999999	1.0930001	2.0640000000000001	15.084	2.2559999999999998	16.486999999999998
10624	2	0	1.7	0.97899997	2.6499999999999999	17.370000000000001	2.5939999999999999	17.004999999999999
10624	3	0	2.2000000000000002	0.89200002	2.9980000000000002	17.198	2.6739999999999999	15.340999999999999
10624	4	0	2.7999999999999998	0.42500001	5.7800000000000002	20.34	2.456	8.6440000000000001
10623	1	0	0.29999999999999999	1.0829999	2.3140000000000001	15.614000000000001	2.5059999999999998	16.91
10623	2	0	1.5	0.917	3.1880000000000002	17.728000000000002	2.923	16.257000000000001
10623	3	0	2	0.87	3.7080000000000002	17.268000000000001	3.226	15.023
10623	4	0	2.5	0.704	5.8360000000000003	19.896000000000001	4.109	14.007
10622	1	0	0.29999999999999999	1.006	2.508	16.628	2.5230000000000001	16.728000000000002
10622	2	0	1.5	0.93099999	3.1320000000000001	16.771999999999998	2.9159999999999999	15.615
10622	3	0	2	0.89200002	3.5640000000000001	17.263999999999999	3.1789999999999998	15.398999999999999
10622	4	0	2.5	0.741	4.3520000000000003	18.071999999999999	3.2250000000000001	13.391
10621	1	0	0.29999999999999999	1.052	2.1960000000000002	17.056000000000001	2.3100000000000001	17.943000000000001
10621	2	0	1.5	0.91100001	2.6099999999999999	16.350000000000001	2.3780000000000001	14.895
10621	3	0	2	0.83399999	2.4940000000000002	17.193999999999999	2.0800000000000001	14.34
10621	4	0	2.5	0.67699999	3.3500000000000001	18.670000000000002	2.2679999999999998	12.640000000000001
10610	1	0	0.29999999999999999	0.55000001	3.5529999999999999	23.273	1.954	12.800000000000001
10610	2	0	1.5	0.33000001	3.6469999999999998	30.106999999999999	1.204	9.9350000000000005
10610	3	0	2	0.16	4.3380000000000001	25.858000000000001	0.69399999999999995	4.1369999999999996
10610	4	0	2.2999999999999998	0.079999998	4.4420000000000002	23.222000000000001	0.35499999999999998	1.8580000000000001
10609	1	0	0.29999999999999999	1.04	5.4800000000000004	27.120000000000001	5.6989999999999998	28.204999999999998
10609	2	0	2.3999999999999999	0.79000002	4.8220000000000001	27.001999999999999	3.8090000000000002	21.332000000000001
10609	3	0	3.2000000000000002	0.52999997	5.6669999999999998	28.847000000000001	3.004	15.289
10609	4	0	3.7999999999999998	0.23999999	6.0910000000000002	28.530999999999999	1.462	6.8470000000000004
10608	1	0	0.29999999999999999	1.4400001	4.5270000000000001	27.847000000000001	6.5190000000000001	40.100000000000001
10608	2	0	2.3999999999999999	1.25	5.5359999999999996	27.916	6.9199999999999999	34.895000000000003
10608	3	0	3.2000000000000002	1.09	5.9269999999999996	29.847000000000001	6.46	32.533000000000001
10608	4	0	3.7999999999999998	0.77999997	6.8730000000000002	27.553000000000001	5.3609999999999998	21.491
10607	1	0	0.29999999999999999	1.53	5.8090000000000002	28.789000000000001	8.8879999999999999	44.046999999999997
10607	2	0	2.5	1.3	7.5510000000000002	29.791	9.8160000000000007	38.728000000000002
10607	3	0	3.2999999999999998	1.21	9.1180000000000003	31.957999999999998	11.032999999999999	38.668999999999997
10607	4	0	3.8999999999999999	0.95999998	13.851000000000001	36.790999999999997	13.297000000000001	35.319000000000003
10606	1	0	0.29999999999999999	1.4	4.593	28.933	6.4299999999999997	40.506
10606	2	0	2.2000000000000002	1.27	5.5110000000000001	29.690999999999999	6.9989999999999997	37.707999999999998
10606	3	0	3	1.09	6.024	27.623999999999999	6.5659999999999998	30.109999999999999
10606	4	0	3.5	0.95999998	7.633	33.993000000000002	7.3280000000000003	32.633000000000003
8220	1	0	0.29999999999999999	1.33	1.8200000000000001	25.379999999999999	2.4209999999999998	33.755000000000003
8220	2	0	3.5	1.23	2.3399999999999999	27.920000000000002	2.8780000000000001	34.341999999999999
8220	3	0	4.5999999999999996	1.16	2.3399999999999999	29.699999999999999	2.714	34.451999999999998
8220	4	0	5.5999999999999996	0.76999998	2.4100000000000001	29.690000000000001	1.8560000000000001	22.861000000000001
8221	1	0	0.29999999999999999	1.6799999	1.8700000000000001	26.09	3.1419999999999999	43.831000000000003
8221	2	0	3.5	1.37	2.4500000000000002	30.41	3.3570000000000002	41.661999999999999
8221	3	0	4.5999999999999996	1.23	3.1099999999999999	27.609999999999999	3.8250000000000002	33.960000000000001
8221	4	0	5.5999999999999996	1.1	3.1299999999999999	28.309999999999999	3.4430000000000001	31.140999999999998
8222	1	0	0.29999999999999999	1.73	2.9900000000000002	30.609999999999999	5.173	52.954999999999998
8222	2	0	3.6000000000000001	1.48	5.0499999999999998	30.190000000000001	7.4740000000000002	44.680999999999997
8222	3	0	4.7999999999999998	1.28	5.8300000000000001	31.93	7.4619999999999997	40.869999999999997
8222	4	0	5.7999999999999998	1.02	13.23	37.229999999999997	13.494999999999999	37.975000000000001
8223	1	0	0.29999999999999999	1.73	4.9000000000000004	30.940000000000001	8.4770000000000003	53.526000000000003
8223	2	0	3.5	1.49	11.32	40.82	16.867000000000001	60.822000000000003
8223	3	0	4.5999999999999996	1.28	25	50.140000000000001	32	64.179000000000002
8223	4	0	5.5999999999999996	0.83999997	196.38	226.25999999999999	164.959	190.05799999999999
8224	1	0	0.29999999999999999	1.52	3.6699999999999999	33.369999999999997	5.5780000000000003	50.722000000000001
8224	2	0	3.2999999999999998	1.28	6.21	39.549999999999997	7.9489999999999998	50.624000000000002
8224	3	0	4.4000000000000004	1.17	8.4700000000000006	37.090000000000003	9.9100000000000001	43.395000000000003
8224	4	0	5.2999999999999998	0.94999999	11.630000000000001	41.450000000000003	11.048	39.378
8060	1	0	0.29999999999999999	0.76800001	2.5600000000000001	42.460000000000001	1.966	32.609000000000002
8060	2	0	1.8999999999999999	0.58899999	2.48	36.060000000000002	1.4610000000000001	21.239000000000001
8060	3	0	2.6000000000000001	0.398	2.48	33.439999999999998	0.98699999999999999	13.308999999999999
8060	4	0	3	0.315	3.0600000000000001	35.759999999999998	0.96399999999999997	11.263999999999999
8061	1	0	0.29999999999999999	1.302	2.52	33.880000000000003	3.2810000000000001	44.112000000000002
8061	2	0	2.7999999999999998	1.0779999	3.9700000000000002	36.57	4.2800000000000002	39.421999999999997
8061	3	0	3.7999999999999998	0.99699998	3.8199999999999998	36.100000000000001	3.8090000000000002	35.991999999999997
8061	4	0	4.5	0.96100003	4.1200000000000001	35.880000000000003	3.9590000000000001	34.481000000000002
8062	1	0	0.29999999999999999	1.457	3.8999999999999999	32.880000000000003	5.6820000000000004	47.905999999999999
8062	2	0	2.7999999999999998	1.309	6.9800000000000004	39.380000000000003	9.1370000000000005	51.548000000000002
8062	3	0	3.7999999999999998	1.164	11.380000000000001	47.079999999999998	13.246	54.801000000000002
8062	4	0	4.5	0.90100002	30.760000000000002	64.420000000000002	27.715	58.042000000000002
8063	1	0	0.29999999999999999	1.576	3.1800000000000002	31.98	5.0119999999999996	50.399999999999999
8063	2	0	2.7999999999999998	1.346	7.9500000000000002	42.829999999999998	10.701000000000001	57.649000000000001
8063	3	0	3.7999999999999998	1.186	13.619999999999999	48.32	16.152999999999999	57.308
8063	4	0	4.5	1.003	38.289999999999999	70.709999999999994	38.405000000000001	70.921999999999997
8064	1	0	0.29999999999999999	1.428	3.3599999999999999	34.359999999999999	4.798	49.066000000000003
8064	2	0	2.7999999999999998	1.244	6.1399999999999997	37.840000000000003	7.6379999999999999	47.073
8064	3	0	3.7999999999999998	1.0650001	8.2200000000000006	40.18	8.7539999999999996	42.792000000000002
8064	4	0	4.5	0.852	15.42	45.640000000000001	13.138	38.884999999999998
7645	1	0	0.29999999999999999	1.86	3.8100000000000001	43.140000000000001	7.0869999999999997	80.239999999999995
7645	2	0	4	1.61	3.9199999999999999	46.590000000000003	6.3109999999999999	75.010000000000005
7645	3	0	5.4000000000000004	1.21	4.6399999999999997	41.310000000000002	5.6139999999999999	49.984999999999999
7645	4	0	6.5	1.05	5.0899999999999999	43.759999999999998	5.3440000000000003	45.948
7646	1	0	0.29999999999999999	2.03	3.4700000000000002	44.140000000000001	7.0439999999999996	89.603999999999999
7646	2	0	4.2999999999999998	1.65	3.77	42.439999999999998	6.2199999999999998	70.025999999999996
7646	3	0	5.7999999999999998	1.64	4.2599999999999998	40.259999999999998	6.9859999999999998	66.025999999999996
7646	4	0	7	1.09	7.3600000000000003	45.359999999999999	8.0220000000000002	49.442
7647	1	0	0.29999999999999999	2.1300001	3.2799999999999998	39.950000000000003	6.9859999999999998	85.093000000000004
7647	2	0	4.5999999999999996	1.73	4.9400000000000004	40.939999999999998	8.5459999999999994	70.825999999999993
7647	3	0	6.2000000000000002	1.58	6.1500000000000004	38.82	9.7170000000000005	61.335999999999999
7647	4	0	7.5	0.94999999	9.7400000000000002	48.399999999999999	9.2530000000000001	45.979999999999997
7648	1	0	0.29999999999999999	2.24	6.5999999999999996	45.939999999999998	14.784000000000001	102.90600000000001
7648	2	0	4.2999999999999998	1.97	14.76	56.090000000000003	29.077000000000002	110.497
7648	3	0	5.7999999999999998	1.67	33.770000000000003	64.439999999999998	56.396000000000001	107.61499999999999
7648	4	0	7	1.37	75.859999999999999	121.19	103.928	166.03
7649	1	0	0.29999999999999999	2.04	4.2999999999999998	32.969999999999999	8.7720000000000002	67.259
7649	2	0	4	1.89	12	44	22.68	83.159999999999997
7649	3	0	5.4000000000000004	1.59	17.559999999999999	64.890000000000001	27.920000000000002	103.175
7649	4	0	6.5	1.21	34.759999999999998	74.75	42.060000000000002	90.447000000000003
7640	1	0	0.29999999999999999	0.57999998	1.6299999999999999	23.129999999999999	0.94499999999999995	13.414999999999999
7640	2	0	1.3	0.27000001	2.0699999999999998	20.57	0.55900000000000005	5.5540000000000003
7640	3	0	1.7	0.20999999	1.6699999999999999	20.670000000000002	0.35099999999999998	4.3410000000000002
7640	4	0	1.8999999999999999	0.18000001	1.9299999999999999	20.43	0.34699999999999998	3.677
7641	1	0	0.29999999999999999	1.0700001	1.8100000000000001	21.32	1.9370000000000001	22.812000000000001
7641	2	0	2.2000000000000002	0.94	1.8500000000000001	19.850000000000001	1.7390000000000001	18.658999999999999
7641	3	0	2.8999999999999999	0.82999998	2.1499999999999999	20.149999999999999	1.784	16.725000000000001
7641	4	0	3.3999999999999999	0.56	2.2200000000000002	22.719999999999999	1.2430000000000001	12.723000000000001
7642	1	0	0.29999999999999999	1.28	1.9299999999999999	21.93	2.4700000000000002	28.07
7642	2	0	2.2999999999999998	1.08	2	22	2.1600000000000001	23.760000000000002
7642	3	0	3	0.97000003	1.96	22.460000000000001	1.901	21.786000000000001
7642	4	0	3.6000000000000001	0.66000003	2.3300000000000001	21.829999999999998	1.538	14.407999999999999
7643	1	0	0.29999999999999999	1.08	2.8500000000000001	23.850000000000001	3.0779999999999998	25.757999999999999
7643	2	0	2.2000000000000002	0.94	7.7400000000000002	27.239999999999998	7.2759999999999998	25.606000000000002
7643	3	0	3	0.82999998	6.5599999999999996	26.559999999999999	5.4450000000000003	22.045000000000002
7643	4	0	3.5	0.55000001	16.300000000000001	38.299999999999997	8.9649999999999999	21.065000000000001
7644	1	0	0.29999999999999999	1.05	2.48	25.48	2.6040000000000001	26.754000000000001
7644	2	0	2.2999999999999998	0.86000001	2.7400000000000002	21.739999999999998	2.3559999999999999	18.696000000000002
7644	3	0	3	0.80000001	4.4800000000000004	23.48	3.5840000000000001	18.783999999999999
7644	4	0	3.6000000000000001	0.49000001	7.7400000000000002	28.739999999999998	3.7930000000000001	14.083
7635	1	0	0.29999999999999999	0.94999999	7.4699999999999998	79.469999999999999	7.0970000000000004	75.495999999999995
7635	2	0	1	0.62	9.4000000000000004	85.400000000000006	5.8280000000000003	52.948
7635	3	0	1.3999999999999999	0.28	8.4100000000000001	85.75	2.355	24.010000000000002
7635	4	0	1.5	0.88999999	14.26	92.930000000000007	12.691000000000001	82.707999999999998
7636	1	0	0.29999999999999999	2.03	8.7200000000000006	90.049999999999997	17.702000000000002	182.80099999999999
7636	2	0	4.2000000000000002	1.6799999	12.91	90.909999999999997	21.689	152.72900000000001
7636	3	0	5.5999999999999996	1.53	15.619999999999999	90.959999999999994	23.899000000000001	139.16900000000001
7636	4	0	6.7999999999999998	0.85000002	17.399999999999999	97.400000000000006	14.789999999999999	82.790000000000006
7637	1	0	0.29999999999999999	1.99	10.19	80.859999999999999	20.277999999999999	160.911
7637	2	0	4.4000000000000004	1.63	13.66	80.989999999999995	22.265999999999998	132.01400000000001
7637	3	0	5.9000000000000004	1.66	15.699999999999999	87.030000000000001	26.062000000000001	144.47
7637	4	0	7.2000000000000002	1.26	18.34	93.010000000000005	23.108000000000001	117.193
7638	1	0	0.29999999999999999	2	16.91	83.569999999999993	33.82	167.13999999999999
7638	2	0	4.2999999999999998	1.62	35.619999999999997	110.29000000000001	57.704000000000001	178.66999999999999
7638	3	0	5.7999999999999998	1.55	42.600000000000001	123.27	66.030000000000001	191.06800000000001
7638	4	0	7	0.91000003	121.73999999999999	207.74000000000001	110.783	189.04300000000001
7639	1	0	0.29999999999999999	1.96	9.2400000000000002	78.579999999999998	18.109999999999999	154.017
7639	2	0	4.2999999999999998	1.66	25.170000000000002	97.170000000000002	41.781999999999996	161.30199999999999
7639	3	0	5.7000000000000002	1.39	28.789999999999999	108.79000000000001	40.018000000000001	151.21799999999999
7639	4	0	6.9000000000000004	0.50999999	82.75	144.75	42.203000000000003	73.822000000000003
7630	1	0	0.29999999999999999	0.52999997	2.0800000000000001	24.079999999999998	1.1020000000000001	12.762
7630	2	0	1.3999999999999999	0.49000001	2.2599999999999998	24.260000000000002	1.107	11.887
7630	3	0	1.8999999999999999	0.43000001	2.3799999999999999	26.379999999999999	1.0229999999999999	11.343
7630	4	0	2.2000000000000002	0.28999999	2.75	24.09	0.79800000000000004	6.9859999999999998
7631	1	0	0.29999999999999999	0.91000003	2	26.670000000000002	1.8200000000000001	24.27
7631	2	0	1.6000000000000001	0.81	2.1499999999999999	28.82	1.742	23.344000000000001
7631	3	0	2.2000000000000002	0.68000001	2.3799999999999999	25.039999999999999	1.6180000000000001	17.027000000000001
7631	4	0	2.5	0.58999997	2.7200000000000002	30.050000000000001	1.605	17.728999999999999
7632	1	0	0.29999999999999999	0.94	2	28.670000000000002	1.8799999999999999	26.949999999999999
7632	2	0	1.6000000000000001	0.79000002	2.6000000000000001	25.940000000000001	2.0539999999999998	20.492999999999999
7632	3	0	2.2000000000000002	0.70999998	3.25	25.25	2.3069999999999999	17.928000000000001
7632	4	0	2.5	0.54000002	3.4300000000000002	26.77	1.8520000000000001	14.456
7633	1	0	0.29999999999999999	0.88	1.77	27.77	1.5580000000000001	24.437999999999999
7574	5	0	2.5	0.66000003	8.1199999999999992	8.1199999999999992	5.359	5.359
7575	1	0	0.29999999999999999	1.5	4	4	6	6
7575	2	0	1.3999999999999999	1.36	5	5	6.7999999999999998	6.7999999999999998
7575	3	0	1.8999999999999999	1.25	5.7599999999999998	5.7599999999999998	7.2000000000000002	7.2000000000000002
7575	4	0	2.3999999999999999	1.0700001	6	6	6.4199999999999999	6.4199999999999999
7575	5	0	2.6000000000000001	0.83999997	10.44	10.44	8.7699999999999996	8.7699999999999996
7576	1	0	0.29999999999999999	1.42	4.1600000000000001	4.1600000000000001	5.907	5.907
7576	2	0	1.6000000000000001	1.3099999	7.5599999999999996	7.5599999999999996	9.9039999999999999	9.9039999999999999
7576	3	0	2.2999999999999998	1.11	8.1600000000000001	8.1600000000000001	9.0579999999999998	9.0579999999999998
7576	4	0	2.7999999999999998	0.86000001	14.720000000000001	14.720000000000001	12.659000000000001	12.659000000000001
7576	5	0	3	0.68000001	29.920000000000002	29.920000000000002	20.346	20.346
7577	1	0	0.29999999999999999	1.29	5.4800000000000004	5.4800000000000004	7.069	7.069
7577	2	0	1.8	1.23	5.4800000000000004	5.4800000000000004	6.7400000000000002	6.7400000000000002
7577	3	0	2.5	1.13	23.920000000000002	23.920000000000002	27.030000000000001	27.030000000000001
7577	4	0	3	0.98000002	26.48	26.48	25.949999999999999	25.949999999999999
7577	5	0	3.1000000000000001	0.89999998	31.960000000000001	31.960000000000001	28.763999999999999	28.763999999999999
7577	6	0	3.2999999999999998	0.86000001	58.100000000000001	58.100000000000001	49.966000000000001	49.966000000000001
7578	1	0	0.29999999999999999	1.4400001	4.8399999999999999	4.8399999999999999	6.9699999999999998	6.9699999999999998
7578	2	0	1.8999999999999999	1.38	6.8799999999999999	6.8799999999999999	9.4939999999999998	9.4939999999999998
7578	3	0	2.7000000000000002	1.11	8.9600000000000009	8.9600000000000009	9.9459999999999997	9.9459999999999997
7578	4	0	3.2000000000000002	0.95999998	16.640000000000001	16.640000000000001	15.974	15.974
7578	5	0	3.3999999999999999	0.72000003	26.239999999999998	26.239999999999998	18.893000000000001	18.893000000000001
7579	1	0	0.29999999999999999	1.45	3.3999999999999999	3.3999999999999999	4.9299999999999997	4.9299999999999997
7579	2	0	1.8999999999999999	1.4	4.8399999999999999	4.8399999999999999	6.7759999999999998	6.7759999999999998
7579	3	0	2.6000000000000001	1.27	3.96	3.96	5.0289999999999999	5.0289999999999999
7579	4	0	3.1000000000000001	1.17	5.2999999999999998	5.2999999999999998	6.2009999999999996	6.2009999999999996
7579	5	0	3.3999999999999999	0.88999999	5.8399999999999999	5.8399999999999999	5.1980000000000004	5.1980000000000004
7579	6	0	3.6000000000000001	0.56	9.1199999999999992	9.1199999999999992	5.1070000000000002	5.1070000000000002
7580	1	0	0.29999999999999999	1.45	3.2799999999999998	3.2799999999999998	4.7560000000000002	4.7560000000000002
7580	2	0	1.8999999999999999	1.33	3.52	3.52	4.6820000000000004	4.6820000000000004
7580	3	0	2.6000000000000001	1.1799999	3.7599999999999998	3.7599999999999998	4.4370000000000003	4.4370000000000003
7580	4	0	3.1000000000000001	1.0599999	4.2400000000000002	4.2400000000000002	4.4939999999999998	4.4939999999999998
7580	5	0	3.6000000000000001	0.63	5.1600000000000001	5.1600000000000001	3.2509999999999999	3.2509999999999999
7581	1	0	0.29999999999999999	1.16	2.4399999999999999	2.4399999999999999	2.8300000000000001	2.8300000000000001
7581	2	0	1.3	1.04	2.6000000000000001	2.6000000000000001	2.7040000000000002	2.7040000000000002
7581	3	0	1.8	0.91000003	2.6400000000000001	2.6400000000000001	2.4020000000000001	2.4020000000000001
7581	4	0	2.1000000000000001	0.76999998	2.6000000000000001	2.6000000000000001	2.0019999999999998	2.0019999999999998
7581	5	0	2.3999999999999999	0.68000001	3.1600000000000001	3.1600000000000001	2.149	2.149
7564	1	0	0.29999999999999999	1.09	2.52	2.52	2.7469999999999999	2.7469999999999999
7564	2	0	1	0.98000002	3.1600000000000001	3.1600000000000001	3.097	3.097
7564	3	0	1.3999999999999999	1.01	2.9199999999999999	2.9199999999999999	2.9489999999999998	2.9489999999999998
7564	4	0	1.6000000000000001	0.51999998	3.2000000000000002	3.2000000000000002	1.6639999999999999	1.6639999999999999
7565	1	0	0.29999999999999999	1.03	2.52	2.52	2.5960000000000001	2.5960000000000001
7565	2	0	1	0.95999998	3.1600000000000001	3.1600000000000001	3.0339999999999998	3.0339999999999998
7565	3	0	1.3999999999999999	0.81999999	3.96	3.96	3.2469999999999999	3.2469999999999999
7565	4	0	1.7	0.63	4.4400000000000004	4.4400000000000004	2.7970000000000002	2.7970000000000002
7565	5	0	1.8999999999999999	0.50999999	5.3200000000000003	5.3200000000000003	2.7130000000000001	2.7130000000000001
7566	1	0	0.29999999999999999	1.28	3.1600000000000001	3.1600000000000001	4.0449999999999999	4.0449999999999999
7566	2	0	1.2	1.1	3.4399999999999999	3.4399999999999999	3.7839999999999998	3.7839999999999998
7566	3	0	1.6000000000000001	0.99000001	3.8799999999999999	3.8799999999999999	3.8410000000000002	3.8410000000000002
7566	4	0	2	0.63	5.8399999999999999	5.8399999999999999	3.6789999999999998	3.6789999999999998
7566	5	0	2.1000000000000001	0.38	5.8399999999999999	5.8399999999999999	2.2189999999999999	2.2189999999999999
7567	1	0	0.29999999999999999	1.16	2.7200000000000002	2.7200000000000002	3.1549999999999998	3.1549999999999998
7567	2	0	1.3999999999999999	1.04	3.52	3.52	3.661	3.661
7567	3	0	1.8	0.88999999	3.2799999999999998	3.2799999999999998	2.919	2.919
7567	4	0	2.1000000000000001	0.76999998	5.3600000000000003	5.3600000000000003	4.1269999999999998	4.1269999999999998
7567	5	0	2.2999999999999998	0.60000002	7.7999999999999998	7.7999999999999998	4.6799999999999997	4.6799999999999997
7568	1	0	0.29999999999999999	1.24	2.7999999999999998	2.7999999999999998	3.472	3.472
7568	2	0	1.3	1.17	3.52	3.52	4.1180000000000003	4.1180000000000003
7568	3	0	1.8	0.94999999	5	5	4.75	4.75
7568	4	0	2.2000000000000002	0.83999997	6.4400000000000004	6.4400000000000004	5.4100000000000001	5.4100000000000001
7568	5	0	2.3999999999999999	0.74000001	10.4	10.4	7.6959999999999997	7.6959999999999997
7569	1	0	0.29999999999999999	1.41	3.8399999999999999	3.8399999999999999	5.4139999999999997	5.4139999999999997
7569	2	0	1.3999999999999999	1.13	5.0800000000000001	5.0800000000000001	5.7400000000000002	5.7400000000000002
7569	3	0	2	1.0599999	10.119999999999999	10.119999999999999	10.727	10.727
7569	4	0	2.3999999999999999	0.86000001	17.039999999999999	17.039999999999999	14.654	14.654
7569	5	0	2.6000000000000001	0.67000002	45.060000000000002	45.060000000000002	30.190000000000001	30.190000000000001
7570	1	0	0.29999999999999999	1.47	3.6800000000000002	3.6800000000000002	5.4100000000000001	5.4100000000000001
7570	2	0	1.6000000000000001	1.24	5.4800000000000004	5.4800000000000004	6.7949999999999999	6.7949999999999999
7570	3	0	2.2000000000000002	1.08	9.4399999999999995	9.4399999999999995	10.195	10.195
7570	4	0	2.6000000000000001	0.89999998	18.199999999999999	18.199999999999999	16.379999999999999	16.379999999999999
7570	5	0	2.8999999999999999	0.63999999	33.920000000000002	33.920000000000002	21.709	21.709
7571	1	0	0.29999999999999999	1.3099999	2.8799999999999999	2.8799999999999999	3.7730000000000001	3.7730000000000001
7571	2	0	1.7	0.97000003	7.1600000000000001	7.1600000000000001	6.9450000000000003	6.9450000000000003
7571	3	0	2.2999999999999998	1.1799999	4.9199999999999999	4.9199999999999999	5.806	5.806
7571	4	0	2.8999999999999999	0.86000001	9.4399999999999995	9.4399999999999995	8.1180000000000003	8.1180000000000003
7571	5	0	3.1000000000000001	0.66000003	15.56	15.56	10.27	10.27
7572	1	0	0.29999999999999999	1.45	3.3999999999999999	3.3999999999999999	4.9299999999999997	4.9299999999999997
7572	2	0	1.8	1.1900001	3.4399999999999999	3.4399999999999999	4.0940000000000003	4.0940000000000003
7572	3	0	2.5	1.12	3.3999999999999999	3.3999999999999999	3.8079999999999998	3.8079999999999998
7572	4	0	3	0.91000003	3.7599999999999998	3.7599999999999998	3.4220000000000002	3.4220000000000002
7572	5	0	3.2999999999999998	0.69999999	5.0800000000000001	5.0800000000000001	3.556	3.556
6653	1	0	0.29999999999999999	1.01	4.4900000000000002	31.16	4.5350000000000001	31.472000000000001
6653	2	0	0.69999999999999996	0.91000003	4.6799999999999997	35.350000000000001	4.2590000000000003	32.167999999999999
6653	3	0	0.90000000000000002	0.77999997	5.2800000000000002	37.950000000000003	4.1180000000000003	29.600999999999999
6653	4	0	1	0.63999999	9.5899999999999999	50.25	6.1379999999999999	32.159999999999997
6654	1	0	0.29999999999999999	1.0700001	5	36.5	5.3499999999999996	39.055
6654	2	0	1	0.95999998	5.6299999999999999	37.130000000000003	5.4050000000000002	35.645000000000003
6654	3	0	1.3	0.83999997	5.96	35.960000000000001	5.0060000000000002	30.206
6654	4	0	1.3999999999999999	0.74000001	6.2599999999999998	36.259999999999998	4.6319999999999997	26.832000000000001
6655	1	0	0.29999999999999999	1.12	4.7000000000000002	30.699999999999999	5.2640000000000002	34.384
6655	2	0	1.1000000000000001	0.94	5.8499999999999996	32.850000000000001	5.4989999999999997	30.879000000000001
6655	3	0	1.5	0.74000001	6.1500000000000004	38.649999999999999	4.5510000000000002	28.600999999999999
6655	4	0	1.7	0.52999997	7.7400000000000002	39.240000000000002	4.1020000000000003	20.797000000000001
6656	1	0	0.29999999999999999	1.28	4.9299999999999997	32.93	6.3099999999999996	42.149999999999999
6656	2	0	1.6000000000000001	1.0599999	5.8499999999999996	36.850000000000001	6.2009999999999996	39.061
6656	3	0	2.1000000000000001	0.88999999	6.3300000000000001	25.829999999999998	5.6340000000000003	22.989000000000001
6656	4	0	2.3999999999999999	0.70999998	9.1099999999999994	39.109999999999999	6.468	27.768000000000001
6657	1	0	0.29999999999999999	1.16	5.8200000000000003	30.82	6.7510000000000003	35.750999999999998
6657	2	0	1.7	0.82999998	7.04	36.539999999999999	5.843	30.327999999999999
6657	3	0	2.2000000000000002	0.70999998	7	41	4.9699999999999998	29.109999999999999
6657	4	0	2.6000000000000001	0.49000001	7.1900000000000004	38.189999999999998	3.5230000000000001	18.713000000000001
6648	1	0	0.29999999999999999	1.05	2.2400000000000002	22.440000000000001	2.3519999999999999	23.562000000000001
6648	2	0	0.59999999999999998	0.94999999	2.29	17.09	2.1760000000000002	16.234999999999999
6648	3	0	0.69999999999999996	0.88	2.5299999999999998	19.530000000000001	2.226	17.186
6648	4	0	0.80000000000000004	0.75	2.73	17.93	2.0470000000000002	13.448
6649	1	0	0.29999999999999999	1.05	2.6699999999999999	15.869999999999999	2.8029999999999999	16.664000000000001
6649	2	0	0.80000000000000004	0.95999998	2.4900000000000002	16.09	2.3900000000000001	15.446
6649	3	0	1.1000000000000001	0.76999998	2.7999999999999998	21.800000000000001	2.1560000000000001	16.786000000000001
6649	4	0	1.2	0.62	3.9500000000000002	24.149999999999999	2.4489999999999998	14.973000000000001
6650	1	0	0.29999999999999999	1.01	2.8900000000000001	22.489999999999998	2.919	22.715
6650	2	0	1	0.85000002	2.98	22.379999999999999	2.5329999999999999	19.023
6650	3	0	1.3999999999999999	0.72000003	3.04	16.640000000000001	2.1890000000000001	11.981
6650	4	0	1.5	0.62	1.55	44.149999999999999	0.96099999999999997	27.373000000000001
6651	1	0	0.29999999999999999	1.1	3.54	18.140000000000001	3.8940000000000001	19.954000000000001
6651	2	0	1.3	1.05	4.3099999999999996	22.710000000000001	4.5250000000000004	23.846
6651	3	0	1.8	0.94999999	4.1100000000000003	20.91	3.9039999999999999	19.864000000000001
6651	4	0	2	0.81	5.6900000000000004	26.09	4.609	21.132999999999999
6652	1	0	0.29999999999999999	1.22	2.5499999999999998	13.949999999999999	3.1110000000000002	17.018999999999998
6652	2	0	1.7	1.0599999	2.6200000000000001	19.620000000000001	2.7770000000000001	20.797000000000001
6652	3	0	2.2000000000000002	0.85000002	2.8399999999999999	17.640000000000001	2.4140000000000001	14.994
6652	4	0	2.6000000000000001	0.54000002	2.8500000000000001	21.66	1.5389999999999999	11.696
6638	1	0	0.29999999999999999	1.03	3.96	34.299999999999997	4.0789999999999997	35.329000000000001
6638	2	0	0.59999999999999998	0.92000002	3.6000000000000001	33.939999999999998	3.3119999999999998	31.225000000000001
6638	3	0	0.80000000000000004	0.75	5	45	3.75	33.75
6639	1	0	0.29999999999999999	1.12	4.3399999999999999	53.009999999999998	4.8609999999999998	59.371000000000002
6639	2	0	1	0.98000002	4.04	57.369999999999997	3.9590000000000001	56.222999999999999
6639	3	0	1.3	0.82999998	5.2300000000000004	60.560000000000002	4.3410000000000002	50.265000000000001
6639	4	0	1.3999999999999999	0.80000001	5.25	56.579999999999998	4.2000000000000002	45.264000000000003
6640	1	0	0.29999999999999999	1.29	4.1100000000000003	34.450000000000003	5.3019999999999996	44.441000000000003
6640	2	0	1.3	1.11	4.9199999999999999	55.590000000000003	5.4610000000000003	61.704999999999998
6640	3	0	1.8	0.88	7.4299999999999997	49.770000000000003	6.5380000000000003	43.798000000000002
6640	4	0	2	0.75999999	8.3399999999999999	35.340000000000003	6.3380000000000001	26.858000000000001
6641	1	0	0.29999999999999999	1.33	3.3799999999999999	48.18	4.4950000000000001	64.078999999999994
6641	2	0	1.3999999999999999	1.2	3.96	36.560000000000002	4.7519999999999998	43.872
6641	3	0	1.8	1.08	5.1100000000000003	50.909999999999997	5.5190000000000001	54.982999999999997
6641	4	0	2.1000000000000001	0.93000001	6	49.799999999999997	5.5800000000000001	46.314
6642	1	0	0.29999999999999999	1.26	2.6699999999999999	43.270000000000003	3.3639999999999999	54.520000000000003
6642	2	0	1.6000000000000001	1.03	3.02	20.02	3.1110000000000002	20.620999999999999
6642	3	0	2.1000000000000001	0.87	3.02	48.020000000000003	2.6269999999999998	41.777000000000001
6642	4	0	2.3999999999999999	0.63	3.4399999999999999	37.640000000000001	2.1669999999999998	23.713000000000001
6663	1	0	0.29999999999999999	1.08	2.6099999999999999	27.359999999999999	2.819	29.548999999999999
6663	2	0	0.80000000000000004	0.94999999	3.02	39.020000000000003	2.8690000000000002	37.069000000000003
6663	3	0	1	0.89999998	3.1699999999999999	25.920000000000002	2.8530000000000002	23.327999999999999
6663	4	0	1.3	0.69	3.7400000000000002	24.239999999999998	2.581	16.725999999999999
6664	1	0	0.29999999999999999	1.1900001	2.5699999999999998	34.57	3.0579999999999998	41.137999999999998
6664	2	0	1	1.12	3	25	3.3599999999999999	28
6664	3	0	1.3999999999999999	0.94	3.0899999999999999	24.09	2.9049999999999998	22.645
6664	4	0	1.7	0.62	3.8900000000000001	32.890000000000001	2.4119999999999999	20.391999999999999
6665	1	0	0.29999999999999999	1.23	3	23.5	3.6899999999999999	28.905000000000001
6665	2	0	1.2	1.04	3.6299999999999999	37.880000000000003	3.7749999999999999	39.395000000000003
6665	3	0	1.6000000000000001	0.83999997	4.4400000000000004	22.940000000000001	3.73	19.27
6665	4	0	2	0.74000001	4.9299999999999997	24.93	3.6480000000000001	18.448
6666	1	0	0.29999999999999999	1.33	3.1099999999999999	23.109999999999999	4.1360000000000001	30.736000000000001
6666	2	0	1.6000000000000001	1.21	3.1699999999999999	27.670000000000002	3.8359999999999999	33.481000000000002
6666	3	0	2.1000000000000001	1.08	3.7799999999999998	38.280000000000001	4.0819999999999999	41.341999999999999
6666	4	0	2.7000000000000002	0.77999997	4.9100000000000001	32.409999999999997	3.8300000000000001	25.280000000000001
6667	1	0	0.29999999999999999	1.3200001	3.1899999999999999	28.68	4.2110000000000003	37.857999999999997
6667	2	0	1.7	1.13	3.5600000000000001	41.060000000000002	4.0229999999999997	46.398000000000003
6667	3	0	2.2999999999999998	0.92000002	3.6299999999999999	22.879999999999999	3.3399999999999999	21.050000000000001
6667	4	0	2.8999999999999999	0.52999997	3.8700000000000001	33.869999999999997	2.0510000000000002	17.951000000000001
6643	1	0	0.29999999999999999	1.53	3.2999999999999998	21.800000000000001	5.0490000000000004	33.353999999999999
6643	2	0	1.6000000000000001	1.38	3.8500000000000001	24.100000000000001	5.3129999999999997	33.258000000000003
6643	3	0	2.2000000000000002	1.2	4.1799999999999997	28.18	5.016	33.816000000000003
6643	4	0	2.6499999999999999	0.98000002	6.8700000000000001	34.630000000000003	6.7329999999999997	33.936999999999998
6644	1	0	0.29999999999999999	1.7	2.1099999999999999	27.109999999999999	3.5870000000000002	46.087000000000003
6644	2	0	2	1.54	4.3700000000000001	23.120000000000001	6.7300000000000004	35.604999999999997
6644	3	0	2.7000000000000002	1.35	6	24	8.0999999999999996	32.399999999999999
6644	4	0	3.3500000000000001	0.95999998	8.4100000000000001	38.659999999999997	8.0739999999999998	37.113999999999997
6645	1	0	0.29999999999999999	1.72	6.9299999999999997	27.68	11.92	47.609999999999999
6645	2	0	2.2999999999999998	1.46	9.5399999999999991	30.289999999999999	13.928000000000001	44.222999999999999
6645	3	0	3	1.3	11.609999999999999	44.359999999999999	15.093	57.667999999999999
6645	4	0	3.75	0.85000002	21.649999999999999	42.149999999999999	18.402000000000001	35.828000000000003
6646	1	0	0.29999999999999999	1.71	3.3900000000000001	26.140000000000001	5.7969999999999997	44.698999999999998
6646	2	0	2.6000000000000001	1.55	4.0199999999999996	32.270000000000003	6.2309999999999999	50.018000000000001
6646	3	0	3.5	1.37	4.3200000000000003	36.810000000000002	5.9180000000000001	50.43
6646	4	0	4.3499999999999996	0.81	3.3100000000000001	24.32	2.681	19.699000000000002
6647	1	0	0.29999999999999999	1.66	3.5699999999999998	29.32	5.9260000000000002	48.670999999999999
6647	2	0	2.7999999999999998	1.49	4.4400000000000004	38.689999999999998	6.6159999999999997	57.648000000000003
6647	3	0	3.7999999999999998	1.26	5.6699999999999999	41.420000000000002	7.1440000000000001	52.189
6647	4	0	4.6500000000000004	0.69999999	7.2599999999999998	37.259999999999998	5.0819999999999999	26.082000000000001
6632	1	0	0.29999999999999999	0.89999998	2.8300000000000001	26.329999999999998	2.5470000000000002	23.696999999999999
6632	2	0	1.6000000000000001	0.80000001	3.0699999999999998	21.07	2.456	16.856000000000002
6632	3	0	2.2000000000000002	0.60000002	3.4300000000000002	21.43	2.0579999999999998	12.858000000000001
6632	4	0	2.5	0.2	3.9399999999999999	23.690000000000001	0.78800000000000003	4.7380000000000004
6633	1	0	0.29999999999999999	1.4	3.0899999999999999	19.09	4.3259999999999996	26.725999999999999
6633	2	0	1.7	1.2	3.9300000000000002	20.43	4.7160000000000002	24.515999999999998
6633	3	0	2.2999999999999998	1.2	3.48	18.73	4.1760000000000002	22.475999999999999
11163	4	0	3.1000000000000001	1.007	3.6619999999999999	16.462	3.6880000000000002	16.577000000000002
11172	1	0	0.29999999999999999	1.0650001	1.4470000000000001	18.387	1.5409999999999999	19.582000000000001
11172	2	0	1.7	0.93000001	2.3490000000000002	17.588999999999999	2.1850000000000001	16.358000000000001
11172	3	0	2.2000000000000002	0.579	1.7889999999999999	27.029	1.036	15.65
11172	4	0	2.5	0.45300001	4.1269999999999998	17.966999999999999	1.8700000000000001	8.1389999999999993
11171	1	0	0.29999999999999999	1.501	1.847	6.4870000000000001	2.7719999999999998	9.7370000000000001
11171	2	0	2.6000000000000001	1.45	3.2400000000000002	15.279999999999999	4.6980000000000004	22.155999999999999
11171	3	0	3.5	1.199	1.4039999999999999	14.624000000000001	1.6830000000000001	17.533999999999999
11171	4	0	4.0999999999999996	0.78500003	4.4160000000000004	23.116	3.4670000000000001	18.146000000000001
11170	1	0	0.29999999999999999	1.673	1.575	19.094999999999999	2.6349999999999998	31.946000000000002
11170	2	0	3.2000000000000002	1.5779999	3.738	21.318000000000001	5.899	33.640000000000001
11170	3	0	4.2000000000000002	1.387	5.8689999999999998	24.189	8.1400000000000006	33.549999999999997
11170	4	0	5	1.16	17.064	30.904	19.794	35.848999999999997
11169	1	0	0.29999999999999999	1.624	1.409	24.349	2.2879999999999998	39.542999999999999
11169	2	0	3.2000000000000002	1.464	4.1360000000000001	22.155999999999999	6.0549999999999997	32.436
11169	3	0	4.2000000000000002	1.3200001	4.8760000000000003	17.515999999999998	6.4359999999999999	23.120999999999999
11169	4	0	5	1.029	21.120000000000001	45.960000000000001	21.731999999999999	47.292999999999999
11168	1	0	0.29999999999999999	1.5930001	0.46000000000000002	27.84	0.73299999999999998	44.348999999999997
11168	2	0	2.7000000000000002	1.401	3.327	20.327000000000002	4.6609999999999996	28.478000000000002
11168	3	0	3.6000000000000001	1.249	4.4349999999999996	20.234999999999999	5.5389999999999997	25.274000000000001
11168	4	0	4.2000000000000002	1.01	9.8330000000000002	32.393000000000001	9.9309999999999992	32.716999999999999
11177	1	0	0.29999999999999999	0.87699997	0.90400000000000003	9.3840000000000003	0.79300000000000004	8.2300000000000004
11177	2	0	0.69999999999999996	0.84500003	1.355	9.5350000000000001	1.145	8.0570000000000004
11177	3	0	0.90000000000000002	0.82099998	1.131	17.850999999999999	0.92900000000000005	14.656000000000001
11177	4	0	1.1000000000000001	0.64200002	0.93100000000000005	12.031000000000001	0.59799999999999998	7.7240000000000002
11176	1	0	0.29999999999999999	1.245	1.069	9.8089999999999993	1.331	12.212
11176	2	0	1.7	1.041	1.175	9.2949999999999999	1.2230000000000001	9.6760000000000002
11176	3	0	2.2000000000000002	0.824	2.222	12.662000000000001	1.831	10.433
11176	4	0	2.5	0.458	3.04	10.48	1.3919999999999999	4.7999999999999998
11175	1	0	0.29999999999999999	1.273	1.74	10.779999999999999	2.2149999999999999	13.723000000000001
11175	2	0	2.2000000000000002	1.158	2.4929999999999999	10.792999999999999	2.887	12.497999999999999
11175	3	0	3	0.91000003	11.129	19.629000000000001	10.127000000000001	17.861999999999998
11175	4	0	3.3999999999999999	0.86500001	26.911000000000001	36.170999999999999	23.277999999999999	31.288
11174	1	0	0.29999999999999999	1.302	2.1200000000000001	9.3800000000000008	2.7599999999999998	12.212999999999999
11174	2	0	2.1000000000000001	1.145	4.1529999999999996	13.853	4.7549999999999999	15.862
11174	3	0	2.7999999999999998	0.91100001	28.164000000000001	36.204000000000001	25.657	32.981999999999999
11174	4	0	3.2000000000000002	0.778	106.66200000000001	115.782	82.983000000000004	90.078000000000003
11173	1	0	0.29999999999999999	1.249	0.91800000000000004	9.2379999999999995	1.147	11.538
11173	2	0	2.5	1.138	1.9550000000000001	9.6150000000000002	2.2250000000000001	10.942
11173	3	0	3.2999999999999998	0.91100001	1.8640000000000001	9.9039999999999999	1.698	9.0229999999999997
11173	4	0	3.7999999999999998	0.85500002	2.956	23.876000000000001	2.5270000000000001	20.414000000000001
11162	1	0	0.29999999999999999	0.62800002	0.627	7.9269999999999996	0.39400000000000002	4.9779999999999998
11162	2	0	0.69999999999999996	0.45899999	0.63600000000000001	7.4960000000000004	0.29199999999999998	3.4409999999999998
11162	3	0	1	0.40799999	0.65600000000000003	7.9359999999999999	0.26800000000000002	3.238
11162	4	0	1.2	0.412	0.66700000000000004	7.9669999999999996	0.27500000000000002	3.282
11161	1	0	0.29999999999999999	1.198	0.75600000000000001	8.5559999999999992	0.90600000000000003	10.25
11161	2	0	1.8	0.63499999	0.88200000000000001	8.8819999999999997	0.56000000000000005	5.6399999999999997
11161	3	0	2.3999999999999999	0.40000001	1.0109999999999999	9.6310000000000002	0.40400000000000003	3.8519999999999999
11161	4	0	2.7000000000000002	0.34999999	1.456	9.0960000000000001	0.51000000000000001	3.1840000000000002
11160	1	0	0.29999999999999999	1.242	0.90900000000000003	7.1689999999999996	1.129	8.9039999999999999
11160	2	0	1.8	1.123	1.665	7.4249999999999998	1.8700000000000001	8.3379999999999992
11160	3	0	2.3999999999999999	1.048	2.5800000000000001	7.6399999999999997	2.7040000000000002	8.0069999999999997
11160	4	0	2.7000000000000002	0.903	8.3089999999999993	12.849	7.5030000000000001	11.603
11159	1	0	0.29999999999999999	1.189	0.71599999999999997	6.1760000000000002	0.85099999999999998	7.343
11159	2	0	1.7	1.066	1.2669999999999999	6.8869999999999996	1.351	7.3419999999999996
11159	3	0	2.2000000000000002	0.95200002	3.718	8.8580000000000005	3.54	8.4329999999999998
11159	4	0	2.5	0.76099998	8.1039999999999992	13.824	6.1669999999999998	10.52
11158	1	0	0.29999999999999999	1.089	0.51600000000000001	6.3559999999999999	0.56200000000000006	6.9219999999999997
11158	2	0	1.7	0.99000001	0.67300000000000004	6.3129999999999997	0.66600000000000004	6.25
11158	3	0	2.2000000000000002	0.86199999	0.80700000000000005	6.1269999999999998	0.69599999999999995	5.2809999999999997
11158	4	0	2.5	0.76599997	1.131	6.351	0.86599999999999999	4.8650000000000002
10950	1	0	0.29999999999999999	1.02	2.3620000000000001	21.202000000000002	2.4089999999999998	21.626000000000001
10950	2	0	1.5	0.90600002	2.605	22.225000000000001	2.3599999999999999	20.135999999999999
10950	3	0	2	0.85799998	2.335	21.114999999999998	2.0030000000000001	18.117000000000001
10950	4	0	2.2000000000000002	0.70700002	2.5249999999999999	21.605	1.7849999999999999	15.275
10949	1	0	0.29999999999999999	1.5319999	2.4159999999999999	20.196000000000002	3.7010000000000001	30.940000000000001
10949	2	0	2.6000000000000001	1.3839999	2.6930000000000001	21.332999999999998	3.7269999999999999	29.524999999999999
10949	3	0	3.3999999999999999	1.194	2.7490000000000001	24.728999999999999	3.282	29.526
10949	4	0	4	0.79400003	3.3639999999999999	23.524000000000001	2.6709999999999998	18.678000000000001
10948	1	0	0.29999999999999999	1.675	2.835	22.114999999999998	4.7489999999999997	37.042999999999999
10948	2	0	3.2999999999999998	1.4299999	4.0949999999999998	24.055	5.8559999999999999	34.399000000000001
10948	3	0	4.4000000000000004	1.416	5.7089999999999996	27.369	8.0839999999999996	38.755000000000003
10948	4	0	5.2000000000000002	1.16	10.178000000000001	29.738	11.805999999999999	34.496000000000002
10947	1	0	0.29999999999999999	1.636	2.573	23.792999999999999	4.2089999999999996	38.924999999999997
10947	2	0	3	1.476	5.0019999999999998	26.602	7.383	39.265000000000001
10947	3	0	4	1.351	8.0470000000000006	31.367000000000001	10.871	42.377000000000002
10947	4	0	4.7000000000000002	1.049	17.800000000000001	40.68	18.672000000000001	42.673000000000002
10946	1	0	0.29999999999999999	1.573	2.2240000000000002	20.824000000000002	3.4980000000000002	32.756
10946	2	0	2.7999999999999998	1.3660001	6.0039999999999996	25.643999999999998	8.2010000000000005	35.030000000000001
10946	3	0	3.7000000000000002	1.187	13.365	32.685000000000002	15.864000000000001	38.796999999999997
10946	4	0	4.2999999999999998	1.066	30.998000000000001	50.258000000000003	33.043999999999997	53.575000000000003
10952	1	0	0.29999999999999999	2.0420001	16.556000000000001	137.17599999999999	33.807000000000002	280.113
10952	2	0	4.5999999999999996	1.878	43.884999999999998	164.48500000000001	82.415999999999997	308.90300000000002
10952	3	0	6.2000000000000002	1.762	60.872999999999998	182.173	107.258	320.98899999999998
10952	4	0	7.4000000000000004	1.298	170.55600000000001	278.45600000000002	221.38200000000001	361.43599999999998
10951	1	0	0.29999999999999999	1.227	13.295999999999999	132.596	16.314	162.69499999999999
10951	2	0	4.0999999999999996	0.73900002	26.484999999999999	136.44499999999999	19.571999999999999	100.833
10951	3	0	4.5	0.59399998	29.991	151.27099999999999	17.815000000000001	89.855000000000004
10951	4	0	6.5	0.41499999	65.307000000000002	179.327	27.102	74.421000000000006
8420	1	0	0.29999999999999999	0.34999999	2.7400000000000002	14.44	0.95899999999999996	5.0540000000000003
8420	2	0	0.69999999999999996	0.40000001	3.2400000000000002	12.44	1.296	4.976
8420	3	0	1	0.37	3.4199999999999999	16.52	1.2649999999999999	6.1120000000000001
8420	4	0	1.2	0.33000001	4.8899999999999997	18.949999999999999	1.6140000000000001	6.2530000000000001
8421	1	0	0.29999999999999999	0.63	2.9399999999999999	17.140000000000001	1.8520000000000001	10.798
8421	2	0	1.3999999999999999	0.68000001	5.7699999999999996	19.670000000000002	3.9239999999999999	13.375999999999999
8421	3	0	1.8999999999999999	0.62	5.9000000000000004	19.780000000000001	3.6579999999999999	12.263999999999999
8421	4	0	2.3999999999999999	0.54000002	5.5199999999999996	18.719999999999999	2.9809999999999999	10.109
8422	1	0	0.29999999999999999	1.13	4.5800000000000001	18.539999999999999	5.1749999999999998	20.949999999999999
8422	2	0	1.3999999999999999	0.94999999	12.35	27.329999999999998	11.733000000000001	25.963000000000001
8422	3	0	1.8999999999999999	0.85000002	20.719999999999999	34.259999999999998	17.611999999999998	29.120999999999999
8422	4	0	2.3999999999999999	0.74000001	26.390000000000001	44.990000000000002	19.529	33.292999999999999
8423	1	0	0.29999999999999999	1.09	3.3100000000000001	17.989999999999998	3.6080000000000001	19.609000000000002
8423	2	0	1.3999999999999999	0.86000001	7.5499999999999998	23.010000000000002	6.4930000000000003	19.789000000000001
8423	3	0	1.8	0.81	7.4500000000000002	22.289999999999999	6.0350000000000001	18.055
8423	4	0	2.2999999999999998	0.44999999	28.82	44.439999999999998	12.968999999999999	19.998000000000001
8424	1	0	0.29999999999999999	0.81999999	1.8600000000000001	16.100000000000001	1.5249999999999999	13.202
8424	2	0	1.3	0.89999998	1.78	16.34	1.6020000000000001	14.706
8424	3	0	1.8	0.81	2.1099999999999999	16.809999999999999	1.7090000000000001	13.616
8424	4	0	2.2000000000000002	0.56	4.5499999999999998	19.91	2.548	11.15
10665	1	0	0.29999999999999999	1	2.2959999999999998	20.436	2.2959999999999998	20.436
10665	2	0	0.69999999999999996	0.86000001	2.798	20.058	2.4060000000000001	17.25
10665	3	0	1	0.75	2.6909999999999998	21.151	2.0179999999999998	15.863
10665	4	0	1.2	0.69999999	2.9129999999999998	20.113	2.0390000000000001	14.079000000000001
10664	1	0	0.29999999999999999	1.42	2.2890000000000001	20.388999999999999	3.25	28.952000000000002
10664	2	0	2	1.39	3.2109999999999999	23.530999999999999	4.4630000000000001	32.707999999999998
10664	3	0	2.6000000000000001	1.24	3.9289999999999998	22.349	4.8719999999999999	27.713000000000001
10664	4	0	3.2999999999999998	0.77999997	5.6669999999999998	23.466999999999999	4.4199999999999999	18.303999999999998
10663	1	0	0.29999999999999999	1.27	7.0709999999999997	26.811	8.9800000000000004	34.049999999999997
10663	2	0	2.2000000000000002	1.12	18.329000000000001	40.728999999999999	20.527999999999999	45.616
10663	3	0	2.8999999999999999	0.99000001	35.558	56.817999999999998	35.201999999999998	56.25
10663	4	0	3.3999999999999999	1.03	47.762	71.081999999999994	49.195	73.213999999999999
10662	1	0	0.29999999999999999	1.11	3.5800000000000001	22.420000000000002	3.9740000000000002	24.885999999999999
10662	2	0	2	1.12	6.1909999999999998	25.431000000000001	6.9340000000000002	28.483000000000001
10662	3	0	2.6000000000000001	0.93000001	11.784000000000001	33.084000000000003	10.959	30.768000000000001
10662	4	0	3.1000000000000001	0.72000003	28.613	49.093000000000004	20.600999999999999	35.347000000000001
10661	1	0	0.29999999999999999	1.16	3.133	24.553000000000001	3.6339999999999999	28.481000000000002
10661	2	0	1.8999999999999999	1.12	4.202	25.602	4.7060000000000004	28.673999999999999
10661	3	0	2.5	0.94999999	5.5620000000000003	26.521999999999998	5.2839999999999998	25.196000000000002
10661	4	0	2.8999999999999999	0.72000003	2.5289999999999999	137.529	1.821	99.021000000000001
8215	1	0	0.29999999999999999	1.35	3.5	27.100000000000001	4.7249999999999996	36.585000000000001
8215	2	0	2	1.26	2.6800000000000002	37.140000000000001	3.3769999999999998	46.795999999999999
8215	3	0	2.6000000000000001	1.11	3.5699999999999998	30.870000000000001	3.9630000000000001	34.265999999999998
8215	4	0	3.1000000000000001	0.79000002	3.2400000000000002	32.460000000000001	2.5600000000000001	25.643000000000001
8216	1	0	0.29999999999999999	1.6900001	2.7799999999999998	28.640000000000001	4.6980000000000004	48.402000000000001
8216	2	0	3.5	1.6900001	3.6000000000000001	31.02	6.0839999999999996	52.423999999999999
8216	3	0	4.5999999999999996	1.4	4.3300000000000001	43.369999999999997	6.0620000000000003	60.718000000000004
8216	4	0	5.5999999999999996	0.81999999	7.0099999999999998	34.590000000000003	5.7480000000000002	28.364000000000001
8217	1	0	0.29999999999999999	1.75	5.4400000000000004	44.979999999999997	9.5199999999999996	78.715000000000003
8217	2	0	3.2999999999999998	1.51	16.460000000000001	48.280000000000001	24.855	72.903000000000006
8217	3	0	4.4000000000000004	1.25	52.810000000000002	93.030000000000001	66.013000000000005	116.28700000000001
8217	4	0	5.2999999999999998	1.14	113.65000000000001	151.61000000000001	129.56100000000001	172.83500000000001
8218	1	0	0.29999999999999999	1.6900001	3.9700000000000002	39.710000000000001	6.7089999999999996	67.109999999999999
8218	2	0	3.1000000000000001	1.64	8.2200000000000006	43.899999999999999	13.481	71.995999999999995
8218	3	0	4.0999999999999996	1.49	16.760000000000002	57.68	24.972000000000001	85.942999999999998
8218	4	0	4.9000000000000004	1.4400001	22.510000000000002	69.890000000000001	32.414000000000001	100.642
8219	1	0	0.29999999999999999	0.98000002	3.9100000000000001	44.590000000000003	3.8319999999999999	43.698
8219	2	0	2.6000000000000001	0.66000003	4.9800000000000004	41.240000000000002	3.2869999999999999	27.218
8219	3	0	3.5	0.56999999	7.2400000000000002	40.780000000000001	4.1269999999999998	23.245000000000001
8219	4	0	4.2000000000000002	0.51999998	7.3499999999999996	46.469999999999999	3.8220000000000001	24.164000000000001
8065	1	0	0.29999999999999999	1.3049999	2.2400000000000002	32.039999999999999	2.923	41.811999999999998
8065	2	0	1.3	1.17	2.8300000000000001	30.469999999999999	3.3109999999999999	35.649999999999999
8065	3	0	1.8	0.94999999	2.4900000000000002	33.630000000000003	2.3660000000000001	31.949000000000002
8065	4	0	2	0.63999999	5.5300000000000002	38.810000000000002	3.5390000000000001	24.838000000000001
8066	1	0	0.29999999999999999	1.469	2.0499999999999998	31.989999999999998	3.0110000000000001	46.993000000000002
8066	2	0	2	1.2690001	2.5899999999999999	33.869999999999997	3.2869999999999999	42.981000000000002
8066	3	0	2.7000000000000002	1.0190001	3.0800000000000001	35.020000000000003	3.1389999999999998	35.685000000000002
8066	4	0	3.2000000000000002	0.71200001	3.77	33.670000000000002	2.6840000000000002	23.972999999999999
8067	1	0	0.29999999999999999	1.656	2.75	32.850000000000001	4.5540000000000003	54.399999999999999
8067	2	0	2.7999999999999998	1.498	7.2400000000000002	40.039999999999999	10.846	59.979999999999997
8067	3	0	3.7999999999999998	1.426	15.890000000000001	47.009999999999998	22.658999999999999	67.036000000000001
8067	4	0	4.5	0.97000003	46.68	77.680000000000007	45.280000000000001	75.349999999999994
8068	1	0	0.29999999999999999	1.658	2.98	32.039999999999999	4.9409999999999998	53.122
8068	2	0	2.7000000000000002	1.467	8.1099999999999994	39.170000000000002	11.897	57.462000000000003
8068	3	0	3.6000000000000001	1.276	17.239999999999998	47.82	21.998000000000001	61.018000000000001
8068	4	0	4.2999999999999998	1.0700001	33.509999999999998	64.030000000000001	35.856000000000002	68.512
8069	1	0	0.29999999999999999	1.535	2.2799999999999998	31.620000000000001	3.5	48.536999999999999
8069	2	0	2.3999999999999999	1.3839999	3.1699999999999999	33.75	4.3869999999999996	46.710000000000001
8069	3	0	3.2000000000000002	1.1720001	5.7199999999999998	32.460000000000001	6.7039999999999997	38.042999999999999
8069	4	0	3.7999999999999998	1.147	22.670000000000002	51.810000000000002	26.001999999999999	59.426000000000002
6845	1	0	0.29999999999999999	1.141	1.111	9.1110000000000007	1.268	10.396000000000001
6845	2	0	1.1000000000000001	1.125	1.1479999999999999	14.148	1.2909999999999999	15.916
6845	3	0	1.3999999999999999	0.92000002	1.2589999999999999	8.7590000000000003	1.1579999999999999	8.0579999999999998
6845	4	0	1.6000000000000001	0.95200002	1.407	12.407	1.339	11.811
6846	1	0	0.29999999999999999	1.48	0.95999999999999996	11.960000000000001	1.421	17.701000000000001
6846	2	0	2.6000000000000001	1.49	1.3	11.800000000000001	1.9370000000000001	17.582000000000001
6846	3	0	3.3999999999999999	1.38	1.0700000000000001	10.07	1.4770000000000001	13.897
6633	4	0	2.7000000000000002	1	5.6699999999999999	24.170000000000002	5.6699999999999999	24.170000000000002
6634	1	0	0.29999999999999999	1.7	4.7000000000000002	28.199999999999999	7.9900000000000002	47.939999999999998
6634	2	0	2	1.45	5.6799999999999997	29.18	8.2360000000000007	42.311
6634	3	0	2.7000000000000002	1.4	6.9400000000000004	14.69	9.7159999999999993	20.565999999999999
6634	4	0	3.2000000000000002	0.89999998	5.7999999999999998	14.800000000000001	5.2199999999999998	13.32
6635	1	0	0.29999999999999999	1.8	5.1500000000000004	23.649999999999999	9.2699999999999996	42.57
6635	2	0	2.2000000000000002	1.5	8.0399999999999991	22.039999999999999	12.06	33.060000000000002
6635	3	0	2.8999999999999999	1.3	11.02	29.02	14.326000000000001	37.725999999999999
6635	4	0	3.3999999999999999	1.1	18.780000000000001	38.780000000000001	20.658000000000001	42.658000000000001
6636	1	0	0.29999999999999999	1.8	2.0600000000000001	13.81	3.7080000000000002	24.858000000000001
6636	2	0	2.6000000000000001	1.6	2.6299999999999999	24.379999999999999	4.2080000000000002	39.008000000000003
6636	3	0	3.5	1.3	2.8900000000000001	25.640000000000001	3.7570000000000001	33.332000000000001
6636	4	0	4.2000000000000002	1.2	3.8500000000000001	18.100000000000001	4.6200000000000001	21.719999999999999
6637	1	0	0.29999999999999999	1.8	1.72	21.219999999999999	3.0960000000000001	38.195999999999998
6637	2	0	2.5	1.4	1.8500000000000001	21.100000000000001	2.5899999999999999	29.539999999999999
6637	3	0	3.3999999999999999	1.3	2.5699999999999998	21.07	3.3410000000000002	27.390999999999998
6637	4	0	4	1	2.98	27.23	2.98	27.23
6628	1	0	0.29999999999999999	1.29	2.6499999999999999	12.15	3.419	15.673
6628	2	0	2.2000000000000002	1.09	2.8700000000000001	12.869999999999999	3.1280000000000001	14.028
6628	3	0	2.7999999999999998	0.67000002	2.9100000000000001	21.41	1.95	14.345000000000001
6629	1	0	0.29999999999999999	1.55	3.46	29.960000000000001	5.3630000000000004	46.438000000000002
6629	2	0	1.8	1.38	1.0900000000000001	21.34	1.504	29.449000000000002
6629	3	0	2.3999999999999999	1.3	3.8500000000000001	30.100000000000001	5.0049999999999999	39.130000000000003
6629	4	0	2.75	0.99000001	5.3700000000000001	19.370000000000001	5.3159999999999998	19.175999999999998
6630	1	0	0.29999999999999999	1.76	2.98	31.23	5.2450000000000001	54.965000000000003
6630	2	0	2.2000000000000002	1.53	6.5800000000000001	38.829999999999998	10.067	59.409999999999997
6630	3	0	3	1.36	8.3699999999999992	41.119999999999997	11.382999999999999	55.923000000000002
6630	4	0	3.4500000000000002	0.99000001	19.82	40.560000000000002	19.622	40.154000000000003
6631	1	0	0.29999999999999999	1.4	2.5600000000000001	25.559999999999999	3.5840000000000001	35.783999999999999
6631	2	0	3	1.23	2.6699999999999999	19.420000000000002	3.2839999999999998	23.887
6631	3	0	4	0.88	3	24	2.6400000000000001	21.120000000000001
6631	4	0	4.7999999999999998	0.69999999	2.1499999999999999	17.649999999999999	1.5049999999999999	12.355
6658	1	0	0.29999999999999999	1.14	1.8500000000000001	20.600000000000001	2.109	23.484000000000002
6658	2	0	2	1.0700001	2.2200000000000002	23.219999999999999	2.375	24.844999999999999
6658	3	0	2.6000000000000001	0.86000001	2	20.260000000000002	1.72	17.423999999999999
6658	4	0	3.1000000000000001	0.61000001	3.4300000000000002	27.18	2.0920000000000001	16.579999999999998
6659	1	0	0.29999999999999999	1.47	2.6099999999999999	18.359999999999999	3.8370000000000002	26.989000000000001
6659	2	0	1.3999999999999999	1.48	3.4399999999999999	21.940000000000001	5.0910000000000002	32.470999999999997
6659	3	0	1.8999999999999999	1.1799999	6.7800000000000002	26.780000000000001	8	31.600000000000001
6659	4	0	2.2000000000000002	0.91000003	7.4400000000000004	28.190000000000001	6.7699999999999996	25.652999999999999
6660	1	0	0.29999999999999999	1.5599999	3.5899999999999999	23.34	5.5999999999999996	36.409999999999997
6660	2	0	2.2000000000000002	1.51	15.800000000000001	39.299999999999997	23.858000000000001	59.343000000000004
6660	3	0	2.8999999999999999	1.26	25.41	47.909999999999997	32.017000000000003	60.366999999999997
6660	4	0	3.3999999999999999	0.87	16.199999999999999	39.700000000000003	14.093999999999999	34.539000000000001
6661	1	0	0.29999999999999999	1.5599999	2.5600000000000001	22.809999999999999	3.9940000000000002	35.584000000000003
6661	2	0	2.7999999999999998	1.46	2.9100000000000001	25.66	4.2489999999999997	37.463999999999999
6661	3	0	3.7999999999999998	1.14	3.54	22.289999999999999	4.0359999999999996	25.411000000000001
6661	4	0	4.5	0.51999998	5.3300000000000001	24.829999999999998	2.7719999999999998	12.912000000000001
6662	1	0	0.29999999999999999	1.3200001	2.02	21.27	2.6659999999999999	28.076000000000001
6662	2	0	3.1000000000000001	1.1900001	3.3100000000000001	22.32	3.9390000000000001	26.561
6662	3	0	4.2000000000000002	1.22	2.6499999999999999	23.899999999999999	3.2330000000000001	29.158000000000001
6662	4	0	5	0.44	4.6100000000000003	27.859999999999999	2.028	12.257999999999999
6623	1	0	0.29999999999999999	1.12	3.0600000000000001	29.309999999999999	3.427	32.826999999999998
6623	2	0	0.90000000000000002	1.05	4	31	4.2000000000000002	32.549999999999997
6623	3	0	1.2	0.93000001	3.2799999999999998	28.030000000000001	3.0499999999999998	26.068000000000001
6623	4	0	1.3	0.81	4.2599999999999998	31.510000000000002	3.4510000000000001	25.523
6624	1	0	0.29999999999999999	1.22	3.2799999999999998	26.780000000000001	4.0019999999999998	32.671999999999997
6624	2	0	1.1000000000000001	1.12	3.98	33.229999999999997	4.4580000000000002	37.218000000000004
6624	3	0	1.3999999999999999	0.97000003	4.2199999999999998	34.469999999999999	4.093	33.436
6624	4	0	1.6000000000000001	0.93000001	4.8399999999999999	22.59	4.5010000000000003	21.009
6625	1	0	0.29999999999999999	1.26	4.54	31.039999999999999	5.7199999999999998	39.109999999999999
6625	2	0	1.3	1.21	6.8399999999999999	38.590000000000003	8.2759999999999998	46.694000000000003
6625	3	0	1.8	1.04	7.9000000000000004	32.399999999999999	8.2159999999999993	33.695999999999998
6625	4	0	2	0.88	11.08	36.829999999999998	9.75	32.409999999999997
6626	1	0	0.29999999999999999	1.29	5.2599999999999998	28.260000000000002	6.7850000000000001	36.454999999999998
6626	2	0	1.8999999999999999	1.1900001	6.9199999999999999	31.170000000000002	8.2349999999999994	37.091999999999999
6626	3	0	2.5	1.05	0.80000000000000004	32.799999999999997	0.83999999999999997	34.439999999999998
6626	4	0	2.9500000000000002	0.81999999	14.58	49.329999999999998	11.956	40.451000000000001
6627	1	0	0.29999999999999999	1.37	4.3799999999999999	30.629999999999999	6.0010000000000003	41.963000000000001
6627	2	0	1.8999999999999999	1.22	4.8600000000000003	35.859999999999999	5.9290000000000003	43.749000000000002
6627	3	0	2.5	1.04	6	33.5	6.2400000000000002	34.840000000000003
6627	4	0	2.8999999999999999	0.56999999	8.8399999999999999	44.100000000000001	5.0389999999999997	25.137
6618	1	0	0.29999999999999999	1.15	4.7599999999999998	49.759999999999998	5.4740000000000002	57.223999999999997
6618	2	0	1.7	1.01	5	61.670000000000002	5.0499999999999998	62.286999999999999
6618	3	0	2.2999999999999998	1.12	5.0599999999999996	56.390000000000001	5.6669999999999998	63.156999999999996
6618	4	0	2.7000000000000002	0.60000002	5.9400000000000004	41.939999999999998	3.5640000000000001	25.164000000000001
6619	1	0	0.29999999999999999	1.67	6.0599999999999996	42.729999999999997	10.119999999999999	71.358999999999995
6619	2	0	2.2000000000000002	1.5700001	5.0999999999999996	57.770000000000003	8.0069999999999997	90.698999999999998
6619	3	0	3	1.25	7.0599999999999996	64.730000000000004	8.8249999999999993	80.912999999999997
6619	4	0	3.5	0.87	11.779999999999999	43.780000000000001	10.249000000000001	38.088999999999999
6620	1	0	0.29999999999999999	1.6799999	5.6200000000000001	64.290000000000006	9.4420000000000002	108.00700000000001
6620	2	0	2.2999999999999998	1.53	9.6600000000000001	68.989999999999995	14.779999999999999	105.55500000000001
6620	3	0	3.1000000000000001	1.29	18.960000000000001	55.960000000000001	24.457999999999998	72.188000000000002
6620	4	0	3.7000000000000002	1.0700001	33.240000000000002	88.239999999999995	35.567	94.417000000000002
6621	1	0	0.29999999999999999	1.79	5.0800000000000001	46.75	9.093	83.683000000000007
6621	2	0	2.7999999999999998	1.5599999	6.6399999999999997	54.640000000000001	10.358000000000001	85.238
6621	3	0	3.7999999999999998	1.38	7.7599999999999998	51.100000000000001	10.709	70.518000000000001
6621	4	0	4.5	1.11	10.98	67.310000000000002	12.188000000000001	74.713999999999999
6622	1	0	0.29999999999999999	1.6900001	4.3200000000000003	64.319999999999993	7.3010000000000002	108.70099999999999
6622	2	0	2.6000000000000001	1.42	4.9000000000000004	53.229999999999997	6.9580000000000002	75.587000000000003
6622	3	0	3.5	1.34	5.2999999999999998	57.299999999999997	7.1020000000000003	76.781999999999996
6622	4	0	4.2000000000000002	0.85000002	7.04	66.040000000000006	5.984	56.134
6614	1	0	2	1.37	4.46	36.130000000000003	6.1100000000000003	49.497999999999998
6614	2	0	2.7000000000000002	1.08	5.3200000000000003	55.990000000000002	5.7460000000000004	60.469000000000001
6614	3	0	3.2000000000000002	0.74000001	14.52	75.849999999999994	10.744999999999999	56.128999999999998
6615	1	0	0.29999999999999999	1.6799999	5.5800000000000001	46.579999999999998	9.3740000000000006	78.254000000000005
6615	2	0	2.2000000000000002	1.4299999	8.0399999999999991	50.039999999999999	11.497	71.557000000000002
6615	3	0	2.8999999999999999	1.24	13.74	62.740000000000002	17.038	77.798000000000002
6615	4	0	3.3999999999999999	0.47999999	35.579999999999998	84.25	17.077999999999999	40.439999999999998
6616	1	0	0.29999999999999999	1.77	5.2999999999999998	46.630000000000003	9.3810000000000002	82.534999999999997
6616	2	0	2.3999999999999999	1.67	11.68	66.680000000000007	19.506	111.35599999999999
6616	3	0	3.2000000000000002	1.63	32.020000000000003	57.689999999999998	52.192999999999998	94.034999999999997
6616	4	0	3.7999999999999998	0.79000002	119.92	174.91999999999999	94.736999999999995	138.18700000000001
6617	1	0	0.29999999999999999	1.36	4.1200000000000001	47.789999999999999	5.6029999999999998	64.994
6617	2	0	3	1.1799999	4.6200000000000001	61.289999999999999	5.452	72.322000000000003
6617	3	0	4	0.97000003	5.3600000000000003	84.030000000000001	5.1989999999999998	81.509
6617	4	0	4.7999999999999998	0.62	6.5199999999999996	46.189999999999998	4.0419999999999998	28.638000000000002
6609	1	0	0.29999999999999999	1.51	4.1100000000000003	73.780000000000001	6.2060000000000004	111.408
6609	2	0	2.5	1.49	5.1299999999999999	83.129999999999995	7.6440000000000001	123.864
6609	3	0	3.3999999999999999	1.21	4.5899999999999999	101.59	5.5540000000000003	122.92400000000001
6609	4	0	4	0.99000001	6.4199999999999999	75.420000000000002	6.3559999999999999	74.665999999999997
6610	1	0	0.29999999999999999	1.92	5.7199999999999998	69.379999999999995	10.981999999999999	133.21000000000001
6610	2	0	2.7999999999999998	1.89	6.4000000000000004	62.729999999999997	12.096	118.56
6610	3	0	3.7000000000000002	1.7	5.6600000000000001	71.989999999999995	9.6219999999999999	122.383
6610	4	0	4.4000000000000004	1.12	16.079999999999998	89.079999999999998	18.010000000000002	99.769999999999996
6611	1	0	0.29999999999999999	2.0999999	8.1699999999999999	77.840000000000003	17.157	163.464
6611	2	0	3.1000000000000001	1.87	15.85	69.519999999999996	29.640000000000001	130.00200000000001
6611	3	0	4.2000000000000002	1.74	28.25	110.25	49.155000000000001	191.83500000000001
6611	4	0	5	0.93000001	134.40000000000001	190.06	124.992	176.756
6612	1	0	0.29999999999999999	2.03	7.4699999999999998	97.469999999999999	15.164	197.864
6612	2	0	3.3999999999999999	1.79	15.4	118.73	27.565999999999999	212.52699999999999
6612	3	0	4.5	1.63	24.57	95.230000000000004	40.048999999999999	155.22499999999999
6612	4	0	5.4000000000000004	0.76999998	61.719999999999999	147.38	47.524000000000001	113.483
6613	1	0	0.29999999999999999	1.92	5	72	9.5999999999999996	138.24000000000001
6613	2	0	3.7999999999999998	1.64	6.4699999999999998	71.810000000000002	10.611000000000001	117.768
6613	3	0	5.0999999999999996	1.24	7.04	123.04000000000001	8.7300000000000004	152.56999999999999
6613	4	0	6.2000000000000002	0.68000001	15.85	121.59	10.778	82.680999999999997
6603	1	0	0.29999999999999999	1.13	3.6400000000000001	34.640000000000001	4.1130000000000004	39.143000000000001
6603	2	0	1.3	0.98000002	4.5099999999999998	27.84	4.4199999999999999	27.283000000000001
6603	3	0	1.8	0.88	3.8500000000000001	23.52	3.3879999999999999	20.698
6603	4	0	2.1499999999999999	0.56999999	5.5499999999999998	33.219999999999999	3.1629999999999998	18.934999999999999
6604	1	0	0.29999999999999999	1.42	3.5099999999999998	34.840000000000003	4.984	49.472999999999999
6604	2	0	1.7	1.1900001	4.4199999999999999	27.75	5.2599999999999998	33.023000000000003
6604	3	0	2.2000000000000002	1.1	4.5999999999999996	28.600000000000001	5.0599999999999996	31.460000000000001
6604	4	0	2.75	0.64999998	5.8300000000000001	36.829999999999998	3.79	23.940000000000001
6605	1	0	0.29999999999999999	1.53	4.1299999999999999	32.799999999999997	6.319	50.183999999999997
6605	2	0	1.8999999999999999	1.4	5.6200000000000001	36.289999999999999	7.8680000000000003	50.805999999999997
6605	3	0	2.6000000000000001	1.23	6.7400000000000002	29.41	8.2899999999999991	36.173999999999999
6605	4	0	3.1499999999999999	0.85000002	10.449999999999999	31.780000000000001	8.8819999999999997	27.013000000000002
6606	1	0	0.29999999999999999	1.64	4.8700000000000001	26.199999999999999	7.9870000000000001	42.968000000000004
6606	2	0	2.1000000000000001	1.49	8.9100000000000001	35.909999999999997	13.276	53.506
6606	3	0	2.7999999999999998	1.3099999	15.91	47.909999999999997	20.841999999999999	62.762
6606	4	0	3.4500000000000002	0.81	38.350000000000001	67.849999999999994	31.064	54.959000000000003
6607	1	0	0.29999999999999999	1.6900001	5.04	32.789999999999999	8.5180000000000007	55.414999999999999
6607	2	0	2.5	1.48	6.96	36.710000000000001	10.301	54.331000000000003
6607	3	0	3.3999999999999999	1.38	8.6899999999999995	38.689999999999998	11.992000000000001	53.392000000000003
6607	4	0	4.1500000000000004	0.97000003	15.93	44.68	15.452	43.340000000000003
6608	1	0	0.29999999999999999	1.59	4.1299999999999999	31.879999999999999	6.5670000000000002	50.689
6608	2	0	2.7000000000000002	1.35	5.2599999999999998	26.260000000000002	7.101	35.451000000000001
6608	3	0	3.6000000000000001	1.15	6.1699999999999999	36.420000000000002	7.0949999999999998	41.883000000000003
6608	4	0	4.4500000000000002	0.80000001	9.1099999999999994	42.359999999999999	7.2880000000000003	33.887999999999998
6599	1	0	0.29999999999999999	1.17	1.6699999999999999	14.92	1.954	17.456
6599	2	0	1	1.03	1.98	20.73	2.0390000000000001	21.352
6599	3	0	1.3	0.95999998	2.2799999999999998	6.7800000000000002	2.1890000000000001	6.5090000000000003
6599	4	0	1.55	0.69	2.6299999999999999	20.129999999999999	1.8149999999999999	13.890000000000001
6600	1	0	0.29999999999999999	1.26	2.1499999999999999	14.4	2.7090000000000001	18.143999999999998
6600	2	0	1.3999999999999999	1.13	2.48	18.48	2.802	20.882000000000001
6600	3	0	1.8999999999999999	1.01	2.8700000000000001	7.8700000000000001	2.899	7.9489999999999998
6600	4	0	2.3500000000000001	0.67000002	4.1699999999999999	19.670000000000002	2.794	13.179
6601	1	0	0.29999999999999999	1.42	2.7200000000000002	19.219999999999999	3.8620000000000001	27.292000000000002
6601	2	0	1.7	1.24	4.0700000000000003	18.82	5.0469999999999997	23.337
6601	3	0	2.2000000000000002	1.08	6	22	6.4800000000000004	23.760000000000002
6601	4	0	2.75	0.69	14.67	23.670000000000002	10.122	16.332000000000001
6602	1	0	0.29999999999999999	1.3200001	2.1699999999999999	19.420000000000002	2.8639999999999999	25.634
6602	2	0	2.1000000000000001	0.98000002	2.8900000000000001	21.140000000000001	2.8319999999999999	20.716999999999999
6602	3	0	2.7999999999999998	0.79000002	3.04	14.539999999999999	2.4020000000000001	11.487
6602	4	0	3.4500000000000002	0.07	4.9800000000000004	11.98	0.34899999999999998	0.83899999999999997
6594	1	0	0.29999999999999999	1.1	2.6099999999999999	37.359999999999999	2.871	41.095999999999997
6594	2	0	0.69999999999999996	1.02	3.6699999999999999	39.420000000000002	3.7429999999999999	40.207999999999998
6594	3	0	0.90000000000000002	0.95999998	3.8199999999999998	46.07	3.6669999999999998	44.226999999999997
6594	4	0	1.1499999999999999	0.64999998	4.8899999999999997	37.140000000000001	3.1779999999999999	24.140999999999998
6595	1	0	0.29999999999999999	1.14	3.5699999999999998	36.07	4.0700000000000003	41.119999999999997
6595	2	0	0.69999999999999996	1.02	3.6699999999999999	39.420000000000002	3.7429999999999999	40.207999999999998
6595	3	0	0.90000000000000002	0.95999998	3.8199999999999998	46.07	3.6669999999999998	44.226999999999997
6595	4	0	1.1499999999999999	0.64999998	4.8899999999999997	37.140000000000001	3.1779999999999999	24.140999999999998
6596	1	0	0.29999999999999999	1.22	4.3899999999999997	43.640000000000001	5.3559999999999999	53.241
6596	2	0	1.1000000000000001	1.0700001	5.4299999999999997	23.18	5.8099999999999996	24.803000000000001
6596	3	0	1.3999999999999999	0.95999998	6.0899999999999999	42.340000000000003	5.8460000000000001	40.646000000000001
6596	4	0	1.8500000000000001	0.55000001	10.199999999999999	40.450000000000003	5.6100000000000003	22.248000000000001
6597	1	0	0.29999999999999999	1.3099999	3.52	35.270000000000003	4.6109999999999998	46.204000000000001
6597	2	0	1.5	1.1799999	4.6799999999999997	23.18	5.5220000000000002	27.352
6597	3	0	2	1.02	5.5199999999999996	24.77	5.6299999999999999	25.265000000000001
6597	4	0	2.5	0.57999998	6.5099999999999998	34.009999999999998	3.7759999999999998	19.725999999999999
6598	1	0	0.29999999999999999	1.35	3.0699999999999998	23.57	4.1440000000000001	31.82
6598	2	0	1.5	1.0599999	3.3300000000000001	50.829999999999998	3.5299999999999998	53.880000000000003
6598	3	0	2	0.85000002	3.3900000000000001	22.140000000000001	2.8820000000000001	18.818999999999999
11394	4	0	2.3999999999999999	0.77499998	4.7690000000000001	50.569000000000003	3.6960000000000002	39.191000000000003
11393	1	0	0.20000000000000001	0.96399999	2.0019999999999998	43.881999999999998	1.9299999999999999	42.302
11393	2	0	1.3	0.84100002	2.2949999999999999	40.034999999999997	1.9299999999999999	33.668999999999997
11393	3	0	1.7	0.78200001	2.8159999999999998	39.515999999999998	2.202	30.902000000000001
11393	4	0	1.8999999999999999	0.70200002	3.4620000000000002	49.222000000000001	2.4300000000000002	34.554000000000002
11392	1	0	0.20000000000000001	0.81400001	1.962	40.661999999999999	1.597	33.098999999999997
11392	2	0	1.1000000000000001	0.75099999	2.1560000000000001	46.195999999999998	1.619	34.692999999999998
11392	3	0	1.5	0.713	2.3050000000000002	43.865000000000002	1.643	31.276
11392	4	0	1.7	0.56	3.0310000000000001	40.710999999999999	1.6970000000000001	22.797999999999998
11391	1	0	0.20000000000000001	0.56	2.04	43.700000000000003	1.1419999999999999	24.472000000000001
11391	2	0	0.69999999999999996	0.53799999	2.4889999999999999	56.009	1.339	30.132999999999999
11391	3	0	1	0.53100002	2.3420000000000001	49.661999999999999	1.244	26.370999999999999
11391	4	0	1.1000000000000001	0.48699999	2.6890000000000001	38.088999999999999	1.3100000000000001	18.548999999999999
11315	1	0	0.20000000000000001	1.082	0.64500000000000002	7.1449999999999996	0.69799999999999995	7.7309999999999999
11315	2	0	1.6000000000000001	1.02	1.1950000000000001	5.5750000000000002	1.2190000000000001	5.6870000000000003
11315	3	0	2.1000000000000001	0.83499998	2.4580000000000002	9.6379999999999999	2.052	8.048
11315	4	0	2.3999999999999999	0.68800002	2.944	8.1440000000000001	2.0249999999999999	5.6029999999999998
11314	1	0	0.20000000000000001	0.991	0.63300000000000001	6.4930000000000003	0.627	6.4349999999999996
11314	2	0	1.3	0.93699998	0.84699999999999998	5.867	0.79400000000000004	5.4969999999999999
11314	3	0	1.7	0.83999997	1.615	7.9550000000000001	1.357	6.6820000000000004
11314	4	0	1.8999999999999999	0.80199999	2.9780000000000002	10.638	2.3879999999999999	8.532
11313	1	0	0.20000000000000001	0.94400001	0.66000000000000003	6.3399999999999999	0.623	5.9850000000000003
11313	2	0	1.3	0.86500001	1.0980000000000001	8.2379999999999995	0.94999999999999996	7.1260000000000003
11313	3	0	1.7	0.82800001	1.2050000000000001	8.1050000000000004	0.998	6.7110000000000003
11313	4	0	1.8999999999999999	0.72000003	3.218	9.2780000000000005	2.3170000000000002	6.6799999999999997
11312	1	0	0.20000000000000001	0.829	0.64400000000000002	5.5839999999999996	0.53400000000000003	4.6289999999999996
11312	2	0	0.90000000000000002	0.76300001	1.718	9.3780000000000001	1.3109999999999999	7.1550000000000002
11312	3	0	1.2	0.708	1.8069999999999999	9.2669999999999995	1.2789999999999999	6.5609999999999999
11312	4	0	1.3	0.59100002	2.524	9.7439999999999998	1.492	5.7590000000000003
11311	1	0	0.20000000000000001	0.78500003	0.63800000000000001	8.3580000000000005	0.501	6.5609999999999999
11311	2	0	0.80000000000000004	0.76300001	1.1180000000000001	8.6180000000000003	0.85299999999999998	6.5759999999999996
11311	3	0	1	0.73400003	1.2949999999999999	13.975	0.95099999999999996	10.257999999999999
11311	4	0	1.1000000000000001	0.66600001	2.5270000000000001	10.547000000000001	1.6830000000000001	7.024
11000	1	0	0.29999999999999999	1.552	0.67300000000000004	7.5330000000000004	1.044	11.691000000000001
11000	2	0	2.7999999999999998	1.505	0.86399999999999999	8.5839999999999996	1.3	12.919
11000	3	0	3.7999999999999998	1.339	0.92000000000000004	10.56	1.232	14.140000000000001
11000	4	0	4.4000000000000004	1.025	1.1040000000000001	7.7039999999999997	1.1319999999999999	7.8970000000000002
10999	1	0	0.29999999999999999	1.222	1.4490000000000001	8.4890000000000008	1.7709999999999999	10.374000000000001
10999	2	0	2.3999999999999999	1.182	5.3200000000000003	10.960000000000001	6.2880000000000003	12.955
10999	3	0	3.2000000000000002	1.0700001	13.445	22.265000000000001	14.385999999999999	23.824000000000002
10999	4	0	3.7000000000000002	0.81699997	20.315999999999999	28.616	16.597999999999999	23.379000000000001
10998	1	0	0.29999999999999999	1.189	2.7469999999999999	9.0470000000000006	3.266	10.757
10998	2	0	1.8	1.02	24.175999999999998	33.475999999999999	24.66	34.146000000000001
10998	3	0	2.3999999999999999	1.024	34.604999999999997	43.805	35.436	44.856000000000002
10998	4	0	2.7000000000000002	0.97100002	45.326999999999998	53.627000000000002	44.012999999999998	52.072000000000003
10997	1	0	0.29999999999999999	0.99299997	5.4160000000000004	14.336	5.3780000000000001	14.236000000000001
10997	2	0	1.8999999999999999	0.78500003	37.783999999999999	47.884	29.66	37.588999999999999
10997	3	0	2.5	0.625	51.741999999999997	61.701999999999998	32.338999999999999	38.564
10997	4	0	2.7999999999999998	0.60600001	77.367000000000004	85.147000000000006	46.884	51.598999999999997
10996	1	0	0.29999999999999999	0.89600003	2.8530000000000002	11.173	2.556	10.010999999999999
10996	2	0	1.5	0.76999998	13.916	19.995999999999999	10.715	15.397
10996	3	0	2	0.70499998	18.652999999999999	30.152999999999999	13.15	21.257999999999999
10996	4	0	2.2000000000000002	0.59899998	34.151000000000003	47.231000000000002	20.456	28.291
10735	1	0	0.29999999999999999	1.12	1.6020000000000001	16.202000000000002	1.794	18.146000000000001
10735	2	0	1.3999999999999999	0.83999997	1.905	16.664999999999999	1.6000000000000001	13.999000000000001
10735	3	0	1.8999999999999999	0.79000002	2.3839999999999999	15.564	1.883	12.295999999999999
10735	4	0	2.2999999999999998	0.75999999	3.2200000000000002	20.120000000000001	2.4470000000000001	15.291
10734	1	0	0.10000000000000001	1.03	1.6839999999999999	15.384	1.7350000000000001	15.846
10734	2	0	1.2	0.83999997	2.4550000000000001	19.094999999999999	2.0619999999999998	16.039999999999999
10734	3	0	1.6000000000000001	0.73000002	3.7090000000000001	18.969000000000001	2.7080000000000002	13.847
10734	4	0	2	0.61000001	9.4220000000000006	26.181999999999999	5.7469999999999999	15.971
10733	1	0	0.10000000000000001	1.05	1.5649999999999999	17.364999999999998	1.643	18.233000000000001
10733	2	0	1.2	0.80000001	2.242	18.562000000000001	1.794	14.85
10733	3	0	1.6000000000000001	0.68000001	3.649	20.568999999999999	2.4809999999999999	13.987
10733	4	0	2	0.55000001	7.2640000000000002	21.303999999999998	3.9950000000000001	11.717000000000001
10732	1	0	0.10000000000000001	1.03	1.6399999999999999	19	1.6890000000000001	19.57
10732	2	0	1.1000000000000001	0.81	3.3530000000000002	18.693000000000001	2.7160000000000002	15.141
10732	3	0	1.5	0.73000002	3.6619999999999999	20.902000000000001	2.673	15.257999999999999
10732	4	0	1.8	0.68000001	5.1470000000000002	22.687000000000001	3.5	15.427
10731	1	0	0.10000000000000001	0.85000002	1.6379999999999999	18.937999999999999	1.3919999999999999	16.097000000000001
10731	2	0	0.80000000000000004	0.66000003	1.915	18.855	1.264	12.444000000000001
10731	3	0	1	0.62	2.4710000000000001	19.771000000000001	1.532	12.257999999999999
10731	4	0	1.2	0.57999998	6.4580000000000002	27.577999999999999	3.746	15.994999999999999
10725	1	0	0.29999999999999999	1.21	3.133	39.792999999999999	3.7909999999999999	48.149999999999999
10725	2	0	1.8999999999999999	1.1109999	5.0069999999999997	45.807000000000002	5.5629999999999997	50.892000000000003
10725	3	0	2.5	1.025	3.9550000000000001	56.975000000000001	4.0540000000000003	58.399000000000001
10725	4	0	3.1000000000000001	0.72500002	5.54	57.079999999999998	4.016	41.383000000000003
10724	1	0	0.29999999999999999	1.114	2.7669999999999999	44.767000000000003	3.0819999999999999	49.869999999999997
10724	2	0	1.8999999999999999	0.98299998	3.3759999999999999	43.695999999999998	3.319	42.953000000000003
10724	3	0	2.5	0.96899998	4.6399999999999997	53	4.4960000000000004	51.356999999999999
10724	4	0	3.1000000000000001	0.671	166.93600000000001	214.45599999999999	112.014	143.90000000000001
10723	1	0	0.29999999999999999	1.112	2.9359999999999999	45.055999999999997	3.2650000000000001	50.101999999999997
10723	2	0	1.8999999999999999	0.95599997	6.3109999999999999	56.951000000000001	6.0330000000000004	54.445
10723	3	0	2.5	0.82800001	5.4960000000000004	55.396000000000001	4.5510000000000002	45.868000000000002
10723	4	0	3	0.611	8.7379999999999995	58.957999999999998	5.3390000000000004	36.023000000000003
10722	1	0	0.29999999999999999	1.011	2.851	50.051000000000002	2.8820000000000001	50.601999999999997
10722	2	0	1.3999999999999999	0.92000002	5.0640000000000001	53.244	4.6589999999999998	48.984000000000002
10722	3	0	1.8	0.84500003	7.9130000000000003	63.152999999999999	6.6859999999999999	53.363999999999997
10722	4	0	2.2999999999999998	0.68800002	12.384	64.263999999999996	8.5199999999999996	44.213999999999999
10721	1	0	0.29999999999999999	0.99000001	3.3330000000000002	47.853000000000002	3.2999999999999998	47.374000000000002
10721	2	0	1.1000000000000001	0.72899997	9.0619999999999994	55.762	6.6059999999999999	40.649999999999999
10721	3	0	1.3999999999999999	0.87900001	5.9509999999999996	48.991	5.2309999999999999	43.063000000000002
10721	4	0	1.8	0.68800002	18.742000000000001	67.001999999999995	12.894	46.097000000000001
10715	1	0	0.29999999999999999	1.4299999	1.829	16.048999999999999	2.6150000000000002	22.949999999999999
10715	2	0	2.3999999999999999	1.3099999	2.2330000000000001	15.032999999999999	2.9249999999999998	19.693000000000001
10715	3	0	3.2000000000000002	0.97000003	2.222	16.021999999999998	2.1549999999999998	15.541
10715	4	0	3.7999999999999998	1.04	3.2999999999999998	18.140000000000001	3.4319999999999999	18.866
10714	1	0	0.29999999999999999	1.4400001	4.9000000000000004	18.079999999999998	7.056	26.035
10714	2	0	2.3999999999999999	1.33	3.6179999999999999	17.777999999999999	4.8120000000000003	23.645
10714	3	0	3.2000000000000002	1.2	3.9689999999999999	22.609000000000002	4.7629999999999999	27.131
10714	4	0	3.7999999999999998	0.83999997	6.3559999999999999	19.635999999999999	5.3390000000000004	16.494
10713	1	0	0.29999999999999999	1.28	1.9710000000000001	16.111000000000001	2.5230000000000001	20.622
10713	2	0	1.6000000000000001	1.09	4.0439999999999996	17.044	4.4080000000000004	18.577999999999999
10713	3	0	2.2000000000000002	0.98000002	10.507	23.867000000000001	10.297000000000001	23.390000000000001
10713	4	0	2.5	0.81999999	24.984000000000002	38.963999999999999	20.486999999999998	31.949999999999999
10712	1	0	0.29999999999999999	1.22	2.2869999999999999	16.047000000000001	2.79	19.577000000000002
10712	2	0	1.5	1.01	5.54	20.780000000000001	5.5949999999999998	20.988
10712	3	0	2	0.98000002	10.298	24.358000000000001	10.092000000000001	23.870999999999999
10712	4	0	2.2999999999999998	0.87	4.1470000000000002	17.407	3.6080000000000001	15.144
10711	1	0	0.29999999999999999	1.01	1.4910000000000001	14.151	1.506	14.292999999999999
10711	2	0	1.1000000000000001	0.94999999	5.3310000000000004	19.030999999999999	5.0640000000000001	18.079000000000001
10711	3	0	1.3999999999999999	0.88	8.6600000000000001	20.32	7.6210000000000004	17.882000000000001
10711	4	0	1.6000000000000001	0.73000002	8.2420000000000009	23.882000000000001	6.0170000000000003	17.434000000000001
8195	1	0	0.29999999999999999	1.02	1.55	33	1.581	33.659999999999997
8195	2	0	1.6000000000000001	0.95999998	1.76	30.440000000000001	1.6899999999999999	29.222000000000001
8195	3	0	2.2000000000000002	0.86000001	2	33.689999999999998	1.72	28.972999999999999
8195	4	0	2.5	0.74000001	2.25	30.969999999999999	1.665	22.917999999999999
8196	1	0	0.29999999999999999	1.21	1.77	31.670000000000002	2.1419999999999999	38.320999999999998
8196	2	0	1.6000000000000001	1	2.5800000000000001	28.949999999999999	2.5800000000000001	28.949999999999999
8196	3	0	2.2000000000000002	0.85000002	3.98	31.800000000000001	3.383	27.030000000000001
8196	4	0	2.5	0.75	6.5700000000000003	35.509999999999998	4.9269999999999996	26.632000000000001
8197	1	0	0.29999999999999999	1.0700001	1.71	24.170000000000002	1.8300000000000001	25.861999999999998
8197	2	0	1.3999999999999999	0.88999999	2.1899999999999999	24.829999999999998	1.9490000000000001	22.099
8197	3	0	1.8999999999999999	0.77999997	4.1699999999999999	28.210000000000001	3.2530000000000001	22.004000000000001
8197	4	0	2.2000000000000002	0.72000003	7.0099999999999998	28.670000000000002	5.0469999999999997	20.641999999999999
8198	1	0	0.29999999999999999	0.89999998	2.5800000000000001	24.859999999999999	2.3220000000000001	22.373999999999999
8198	2	0	1	0.77999997	4.1299999999999999	29.850000000000001	3.2210000000000001	23.283000000000001
8198	3	0	1.3999999999999999	0.72000003	5.7599999999999998	30.780000000000001	4.1470000000000002	22.161999999999999
8198	4	0	1.5	0.68000001	3.29	32.890000000000001	2.2370000000000001	22.364999999999998
8199	1	0	0.29999999999999999	0.82999998	1.5900000000000001	28.670000000000002	1.3200000000000001	23.795999999999999
8199	2	0	0.69999999999999996	0.75	2.21	25.690000000000001	1.657	19.268000000000001
8199	3	0	1	0.64999998	2.0499999999999998	24.149999999999999	1.3320000000000001	15.698
8199	4	0	1.1000000000000001	0.60000002	5.3600000000000003	33.420000000000002	3.2160000000000002	20.052
8190	1	0	0.29999999999999999	1.5599999	2.1699999999999999	32.350000000000001	3.3849999999999998	50.466000000000001
8190	2	0	3.2999999999999998	1.51	2.1299999999999999	30.140000000000001	3.2160000000000002	45.511000000000003
8190	3	0	4.4000000000000004	1.46	2.5800000000000001	33.899999999999999	3.7669999999999999	49.494
8190	4	0	5.2999999999999998	1.1900001	2.6600000000000001	30.52	3.165	36.319000000000003
8191	1	0	0.29999999999999999	1.47	3	33.030000000000001	4.4100000000000001	48.554000000000002
8191	2	0	2.7000000000000002	1.3200001	5.2999999999999998	35.920000000000002	6.9960000000000004	47.414000000000001
8191	3	0	3.6000000000000001	1.14	10.32	38.75	11.765000000000001	44.174999999999997
8191	4	0	4.2000000000000002	0.98000002	23.879999999999999	56.060000000000002	23.402000000000001	54.939
8192	1	0	0.29999999999999999	1.38	3.3399999999999999	40.359999999999999	4.609	55.697000000000003
8192	2	0	2.5	1.33	5.0800000000000001	33.420000000000002	6.7560000000000002	44.448999999999998
8192	3	0	3.3999999999999999	1.17	11.109999999999999	43.270000000000003	12.999000000000001	50.625999999999998
8192	4	0	4	1.02	22.399999999999999	54.020000000000003	22.847999999999999	55.100000000000001
8193	1	0	0.29999999999999999	1.22	3.1000000000000001	41.740000000000002	3.782	50.923000000000002
8193	2	0	2.3999999999999999	1.09	5.21	38.469999999999999	5.6790000000000003	41.932000000000002
8193	3	0	3.2000000000000002	1.05	12.32	43.979999999999997	12.936	46.179000000000002
8193	4	0	3.7999999999999998	0.82999998	36.57	72.489999999999995	30.353000000000002	60.167000000000002
8194	1	0	0.29999999999999999	1.21	2.77	34.229999999999997	3.3519999999999999	41.417999999999999
8194	2	0	2.1000000000000001	1.13	4.0899999999999999	37.229999999999997	4.6219999999999999	42.07
8194	3	0	2.7999999999999998	0.99000001	5.79	36.109999999999999	5.7320000000000002	35.749000000000002
8194	4	0	3.2000000000000002	0.80000001	27.68	67.099999999999994	22.143999999999998	53.68
8080	1	0	0.29999999999999999	1.41	2.0800000000000001	32.619999999999997	2.9329999999999998	45.994
8080	2	0	2.3999999999999999	1.38	2.23	33.590000000000003	3.077	46.353999999999999
8080	3	0	3.2000000000000002	1.24	2.1800000000000002	33.420000000000002	2.7029999999999998	41.441000000000003
8080	4	0	3.7999999999999998	0.30000001	2.6499999999999999	36.350000000000001	0.79500000000000004	10.904999999999999
8081	1	0	0.29999999999999999	1.6	2.5600000000000001	35.140000000000001	4.0960000000000001	56.223999999999997
8081	2	0	3.2000000000000002	1.39	4.2199999999999998	29.02	5.8659999999999997	40.338000000000001
8081	3	0	4.2999999999999998	1.27	6.46	12.4	8.2040000000000006	15.747999999999999
8081	4	0	5.2000000000000002	1.08	13.710000000000001	49.030000000000001	14.807	52.951999999999998
8082	1	0	0.29999999999999999	1.47	3.48	32.340000000000003	5.1159999999999997	47.539999999999999
8082	2	0	2.5	1.35	5.5700000000000003	38.950000000000003	7.5199999999999996	52.582999999999998
8082	3	0	3.3999999999999999	1.1900001	10.220000000000001	43.979999999999997	12.162000000000001	52.335999999999999
8082	4	0	4	0.97000003	26.809999999999999	60.969999999999999	26.006	59.140999999999998
8083	1	0	0.29999999999999999	1.3200001	2.8199999999999998	37.119999999999997	3.722	48.997999999999998
8083	2	0	2.2999999999999998	1.16	5.9199999999999999	35.579999999999998	6.867	41.273000000000003
8083	3	0	3	1.0599999	12.44	46.340000000000003	13.186	49.119999999999997
8083	4	0	3.6000000000000001	0.75999999	29.719999999999999	62.240000000000002	22.587	47.302
8084	1	0	0.29999999999999999	0.66000003	2.2599999999999998	32.079999999999998	1.492	21.172999999999998
8084	2	0	2.1000000000000001	0.63999999	2.9399999999999999	37.420000000000002	1.8819999999999999	23.949000000000002
8084	3	0	2.7999999999999998	0.57999998	4.7300000000000004	36.649999999999999	2.7429999999999999	21.257000000000001
8084	4	0	3.2999999999999998	0.41999999	6.4699999999999998	43.189999999999998	2.7170000000000001	18.140000000000001
7045	1	0	0.29999999999999999	1.8099999	0.56000000000000005	10.56	1.014	19.114000000000001
7045	2	0	3.3999999999999999	1.8200001	0.40999999999999998	11.41	0.746	20.765999999999998
7045	3	0	4.5	1.46	0.40999999999999998	8.4100000000000001	0.59899999999999998	12.279
7045	4	0	5.4000000000000004	1.08	0.58999999999999997	8.5899999999999999	0.63700000000000001	9.2769999999999992
7046	1	0	0.29999999999999999	1.9400001	1.74	12.24	3.3759999999999999	23.745999999999999
7633	2	0	1.8	0.76999998	2.2599999999999998	24.260000000000002	1.74	18.68
7633	3	0	2.3999999999999999	0.67000002	2.79	26.129999999999999	1.869	17.507000000000001
7633	4	0	2.7999999999999998	0.44	3.7000000000000002	35.030000000000001	1.6279999999999999	15.413
7634	1	0	0.29999999999999999	0.85000002	1.8100000000000001	23.140000000000001	1.538	19.669
7634	2	0	1.7	0.73000002	2.0800000000000001	24.079999999999998	1.518	17.577999999999999
7634	3	0	2.2999999999999998	0.66000003	2.2599999999999998	28.260000000000002	1.492	18.652000000000001
7634	4	0	2.7000000000000002	0.55000001	5.0899999999999999	34.43	2.7989999999999999	18.937000000000001
7625	1	0	0.29999999999999999	0.49000001	1.3799999999999999	13.380000000000001	0.67600000000000005	6.556
7625	2	0	1.5	0.43000001	1.9299999999999999	9.2599999999999998	0.82999999999999996	3.9820000000000002
7625	3	0	2	0.40000001	1.9299999999999999	7.9199999999999999	0.77200000000000002	3.1680000000000001
7625	4	0	2.2999999999999998	0.33000001	2.04	13.369999999999999	0.67300000000000004	4.4119999999999999
7626	1	0	0.29999999999999999	0.86000001	2.0800000000000001	18.739999999999998	1.7889999999999999	16.116
7626	2	0	1.7	0.68000001	1.96	14.630000000000001	1.333	9.9480000000000004
7626	3	0	2.2000000000000002	0.62	1.8500000000000001	17.850000000000001	1.147	11.067
7626	4	0	2.6000000000000001	0.41999999	2.1099999999999999	17.449999999999999	0.88600000000000001	7.3289999999999997
7627	1	0	0.29999999999999999	1.09	1.6200000000000001	7.6200000000000001	1.766	8.3059999999999992
7627	2	0	1.6000000000000001	0.91000003	1.7	7.0300000000000002	1.5469999999999999	6.3970000000000002
7627	3	0	2.2000000000000002	0.68000001	1.8899999999999999	8.5500000000000007	1.2849999999999999	5.8140000000000001
7627	4	0	2.5	0.64999998	2.3399999999999999	5.6699999999999999	1.5209999999999999	3.6859999999999999
7628	1	0	0.29999999999999999	1.03	1.3999999999999999	8.0600000000000005	1.4419999999999999	8.3019999999999996
7628	2	0	1.6000000000000001	0.88999999	2	12	1.78	10.68
7628	3	0	2.2000000000000002	0.86000001	2.1499999999999999	9.4800000000000004	1.849	8.1530000000000005
7628	4	0	2.7000000000000002	0.5	3.1299999999999999	13.800000000000001	1.5649999999999999	6.9000000000000004
7629	1	0	0.29999999999999999	0.91000003	1.5800000000000001	9.5899999999999999	1.4379999999999999	8.7270000000000003
7629	2	0	1.8999999999999999	0.69	2	13.33	1.3799999999999999	9.1980000000000004
7629	3	0	2.6000000000000001	0.63	2.2999999999999998	12.970000000000001	1.4490000000000001	8.1709999999999994
7629	4	0	3	0.56	2.9399999999999999	10.94	1.6459999999999999	6.1260000000000003
7621	1	0	0.29999999999999999	0.89999998	2.5299999999999998	24.530000000000001	2.2770000000000001	22.077000000000002
7621	2	0	2.7999999999999998	0.60000002	2.9100000000000001	22.239999999999998	1.746	13.343999999999999
7621	3	0	3.7999999999999998	0.47999999	2.4199999999999999	25.079999999999998	1.1619999999999999	12.038
7621	4	0	4.5	0.40000001	2.6000000000000001	24.600000000000001	1.04	9.8399999999999999
7622	1	0	0.29999999999999999	1.24	1.9299999999999999	23.93	2.3929999999999998	29.672999999999998
7622	2	0	3.1000000000000001	0.95999998	2.1499999999999999	24.149999999999999	2.0640000000000001	23.184000000000001
7622	3	0	4.2000000000000002	0.85000002	2.4199999999999999	23.079999999999998	2.0569999999999999	19.617999999999999
7622	4	0	5	0.76999998	3.0600000000000001	20.390000000000001	2.3559999999999999	15.699999999999999
7623	1	0	0.29999999999999999	1.5	1.8200000000000001	19.809999999999999	2.73	29.715
7623	2	0	2.7999999999999998	1.2	2.1899999999999999	21.52	2.6280000000000001	25.824000000000002
7623	3	0	3.7999999999999998	1.0700001	2.4199999999999999	21.079999999999998	2.589	22.556000000000001
7623	4	0	4.5	0.99000001	3.8100000000000001	21.140000000000001	3.7719999999999998	20.928999999999998
7624	1	0	0.29999999999999999	1.13	1.0900000000000001	34.43	1.232	38.905999999999999
7624	2	0	2.5	0.98000002	1.74	20.399999999999999	1.7050000000000001	19.992000000000001
7624	3	0	3.3999999999999999	0.92000002	1.55	21.550000000000001	1.4259999999999999	19.826000000000001
7624	4	0	4	0.88	2.04	21.370000000000001	1.7949999999999999	18.806000000000001
7620	1	0	0.29999999999999999	1.4299999	2.5899999999999999	30.59	3.7040000000000002	43.744
7620	2	0	2.3999999999999999	1.23	2.9300000000000002	30.43	3.6040000000000001	37.429000000000002
7620	3	0	3.2999999999999998	1.14	3.2599999999999998	28.760000000000002	3.7160000000000002	32.786000000000001
7620	4	0	4	1.08	3.4399999999999999	29.940000000000001	3.7149999999999999	32.335000000000001
7620	5	0	4.5	1.03	4.2199999999999998	30.719999999999999	4.3470000000000004	31.641999999999999
7619	1	0	0.29999999999999999	0.80000001	1.9299999999999999	21.43	1.544	17.143999999999998
7619	2	0	1.3999999999999999	0.73000002	1.6299999999999999	18.629999999999999	1.1899999999999999	13.6
7619	3	0	1.8999999999999999	0.70999998	1.52	26.02	1.079	18.474
7619	4	0	2.2999999999999998	0.66000003	1.52	21.52	1.0029999999999999	14.202999999999999
7619	5	0	2.5	0.61000001	4.1100000000000003	34.109999999999999	2.5070000000000001	20.806999999999999
7618	1	0	0.29999999999999999	1.13	4.6200000000000001	54.219999999999999	5.2210000000000001	61.268999999999998
7618	2	0	2.1000000000000001	1.0700001	5.6399999999999997	59.640000000000001	6.0350000000000001	63.814999999999998
7618	3	0	2.8999999999999999	1.04	5.7800000000000002	55.780000000000001	6.0110000000000001	58.011000000000003
7618	4	0	3.5	0.95999998	5.5300000000000002	47.530000000000001	5.3090000000000002	45.628999999999998
7618	5	0	3.8999999999999999	0.69	6.4000000000000004	57.600000000000001	4.4160000000000004	39.744
6785	1	0	0.29999999999999999	0.57999998	3.04	3.04	1.7629999999999999	1.7629999999999999
6785	2	0	2.3999999999999999	0.68000001	2.3199999999999998	2.3199999999999998	1.5780000000000001	1.5780000000000001
6785	3	0	3.3999999999999999	0.47	5.0800000000000001	5.0800000000000001	2.3879999999999999	2.3879999999999999
6785	4	0	4.0999999999999996	0.44999999	3.0800000000000001	3.0800000000000001	1.3859999999999999	1.3859999999999999
6785	5	0	4.5999999999999996	0.31999999	3.52	3.52	1.1259999999999999	1.1259999999999999
6786	1	0	0.29999999999999999	0.92000002	2	2	1.8400000000000001	1.8400000000000001
6786	2	0	2.5	0.93000001	2.7200000000000002	2.7200000000000002	2.5299999999999998	2.5299999999999998
6786	3	0	3.3999999999999999	0.82999998	3.3599999999999999	3.3599999999999999	2.7890000000000001	2.7890000000000001
6786	4	0	4.2000000000000002	0.75	3.52	3.52	2.6400000000000001	2.6400000000000001
6786	5	0	4.7000000000000002	0.50999999	4.5599999999999996	4.5599999999999996	2.3260000000000001	2.3260000000000001
6787	1	0	0.29999999999999999	0.99000001	2.6400000000000001	2.6400000000000001	2.6139999999999999	2.6139999999999999
6787	2	0	2.3999999999999999	1.0700001	2.7999999999999998	2.7999999999999998	2.996	2.996
6787	3	0	3.2999999999999998	1.03	2.7200000000000002	2.7200000000000002	2.802	2.802
6787	4	0	4	0.93000001	5.7999999999999998	5.7999999999999998	5.3940000000000001	5.3940000000000001
6787	5	0	4.5	0.60000002	5.1600000000000001	5.1600000000000001	3.0960000000000001	3.0960000000000001
6788	1	0	0.29999999999999999	1.15	1.96	1.96	2.254	2.254
6788	2	0	2.2000000000000002	1.09	2.6000000000000001	2.6000000000000001	2.8340000000000001	2.8340000000000001
6788	3	0	3	1.0700001	2.96	2.96	3.1669999999999998	3.1669999999999998
6788	4	0	3.7000000000000002	0.99000001	3.6400000000000001	3.6400000000000001	3.6040000000000001	3.6040000000000001
6788	5	0	4.0999999999999996	0.72000003	5.7199999999999998	5.7199999999999998	4.1180000000000003	4.1180000000000003
6789	1	0	0.29999999999999999	1.01	3.3199999999999998	3.3199999999999998	3.3530000000000002	3.3530000000000002
6789	2	0	1.8999999999999999	0.93000001	3.52	3.52	3.274	3.274
6789	3	0	2.6000000000000001	0.87	2.6800000000000002	2.6800000000000002	2.3319999999999999	2.3319999999999999
6789	4	0	3.5	0.41	1.9199999999999999	1.9199999999999999	0.78700000000000003	0.78700000000000003
6782	1	0	0.29999999999999999	0.87	2	8.4000000000000004	1.74	7.3079999999999998
6782	2	0	2.5	1.01	2.6200000000000001	9.4199999999999999	2.6459999999999999	9.5139999999999993
6782	3	0	3.2999999999999998	0.89999998	3.2400000000000002	10.039999999999999	2.9159999999999999	9.0359999999999996
6782	4	0	3.8999999999999999	0.67000002	5.8200000000000003	9.0199999999999996	3.899	6.0430000000000001
6783	1	0	0.29999999999999999	0.91000003	2.4700000000000002	13.67	2.2480000000000002	12.44
6783	2	0	2.2000000000000002	0.95999998	2.9500000000000002	10.949999999999999	2.8319999999999999	10.512
6783	3	0	3	0.80000001	3.71	11.710000000000001	2.968	9.3680000000000003
6783	4	0	3.5	0.54000002	5.1600000000000001	12.359999999999999	2.786	6.6740000000000004
6784	1	0	0.29999999999999999	0.74000001	2.4700000000000002	8.8699999999999992	1.8280000000000001	6.5640000000000001
6784	2	0	1.8999999999999999	0.72000003	1.9299999999999999	6.7300000000000004	1.3899999999999999	4.8460000000000001
6784	3	0	2.5	0.63999999	2	7.2000000000000002	1.28	4.6079999999999997
6784	4	0	2.8999999999999999	0.50999999	2.3300000000000001	4.9299999999999997	1.1879999999999999	2.5139999999999998
6779	1	0	0.29999999999999999	0.69	2.8399999999999999	12.84	1.96	8.8599999999999994
6779	2	0	2.2999999999999998	0.57999998	3.2400000000000002	18.039999999999999	1.879	10.462999999999999
6779	3	0	3	0.49000001	3.27	14.07	1.6020000000000001	6.8940000000000001
6779	4	0	3.6000000000000001	0.43000001	3.4700000000000002	15.470000000000001	1.492	6.6520000000000001
6780	1	0	0.29999999999999999	0.75	3.71	16.710000000000001	2.782	12.532
6780	2	0	2	0.69	4.0700000000000003	22.469999999999999	2.8079999999999998	15.504
6780	3	0	2.7000000000000002	0.67000002	4.9500000000000002	16.350000000000001	3.3170000000000002	10.955
6780	4	0	3.2000000000000002	0.68000001	4.9500000000000002	20.149999999999999	3.3660000000000001	13.702
6781	1	0	0.29999999999999999	0.83999997	2.6899999999999999	18.690000000000001	2.2599999999999998	15.699999999999999
6781	2	0	1.6000000000000001	0.76999998	3.27	20.07	2.5179999999999998	15.454000000000001
6781	3	0	2.2000000000000002	0.69	3.73	14.93	2.5739999999999998	10.302
6781	4	0	2.7000000000000002	0.61000001	3.5499999999999998	14.35	2.165	8.7530000000000001
6790	1	0	0.29999999999999999	0.83999997	3.6200000000000001	26.620000000000001	3.0409999999999999	22.361000000000001
6790	2	0	1.3	0.69	3.9399999999999999	35.280000000000001	2.7189999999999999	24.343
6790	3	0	1.7	0.58999997	3.9100000000000001	28.57	2.3069999999999999	16.856000000000002
6790	4	0	2	0.44999999	4.8499999999999996	35.520000000000003	2.1819999999999999	15.984
6791	1	0	0.29999999999999999	1.05	4.2300000000000004	34.890000000000001	4.4420000000000002	36.634
6791	2	0	3.3999999999999999	0.82999998	5.25	30.25	4.3570000000000002	25.106999999999999
6791	3	0	4.5	0.63	6.1500000000000004	23.48	3.875	14.792
6791	4	0	5.4500000000000002	0.34999999	5.8499999999999996	37.850000000000001	2.0470000000000002	13.247
6792	1	0	0.29999999999999999	1.54	4.3399999999999999	35.340000000000003	6.6840000000000002	54.423999999999999
6792	2	0	3.7000000000000002	1.24	8.0399999999999991	39.700000000000003	9.9700000000000006	49.228000000000002
6792	3	0	5	1.04	11.59	42.25	12.054	43.939999999999998
6792	4	0	5.9500000000000002	0.67000002	8.5700000000000003	36.32	5.742	24.334
6793	1	0	0.29999999999999999	1.47	4.3200000000000003	30.649999999999999	6.3499999999999996	45.055
6793	2	0	3.3999999999999999	1.41	5.4299999999999997	35.770000000000003	7.6559999999999997	50.436
6793	3	0	4.5	1.27	15.76	47.759999999999998	20.015000000000001	60.655000000000001
6793	4	0	5.4000000000000004	0.98000002	7.4299999999999997	34.770000000000003	7.2809999999999997	34.075000000000003
6794	1	0	0.29999999999999999	1.26	2.9100000000000001	30.57	3.6669999999999998	38.518000000000001
6794	2	0	2.7999999999999998	1.13	2.6600000000000001	31.66	3.0059999999999998	35.776000000000003
6794	3	0	3.7000000000000002	1.0599999	2.6000000000000001	24.27	2.7559999999999998	25.725999999999999
6794	4	0	4.4500000000000002	0.83999997	3.3999999999999999	32.060000000000002	2.8559999999999999	26.93
6774	1	0	0.29999999999999999	0.70999998	2.3300000000000001	24.579999999999998	1.6539999999999999	17.452000000000002
6774	2	0	2.5	0.56999999	2.8300000000000001	15.08	1.613	8.5960000000000001
6774	3	0	3.3999999999999999	0.44999999	3.5699999999999998	18.07	1.607	8.1319999999999997
6774	4	0	4.1500000000000004	0.38999999	3.7799999999999998	23.780000000000001	1.474	9.2739999999999991
6775	1	0	0.29999999999999999	0.95999998	2.7999999999999998	15.300000000000001	2.6880000000000002	14.688000000000001
6775	2	0	2.3999999999999999	0.79000002	3.8900000000000001	17.890000000000001	3.073	14.132999999999999
6775	3	0	3.2000000000000002	0.73000002	4.21	21.960000000000001	3.073	16.030999999999999
6775	4	0	3.9500000000000002	0.60000002	6.1299999999999999	29.129999999999999	3.6779999999999999	17.478000000000002
6776	1	0	0.29999999999999999	0.83999997	2.1699999999999999	15.42	1.823	12.952999999999999
6776	2	0	2.2999999999999998	0.73000002	3.5600000000000001	23.809999999999999	2.5990000000000002	17.381
6776	3	0	3	0.67000002	7	26.75	4.6900000000000004	17.922000000000001
6776	4	0	3.75	0.52999997	11.26	29.010000000000002	5.968	15.375
6777	1	0	0.29999999999999999	0.94999999	2.7999999999999998	21.800000000000001	2.6600000000000001	20.710000000000001
6777	2	0	2.2000000000000002	0.74000001	2.8700000000000001	17.120000000000001	2.1240000000000001	12.669
6777	3	0	2.8999999999999999	0.68000001	3.3300000000000001	23.579999999999998	2.2639999999999998	16.033999999999999
6777	4	0	3.5499999999999998	0.60000002	4.7000000000000002	22.449999999999999	2.8199999999999998	13.470000000000001
6778	1	0	0.29999999999999999	0.83999997	1.6299999999999999	21.379999999999999	1.369	17.959
6778	2	0	2.1000000000000001	0.80000001	2.04	15.789999999999999	1.6319999999999999	12.632
6778	3	0	2.7999999999999998	0.70999998	2.2599999999999998	17.260000000000002	1.605	12.255000000000001
6778	4	0	3.4500000000000002	0.49000001	3.6899999999999999	24.18	1.8080000000000001	11.848000000000001
6763	1	0	0.29999999999999999	0.69999999	5.8099999999999996	77.810000000000002	4.0670000000000002	54.466999999999999
6763	2	0	2.7000000000000002	0.70999998	6.7000000000000002	93.700000000000003	4.7569999999999997	66.527000000000001
6763	3	0	3.6000000000000001	0.66000003	7.2599999999999998	109.26000000000001	4.7919999999999998	72.111999999999995
6763	4	0	4.4500000000000002	0.46000001	6.7000000000000002	77.700000000000003	3.0819999999999999	35.741999999999997
6764	1	0	0.29999999999999999	0.87	6.4299999999999997	72.769999999999996	5.5940000000000003	63.310000000000002
6764	2	0	3.2999999999999998	0.93000001	7.1699999999999999	76.170000000000002	6.6680000000000001	70.837999999999994
6764	3	0	4.4000000000000004	0.87	7.1100000000000003	95.780000000000001	6.1859999999999999	83.328999999999994
6764	4	0	5.4500000000000002	0.81999999	8.1300000000000008	63.469999999999999	6.6669999999999998	52.045000000000002
6765	1	0	0.29999999999999999	1	6.7199999999999998	86.049999999999997	6.7199999999999998	86.049999999999997
6765	2	0	3.1000000000000001	0.94999999	7.5099999999999998	75.510000000000005	7.1340000000000003	71.733999999999995
6765	3	0	4.2000000000000002	0.83999997	9.9399999999999995	61.609999999999999	8.3499999999999996	51.752000000000002
6765	4	0	5.1500000000000004	0.69	12.02	74.349999999999994	8.2940000000000005	51.301000000000002
6766	1	0	0.29999999999999999	1.0700001	6.1299999999999999	80.129999999999995	6.5590000000000002	85.739000000000004
6766	2	0	2.7000000000000002	0.92000002	8.4299999999999997	68.430000000000007	7.7560000000000002	62.956000000000003
6766	3	0	3.6000000000000001	0.92000002	10.869999999999999	86.870000000000005	10	79.920000000000002
6766	4	0	4.4500000000000002	0.62	22.960000000000001	88.629999999999995	14.234999999999999	54.951000000000001
6767	1	0	0.29999999999999999	1.02	5.2999999999999998	64.640000000000001	5.4059999999999997	65.933000000000007
6767	2	0	2.3999999999999999	0.94	6.9800000000000004	99.980000000000004	6.5609999999999999	93.980999999999995
6767	3	0	3.2000000000000002	0.82999998	8.5899999999999999	65.25	7.1299999999999999	54.158000000000001
6767	4	0	3.9500000000000002	0.69	13.06	85.390000000000001	9.0109999999999992	58.918999999999997
6768	1	0	0.29999999999999999	0.75	5.04	90.709999999999994	3.7799999999999998	68.033000000000001
6768	2	0	2.1000000000000001	0.82999998	6.79	71.129999999999995	5.6360000000000001	59.037999999999997
6768	3	0	2.7999999999999998	0.80000001	6.8499999999999996	85.849999999999994	5.4800000000000004	68.680000000000007
6768	4	0	3.6499999999999999	0.63999999	8.9800000000000004	92.310000000000002	5.7469999999999999	59.078000000000003
6769	1	0	0.29999999999999999	0.88	5.1299999999999999	44.130000000000003	4.5140000000000002	38.834000000000003
6769	2	0	1.2	0.66000003	6.4800000000000004	48.229999999999997	4.2770000000000001	31.832000000000001
6769	3	0	1.6000000000000001	0.47	7.7999999999999998	52.549999999999997	3.6659999999999999	24.698
6769	4	0	1.8	0.36000001	10.800000000000001	58.299999999999997	3.8879999999999999	20.988
6770	1	0	0.29999999999999999	1.3099999	5.3300000000000001	22.079999999999998	6.9820000000000002	28.925000000000001
6770	2	0	2.2000000000000002	1.04	6.3899999999999997	34.890000000000001	6.6459999999999999	36.286000000000001
6770	3	0	2.8999999999999999	1.01	6.5199999999999996	39.020000000000003	6.585	39.409999999999997
6770	4	0	3.3999999999999999	0.64999998	9.1899999999999995	43.689999999999998	5.9740000000000002	28.399000000000001
6771	1	0	0.29999999999999999	1.53	4.8700000000000001	38.369999999999997	7.4509999999999996	58.706000000000003
6771	2	0	2.2999999999999998	1.28	7.4100000000000001	37.409999999999997	9.4849999999999994	47.884999999999998
6771	3	0	3	1.16	7.7000000000000002	59.950000000000003	8.9320000000000004	69.542000000000002
6771	4	0	3.6000000000000001	0.89999998	9.3000000000000007	28.300000000000001	8.3699999999999992	25.469999999999999
6772	1	0	0.29999999999999999	1.46	7.2999999999999998	27.300000000000001	10.657999999999999	39.857999999999997
6772	2	0	2.2999999999999998	1.28	7.8700000000000001	56.619999999999997	10.074	72.474000000000004
6772	3	0	3	1.11	15.5	64	17.204999999999998	71.040000000000006
6772	4	0	3.7999999999999998	0.81999999	22.739999999999998	56.490000000000002	18.646999999999998	46.322000000000003
6773	1	0	0.29999999999999999	1.36	5.9800000000000004	33.479999999999997	8.1329999999999991	45.533000000000001
6773	2	0	3	1.29	7.3700000000000001	32.619999999999997	9.5069999999999997	42.079999999999998
13131	2	0	2.7000000000000002	1.462	4.3799999999999999	18.379999999999999	6.4039999999999999	26.872
13131	3	0	3.6000000000000001	1.363	5.0110000000000001	21.491	6.8300000000000001	29.292000000000002
13131	4	0	4.2999999999999998	0.76300001	7.484	26.184000000000001	5.71	19.978000000000002
13132	1	0	0.29999999999999999	1.916	3.9329999999999998	25.753	7.5359999999999996	49.343000000000004
13132	2	0	2.7999999999999998	1.774	5.024	28.263999999999999	8.9130000000000003	50.140000000000001
13132	3	0	3.7999999999999998	1.586	5.2999999999999998	21.059999999999999	8.4060000000000006	33.401000000000003
13132	4	0	4.5	0.91600001	11.657999999999999	26.577999999999999	10.679	24.344999999999999
13133	1	0	0.29999999999999999	2.1700001	3.831	25.571000000000002	8.3130000000000006	55.488999999999997
13133	2	0	3.1000000000000001	2.0009999	5.6890000000000001	19.689	11.384	39.398000000000003
13133	3	0	4.2000000000000002	1.711	8.3160000000000007	22.056000000000001	14.228999999999999	37.738
13133	4	0	4.7000000000000002	1.561	6.2110000000000003	28.411000000000001	9.6950000000000003	44.350000000000001
13133	5	0	5	1.322	6.7750000000000004	31.355	8.9570000000000007	41.451000000000001
13134	1	0	0.29999999999999999	2.2409999	4.8310000000000004	20.370999999999999	10.826000000000001	45.651000000000003
13134	2	0	3.3999999999999999	2.069	12.255000000000001	33.575000000000003	25.356000000000002	69.466999999999999
13134	3	0	4.5999999999999996	1.881	10.064	28.904	18.93	54.368000000000002
13134	4	0	5.0999999999999996	1.755	8.7420000000000009	24.902000000000001	15.342000000000001	43.703000000000003
13134	5	0	5.5	1.401	11.778	25.597999999999999	16.501000000000001	35.863
13135	1	0	0.29999999999999999	2.2409999	4.6150000000000002	15.175000000000001	10.342000000000001	34.006999999999998
13135	2	0	3.7000000000000002	1.878	7.4349999999999996	24.594999999999999	13.962999999999999	46.189
13135	3	0	5	1.8150001	4.9290000000000003	20.489000000000001	8.9459999999999997	37.188000000000002
13135	4	0	5.5999999999999996	1.67	6.3869999999999996	19.126999999999999	10.666	31.942
13135	5	0	6	0.89899999	6.0549999999999997	26.875	5.4429999999999996	24.161000000000001
12911	1	0	0.29999999999999999	0.49900001	1.2729999999999999	12.532999999999999	0.63500000000000001	6.2539999999999996
12911	2	0	0.59999999999999998	0.45300001	10.76	19.300000000000001	4.8739999999999997	8.7430000000000003
12911	3	0	0.80000000000000004	0.419	1.536	9.1359999999999992	0.64400000000000002	3.8279999999999998
12912	1	0	0.29999999999999999	0.99699998	1.1240000000000001	10.904	1.121	10.871
12912	2	0	0.80000000000000004	0.79699999	1.1910000000000001	11.670999999999999	0.94899999999999995	9.3019999999999996
12912	3	0	1.1000000000000001	0.461	1.7649999999999999	12.505000000000001	0.81399999999999995	5.7649999999999997
12913	1	0	0.29999999999999999	1.102	0.94899999999999995	9.5690000000000008	1.046	10.545
12913	2	0	1	0.73699999	1.956	10.756	1.4419999999999999	7.9269999999999996
12913	3	0	1.5	0.57700002	2.5800000000000001	12.039999999999999	1.4890000000000001	6.9470000000000001
12914	1	0	0.29999999999999999	1.2180001	1.3160000000000001	8.2759999999999998	1.603	10.08
12914	2	0	1.3999999999999999	1.1059999	1.2729999999999999	7.9329999999999998	1.4079999999999999	8.7739999999999991
12914	3	0	1.8999999999999999	0.88200003	2.4420000000000002	10.401999999999999	2.1539999999999999	9.1750000000000007
12914	4	0	2.2000000000000002	0.456	20.777999999999999	28.318000000000001	9.4749999999999996	12.913
12915	1	0	0.29999999999999999	1.2970001	0.95099999999999996	6.6710000000000003	1.2330000000000001	8.6519999999999992
12915	2	0	1.6000000000000001	1.1569999	1.702	9.0619999999999994	1.9690000000000001	10.484999999999999
12915	3	0	2.1000000000000001	0.90799999	2.7069999999999999	8.8870000000000005	2.4580000000000002	8.0690000000000008
12915	4	0	2.3999999999999999	0.62099999	25.978000000000002	32.618000000000002	16.132000000000001	20.256
12290	1	0	0.29999999999999999	1.392	1.4890000000000001	10.888999999999999	2.073	15.157
12290	2	0	1.7	1.283	1.6759999999999999	8.7360000000000007	2.1499999999999999	11.208
12290	3	0	2.2999999999999998	1.145	2.0110000000000001	14.631	2.3029999999999999	16.751999999999999
12290	4	0	2.7000000000000002	0.80400002	3.0449999999999999	15.404999999999999	2.448	12.385999999999999
12289	1	0	0.29999999999999999	1.772	1.982	13.882	3.512	24.599
12289	2	0	1.8999999999999999	1.54	2.2890000000000001	14.749000000000001	3.5249999999999999	22.713000000000001
12289	3	0	2.6000000000000001	1.392	3.1019999999999999	15.302	4.3179999999999996	21.300000000000001
12289	4	0	3	1.1619999	4.4850000000000003	16.065000000000001	5.2119999999999997	18.667999999999999
12288	1	0	0.29999999999999999	1.716	2.4449999999999998	13.904999999999999	4.1959999999999997	23.861000000000001
12288	2	0	2.1000000000000001	1.546	4.0890000000000004	16.309000000000001	6.3220000000000001	25.213999999999999
12288	3	0	2.7999999999999998	1.288	6.5179999999999998	18.437999999999999	8.3949999999999996	23.748000000000001
12288	4	0	3.2999999999999998	0.92500001	22.375	37.395000000000003	20.696999999999999	34.590000000000003
12287	1	0	0.29999999999999999	1.827	1.9750000000000001	13.195	3.6080000000000001	24.106999999999999
12287	2	0	2.5	1.602	4.8220000000000001	15.321999999999999	7.7249999999999996	24.545999999999999
12287	3	0	3.3999999999999999	1.355	18.484000000000002	29.123999999999999	25.045999999999999	39.463000000000001
12287	4	0	4	0.84799999	168.673	184.613	143.035	156.55199999999999
12286	1	0	0.29999999999999999	1.827	2.113	12.813000000000001	3.8599999999999999	23.408999999999999
12286	2	0	2.7000000000000002	1.605	1.8069999999999999	12.127000000000001	2.8999999999999999	19.463999999999999
12286	3	0	3.6000000000000001	1.368	3.0950000000000002	12.695	4.234	17.367000000000001
12286	4	0	4.2999999999999998	0.838	8.2149999999999999	20.175000000000001	6.8840000000000003	16.907
11182	1	0	0.29999999999999999	1.007	1.0800000000000001	13.220000000000001	1.0880000000000001	13.313000000000001
11182	2	0	0.69999999999999996	0.94400001	1.2529999999999999	14.813000000000001	1.1830000000000001	13.983000000000001
11182	3	0	0.90000000000000002	0.87	1.2909999999999999	14.911	1.123	12.973000000000001
11182	4	0	1	0.778	1.3400000000000001	15.52	1.0429999999999999	12.074999999999999
11181	1	0	0.29999999999999999	1.118	1.3220000000000001	14.262	1.478	15.945
11181	2	0	0.80000000000000004	1.034	1.3360000000000001	14.375999999999999	1.381	14.865
11181	3	0	1	1.01	1.2729999999999999	14.073	1.286	14.214
11181	4	0	1.2	0.79400003	1.298	13.757999999999999	1.0309999999999999	10.923999999999999
11180	1	0	0.29999999999999999	1.1619999	1.413	13.833	1.6419999999999999	16.074000000000002
11180	2	0	0.90000000000000002	1.136	1.5049999999999999	14.085000000000001	1.71	16.001000000000001
11180	3	0	1.2	1.034	1.575	14.775	1.629	15.276999999999999
11180	4	0	1.3999999999999999	0.81699997	2.0329999999999999	14.933	1.661	12.199999999999999
11179	1	0	0.29999999999999999	1.368	1.5449999999999999	14.565	2.1139999999999999	19.925000000000001
11179	2	0	1.5	1.266	2.0579999999999998	5.0529999999999999	2.605	6.3970000000000002
11179	3	0	2	1.191	2.536	5.5339999999999998	3.02	6.5910000000000002
11179	4	0	2.2000000000000002	1.024	5.9089999999999998	18.849	6.0510000000000002	19.300999999999998
11178	1	0	0.29999999999999999	1.353	1.2529999999999999	13.553000000000001	1.6950000000000001	18.337
11178	2	0	1.7	1.242	1.5640000000000001	14.023999999999999	1.9419999999999999	17.417999999999999
11178	3	0	2.2000000000000002	1.0369999	1.724	15.144	1.788	15.704000000000001
11178	4	0	2.5	0.82300001	2.262	14.342000000000001	1.8620000000000001	11.803000000000001
11187	1	0	0.29999999999999999	1.041	0.502	7.4420000000000002	0.52300000000000002	7.7469999999999999
11187	2	0	0.59999999999999998	0.986	0.67500000000000004	8.3550000000000004	0.66600000000000004	8.2379999999999995
11187	3	0	0.69999999999999996	0.83999997	0.96499999999999997	8.4450000000000003	0.81100000000000005	7.0940000000000003
11186	1	0	0.29999999999999999	1.143	0.998	13.938000000000001	1.141	15.930999999999999
11186	2	0	0.69999999999999996	1.128	0.95299999999999996	10.452999999999999	1.075	11.791
11186	3	0	0.90000000000000002	1.044	1.0269999999999999	9.3870000000000005	1.0720000000000001	9.8000000000000007
11186	4	0	1.1000000000000001	0.84600002	1.6559999999999999	11.795999999999999	1.401	9.9789999999999992
11185	1	0	0.29999999999999999	1.3150001	0.82899999999999996	8.6690000000000005	1.0900000000000001	11.4
11185	2	0	0.80000000000000004	1.181	0.88700000000000001	4.9669999999999996	1.048	5.8659999999999997
11185	3	0	1	1.043	1.042	7.242	1.087	7.5529999999999999
11185	4	0	1.3	0.91600001	1.238	8.6980000000000004	1.1339999999999999	7.9669999999999996
11184	1	0	0.29999999999999999	1.3150001	1.0249999999999999	7.6849999999999996	1.3480000000000001	10.106
11184	2	0	1.5	1.182	2.0779999999999998	10.878	2.456	12.858000000000001
11184	3	0	2	1.005	2.7160000000000002	10.096	2.73	10.146000000000001
11184	4	0	2.2000000000000002	0.852	4.9269999999999996	11.186999999999999	4.1980000000000004	9.5310000000000006
11183	1	0	0.29999999999999999	1.278	0.629	6.5490000000000004	0.80400000000000005	8.3699999999999992
11183	2	0	1.6000000000000001	1.1619999	0.79600000000000004	6.3959999999999999	0.92500000000000004	7.4320000000000004
11183	3	0	2.1000000000000001	0.91500002	0.90900000000000003	7.6890000000000001	0.83199999999999996	7.0350000000000001
11183	4	0	2.2999999999999998	0.80900002	1.256	7.556	1.016	6.1130000000000004
10957	1	0	0.29999999999999999	1.569	3.1360000000000001	31.756	4.9199999999999999	49.825000000000003
10957	2	0	2.6000000000000001	1.351	4.2220000000000004	33.521999999999998	5.7039999999999997	45.287999999999997
10957	3	0	3.3999999999999999	1.23	5.1580000000000004	28.437999999999999	6.3440000000000003	34.978999999999999
10957	4	0	4	1.051	5.7880000000000003	35.808	6.0830000000000002	37.634
10956	1	0	0.29999999999999999	2.0020001	3.8380000000000001	26.038	7.6840000000000002	52.128
10956	2	0	2.8999999999999999	1.878	4.3579999999999997	21.658000000000001	8.1839999999999993	40.673999999999999
10956	3	0	3.7999999999999998	1.702	5.7960000000000003	33.996000000000002	9.8650000000000002	57.860999999999997
10956	4	0	4.5	1.517	8.4719999999999995	39.652000000000001	12.852	60.152000000000001
10955	1	0	0.29999999999999999	2.1930001	5.5720000000000001	32.112000000000002	12.218999999999999	70.421999999999997
10955	2	0	3.2000000000000002	2.0020001	17.763999999999999	50.584000000000003	35.564	101.26900000000001
10955	3	0	4.2000000000000002	1.837	32.997999999999998	61.238	60.616999999999997	112.494
10955	4	0	5	1.346	106.176	138.05600000000001	142.91300000000001	185.82300000000001
10954	1	0	0.29999999999999999	2.2409999	7.4779999999999998	31.718	16.757999999999999	71.079999999999998
10954	2	0	3.5	2.135	14.708	45.667999999999999	31.402000000000001	97.501000000000005
10954	3	0	4.5999999999999996	1.868	39.112000000000002	67.231999999999999	73.061000000000007	125.589
10954	4	0	5.5	1.216	284.95800000000003	314.55799999999999	346.50900000000001	382.50299999999999
10953	1	0	0.29999999999999999	2.108	4.3140000000000001	35.814	9.0939999999999994	75.495999999999995
10953	2	0	3.7999999999999998	1.9119999	7.1500000000000004	37.170000000000002	13.670999999999999	71.069000000000003
10953	3	0	5	1.6289999	10.378	32.857999999999997	16.905999999999999	53.526000000000003
10953	4	0	6	0.81900001	19.686	47.945999999999998	16.123000000000001	39.268000000000001
10650	1	0	0.29999999999999999	0.99599999	3.1619999999999999	18.242000000000001	3.149	18.169
10650	2	0	0.41999999999999998	0.99400002	3.6080000000000001	19.088000000000001	3.5859999999999999	18.972999999999999
10650	3	0	0.56000000000000005	0.90700001	5.3799999999999999	21.219999999999999	4.8799999999999999	19.247
10650	4	0	0.69999999999999996	0.67900002	2.6920000000000002	14.952	1.8280000000000001	10.151999999999999
10649	1	0	0.29999999999999999	1.008	1.702	15.901999999999999	1.716	16.029
10649	2	0	0.69999999999999996	1.003	1.8220000000000001	15.022	1.827	15.067
10649	3	0	0.90000000000000002	0.88700002	2.1440000000000001	15.404	1.9019999999999999	13.663
10649	4	0	1.1000000000000001	0.66500002	2.6859999999999999	16.306000000000001	1.786	10.843
10648	1	0	0.29999999999999999	0.96700001	2.8679999999999999	15.628	2.7730000000000001	15.112
10648	2	0	0.69999999999999996	0.912	3.1779999999999999	15.997999999999999	2.8980000000000001	14.59
10648	3	0	0.90000000000000002	0.82999998	3.7719999999999998	17.812000000000001	3.1309999999999998	14.784000000000001
10648	4	0	1.1000000000000001	0.62199998	6.1379999999999999	19.898	3.8180000000000001	12.377000000000001
10647	1	0	0.29999999999999999	1.1900001	4.5759999999999996	19.856000000000002	5.4450000000000003	23.629000000000001
10647	2	0	1	1.115	5.8819999999999997	23.742000000000001	6.5579999999999998	26.472000000000001
10647	3	0	1.3	0.97399998	7.1840000000000002	23.324000000000002	6.9969999999999999	22.718
10647	4	0	1.6000000000000001	0.71600002	23.568000000000001	39.667999999999999	16.875	28.402000000000001
10646	1	0	0.29999999999999999	1.265	3.7000000000000002	17.239999999999998	4.6799999999999997	21.809000000000001
10646	2	0	1.1000000000000001	1.178	3.9900000000000002	20.829999999999998	4.7000000000000002	24.538
10646	3	0	1.3999999999999999	0.98000002	5.6779999999999999	24.297999999999998	5.5640000000000001	23.812000000000001
10646	4	0	1.8	0.71600002	10.012	30.352	7.1689999999999996	21.731999999999999
10645	1	0	0.29999999999999999	1.631	4.3399999999999999	51.259999999999998	7.0789999999999997	83.605000000000004
10645	2	0	2	1.498	5.7000000000000002	47.039999999999999	8.5389999999999997	70.465999999999994
10645	3	0	2.6000000000000001	1.3559999	6.3600000000000003	29.48	8.6240000000000006	39.975000000000001
10645	4	0	3.1000000000000001	0.98100001	9.3330000000000002	41.253	9.1560000000000006	40.469000000000001
10644	1	0	0.29999999999999999	1.779	4.867	28.266999999999999	8.6579999999999995	50.286999999999999
10644	2	0	2.2000000000000002	1.638	5.9269999999999996	29.887	9.7080000000000002	48.954999999999998
10644	3	0	2.8999999999999999	1.4910001	7.5529999999999999	40.033000000000001	11.262	59.689
10644	4	0	3.3999999999999999	1.123	12.871	45.570999999999998	14.454000000000001	51.176000000000002
10643	1	0	0.29999999999999999	2.0009999	14.073	44.912999999999997	28.16	89.870999999999995
10643	2	0	2.3999999999999999	1.726	12.481999999999999	47.502000000000002	21.544	81.988
10643	3	0	3.2000000000000002	1.585	22	58.799999999999997	34.869999999999997	93.197999999999993
10643	4	0	3.7999999999999998	1.141	65.456000000000003	100.316	74.685000000000002	114.461
10642	1	0	0.29999999999999999	2.03	8.3360000000000003	45.436	16.922000000000001	92.234999999999999
10642	2	0	3	1.827	17.059999999999999	52.479999999999997	31.169	95.881
10642	3	0	4	1.6670001	18.404	58.124000000000002	30.678999999999998	96.893000000000001
10642	4	0	4.7999999999999998	1.133	51.817999999999998	90.778000000000006	58.710000000000001	102.851
10641	1	0	0.29999999999999999	1.944	7.4290000000000003	46.029000000000003	14.442	89.480000000000004
10641	2	0	3.2999999999999998	1.6849999	4.0090000000000003	92.549000000000007	6.7549999999999999	155.94499999999999
10641	3	0	4.4000000000000004	1.177	14.302	52.561999999999998	16.832999999999998	61.865000000000002
10641	4	0	5.2999999999999998	0.81699997	25.797999999999998	56.277999999999999	21.077000000000002	45.978999999999999
8225	1	0	0.29999999999999999	1.23	1.72	21.16	2.1160000000000001	26.027000000000001
8225	2	0	1.3999999999999999	1.112	2.7000000000000002	20.739999999999998	3.0019999999999998	23.062999999999999
8225	3	0	1.8	0.991	3.5699999999999998	20.760000000000002	3.5379999999999998	20.573
8225	4	0	2.1000000000000001	0.84299999	2.3399999999999999	20.440000000000001	1.9730000000000001	17.231000000000002
8226	1	0	0.29999999999999999	1.643	1.5900000000000001	19.969999999999999	2.6120000000000001	32.811
8226	2	0	1.8	1.477	2.96	22.879999999999999	4.3719999999999999	33.793999999999997
8226	3	0	2.3999999999999999	1.365	4.8899999999999997	23.07	6.6749999999999998	31.491
8226	4	0	2.7999999999999998	1.104	3.3199999999999998	23.039999999999999	3.665	25.436
8227	1	0	0.29999999999999999	1.59	3.4900000000000002	23.25	5.5490000000000004	36.968000000000004
8227	2	0	2	1.423	6.96	27.52	9.9039999999999999	39.161000000000001
8227	3	0	2.6000000000000001	1.2920001	20.989999999999998	42.609999999999999	27.119	55.052
8227	4	0	3.1000000000000001	1.072	31.170000000000002	51.049999999999997	33.414000000000001	54.725999999999999
13131	1	0	0.29999999999999999	1.595	3.4649999999999999	31.045000000000002	5.5270000000000001	49.517000000000003
7043	2	0	1.3	0.88999999	6.29	42.789999999999999	5.5979999999999999	38.082999999999998
7043	3	0	1.8	0.68000001	5.0700000000000003	42.07	3.448	28.608000000000001
7043	4	0	2	0.54000002	8.6300000000000008	43.130000000000003	4.6600000000000001	23.289999999999999
7044	1	0	0.29999999999999999	0.93000001	4.4100000000000001	41.409999999999997	4.101	38.511000000000003
7044	2	0	1.3	0.81	4.7800000000000002	44.280000000000001	3.8719999999999999	35.866999999999997
7044	3	0	1.7	0.72000003	5.96	41.960000000000001	4.2910000000000004	30.210999999999999
7044	4	0	1.8999999999999999	0.57999998	7.1500000000000004	40.649999999999999	4.1470000000000002	23.577000000000002
6987	1	0	0.29999999999999999	1.16	4.4199999999999999	4.4199999999999999	5.1269999999999998	5.1269999999999998
6987	2	0	1.3999999999999999	1.0599999	4.9199999999999999	4.9199999999999999	5.2149999999999999	5.2149999999999999
6987	3	0	2	0.94999999	5.8399999999999999	5.8399999999999999	5.548	5.548
6987	4	0	2.3999999999999999	0.81	6.4000000000000004	6.4000000000000004	5.1840000000000002	5.1840000000000002
6987	5	0	2.6000000000000001	0.70999998	7.2000000000000002	7.2000000000000002	5.1120000000000001	5.1120000000000001
6988	1	0	0.29999999999999999	1.16	6.7599999999999998	6.7599999999999998	7.8419999999999996	7.8419999999999996
6988	2	0	1.3	1.08	6.6799999999999997	6.6799999999999997	7.2140000000000004	7.2140000000000004
6988	3	0	1.8	0.95999998	11.44	11.44	10.981999999999999	10.981999999999999
6988	4	0	2.2000000000000002	0.82999998	5.3200000000000003	5.3200000000000003	4.4160000000000004	4.4160000000000004
6988	5	0	2.3999999999999999	0.69999999	7.7199999999999998	7.7199999999999998	5.4039999999999999	5.4039999999999999
6989	1	0	0.29999999999999999	1.04	5.5099999999999998	5.5099999999999998	5.7300000000000004	5.7300000000000004
6989	2	0	1.3999999999999999	0.93000001	5.2000000000000002	5.2000000000000002	4.8360000000000003	4.8360000000000003
6989	3	0	1.8999999999999999	0.89999998	5.6399999999999997	5.6399999999999997	5.0759999999999996	5.0759999999999996
6989	4	0	2.2999999999999998	0.74000001	4.3600000000000003	4.3600000000000003	3.226	3.226
6989	5	0	2.5	0.72000003	6.2800000000000002	6.2800000000000002	4.5220000000000002	4.5220000000000002
6990	1	0	0.29999999999999999	0.95999998	5.0700000000000003	5.0700000000000003	4.867	4.867
6990	2	0	1.3	0.89999998	5.5199999999999996	5.5199999999999996	4.968	4.968
6990	3	0	1.8	0.85000002	6.1600000000000001	6.1600000000000001	5.2359999999999998	5.2359999999999998
6990	4	0	2.2000000000000002	0.76999998	6.2800000000000002	6.2800000000000002	4.8360000000000003	4.8360000000000003
6990	5	0	2.3999999999999999	0.64999998	6.4800000000000004	6.4800000000000004	4.2119999999999997	4.2119999999999997
6982	1	0	0.29999999999999999	0.99000001	3.3300000000000001	32.829999999999998	3.2970000000000002	32.502000000000002
6982	2	0	2.2999999999999998	1.14	3.2999999999999998	31.300000000000001	3.762	35.682000000000002
6982	3	0	3	1.0700001	3.7000000000000002	34.700000000000003	3.9590000000000001	37.128999999999998
6982	4	0	3.6000000000000001	0.81	3.7999999999999998	35.049999999999997	3.0779999999999998	28.390000000000001
6983	1	0	0.29999999999999999	1.29	2.8700000000000001	28.120000000000001	3.702	36.274999999999999
6983	2	0	1.8	1.17	3.02	31.77	3.5329999999999999	37.170999999999999
6983	3	0	2.3999999999999999	1.1	3.4300000000000002	30.68	3.7730000000000001	33.747999999999998
6983	4	0	2.7999999999999998	0.82999998	5.5499999999999998	31.550000000000001	4.6070000000000002	26.187000000000001
6984	1	0	0.29999999999999999	1.24	2.7999999999999998	29.550000000000001	3.472	36.642000000000003
6984	2	0	1.8999999999999999	1.09	3.2799999999999998	31.030000000000001	3.5750000000000002	33.823
6984	3	0	2.5	0.99000001	4.0700000000000003	32.57	4.0289999999999999	32.244
6984	4	0	2.8999999999999999	0.63999999	4.6500000000000004	32.149999999999999	2.976	20.576000000000001
6985	1	0	0.29999999999999999	1.03	2.54	29.789999999999999	2.6160000000000001	30.684000000000001
6985	2	0	1.7	0.95999998	3.2000000000000002	31.199999999999999	3.0720000000000001	29.952000000000002
6985	3	0	2.2999999999999998	0.94999999	4.1299999999999999	32.380000000000003	3.923	30.760999999999999
6985	4	0	2.7000000000000002	0.81999999	6.8700000000000001	34.869999999999997	5.633	28.593
6986	1	0	0.29999999999999999	1.25	2.5899999999999999	29.59	3.238	36.987000000000002
6986	2	0	1.7	1.16	3.2999999999999998	23.300000000000001	3.8279999999999998	27.027999999999999
6986	3	0	2.2999999999999998	1.09	4.3200000000000003	30.82	4.7089999999999996	33.594000000000001
6977	1	0	1.6000000000000001	0.95999998	6.1699999999999999	54.170000000000002	5.923	52.003
6977	2	0	2.1000000000000001	0.85000002	6.5700000000000003	79.230000000000004	5.585	67.346000000000004
6977	3	0	2.3999999999999999	0.69	7.3799999999999999	52.039999999999999	5.0919999999999996	35.908000000000001
6978	1	0	0.29999999999999999	1.1799999	6.4699999999999998	59.140000000000001	7.6349999999999998	69.784999999999997
6978	2	0	1.3999999999999999	1.12	7.8899999999999997	47.890000000000001	8.8369999999999997	53.637
6978	3	0	1.8999999999999999	1.03	7.9199999999999999	61.920000000000002	8.1579999999999995	63.777999999999999
6978	4	0	2.2000000000000002	0.81	8.9299999999999997	88.590000000000003	7.2329999999999997	71.757999999999996
6979	1	0	0.29999999999999999	1.15	6.5800000000000001	82.25	7.5670000000000002	94.587000000000003
6979	2	0	1.5	1.05	8.2400000000000002	55.909999999999997	8.6519999999999992	58.706000000000003
6979	3	0	2	0.97000003	12.09	90.430000000000007	11.727	87.716999999999999
6979	4	0	2.2999999999999998	0.69	9.1500000000000004	92.150000000000006	6.3129999999999997	63.584000000000003
6980	1	0	0.29999999999999999	1.17	6.4500000000000002	44.450000000000003	7.5460000000000003	52.006
6980	2	0	1.5	1.04	8.1699999999999999	68.840000000000003	8.4969999999999999	71.593999999999994
6980	3	0	2	0.93000001	9.5299999999999994	47.530000000000001	8.8629999999999995	44.203000000000003
6980	4	0	2.2999999999999998	0.51999998	11.09	72.430000000000007	5.7670000000000003	37.664000000000001
6981	1	0	0.29999999999999999	1.05	5.9800000000000004	62.18	6.2789999999999999	65.289000000000001
6981	2	0	1.6000000000000001	0.97000003	6.29	38.090000000000003	6.101	36.947000000000003
6981	3	0	2.1000000000000001	0.88	7.9800000000000004	62.780000000000001	7.0220000000000002	55.246000000000002
6981	4	0	2.3999999999999999	0.74000001	11.24	72.439999999999998	8.3179999999999996	53.606000000000002
7035	1	0	0.29999999999999999	1.8	4.9100000000000001	77.239999999999995	8.8379999999999992	139.03200000000001
7035	2	0	3.7000000000000002	1.76	8	75.670000000000002	14.08	133.179
7035	3	0	4.9000000000000004	1.6	9.1799999999999997	70.849999999999994	14.688000000000001	113.36
7035	4	0	6.0999999999999996	1.14	22.059999999999999	85.730000000000004	25.148	97.731999999999999
7036	1	0	0.29999999999999999	1.6799999	7.6299999999999999	62.630000000000003	12.818	105.218
7036	2	0	3.6000000000000001	1.46	15.789999999999999	78.459999999999994	23.053000000000001	114.55200000000001
7036	3	0	4.7999999999999998	1.3200001	15.789999999999999	89.459999999999994	20.843	118.087
7036	4	0	6	0.75	25.809999999999999	82.480000000000004	19.356999999999999	61.859999999999999
7037	1	0	0.29999999999999999	1.71	6.3499999999999996	82.019999999999996	10.859	140.25399999999999
7037	2	0	3.2000000000000002	1.54	8.7200000000000006	53.049999999999997	13.429	81.697000000000003
7037	3	0	4.2999999999999998	1.42	18.84	92.840000000000003	26.753	131.833
7037	4	0	5.4000000000000004	1.05	58.840000000000003	139.84	61.781999999999996	146.83199999999999
7038	1	0	0.29999999999999999	1.7	8.8399999999999999	86.170000000000002	15.028	146.489
7038	2	0	3.2000000000000002	1.47	29.629999999999999	98.629999999999995	43.555999999999997	144.98599999999999
7038	3	0	4.2000000000000002	1.25	41.259999999999998	69.590000000000003	51.575000000000003	86.988
7038	4	0	5.2999999999999998	0.92000002	109.56	143.88999999999999	100.795	132.37899999999999
7039	1	0	0.29999999999999999	0.68000001	8.3499999999999996	36.68	5.6779999999999999	24.942
7039	2	0	2.7000000000000002	0.56	12.67	71.010000000000005	7.0949999999999998	39.765999999999998
7039	3	0	3.6000000000000001	0.47	26.140000000000001	57.469999999999999	12.286	27.010999999999999
7039	4	0	4.5	0.46000001	31.879999999999999	108.22	14.664999999999999	49.780999999999999
6973	1	0	0.29999999999999999	1.15	2.98	23.98	3.427	27.577000000000002
6973	2	0	1.8999999999999999	1	2.9199999999999999	25.93	2.9199999999999999	25.93
6973	3	0	2.6000000000000001	0.91000003	2.21	20.879999999999999	2.0110000000000001	19.001000000000001
6973	4	0	2.7999999999999998	0.77999997	2.5099999999999998	30.84	1.958	24.055
6974	1	0	0.29999999999999999	1.1	2.1699999999999999	24.5	2.387	26.949999999999999
6974	2	0	1.7	1.01	2.3999999999999999	24.059999999999999	2.4239999999999999	24.300999999999998
6974	3	0	2.2000000000000002	0.85000002	2.5099999999999998	21.84	2.133	18.564
6974	4	0	2.5	0.74000001	3.02	27.690000000000001	2.2349999999999999	20.491
6975	1	0	0.29999999999999999	1.05	2.1099999999999999	24.109999999999999	2.2160000000000002	25.315000000000001
6975	2	0	1.7	0.95999998	2.6000000000000001	22.940000000000001	2.496	22.021999999999998
6975	3	0	2.2000000000000002	0.88999999	3.1099999999999999	23.109999999999999	2.7679999999999998	20.568000000000001
6975	4	0	2.5	0.81	3.79	21.129999999999999	3.0699999999999998	17.114999999999998
6976	1	0	0.29999999999999999	1.03	2.23	23.559999999999999	2.2970000000000002	24.266999999999999
6976	2	0	1.7	0.89999998	3.6000000000000001	22.940000000000001	3.2400000000000002	20.646000000000001
6976	3	0	2.2000000000000002	0.81	9.1500000000000004	26.149999999999999	7.4119999999999999	21.181000000000001
6976	4	0	2.5	0.68000001	21.379999999999999	38.380000000000003	14.538	26.097999999999999
6968	1	0	0.29999999999999999	0.91000003	1.3999999999999999	22.649999999999999	1.274	20.611000000000001
6968	2	0	1.8999999999999999	0.63	1.8400000000000001	23.84	1.159	15.019
6968	3	0	2.5	0.57999998	2.04	20.539999999999999	1.1830000000000001	11.913
6968	4	0	2.8999999999999999	0.34	3.1400000000000001	22.390000000000001	1.0680000000000001	7.6130000000000004
6969	1	0	0.29999999999999999	1.62	1.6799999999999999	18.43	2.722	29.856999999999999
6969	2	0	2.7999999999999998	1.4400001	2.7200000000000002	27.469999999999999	3.9169999999999998	39.557000000000002
6969	3	0	3.7999999999999998	1.25	3.0800000000000001	22.829999999999998	3.8500000000000001	28.536999999999999
6969	4	0	4.5	0.69999999	4.9000000000000004	34.649999999999999	3.4300000000000002	24.254999999999999
6970	1	0	0.29999999999999999	1.54	1.8799999999999999	18.629999999999999	2.895	28.690000000000001
6970	2	0	2.7999999999999998	1.33	3.3199999999999998	34.07	4.4160000000000004	45.313000000000002
6970	3	0	3.7000000000000002	1.26	5.54	17.289999999999999	6.9800000000000004	21.785
6970	4	0	4.4000000000000004	0.75999999	19.539999999999999	46.789999999999999	14.85	35.560000000000002
6971	1	0	0.29999999999999999	1.46	2.52	28.52	3.6789999999999998	41.639000000000003
6971	2	0	2.7999999999999998	1.1900001	7.7000000000000002	21.449999999999999	9.1630000000000003	25.524999999999999
6971	3	0	3.7999999999999998	1.08	21.300000000000001	40.549999999999997	23.004000000000001	43.793999999999997
6971	4	0	4.5	0.69999999	110	134.5	77	94.150000000000006
6972	1	0	0.29999999999999999	1.33	2.5800000000000001	19.829999999999998	3.431	26.373999999999999
6972	2	0	2.6000000000000001	1.23	5.3799999999999999	20.829999999999998	6.617	25.620999999999999
6972	3	0	3.3999999999999999	1.15	8.8399999999999999	23.59	10.166	27.129000000000001
6972	4	0	4.0999999999999996	0.75999999	58.880000000000003	76.129999999999995	44.749000000000002	57.859000000000002
6963	1	0	0.29999999999999999	1.05	1.1599999999999999	31.16	1.218	32.718000000000004
6963	2	0	1.6000000000000001	1.03	1.28	14.58	1.3180000000000001	15.016999999999999
6963	3	0	2.1000000000000001	0.95999998	1.3200000000000001	33.32	1.2669999999999999	31.986999999999998
6963	4	0	2.3999999999999999	0.70999998	1.54	23.84	1.093	16.925999999999998
6964	1	0	0.29999999999999999	1.1900001	1.26	26.260000000000002	1.4990000000000001	31.248999999999999
6964	2	0	1.6000000000000001	1.09	2.1200000000000001	9.4199999999999999	2.3109999999999999	10.268000000000001
6964	3	0	2.1000000000000001	0.98000002	1.04	21.039999999999999	1.0189999999999999	20.619
6964	4	0	2.3999999999999999	0.72000003	2.0600000000000001	34.359999999999999	1.4830000000000001	24.739000000000001
6965	1	0	0.29999999999999999	1.15	1.72	16.32	1.978	18.768000000000001
6965	2	0	1.7	0.99000001	2.1000000000000001	43.399999999999999	2.0790000000000002	42.966000000000001
6965	3	0	2.2000000000000002	0.87	1.6799999999999999	48.68	1.462	42.351999999999997
6965	4	0	2.6000000000000001	0.75	2.6800000000000002	52.280000000000001	2.0099999999999998	39.210000000000001
6966	1	0	0.29999999999999999	0.99000001	1.6000000000000001	4.9000000000000004	1.5840000000000001	4.851
6966	2	0	1.7	0.87	2.46	10.06	2.1400000000000001	8.7520000000000007
6966	3	0	2.2000000000000002	0.77999997	3.8799999999999999	44.880000000000003	3.0259999999999998	35.006
6966	4	0	2.6000000000000001	0.28	8.1400000000000006	40.439999999999998	2.2789999999999999	11.323
6967	1	0	0.29999999999999999	0.98000002	1.28	19.879999999999999	1.254	19.481999999999999
6967	2	0	1.6000000000000001	0.91000003	1.5600000000000001	15.859999999999999	1.4199999999999999	14.433
6967	3	0	2.1000000000000001	0.80000001	2.1800000000000002	30.510000000000002	1.744	24.408000000000001
6967	4	0	2.3999999999999999	0.58999997	4.5099999999999998	48.109999999999999	2.661	28.385000000000002
6958	1	0	0.29999999999999999	1.24	1.5900000000000001	52.590000000000003	1.972	65.212000000000003
6958	2	0	2.3999999999999999	1.21	2.2599999999999998	51.259999999999998	2.7349999999999999	62.024999999999999
6958	3	0	3.2000000000000002	1.04	2.0600000000000001	62.560000000000002	2.1419999999999999	65.061999999999998
6958	4	0	3.7999999999999998	1.27	2.2200000000000002	39.719999999999999	2.819	50.444000000000003
6959	1	0	0.29999999999999999	1.39	2.02	26.02	2.8079999999999998	36.167999999999999
6959	2	0	2.2999999999999998	1.24	1.8500000000000001	56.100000000000001	2.294	69.563999999999993
6959	3	0	3	1.05	1.1299999999999999	60.880000000000003	1.1870000000000001	63.923999999999999
6959	4	0	3.6000000000000001	0.88999999	2.02	65.269999999999996	1.798	58.090000000000003
6960	1	0	0.29999999999999999	1.39	1.46	59.710000000000001	2.0289999999999999	82.997
6960	2	0	2	1.22	1.8300000000000001	24.239999999999998	2.2330000000000001	29.573
6960	3	0	3	1.0599999	2.5899999999999999	68.340000000000003	2.7450000000000001	72.439999999999998
6960	4	0	3.6000000000000001	0.58999997	7.7400000000000002	72.989999999999995	4.5670000000000002	43.064
6961	1	0	0.29999999999999999	1.26	2.02	63.020000000000003	2.5449999999999999	79.405000000000001
6961	2	0	2.2999999999999998	1.0700001	4.2999999999999998	10.800000000000001	4.601	11.555999999999999
6961	3	0	3	0.77999997	17.760000000000002	77.760000000000005	13.853	60.652999999999999
6961	4	0	3.6000000000000001	0.41999999	80.280000000000001	140.03	33.718000000000004	58.813000000000002
6962	1	0	0.29999999999999999	1.11	1.46	34.460000000000001	1.621	38.250999999999998
6962	2	0	2.3999999999999999	1.05	2.1699999999999999	38.420000000000002	2.278	40.341000000000001
6962	3	0	3.2000000000000002	0.85000002	6.1299999999999999	38.380000000000003	5.2110000000000003	32.622999999999998
6962	4	0	3.7999999999999998	0.77999997	24.199999999999999	70.450000000000003	18.876000000000001	54.951000000000001
6953	1	0	0.29999999999999999	1.3200001	2.96	42.210000000000001	3.907	55.716999999999999
6953	2	0	2.6000000000000001	1.27	3.2000000000000002	50.700000000000003	4.0640000000000001	64.388999999999996
6953	3	0	3.5	1.12	3.1299999999999999	45.380000000000003	3.5059999999999998	50.826000000000001
6953	4	0	4.2000000000000002	0.89999998	3.2799999999999998	47.030000000000001	2.952	42.326999999999998
6954	1	0	0.29999999999999999	1.58	3.0600000000000001	59.549999999999997	4.835	94.088999999999999
6954	2	0	2.5	1.42	3.1400000000000001	46.390000000000001	4.4589999999999996	65.873999999999995
6954	3	0	3.3999999999999999	1.27	3.3700000000000001	61.619999999999997	4.2800000000000002	78.257000000000005
6954	4	0	4	1.03	4.1799999999999997	54.560000000000002	4.3049999999999997	56.197000000000003
6955	1	0	0.29999999999999999	1.5599999	2.96	58.960000000000001	4.6180000000000003	91.977999999999994
6955	2	0	2.5	1.45	3.2000000000000002	44.950000000000003	4.6399999999999997	65.177999999999997
6955	3	0	3.3999999999999999	1.3200001	4.6699999999999999	45.409999999999997	6.1639999999999997	59.941000000000003
6955	4	0	4	0.97000003	8.4199999999999999	59.670000000000002	8.1669999999999998	57.880000000000003
6956	1	0	0.29999999999999999	1.39	4.6799999999999997	40.189999999999998	6.5049999999999999	55.863999999999997
6956	2	0	2.5	1.3	9.3699999999999992	57.869999999999997	12.180999999999999	75.230999999999995
6956	3	0	3.3999999999999999	1.13	17.629999999999999	66.879999999999995	19.922000000000001	75.573999999999998
6956	4	0	4	0.36000001	93.849999999999994	132.84999999999999	33.786000000000001	47.826000000000001
6957	1	0	0.29999999999999999	1.35	3.5	61.75	4.7249999999999996	83.363
6957	2	0	2.5	1.2	7.04	62.240000000000002	8.4480000000000004	74.688000000000002
6957	3	0	3.3999999999999999	1.04	12.94	72.189999999999998	13.458	75.078000000000003
6957	4	0	4	0.58999997	129.25999999999999	183.03999999999999	76.263000000000005	107.994
6950	1	0	0.29999999999999999	1.39	1.54	30.789999999999999	2.141	42.798000000000002
6950	2	0	2.2999999999999998	1.28	1.48	21.98	1.8939999999999999	28.134
6950	3	0	3	1.15	1.52	20.52	1.748	23.597999999999999
6950	4	0	3.6000000000000001	0.77999997	1.72	20.969999999999999	1.3420000000000001	16.356999999999999
7131	3	0	1.8	0.61000001	0.67000000000000004	7.1699999999999999	0.40899999999999997	4.3739999999999997
7131	4	0	2	0.34999999	1.0700000000000001	13.57	0.375	4.7489999999999997
7132	1	0	0.29999999999999999	1.37	1.0700000000000001	13.07	1.466	17.905999999999999
7132	2	0	3.1000000000000001	1.13	3.5600000000000001	14.06	4.0229999999999997	15.888
7132	3	0	4.2000000000000002	0.91000003	6.5199999999999996	17.52	5.9329999999999998	15.943
7132	4	0	5	0.41999999	38.670000000000002	51.170000000000002	16.241	21.491
7133	1	0	0.29999999999999999	1.41	1.8500000000000001	14.85	2.609	20.937999999999999
7133	2	0	2.6000000000000001	1.27	6.8899999999999997	19.390000000000001	8.75	24.625
7133	3	0	3.5	1.1	10.33	25.329999999999998	11.363	27.863
7133	4	0	4.2000000000000002	0.81999999	21.109999999999999	35.609999999999999	17.309999999999999	29.199999999999999
7134	1	0	0.29999999999999999	1.53	0.89000000000000001	13.390000000000001	1.3620000000000001	20.486999999999998
7134	2	0	2.6000000000000001	1.22	2.3300000000000001	15.33	2.843	18.702999999999999
7134	3	0	3.3999999999999999	1.1799999	5.04	20.539999999999999	5.9470000000000001	24.236999999999998
7134	4	0	4.0999999999999996	0.88999999	29.559999999999999	42.560000000000002	26.308	37.878
7135	1	0	0.29999999999999999	1.4400001	0.81000000000000005	12.31	1.1659999999999999	17.725999999999999
7135	2	0	2.6000000000000001	1.3200001	1.26	14.76	1.663	19.483000000000001
7135	3	0	3.3999999999999999	1.15	2.6699999999999999	14.17	3.0699999999999998	16.295000000000002
7135	4	0	4.0999999999999996	0.82999998	20.82	35.310000000000002	17.280999999999999	29.306999999999999
7126	1	0	0.29999999999999999	1.04	1.3300000000000001	10.83	1.383	11.263
7126	2	0	1.3	0.94	2	6	1.8799999999999999	5.6399999999999997
7126	3	0	1.8	0.79000002	2.7400000000000002	6.7400000000000002	2.165	5.3250000000000002
7126	4	0	2	0.68000001	3.48	8.4800000000000004	2.3660000000000001	5.766
7127	1	0	0.29999999999999999	1.11	1.8100000000000001	7.8200000000000003	2.0089999999999999	8.6799999999999997
7127	2	0	1.3	0.94999999	4.1100000000000003	10.109999999999999	3.9039999999999999	9.6050000000000004
7127	3	0	1.8	0.77999997	8.6300000000000008	15.630000000000001	6.7309999999999999	12.191000000000001
7127	4	0	2	0.63	16.260000000000002	21.760000000000002	10.244	13.709
7128	1	0	0.29999999999999999	1.0700001	2.1099999999999999	5.6100000000000003	2.258	6.0030000000000001
7128	2	0	1.6000000000000001	0.88999999	3.8500000000000001	12.85	3.427	11.436
7128	3	0	2.2000000000000002	0.75	26	31	19.5	23.25
7128	4	0	2.5	0.28999999	40.5	45.5	11.744999999999999	13.195
7129	1	0	0.29999999999999999	1.02	1.96	7.96	1.9990000000000001	8.1189999999999998
7129	2	0	1.6000000000000001	0.91000003	4.8200000000000003	10.31	4.3860000000000001	9.3819999999999997
7129	3	0	2.1000000000000001	0.72000003	8.6999999999999993	18.199999999999999	6.2640000000000002	13.103999999999999
7129	4	0	2.3999999999999999	0.47	17.93	25.93	8.4269999999999996	12.186999999999999
7130	1	0	0.29999999999999999	1.01	1.6699999999999999	5.6699999999999999	1.6870000000000001	5.7270000000000003
7130	2	0	1.6000000000000001	0.82999998	2.3300000000000001	8.3300000000000001	1.9339999999999999	6.9139999999999997
7130	3	0	2.2000000000000002	0.69999999	6.1799999999999997	16.68	4.3259999999999996	11.676
7130	4	0	2.5	0.47	42.130000000000003	55.130000000000003	19.800999999999998	25.911000000000001
7121	1	0	0.29999999999999999	0.88	2.98	42.979999999999997	2.6219999999999999	37.822000000000003
7121	2	0	1.6000000000000001	0.80000001	3.21	30.539999999999999	2.5680000000000001	24.431999999999999
7121	3	0	2.2000000000000002	0.74000001	4.8700000000000001	41.530000000000001	3.6040000000000001	30.731999999999999
7121	4	0	2.5	0.63	5.7000000000000002	36.369999999999997	3.5910000000000002	22.913
7122	1	0	0.29999999999999999	1.27	4.9100000000000001	41.539999999999999	6.2359999999999998	52.756
7122	2	0	3.7999999999999998	1.24	5.96	45.299999999999997	7.3899999999999997	56.171999999999997
7122	3	0	5	1.1	7.0899999999999999	41.759999999999998	7.7990000000000004	45.936
7122	4	0	6.0999999999999996	0.63	11.85	46.520000000000003	7.4660000000000002	29.308
7123	1	0	0.29999999999999999	1.77	7.4000000000000004	49.399999999999999	13.098000000000001	87.438000000000002
7123	2	0	3.7000000000000002	1.53	15.890000000000001	62.549999999999997	24.312000000000001	95.700999999999993
7123	3	0	4.9000000000000004	1.38	33.509999999999998	82.840000000000003	46.244	114.319
7123	4	0	5.9000000000000004	0.66000003	169.16999999999999	217.84	111.652	143.774
7124	1	0	0.29999999999999999	1.67	9.1699999999999999	53.840000000000003	15.314	89.912999999999997
7124	2	0	3.7000000000000002	1.48	31.059999999999999	101.06	45.969000000000001	149.56899999999999
7124	3	0	5	1.38	42.960000000000001	91.629999999999995	59.284999999999997	126.449
7124	4	0	6.2000000000000002	0.62	263.31999999999999	298.64999999999998	163.25800000000001	185.16300000000001
7125	1	0	0.29999999999999999	1.62	4.6799999999999997	42.009999999999998	7.5819999999999999	68.055999999999997
7125	2	0	3.5	1.51	6.79	55.460000000000001	10.253	83.745000000000005
7125	3	0	4.7000000000000002	1.3200001	9.5500000000000007	54.880000000000003	12.606	72.441999999999993
7125	4	0	5.9000000000000004	0.79000002	34.979999999999997	79.650000000000006	27.634	62.923999999999999
7116	1	0	0.29999999999999999	0.94	0.89000000000000001	8.8900000000000006	0.83699999999999997	8.3569999999999993
7116	2	0	1.3	0.86000001	1.1899999999999999	9.6899999999999995	1.0229999999999999	8.3330000000000002
7116	3	0	1.8	0.73000002	1.6699999999999999	12.17	1.2190000000000001	8.8840000000000003
7116	4	0	2	0.58999997	2.1899999999999999	12.69	1.292	7.4870000000000001
7117	1	0	0.29999999999999999	0.98000002	1.9299999999999999	8.4299999999999997	1.891	8.2609999999999992
7117	2	0	1.3	0.86000001	2.48	12.98	2.133	11.163
7117	3	0	1.8	0.68000001	4.1100000000000003	14.109999999999999	2.7949999999999999	9.5950000000000006
7117	4	0	2	0.60000002	12.56	21.559999999999999	7.5359999999999996	12.936
7118	1	0	0.29999999999999999	0.89999998	1.78	11.779999999999999	1.6020000000000001	10.602
7118	2	0	1.3	0.80000001	2.4399999999999999	14.94	1.952	11.952
7118	3	0	1.7	0.68000001	4.3700000000000001	18.870000000000001	2.972	12.832000000000001
7118	4	0	1.8999999999999999	0.62	6.1100000000000003	17.609999999999999	3.7879999999999998	10.917999999999999
7119	1	0	0.29999999999999999	0.88999999	1.9299999999999999	11.43	1.718	10.173
7119	2	0	1.3	0.83999997	2.3300000000000001	13.33	1.9570000000000001	11.196999999999999
7119	3	0	1.7	0.70999998	4.8499999999999996	16.350000000000001	3.4430000000000001	11.609
7119	4	0	1.8999999999999999	0.64999998	7.4400000000000004	15.44	4.8360000000000003	10.036
7120	1	0	0.29999999999999999	0.99000001	1.1899999999999999	9.1899999999999995	1.1779999999999999	9.0980000000000008
7120	2	0	1	0.89999998	1.26	8.7599999999999998	1.1339999999999999	7.8840000000000003
7120	3	0	1.3999999999999999	0.75999999	2.5899999999999999	12.09	1.968	9.1880000000000006
7120	4	0	1.5	0.52999997	10.44	22.440000000000001	5.5330000000000004	11.893000000000001
7111	1	0	0.29999999999999999	1.03	1.8100000000000001	29.140000000000001	1.8640000000000001	30.013999999999999
7111	2	0	1.7	0.91000003	2.4199999999999999	30.41	2.202	27.672999999999998
7111	3	0	2.2999999999999998	0.79000002	2.79	29.460000000000001	2.2040000000000002	23.273
7111	4	0	2.7000000000000002	0.58999997	5.4000000000000004	36.060000000000002	3.1859999999999999	21.274999999999999
7112	1	0	0.29999999999999999	1.05	2.4399999999999999	29.77	2.5619999999999998	31.259
7112	2	0	1.8	0.91000003	2.79	36.130000000000003	2.5390000000000001	32.878
7112	3	0	2.3999999999999999	0.82999998	4.3399999999999999	35.670000000000002	3.6019999999999999	29.606000000000002
7112	4	0	2.7999999999999998	0.62	6.1500000000000004	40.82	3.8130000000000002	25.308
7113	1	0	0.29999999999999999	1.0700001	2.6800000000000002	38.68	2.8679999999999999	41.387999999999998
7113	2	0	2	0.92000002	2.75	40.090000000000003	2.5299999999999998	36.883000000000003
7113	3	0	2.6000000000000001	0.77999997	4	39.329999999999998	3.1200000000000001	30.677
7113	4	0	3.1000000000000001	0.31	15.890000000000001	52.549999999999997	4.9260000000000002	16.289999999999999
7114	1	0	0.29999999999999999	1.02	2.6800000000000002	37.350000000000001	2.734	38.097000000000001
7114	2	0	1.8	0.88999999	3.0600000000000001	42.390000000000001	2.7229999999999999	37.726999999999997
7114	3	0	2.3999999999999999	0.76999998	3.5800000000000001	41.590000000000003	2.7570000000000001	32.024000000000001
7114	4	0	2.7999999999999998	0.25999999	12.68	50.009999999999998	3.2970000000000002	13.003
7115	1	0	0.29999999999999999	1.05	2.1899999999999999	38.859999999999999	2.2989999999999999	40.802999999999997
7115	2	0	1.8	0.89999998	2.0800000000000001	32.740000000000002	1.8720000000000001	29.466000000000001
7115	3	0	2.3999999999999999	0.88	2.5600000000000001	40.560000000000002	2.2530000000000001	35.692999999999998
7115	4	0	2.7999999999999998	0.52999997	7.7400000000000002	47.100000000000001	4.1020000000000003	24.963000000000001
7106	1	0	0.29999999999999999	0.97000003	3.3300000000000001	19.829999999999998	3.23	19.234999999999999
7106	2	0	2	0.88999999	4.2199999999999998	21.219999999999999	3.7559999999999998	18.885999999999999
7106	3	0	2.7000000000000002	0.79000002	3.8100000000000001	20.32	3.0099999999999998	16.053000000000001
7106	4	0	3.2000000000000002	0.60000002	4.2599999999999998	20.260000000000002	2.556	12.156000000000001
7107	1	0	0.29999999999999999	1.45	3.5899999999999999	22.09	5.2060000000000004	32.030000000000001
7107	2	0	3.1000000000000001	1.41	5	22.5	7.0499999999999998	31.725000000000001
7107	3	0	4.0999999999999996	1.23	4.2199999999999998	22.219999999999999	5.1909999999999998	27.331
7107	4	0	5.0999999999999996	0.81	5.2599999999999998	23.260000000000002	4.2610000000000001	18.841000000000001
7108	1	0	0.29999999999999999	1.64	4.3700000000000001	19.870000000000001	7.1669999999999998	32.587000000000003
7108	2	0	3.1000000000000001	1.5	5.2999999999999998	24.800000000000001	7.9500000000000002	37.200000000000003
7108	3	0	4.0999999999999996	1.34	6.5599999999999996	24.059999999999999	8.7899999999999991	32.240000000000002
7108	4	0	4.9000000000000004	0.37	12.67	31.170000000000002	4.6879999999999997	11.532999999999999
7109	1	0	0.29999999999999999	1.64	4.1799999999999997	22.68	6.8550000000000004	37.195
7109	2	0	3.1000000000000001	1.46	4.96	23.460000000000001	7.242	34.252000000000002
7109	3	0	4.2000000000000002	1.24	6.6699999999999999	26.670000000000002	8.2710000000000008	33.070999999999998
7109	4	0	5	1.05	6.9299999999999997	29.43	7.2770000000000001	30.902000000000001
7110	1	0	0.29999999999999999	1.46	3.3300000000000001	22.829999999999998	4.8620000000000001	33.332000000000001
7110	2	0	3.2000000000000002	1.34	3.7000000000000002	19.699999999999999	4.9580000000000002	26.398
7110	3	0	4.2000000000000002	1.2	14	30	16.800000000000001	36
7110	4	0	5.0999999999999996	0.80000001	3.3300000000000001	20.329999999999998	2.6640000000000001	16.263999999999999
7101	1	0	0.29999999999999999	1.03	1.74	25.739999999999998	1.792	26.512
7101	2	0	2.5	0.97000003	2	30	1.9399999999999999	29.100000000000001
7101	3	0	3.2999999999999998	0.82999998	2.4500000000000002	29.789999999999999	2.0329999999999999	24.725999999999999
7101	4	0	3.8999999999999999	0.46000001	3.3599999999999999	31.359999999999999	1.546	14.426
7102	1	0	0.29999999999999999	1.37	2.1099999999999999	23.449999999999999	2.891	32.127000000000002
7102	2	0	2.5	1.21	4.5300000000000002	31.199999999999999	5.4809999999999999	37.752000000000002
7102	3	0	3.3999999999999999	1.01	4.9400000000000004	33.609999999999999	4.9889999999999999	33.945999999999998
7102	4	0	4	0.50999999	7.6600000000000001	34.990000000000002	3.907	17.844999999999999
7103	1	0	0.29999999999999999	1.38	5.7699999999999996	38.439999999999998	7.9630000000000001	53.046999999999997
7103	2	0	2.3999999999999999	1.22	7.9199999999999999	37.920000000000002	9.6620000000000008	46.262
7103	3	0	3.2000000000000002	0.94	11.210000000000001	43.210000000000001	10.537000000000001	40.616999999999997
7103	4	0	3.7999999999999998	0.50999999	14.380000000000001	35.710000000000001	7.3339999999999996	18.212
7104	1	0	0.29999999999999999	1.42	4.1100000000000003	23.449999999999999	5.8360000000000003	33.298999999999999
7104	2	0	2.2999999999999998	1.35	3.8500000000000001	35.18	5.1980000000000004	47.493000000000002
7104	3	0	3	1.27	6.2999999999999998	45.630000000000003	8.0009999999999994	57.950000000000003
7104	4	0	3.6000000000000001	1	15.51	48.840000000000003	15.51	48.840000000000003
7105	1	0	0.29999999999999999	1.4	2.5699999999999998	35.229999999999997	3.5979999999999999	49.322000000000003
7105	2	0	2.2000000000000002	1.33	2.79	35.460000000000001	3.7109999999999999	47.161999999999999
7105	3	0	2.8999999999999999	1.23	2.98	28.309999999999999	3.665	34.820999999999998
7105	4	0	3.3999999999999999	0.83999997	5.96	35.299999999999997	5.0060000000000002	29.652000000000001
7096	1	0	0.29999999999999999	0.93000001	3.6600000000000001	18.989999999999998	3.4039999999999999	17.661000000000001
7096	2	0	1.3	0.77999997	2.8300000000000001	17.5	2.2069999999999999	13.65
7096	3	0	1.8	0.68000001	3.5099999999999998	18.18	2.387	12.362
7096	4	0	2.2000000000000002	0.44999999	4.04	18.699999999999999	1.8180000000000001	8.4149999999999991
7097	1	0	0.29999999999999999	0.95999998	6.1900000000000004	21.52	5.9420000000000002	20.658999999999999
7097	2	0	1.3	0.88	3.4300000000000002	21.43	3.0179999999999998	18.858000000000001
7097	3	0	1.8	0.81	4.04	24.039999999999999	3.2719999999999998	19.472000000000001
7097	4	0	2	0.86000001	4.6399999999999997	19.98	3.9900000000000002	17.183
7098	1	0	0.29999999999999999	0.88999999	4.5700000000000003	23.23	4.0670000000000002	20.675000000000001
7098	2	0	1.2	0.83999997	4.7199999999999998	21.379999999999999	3.9649999999999999	17.959
7098	3	0	1.6000000000000001	0.68000001	4.1100000000000003	30.780000000000001	2.7949999999999999	20.93
7098	4	0	1.8	0.56	5.9199999999999999	21.93	3.3149999999999999	12.281000000000001
7099	1	0	0.29999999999999999	0.95999998	3.4300000000000002	29.43	3.2930000000000001	28.253
7099	2	0	1.2	0.87	4.9400000000000004	31.609999999999999	4.298	27.501000000000001
7099	3	0	1.6000000000000001	0.75	3.3999999999999999	25.399999999999999	2.5499999999999998	19.050000000000001
7099	4	0	1.8	0.75	4.2999999999999998	28.969999999999999	3.2250000000000001	21.728000000000002
7100	1	0	0.29999999999999999	0.76999998	2.98	19.379999999999999	2.2949999999999999	14.923
7100	2	0	1.3999999999999999	0.68000001	3.4199999999999999	25.02	2.3260000000000001	17.013999999999999
7100	3	0	1.8	0.64999998	3.4900000000000002	16.690000000000001	2.2690000000000001	10.849
7100	4	0	2.2999999999999998	0.54000002	4.4400000000000004	24.440000000000001	2.3980000000000001	13.198
7094	1	0	0.29999999999999999	0.88999999	1.5600000000000001	10.359999999999999	1.3879999999999999	9.2200000000000006
7094	2	0	1.1000000000000001	0.75999999	3	11.6	2.2799999999999998	8.8160000000000007
7094	3	0	1.5	0.67000002	4.6900000000000004	14.69	3.1419999999999999	9.8420000000000005
7094	4	0	1.7	0.49000001	9.0899999999999999	19.690000000000001	4.4539999999999997	9.6479999999999997
7095	1	0	0.29999999999999999	0.97000003	1.3999999999999999	12.6	1.3580000000000001	12.222
7095	2	0	0.90000000000000002	0.82999998	1.2	11.199999999999999	0.996	9.2959999999999994
7095	3	0	1.2	0.77999997	1.3799999999999999	11.98	1.0760000000000001	9.3439999999999994
7095	4	0	1.3	0.77999997	1.96	11.76	1.5289999999999999	9.173
7089	1	0	0.29999999999999999	1.03	2.7999999999999998	45.799999999999997	2.8839999999999999	47.173999999999999
7089	2	0	0.90000000000000002	1.03	3.3799999999999999	31.579999999999998	3.4809999999999999	32.527000000000001
7089	3	0	1.2	0.70999998	5.0499999999999998	26.66	3.585	18.928999999999998
7089	4	0	1.3	0.69	5.7999999999999998	37.049999999999997	4.0019999999999998	25.564
7090	1	0	0.29999999999999999	1.02	2.75	41.350000000000001	2.8050000000000002	42.177
7090	2	0	1	0.88999999	3.2400000000000002	36.439999999999998	2.8839999999999999	32.432000000000002
7090	3	0	1.3	0.81	3.8199999999999998	48.219999999999999	3.0939999999999999	39.058
7090	4	0	1.6000000000000001	0.76999998	3.73	43.729999999999997	2.8719999999999999	33.671999999999997
7091	1	0	0.29999999999999999	1.0700001	3.02	39.219999999999999	3.2309999999999999	41.965000000000003
7091	2	0	1.1000000000000001	0.94999999	3.3300000000000001	36.130000000000003	3.1640000000000001	34.323
7091	3	0	1.5	0.76999998	4.7599999999999998	42.560000000000002	3.665	32.771000000000001
7091	4	0	1.7	0.74000001	4.0199999999999996	24.620000000000001	2.9750000000000001	18.219000000000001
7092	1	0	0.29999999999999999	1.02	3.04	27.239999999999998	3.101	27.785
7092	2	0	1.1000000000000001	0.93000001	3.2000000000000002	40.399999999999999	2.976	37.572000000000003
7092	3	0	1.5	0.79000002	3.3799999999999999	27.98	2.6699999999999999	22.103999999999999
7092	4	0	1.7	0.70999998	8.6699999999999999	30.07	6.1559999999999997	21.350000000000001
7093	1	0	0.29999999999999999	1	2.6000000000000001	40.399999999999999	2.6000000000000001	40.399999999999999
7093	2	0	1.1000000000000001	0.88999999	2.6499999999999999	39.049999999999997	2.359	34.755000000000003
7093	3	0	1.3999999999999999	0.81	2.6499999999999999	40.259999999999998	2.1459999999999999	32.610999999999997
7093	4	0	1.5	0.79000002	5.1799999999999997	21.379999999999999	4.0919999999999996	16.890000000000001
7146	1	0	0.29999999999999999	0.93000001	3.4500000000000002	35.789999999999999	3.2090000000000001	33.284999999999997
6598	4	0	2.5	0.5	3.9100000000000001	22.91	1.9550000000000001	11.455
6590	1	0	0.29999999999999999	1.08	5.2000000000000002	58.950000000000003	5.6159999999999997	63.665999999999997
6590	2	0	0.90000000000000002	0.99000001	5.3499999999999996	52.100000000000001	5.2960000000000003	51.579000000000001
6590	3	0	1.2	0.81999999	6.3200000000000003	50.32	5.1820000000000004	41.262
6590	4	0	1.45	0.64999998	7.2000000000000002	63.200000000000003	4.6799999999999997	41.079999999999998
6591	1	0	0.29999999999999999	1.21	6.0199999999999996	60.270000000000003	7.2839999999999998	72.927000000000007
6591	2	0	1.1000000000000001	1.0599999	7.3899999999999997	76.640000000000001	7.8330000000000002	81.238
6591	3	0	1.3999999999999999	0.99000001	8.1899999999999995	76.439999999999998	8.1080000000000005	75.676000000000002
6591	4	0	1.75	0.81999999	8.7200000000000006	63.219999999999999	7.1500000000000004	51.840000000000003
6592	1	0	0.29999999999999999	1.3	6.7400000000000002	61.740000000000002	8.7620000000000005	80.262
6592	2	0	1.3999999999999999	1.14	7.8700000000000001	78.370000000000005	8.9719999999999995	89.341999999999999
6592	3	0	1.8999999999999999	0.99000001	9.0999999999999996	64.349999999999994	9.0090000000000003	63.706000000000003
6592	4	0	2.3500000000000001	0.91000003	9.8100000000000005	67.319999999999993	8.9269999999999996	61.261000000000003
6593	1	0	0.29999999999999999	1.3200001	5.5	50	7.2599999999999998	66
6593	2	0	1.8	1.11	6.1699999999999999	48.920000000000002	6.8490000000000002	54.301000000000002
6593	3	0	2.3999999999999999	0.88	6.3899999999999997	59.390000000000001	5.6230000000000002	52.262999999999998
6593	4	0	2.9500000000000002	0.70999998	7.1799999999999997	61.939999999999998	5.0979999999999999	43.976999999999997
6585	1	0	0.29999999999999999	1.78	4.8200000000000003	65.420000000000002	8.5800000000000001	116.44799999999999
6585	2	0	2.7999999999999998	1.62	5.9199999999999999	69.920000000000002	9.5899999999999999	113.27
6585	3	0	3.7999999999999998	1.26	7.8600000000000003	50.859999999999999	9.9039999999999999	64.084000000000003
6585	4	0	4.5	0.92000002	9.1999999999999993	76.5	8.4640000000000004	70.379999999999995
6586	1	0	0.29999999999999999	2.04	4.8200000000000003	63.82	9.8330000000000002	130.19300000000001
6586	2	0	3	1.85	6.6600000000000001	70.659999999999997	12.321	130.721
6586	3	0	4	1.7	10.779999999999999	79.379999999999995	18.326000000000001	134.946
6586	4	0	4.7999999999999998	1.12	21.260000000000002	104.56	23.811	117.107
6587	1	0	0.29999999999999999	2.0599999	17.219999999999999	88.209999999999994	35.472999999999999	181.71299999999999
6587	2	0	3.2000000000000002	1.8200001	12.359999999999999	64.959999999999994	22.495000000000001	118.227
6587	3	0	4.2999999999999998	1.51	25.719999999999999	109.2	38.837000000000003	164.892
6587	4	0	5.2000000000000002	0.75	90.680000000000007	243.68000000000001	68.010000000000005	182.75999999999999
6588	1	0	0.29999999999999999	2.05	5.7199999999999998	65.019999999999996	11.726000000000001	133.291
6588	2	0	3.7000000000000002	1.6900001	6.6399999999999997	43.240000000000002	11.222	73.075999999999993
6588	3	0	4.9000000000000004	1.4	7.7199999999999998	65.719999999999999	10.808	92.007999999999996
6588	4	0	5.9000000000000004	0.74000001	12	82	8.8800000000000008	60.68
6589	1	0	0.29999999999999999	1.98	5.7400000000000002	65.040000000000006	11.365	128.779
6589	2	0	3.6000000000000001	1.6	5.6399999999999997	64.239999999999995	9.0239999999999991	102.78400000000001
6589	3	0	4.7999999999999998	1.37	6.9199999999999999	67.920000000000002	9.4800000000000004	93.049999999999997
6589	4	0	5.7999999999999998	0.83999997	12.6	78.200000000000003	10.584	65.688000000000002
6580	1	0	0.29999999999999999	1.26	2.8799999999999999	98.209999999999994	3.629	123.745
6580	2	0	1.7	1.2	2.52	35.520000000000003	3.024	42.624000000000002
6580	3	0	2.2000000000000002	1.04	3.7200000000000002	32.719999999999999	3.8690000000000002	34.029000000000003
6580	4	0	2.6000000000000001	0.70999998	3.7000000000000002	30.699999999999999	2.6269999999999998	21.797000000000001
6581	1	0	0.29999999999999999	1.53	1.8799999999999999	30.879999999999999	2.8759999999999999	47.246000000000002
6581	2	0	1.8999999999999999	1.3099999	2.3799999999999999	42.049999999999997	3.1179999999999999	55.085000000000001
6581	3	0	2.6000000000000001	1.27	2.3799999999999999	23.379999999999999	3.0230000000000001	29.693000000000001
6581	4	0	3	0.80000001	3.3799999999999999	28.710000000000001	2.7040000000000002	22.968
6582	1	0	0.29999999999999999	1.65	2.7599999999999998	29.09	4.5540000000000003	47.999000000000002
6582	2	0	2.2000000000000002	1.36	5.7800000000000002	33.450000000000003	7.8609999999999998	45.491999999999997
6582	3	0	3	1.14	15.800000000000001	40.130000000000003	18.012	45.747999999999998
6582	4	0	3.5	0.69999999	32.719999999999999	59.390000000000001	22.904	41.573
6583	1	0	0.29999999999999999	1.67	2.54	24.870000000000001	4.242	41.533000000000001
6583	2	0	2.5	1.4	5.1200000000000001	29.789999999999999	7.1680000000000001	41.706000000000003
6583	3	0	3.3999999999999999	1.36	5.4800000000000004	30.149999999999999	7.4530000000000003	41.003999999999998
6583	4	0	4	0.98000002	17.800000000000001	41.799999999999997	17.443999999999999	40.963999999999999
6584	1	0	0.29999999999999999	1.61	2.1000000000000001	24.77	3.3809999999999998	39.880000000000003
6584	2	0	2.7999999999999998	1.41	2.1600000000000001	27.829999999999998	3.0459999999999998	39.240000000000002
6584	3	0	3.7000000000000002	1.34	2.2999999999999998	29.969999999999999	3.0819999999999999	40.159999999999997
6584	4	0	4.4000000000000004	1	2.7999999999999998	28.469999999999999	2.7999999999999998	28.469999999999999
6574	1	0	0.29999999999999999	1.11	2.8799999999999999	41.880000000000003	3.1970000000000001	46.487000000000002
6574	2	0	1.3999999999999999	0.95999998	2.8599999999999999	45.460000000000001	2.746	43.642000000000003
6574	3	0	1.8	0.89999998	2.7799999999999998	41.380000000000003	2.5019999999999998	37.241999999999997
6574	4	0	2.1000000000000001	0.56	3.2000000000000002	46.200000000000003	1.792	25.872
6575	1	0	0.29999999999999999	1.41	2.5800000000000001	37.579999999999998	3.6379999999999999	52.988
6575	2	0	1.8	1.04	3.2200000000000002	43.520000000000003	3.3490000000000002	45.261000000000003
6575	3	0	2.3999999999999999	0.95999998	3.5600000000000001	43.560000000000002	3.4180000000000001	41.817999999999998
6575	4	0	2.7999999999999998	0.68000001	6.3600000000000003	45.359999999999999	4.3250000000000002	30.844999999999999
6576	1	0	0.29999999999999999	1.5599999	3.4199999999999999	46.020000000000003	5.335	71.790999999999997
6576	2	0	2	1.38	3.2400000000000002	43.840000000000003	4.4710000000000001	60.499000000000002
6576	3	0	2.7000000000000002	1.22	3.7400000000000002	50.340000000000003	4.5629999999999997	61.414999999999999
6576	4	0	3.2000000000000002	0.89999998	5.7999999999999998	46.130000000000003	5.2199999999999998	41.517000000000003
6577	1	0	0.29999999999999999	1.74	3.2200000000000002	47.219999999999999	5.6029999999999998	82.162999999999997
6577	2	0	2.2999999999999998	1.33	6.0999999999999996	53.700000000000003	8.1129999999999995	71.421000000000006
6577	3	0	3	1.08	21	86.299999999999997	22.68	93.203999999999994
6577	4	0	3.6000000000000001	0.63	31.420000000000002	115.02	19.795000000000002	72.462999999999994
6578	1	0	0.29999999999999999	1.63	2.9199999999999999	42.920000000000002	4.7599999999999998	69.959999999999994
6578	2	0	2.7999999999999998	1.38	3.3399999999999999	42.939999999999998	4.609	59.256999999999998
6578	3	0	3.7999999999999998	1.22	3.6000000000000001	41.899999999999999	4.3920000000000003	51.118000000000002
6578	4	0	4.5	0.86000001	4.46	47.759999999999998	3.8359999999999999	41.073999999999998
6579	1	0	0.29999999999999999	1.55	2.8199999999999998	44.82	4.3710000000000004	69.471000000000004
6579	2	0	2.8999999999999999	1.27	2.96	39.560000000000002	3.7589999999999999	50.241
6579	3	0	3.7999999999999998	1.03	3.3799999999999999	45.039999999999999	3.4809999999999999	46.390999999999998
6579	4	0	4.5999999999999996	0.91000003	3.2799999999999998	41.579999999999998	2.9849999999999999	37.838000000000001
6571	1	0	0.29999999999999999	1.64	7	44.329999999999998	11.48	72.700999999999993
6571	2	0	2.2000000000000002	1.5700001	10.09	64.090000000000003	15.840999999999999	100.621
6571	3	0	3	1.39	7.0599999999999996	56.060000000000002	9.8130000000000006	77.923000000000002
6571	4	0	3.5	1.22	10.65	45.32	12.993	55.289999999999999
6572	1	0	0.29999999999999999	1.85	9.0800000000000001	55.75	16.797999999999998	103.13800000000001
6572	2	0	2.8999999999999999	1.5700001	21.82	81.819999999999993	34.256999999999998	128.45699999999999
6572	3	0	3.8999999999999999	1.4	20.18	56.509999999999998	28.251999999999999	79.114000000000004
6572	4	0	4.7000000000000002	0.60000002	71.640000000000001	117.31	42.984000000000002	70.385999999999996
6573	1	0	0.29999999999999999	1.8	6.7000000000000002	82.370000000000005	12.06	148.26599999999999
6573	2	0	3.2999999999999998	1.67	4.04	76.709999999999994	6.7469999999999999	128.10599999999999
6573	3	0	4.4000000000000004	1.46	8.6199999999999992	86.620000000000005	12.585000000000001	126.465
6573	4	0	5.2999999999999998	0.23999999	12.539999999999999	89.209999999999994	3.0099999999999998	21.41
13140	1	0	0.29999999999999999	2.1289999	6.056	35.756	12.893000000000001	76.125
13140	2	0	4.5	1.893	6.5800000000000001	26.699999999999999	12.456	50.542999999999999
13140	3	0	6	1.627	6.7839999999999998	33.503999999999998	11.038	54.511000000000003
13140	4	0	6.7000000000000002	1.404	7.1890000000000001	41.628999999999998	10.093	58.447000000000003
13140	5	0	7.2999999999999998	1.08	9.7050000000000001	34.545000000000002	10.481	37.308999999999997
13141	1	0	0.29999999999999999	2.3139999	6.2089999999999996	36.908999999999999	14.368	85.406999999999996
13141	2	0	3.8999999999999999	2.125	8.0039999999999996	42.444000000000003	17.007999999999999	90.194000000000003
13141	3	0	5.2000000000000002	2.0090001	7.8869999999999996	35.127000000000002	15.845000000000001	70.569999999999993
13141	4	0	5.9000000000000004	1.6390001	10.544	38.524000000000001	17.282	63.140999999999998
13141	5	0	6.2999999999999998	1.0829999	15.02	41.979999999999997	16.266999999999999	45.463999999999999
13142	1	0	0.29999999999999999	2.303	8.5329999999999995	33.372999999999998	19.651	76.858000000000004
13142	2	0	3.8999999999999999	2.079	16.645	41.164999999999999	34.604999999999997	85.581999999999994
13142	3	0	5.2000000000000002	1.781	28.149000000000001	45.448999999999998	50.133000000000003	80.944999999999993
13142	4	0	5.9000000000000004	1.755	38.167000000000002	63.567	66.983000000000004	111.56
13142	5	0	6.2999999999999998	1.286	114.04900000000001	148.66900000000001	146.667	191.18799999999999
12901	1	0	0.29999999999999999	1.179	1.456	12.256	1.7170000000000001	14.449999999999999
12901	2	0	1.5	1.189	1.5840000000000001	12.144	1.883	14.439
12901	3	0	2	1.158	1.3580000000000001	11.038	1.573	12.782
12901	4	0	2.2999999999999998	0.89099997	2.4180000000000001	14.077999999999999	2.1539999999999999	12.542999999999999
12902	1	0	0.29999999999999999	1.416	2.2709999999999999	7.5510000000000002	3.2160000000000002	10.692
12902	2	0	1.3	1.16	3.544	13.324	4.1109999999999998	15.456
12902	3	0	1.8	1.053	5.6200000000000001	17.940000000000001	5.9180000000000001	18.890999999999998
12902	4	0	2	0.57700002	13.140000000000001	23.539999999999999	7.5819999999999999	13.583
12903	1	0	0.29999999999999999	1.3559999	3.3199999999999998	6.8799999999999999	4.5019999999999998	9.3290000000000006
12903	2	0	1.3	1.054	5.431	13.951000000000001	5.7240000000000002	14.704000000000001
12903	3	0	1.8	0.98500001	6.1799999999999997	10.98	6.0869999999999997	10.815
12903	4	0	2	0.78299999	16.242000000000001	22.382000000000001	12.717000000000001	17.524999999999999
12904	1	0	0.29999999999999999	1.336	2.0129999999999999	13.513	2.6890000000000001	18.053000000000001
12904	2	0	1.3999999999999999	1.2079999	2.5350000000000001	13.355	3.0619999999999998	16.132999999999999
12904	3	0	1.8999999999999999	0.97399998	4.4290000000000003	16.149000000000001	4.3140000000000001	15.728999999999999
12904	4	0	2.2000000000000002	0.37200001	12.837999999999999	24.338000000000001	4.7759999999999998	9.0540000000000003
12905	1	0	0.29999999999999999	1.3099999	2.669	10.509	3.496	13.766999999999999
12905	2	0	1.3999999999999999	1.085	2.8639999999999999	10.284000000000001	3.1070000000000002	11.157999999999999
12905	3	0	1.8	1	3.3180000000000001	14.178000000000001	3.3180000000000001	14.178000000000001
12905	4	0	2.1000000000000001	0.71200001	6.7850000000000001	16.704999999999998	4.8310000000000004	11.894
12195	1	0	0.29999999999999999	1.622	1.1930000000000001	13.833	1.9350000000000001	22.437000000000001
12195	2	0	3.2999999999999998	1.36	1.429	13.769	1.9430000000000001	18.725999999999999
12195	3	0	4.2999999999999998	1.244	1.4530000000000001	16.233000000000001	1.8080000000000001	20.193999999999999
12195	4	0	5.0999999999999996	0.80900002	1.8049999999999999	15.545	1.46	12.576000000000001
12193	1	0	0.29999999999999999	1.76	2.1819999999999999	16.242000000000001	3.8399999999999999	28.585999999999999
12193	2	0	3	1.684	3.9649999999999999	17.065000000000001	6.6769999999999996	28.736999999999998
12193	3	0	4	1.518	15.321999999999999	30.622	23.259	46.484000000000002
12193	4	0	4.7000000000000002	1.251	58.524999999999999	73.965000000000003	73.215000000000003	92.530000000000001
12194	1	0	0.29999999999999999	1.772	2.569	17.649000000000001	4.5519999999999996	31.274000000000001
12194	2	0	2.5	1.663	3.3439999999999999	16.564	5.5609999999999999	27.545999999999999
12194	3	0	3.2999999999999998	1.47	9.8670000000000009	24.087	14.504	35.408000000000001
12194	4	0	3.7999999999999998	1.17	17.945	30.265000000000001	20.995999999999999	35.409999999999997
12192	1	0	0.29999999999999999	1.745	2.1709999999999998	16.991	3.7879999999999998	29.649000000000001
12192	2	0	2.6000000000000001	1.598	3.5	17.199999999999999	5.593	27.486000000000001
12192	3	0	3.5	1.392	5.5039999999999996	19.724	7.6619999999999999	27.456
12192	4	0	4.0999999999999996	0.91100001	21.369	37.329000000000001	19.466999999999999	34.006999999999998
12191	1	0	0.29999999999999999	1.6849999	1.978	18.638000000000002	3.3330000000000002	31.405000000000001
12191	2	0	2.6000000000000001	1.457	4.7380000000000004	19.577999999999999	6.9029999999999996	28.524999999999999
12191	3	0	3.5	1.244	8.6669999999999998	23.427	10.782	29.143000000000001
12191	4	0	4.0999999999999996	0.50400001	19.696000000000002	34.756	9.9269999999999996	17.516999999999999
11295	1	0	0.29999999999999999	0.71499997	1.3069999999999999	12.827	0.93500000000000005	9.1709999999999994
11295	2	0	1.8	0.65200001	1.6200000000000001	12.640000000000001	1.056	8.2409999999999997
11295	3	0	2.3999999999999999	0.55500001	1.149	11.209	0.63800000000000001	6.2210000000000001
11295	4	0	2.7000000000000002	0.391	1.4379999999999999	13.358000000000001	0.56200000000000006	5.2229999999999999
11294	1	0	0.29999999999999999	1.228	1.3220000000000001	13.022	1.623	15.991
11294	2	0	1.8	1.051	1.484	14.784000000000001	1.5600000000000001	15.538
11294	3	0	2.3999999999999999	0.96100003	1.6379999999999999	14.138	1.5740000000000001	13.587
11294	4	0	2.7000000000000002	0.78299999	2.1360000000000001	14.436	1.6719999999999999	11.303000000000001
11293	1	0	0.29999999999999999	1.199	1.6180000000000001	12.598000000000001	1.9399999999999999	15.105
11293	2	0	1.8999999999999999	1.063	2.698	13.818	2.8679999999999999	14.689
11293	3	0	2.6000000000000001	0.949	3.9980000000000002	16.117999999999999	3.794	15.295999999999999
11293	4	0	2.8999999999999999	0.60299999	14.779999999999999	25.920000000000002	8.9120000000000008	15.630000000000001
11292	1	0	0.29999999999999999	1.164	1.8360000000000001	12.456	2.137	14.499000000000001
11292	2	0	2	1.008	1.4399999999999999	13	1.452	13.103999999999999
11292	3	0	2.7000000000000002	0.90600002	2.593	14.593	2.3490000000000002	13.221
11292	4	0	3.1000000000000001	0.71200001	3.1150000000000002	14.355	2.218	10.221
11291	1	0	0.29999999999999999	1.148	1.2250000000000001	12.945	1.4059999999999999	14.861000000000001
11291	2	0	2.1000000000000001	0.94499999	1.2549999999999999	12.414999999999999	1.1859999999999999	11.731999999999999
11291	3	0	2.7999999999999998	0.86699998	1.9730000000000001	13.872999999999999	1.7110000000000001	12.028
11291	4	0	3.2000000000000002	0.66900003	7.9779999999999998	20.898	5.3369999999999997	13.981
11290	1	0	0.29999999999999999	0	0.33800000000000002	3.0579999999999998	0	0
11290	2	0	1.5	0	0.29799999999999999	2.8580000000000001	0	0
11290	3	0	2	0	0.40500000000000003	2.8050000000000002	0	0
11290	4	0	2.2000000000000002	0	0.39800000000000002	2.8580000000000001	0	0
11289	1	0	0.29999999999999999	0	0.32200000000000001	3.5419999999999998	0	0
11289	2	0	1.7	0	0.52500000000000002	4.9850000000000003	0	0
11289	3	0	2.2000000000000002	0	0.49299999999999999	3.133	0	0
11289	4	0	2.5	0	0.48199999999999998	2.6819999999999999	0	0
11288	1	0	0.29999999999999999	0	0.55500000000000005	3.7349999999999999	0	0
11288	2	0	1.8999999999999999	0	0.67100000000000004	3.0710000000000002	0	0
11288	3	0	2.5	0	1.46	3.7799999999999998	0	0
11288	4	0	2.8999999999999999	0	1.675	3.9350000000000001	0	0
8228	1	0	0.29999999999999999	1.641	2.54	21.02	4.1680000000000001	34.494
8228	2	0	2.2999999999999998	1.501	6.9400000000000004	24.719999999999999	10.417	37.104999999999997
8228	3	0	3	1.295	5.6100000000000003	25.07	7.2649999999999997	32.466000000000001
8228	4	0	3.6000000000000001	1.307	11.720000000000001	32.240000000000002	15.318	42.137999999999998
8229	1	0	0.29999999999999999	1.607	1.8999999999999999	22.84	3.0529999999999999	36.704000000000001
8229	2	0	2.3999999999999999	1.455	2.1699999999999999	25.41	3.157	36.972000000000001
8229	3	0	3.2000000000000002	1.302	3.27	22.030000000000001	4.258	28.683
8229	4	0	3.7999999999999998	0.92799997	19.879999999999999	39.5	18.449000000000002	36.655999999999999
8055	1	0	0.29999999999999999	1.263	2.75	32.469999999999999	3.4729999999999999	41.009999999999998
8055	2	0	1.1000000000000001	1.177	3	27.280000000000001	3.5310000000000001	32.109000000000002
8055	3	0	1.3999999999999999	1.11	2.77	31.149999999999999	3.0750000000000002	34.576000000000001
8055	4	0	1.8	0.88599998	3.6600000000000001	29.699999999999999	3.2429999999999999	26.314
8056	1	0	0.29999999999999999	1.375	2.9500000000000002	32.009999999999998	4.056	44.014000000000003
8056	2	0	1.5	1.24	3.27	30.329999999999998	4.0549999999999997	37.609000000000002
8056	3	0	2	1.102	3.6600000000000001	31.300000000000001	4.0330000000000004	34.493000000000002
8056	4	0	2.2999999999999998	0.90399998	5.9800000000000004	38.82	5.4059999999999997	35.093000000000004
8057	1	0	0.29999999999999999	1.534	3.8399999999999999	34.299999999999997	5.891	52.616
8057	2	0	1.8	1.41	7.9299999999999997	37.310000000000002	11.180999999999999	52.606999999999999
8057	3	0	2.3999999999999999	1.234	19.600000000000001	51.619999999999997	24.186	63.698999999999998
8057	4	0	2.7999999999999998	0.92799997	94.129999999999995	124.47	87.352999999999994	115.508
8058	1	0	0.29999999999999999	1.615	3.7799999999999998	30.84	6.1050000000000004	49.807000000000002
8058	2	0	2.2000000000000002	1.4859999	5.1799999999999997	33.079999999999998	7.6970000000000001	49.156999999999996
8058	3	0	2.8999999999999999	1.346	10.119999999999999	41.32	13.622	55.616999999999997
8058	4	0	3.3999999999999999	0.935	28.710000000000001	60.25	26.844000000000001	56.334000000000003
8059	1	0	0.29999999999999999	1.5369999	2.8100000000000001	31.129999999999999	4.319	47.847000000000001
8059	2	0	2.3999999999999999	1.3430001	3.4199999999999999	32.640000000000001	4.593	43.835999999999999
8059	3	0	3.2000000000000002	1.1619999	4.21	34.810000000000002	4.8920000000000003	40.448999999999998
8059	4	0	3.7999999999999998	0.86000001	5.5499999999999998	37.289999999999999	4.7729999999999997	32.069000000000003
7613	1	0	0.29999999999999999	1.3200001	3.6200000000000001	63.619999999999997	4.7779999999999996	83.977999999999994
7613	2	0	2.8999999999999999	1.09	4.5999999999999996	61.939999999999998	5.0140000000000002	67.515000000000001
7613	3	0	3.7999999999999998	1.04	5.4299999999999997	64.769999999999996	5.6470000000000002	67.361000000000004
7613	4	0	4.5999999999999996	0.75	8.7200000000000006	71.379999999999995	6.54	53.534999999999997
7614	1	0	0.29999999999999999	1.84	3.8900000000000001	61.219999999999999	7.1580000000000004	112.645
7614	2	0	3.1000000000000001	1.75	4.5300000000000002	61.200000000000003	7.9269999999999996	107.09999999999999
7614	3	0	4.0999999999999996	1.4299999	5.8899999999999997	61.890000000000001	8.423	88.503
7614	4	0	4.9000000000000004	1.3	11.81	71.810000000000002	15.353	93.352999999999994
7615	1	0	0.29999999999999999	2.23	4.2599999999999998	67.599999999999994	9.5	150.74799999999999
7615	2	0	3.3999999999999999	1.96	7.3600000000000003	60.689999999999998	14.426	118.952
7615	3	0	4.5	1.7	13.210000000000001	69.209999999999994	22.457000000000001	117.657
7615	4	0	5.4000000000000004	1.35	43.109999999999999	100.45	58.198	135.608
7616	1	0	0.29999999999999999	2.3399999	4.8700000000000001	51.530000000000001	11.396000000000001	120.58
7616	2	0	3.5	2.04	13.130000000000001	77.129999999999995	26.785	157.345
7616	3	0	4.7000000000000002	1.8	31.280000000000001	107.28	56.304000000000002	193.10400000000001
7616	4	0	5.7000000000000002	1.55	170.83000000000001	235.5	264.78699999999998	365.02499999999998
7617	1	0	0.29999999999999999	2.26	4.75	74.75	10.734999999999999	168.935
7617	2	0	3.8999999999999999	2.25	6.2999999999999998	73.640000000000001	14.175000000000001	165.69
7617	3	0	5.2000000000000002	1.9299999	7.4299999999999997	72.769999999999996	14.34	140.446
7617	4	0	6.2999999999999998	1.33	11.039999999999999	71.040000000000006	14.683	94.483000000000004
7608	1	0	0.29999999999999999	1.1900001	1.52	21.02	1.8089999999999999	25.013999999999999
7608	2	0	1.3	1.03	1.8	22.050000000000001	1.8540000000000001	22.710999999999999
7608	3	0	1.8	0.85000002	1.96	20.460000000000001	1.6659999999999999	17.390999999999998
7608	4	0	2	0.62	2.46	22.960000000000001	1.5249999999999999	14.234999999999999
7609	1	0	0.29999999999999999	1.4400001	1.52	15.52	2.1890000000000001	22.349
7609	2	0	1.6000000000000001	1.21	2.0899999999999999	20.59	2.5289999999999999	24.914000000000001
7609	3	0	2.1000000000000001	0.92000002	2.54	20.539999999999999	2.3370000000000002	18.896999999999998
7609	4	0	2.3999999999999999	0.74000001	3.4300000000000002	23.68	2.5379999999999998	17.523
7610	1	0	0.29999999999999999	1.46	1.7	19.449999999999999	2.4820000000000002	28.396999999999998
7610	2	0	1.7	1.28	2.7200000000000002	21.719999999999999	3.4820000000000002	27.802
7610	3	0	2.2000000000000002	1.04	3.7999999999999998	23.41	3.952	24.346
7610	4	0	2.6000000000000001	0.83999997	6.7800000000000002	26.780000000000001	5.6950000000000003	22.495000000000001
7611	1	0	0.29999999999999999	1.5599999	1.8500000000000001	19.850000000000001	2.8860000000000001	30.966000000000001
7611	2	0	2.1000000000000001	1.37	2.3700000000000001	22.120000000000001	3.2469999999999999	30.303999999999998
7611	3	0	2.7999999999999998	1.15	3.1899999999999999	21.68	3.669	24.931999999999999
7611	4	0	3.2999999999999998	0.77999997	8.1699999999999999	27.420000000000002	6.3730000000000002	21.388000000000002
7612	1	0	0.29999999999999999	1.42	1.76	23.260000000000002	2.4990000000000001	33.029000000000003
7612	2	0	2.2000000000000002	1.23	2.2799999999999998	21.780000000000001	2.8039999999999998	26.789000000000001
7612	3	0	3	0.98000002	2.7200000000000002	21.969999999999999	2.6659999999999999	21.530999999999999
7612	4	0	3.5	0.83999997	2.2599999999999998	22.760000000000002	1.8979999999999999	19.117999999999999
7603	1	0	0.29999999999999999	1.27	6.4100000000000001	84.909999999999997	8.141	107.836
7603	2	0	2.1000000000000001	0.81999999	9.1899999999999995	39.189999999999998	7.5359999999999996	32.136000000000003
7603	3	0	2.7999999999999998	0.85000002	7.6699999999999999	89.670000000000002	6.5190000000000001	76.218999999999994
7603	4	0	3.2999999999999998	0.34999999	10.33	97.829999999999998	3.6160000000000001	34.240000000000002
7604	1	0	0.29999999999999999	1.7	7.6699999999999999	57.170000000000002	13.039	97.188999999999993
7604	2	0	2.7999999999999998	1.53	11.109999999999999	92.609999999999999	16.998000000000001	141.69300000000001
7604	3	0	3.7999999999999998	1.28	13.85	88.849999999999994	17.728000000000002	113.72799999999999
7604	4	0	4.5	0.91000003	25.329999999999998	106.33	23.050000000000001	96.760000000000005
7605	1	0	0.29999999999999999	2.0799999	7.0700000000000003	95.569999999999993	14.706	198.786
7605	2	0	3.1000000000000001	1.9	14.81	99.310000000000002	28.138999999999999	188.68899999999999
7605	3	0	4.0999999999999996	1.72	14.220000000000001	94.719999999999999	24.457999999999998	162.91800000000001
7605	4	0	4.9000000000000004	1.24	45.520000000000003	128.52000000000001	56.445	159.36500000000001
7606	1	0	0.29999999999999999	2.21	12.699999999999999	93.700000000000003	28.067	207.077
7606	2	0	3.7000000000000002	1.91	20.82	63.310000000000002	39.765999999999998	120.922
7606	3	0	4.9000000000000004	1.67	27.039999999999999	75.540000000000006	45.156999999999996	126.152
7606	4	0	5.9000000000000004	1.03	41.909999999999997	68.409999999999997	43.167000000000002	70.462000000000003
7607	1	0	0.29999999999999999	2.0699999	8.9600000000000009	72.459999999999994	18.547000000000001	149.99199999999999
7607	2	0	4	1.92	15.07	64.069999999999993	28.934000000000001	123.014
7607	3	0	5.4000000000000004	1.6	16.670000000000002	64.170000000000002	26.672000000000001	102.672
7607	4	0	6.5	0.85000002	20.760000000000002	65.560000000000002	17.646000000000001	55.725999999999999
7598	1	0	0.29999999999999999	1	1.48	9.4800000000000004	1.48	9.4800000000000004
7598	2	0	0.80000000000000004	0.88	1.6699999999999999	10.67	1.47	9.3900000000000006
7598	3	0	1	0.77999997	1.74	10.74	1.357	8.3770000000000007
7598	4	0	1.1000000000000001	0.61000001	2.04	12.039999999999999	1.244	7.3440000000000003
7599	1	0	0.29999999999999999	1.08	1.6699999999999999	10.67	1.804	11.523999999999999
7599	2	0	0.90000000000000002	0.93000001	1.9299999999999999	9.4299999999999997	1.7949999999999999	8.7699999999999996
7599	3	0	1.2	0.75	2.2599999999999998	10.76	1.6950000000000001	8.0700000000000003
7599	4	0	1.3	0.68000001	2.3700000000000001	9.8699999999999992	1.6120000000000001	6.7119999999999997
7600	1	0	0.29999999999999999	1.11	1.79	9.2899999999999991	1.9870000000000001	10.311999999999999
7600	2	0	1.1000000000000001	0.93000001	2.3300000000000001	10.33	2.1669999999999998	9.6069999999999993
7600	3	0	1.5	0.76999998	3.2999999999999998	12.300000000000001	2.5409999999999999	9.4710000000000001
7600	4	0	1.7	0.56	5.7400000000000002	14.24	3.214	7.9740000000000002
7601	1	0	0.29999999999999999	1.26	2.2999999999999998	11.800000000000001	2.8980000000000001	14.868
7601	2	0	1.6000000000000001	1.0599999	3.7400000000000002	11.74	3.964	12.444000000000001
7601	3	0	2.1000000000000001	0.85000002	5.2599999999999998	14.26	4.4710000000000001	12.121
7601	4	0	2.3999999999999999	0.69	9.8499999999999996	18.350000000000001	6.7960000000000003	12.662000000000001
7602	1	0	0.29999999999999999	1.2	1.5900000000000001	8.0899999999999999	1.9079999999999999	9.7080000000000002
7602	2	0	1.8999999999999999	0.91000003	2	11.5	1.8200000000000001	10.465
7602	3	0	2.5	0.74000001	2.3300000000000001	9.8300000000000001	1.724	7.274
7602	4	0	2.8999999999999999	0.41	2.7000000000000002	10.699999999999999	1.107	4.3869999999999996
7597	1	0	0.29999999999999999	1.65	1.51	14.84	2.492	24.486000000000001
7597	2	0	1.8999999999999999	1.38	1.74	14.4	2.4009999999999998	19.872
7597	3	0	2.7000000000000002	1.25	1.8500000000000001	13.85	2.3130000000000002	17.312000000000001
7597	4	0	3.2000000000000002	1.17	2.8700000000000001	14.199999999999999	3.3580000000000001	16.614000000000001
7597	5	0	3.6000000000000001	1.1	3.9199999999999999	16.59	4.3120000000000003	18.248999999999999
7592	1	0	0.29999999999999999	1.35	1.51	15.51	2.0390000000000001	20.939
7592	2	0	2.1000000000000001	0.95999998	1.3999999999999999	16.059999999999999	1.3440000000000001	15.417999999999999
7592	3	0	2.7999999999999998	0.80000001	1.51	14.18	1.208	11.343999999999999
7592	4	0	3.5	0.64999998	2.4500000000000002	17.789999999999999	1.593	11.564
7593	1	0	0.29999999999999999	1.8	1.55	16.879999999999999	2.79	30.384
7593	2	0	2.5	1.3099999	1.77	15.77	2.319	20.658999999999999
7593	3	0	3.2999999999999998	1.13	2.0800000000000001	15.41	2.3500000000000001	17.413
7593	4	0	3.8999999999999999	1	2	14.67	2	14.67
7594	1	0	0.29999999999999999	1.9299999	1.77	16.440000000000001	3.4159999999999999	31.728999999999999
7594	2	0	2.7999999999999998	1.42	2.23	19.559999999999999	3.1669999999999998	27.774999999999999
7594	3	0	3.7000000000000002	1.24	3.02	17.690000000000001	3.7450000000000001	21.936
7594	4	0	4.4000000000000004	1.1	4.2300000000000004	18.23	4.6529999999999996	20.053000000000001
7595	1	0	0.29999999999999999	2.0799999	1.8899999999999999	17.890000000000001	3.931	37.210999999999999
7595	2	0	3.1000000000000001	1.98	2.5699999999999998	15.9	5.0890000000000004	31.481999999999999
7595	3	0	4.2000000000000002	1.37	3.25	17.25	4.4530000000000003	23.632000000000001
7595	4	0	5	0.99000001	5.1699999999999999	22.5	5.1180000000000003	22.274999999999999
7596	1	0	0.29999999999999999	1.9	2.1099999999999999	18.109999999999999	4.0090000000000003	34.408999999999999
7596	2	0	3.5	1.15	1.6200000000000001	14.960000000000001	1.863	17.204000000000001
7596	3	0	4.7000000000000002	0.87	1.5900000000000001	18.920000000000002	1.383	16.460000000000001
7596	4	0	5.7000000000000002	0.63999999	2.5299999999999998	17.199999999999999	1.619	11.007999999999999
7589	1	0	0.29999999999999999	0.98000002	1.96	23.960000000000001	1.921	23.481000000000002
7589	2	0	0.69999999999999996	0.89999998	2.1099999999999999	24.609999999999999	1.899	22.149000000000001
7589	3	0	0.90000000000000002	0.83999997	2.2599999999999998	25.760000000000002	1.8979999999999999	21.638000000000002
7589	4	0	1	0.68000001	2.4399999999999999	27.940000000000001	1.659	18.998999999999999
7590	1	0	0.29999999999999999	1.08	3.1899999999999999	26.68	3.4449999999999998	28.814
7590	2	0	1	0.95999998	3.7400000000000002	26.239999999999998	3.5899999999999999	25.190000000000001
7590	3	0	1.3999999999999999	0.81	4.6299999999999999	28.629999999999999	3.75	23.190000000000001
7590	4	0	1.8	0.5	7.4800000000000004	28.48	3.7400000000000002	14.24
7591	1	0	0.29999999999999999	1.16	2.1499999999999999	23.649999999999999	2.4940000000000002	27.434000000000001
7591	2	0	1.1000000000000001	0.85000002	2.3300000000000001	23.829999999999998	1.9810000000000001	20.254999999999999
7591	3	0	1.5	0.74000001	2.48	23.98	1.835	17.745000000000001
7591	4	0	1.7	0.60000002	2.3700000000000001	25.370000000000001	1.4219999999999999	15.222
7588	1	0	0.29999999999999999	0.94999999	2.4100000000000001	24.41	2.29	23.190000000000001
7588	2	0	0.59999999999999998	0.86000001	2.52	24.52	2.1669999999999998	21.087
7588	3	0	0.90000000000000002	0.79000002	2.7799999999999998	26.280000000000001	2.1960000000000002	20.760999999999999
7588	4	0	1.1000000000000001	0.58999997	3.0699999999999998	26.57	1.8109999999999999	15.676
7588	5	0	1.2	0.38999999	4.1500000000000004	26.149999999999999	1.619	10.198
7587	1	0	0.29999999999999999	1.01	2.3700000000000001	28.870000000000001	2.3940000000000001	29.158999999999999
7587	2	0	0.59999999999999998	0.99000001	2.4100000000000001	28.91	2.3860000000000001	28.620999999999999
7587	3	0	0.90000000000000002	0.95999998	2.5600000000000001	26.559999999999999	2.4580000000000002	25.498000000000001
7587	4	0	1.1000000000000001	0.77999997	2.4100000000000001	28.41	1.8799999999999999	22.16
7587	5	0	1.2	0.63999999	3.2200000000000002	30.719999999999999	2.0609999999999999	19.661000000000001
7582	1	0	0.29999999999999999	1.38	1.78	12.279999999999999	2.456	16.946000000000002
7582	2	0	1.5	1.22	1.5900000000000001	11.09	1.9399999999999999	13.529999999999999
7582	3	0	2	1.03	2.0699999999999998	10.57	2.1320000000000001	10.887
7582	4	0	2.2999999999999998	0.62	3	12	1.8600000000000001	7.4400000000000004
7583	1	0	0.29999999999999999	1.5	1.5900000000000001	11.09	2.3849999999999998	16.635000000000002
7583	2	0	1.8	1.3200001	1.9299999999999999	10.93	2.548	14.428000000000001
7583	3	0	2.3999999999999999	1.14	1.96	10.960000000000001	2.234	12.494
7583	4	0	2.7999999999999998	0.63	2.8500000000000001	12.35	1.796	7.7800000000000002
7584	1	0	0.29999999999999999	1.5700001	1.5900000000000001	9.0899999999999999	2.496	14.271000000000001
7584	2	0	1.8999999999999999	1.4	2.8100000000000001	8.3100000000000005	3.9340000000000002	11.634
7584	3	0	2.6000000000000001	1.1900001	4.7000000000000002	10.699999999999999	5.593	12.733000000000001
7584	4	0	3	0.75	13.779999999999999	22.780000000000001	10.335000000000001	17.085000000000001
7585	1	0	0.29999999999999999	1.61	1.6299999999999999	10.130000000000001	2.6240000000000001	16.309000000000001
7585	2	0	2.5	1.45	1.96	8.9600000000000009	2.8420000000000001	12.992000000000001
7585	3	0	3.2999999999999998	1.25	2.3300000000000001	10.83	2.9119999999999999	13.538
7585	4	0	3.8999999999999999	0.61000001	4.5899999999999999	15.09	2.7999999999999998	9.2050000000000001
7586	1	0	0.29999999999999999	1.51	1.8600000000000001	9.8499999999999996	2.8090000000000002	14.874000000000001
7586	2	0	2.7000000000000002	1.24	2.0699999999999998	12.07	2.5670000000000002	14.967000000000001
7586	3	0	3.6000000000000001	1.01	2.8500000000000001	11.35	2.879	11.464
7586	4	0	4.2999999999999998	0.46000001	4.5199999999999996	11.52	2.0790000000000002	5.2990000000000004
7573	1	0	0.29999999999999999	1.34	3.2000000000000002	3.2000000000000002	4.2880000000000003	4.2880000000000003
7573	2	0	1.1000000000000001	1.25	3.6400000000000001	3.6400000000000001	4.5499999999999998	4.5499999999999998
7573	3	0	1.5	1.15	3.7200000000000002	3.7200000000000002	4.2779999999999996	4.2779999999999996
7573	4	0	1.8999999999999999	0.98000002	3.7599999999999998	3.7599999999999998	3.6850000000000001	3.6850000000000001
7573	5	0	2.1000000000000001	0.57999998	5.1200000000000001	5.1200000000000001	2.9700000000000002	2.9700000000000002
7574	1	0	0.29999999999999999	1.45	3.2799999999999998	3.2799999999999998	4.7560000000000002	4.7560000000000002
7574	2	0	1.3	1.36	3.7200000000000002	3.7200000000000002	5.0590000000000002	5.0590000000000002
7574	3	0	1.8999999999999999	1.2	4.2800000000000002	4.2800000000000002	5.1360000000000001	5.1360000000000001
7574	4	0	2.2999999999999998	0.94	5.1200000000000001	5.1200000000000001	4.8129999999999997	4.8129999999999997
11056	2	0	1.3	0.96899998	0.60199999999999998	7.9020000000000001	0.58299999999999996	7.657
11056	3	0	1.7	0.85299999	1.0449999999999999	7.7450000000000001	0.89100000000000001	6.6059999999999999
11056	4	0	2.1000000000000001	0.60600001	2.2890000000000001	11.728999999999999	1.387	7.1079999999999997
10925	1	0	0.29999999999999999	0	0.35299999999999998	8.4130000000000003	0	0
10925	2	0	1.3999999999999999	0	0.45500000000000002	6.6550000000000002	0	0
10925	3	0	1.8	0	0.438	7.2779999999999996	0	0
10925	4	0	2	0	0.56200000000000006	6.0620000000000003	0	0
10924	1	0	0.29999999999999999	0	0.73499999999999999	6.8550000000000004	0	0
10924	2	0	2.2999999999999998	0	0.96899999999999997	6.5090000000000003	0	0
10924	3	0	3	0	2.0129999999999999	7.8730000000000002	0	0
10924	4	0	3.5	0	4.9290000000000003	12.109	0	0
10923	1	0	0.29999999999999999	0	1.024	8.6440000000000001	0	0
10923	2	0	2.1000000000000001	0	2.2290000000000001	8.9689999999999994	0	0
10923	3	0	2.7999999999999998	0	3.3239999999999998	9.6639999999999997	0	0
10923	4	0	3.2000000000000002	0	7.2930000000000001	14.292999999999999	0	0
10922	1	0	0.29999999999999999	0	2.1890000000000001	8.8689999999999998	0	0
10922	2	0	2.2999999999999998	0	4.4729999999999999	11.173	0	0
10922	3	0	3	0	12.173	20.253	0	0
10922	4	0	3.5	0	27.539999999999999	35.32	0	0
10921	1	0	0.29999999999999999	0	0.92500000000000004	9.3650000000000002	0	0
10921	2	0	2.2999999999999998	0	1.6020000000000001	11.061999999999999	0	0
10921	3	0	3	0	4.944	13.103999999999999	0	0
10921	4	0	3.5	0	14.9	22.68	0	0
10765	1	0	0.10000000000000001	0.51999998	0.95999999999999996	13.539999999999999	0.499	7.0410000000000004
10765	2	0	1.2	0.43000001	1.1359999999999999	13.916	0.48799999999999999	5.984
10765	3	0	1.6000000000000001	0.41	1.0549999999999999	14.315	0.433	5.8689999999999998
10765	4	0	1.8999999999999999	0.38	1.1040000000000001	13.804	0.41999999999999998	5.2460000000000004
10764	1	0	0.10000000000000001	1.03	1.2150000000000001	14.455	1.2509999999999999	14.888999999999999
10764	2	0	1.1000000000000001	0.77999997	1.627	15.247	1.2689999999999999	11.893000000000001
10764	3	0	1.3999999999999999	0.70999998	2.516	15.396000000000001	1.786	10.930999999999999
10764	4	0	1.8	0.60000002	5.5220000000000002	19.122	3.3130000000000002	11.473000000000001
10763	1	0	0.10000000000000001	0.97000003	1.296	13.316000000000001	1.2569999999999999	12.917
10763	2	0	1.1000000000000001	0.76999998	1.9019999999999999	14.742000000000001	1.4650000000000001	11.351000000000001
10763	3	0	1.3999999999999999	0.70999998	2.3069999999999999	15.686999999999999	1.6379999999999999	11.138
10763	4	0	1.8	0.62	6.6749999999999998	18.035	4.1390000000000002	11.182
10762	1	0	0.10000000000000001	1.03	1.444	13.984	1.4870000000000001	14.404
10762	2	0	1.1000000000000001	0.77999997	2.0649999999999999	14.925000000000001	1.611	11.641
10762	3	0	1.3999999999999999	0.69	2.3130000000000002	17.853000000000002	1.5960000000000001	12.319000000000001
10762	4	0	1.8	0.56999999	6.2149999999999999	18.895	3.5430000000000001	10.77
10761	1	0	0.10000000000000001	1	1.3420000000000001	16.681999999999999	1.3420000000000001	16.681999999999999
10761	2	0	1.2	0.69	1.784	16.384	1.2310000000000001	11.305
10761	3	0	1.6000000000000001	0.55000001	3.4249999999999998	17.545000000000002	1.8839999999999999	9.6500000000000004
10761	4	0	1.8999999999999999	0.44999999	9.0730000000000004	22.832999999999998	4.0830000000000002	10.275
10750	1	0	0.29999999999999999	0.82599998	1.9199999999999999	33.719999999999999	1.5860000000000001	27.853000000000002
10750	2	0	1	0.79500002	2.0019999999999998	26.122	1.5920000000000001	20.766999999999999
10750	3	0	1.3999999999999999	0.69	1.911	36.051000000000002	1.319	24.875
10750	4	0	1.7	0.53799999	2.1600000000000001	27.84	1.1619999999999999	14.978
10749	1	0	0.29999999999999999	1.1160001	2.3690000000000002	32.249000000000002	2.6440000000000001	35.990000000000002
10749	2	0	1.3	1.0369999	2.6040000000000001	38.884	2.7000000000000002	40.323
10749	3	0	1.8	0.88599998	3.4620000000000002	34.521999999999998	3.0670000000000002	30.585999999999999
10749	4	0	2.2000000000000002	0.74800003	4.3239999999999998	37.304000000000002	3.234	27.902999999999999
10748	1	0	0.29999999999999999	1.085	1.762	30.321999999999999	1.9119999999999999	32.899000000000001
10748	2	0	1.3	1.0319999	2.8490000000000002	25.908999999999999	2.9399999999999999	26.738
10748	3	0	1.8	0.88599998	4.6550000000000002	37.215000000000003	4.1239999999999997	32.972000000000001
10748	4	0	2.2000000000000002	0.79699999	6.7999999999999998	41.020000000000003	5.4199999999999999	32.692999999999998
10747	1	0	0.29999999999999999	1.131	1.6930000000000001	38.113	1.915	43.106000000000002
10747	2	0	1.3999999999999999	0.98100001	2.8580000000000001	43.618000000000002	2.8039999999999998	42.789000000000001
10747	3	0	1.8999999999999999	0.84799999	3.5750000000000002	31.614999999999998	3.032	26.809999999999999
10747	4	0	2.3999999999999999	0.273	16.024999999999999	53.265000000000001	4.375	14.541
10746	1	0	0.29999999999999999	1.124	2.2749999999999999	40.494999999999997	2.5569999999999999	45.515999999999998
10746	2	0	1.3999999999999999	1.0369999	2.3580000000000001	43.478000000000002	2.4449999999999998	45.087000000000003
10746	3	0	1.8	0.92799997	3.5	44.68	3.2480000000000002	41.463000000000001
10746	4	0	2.2999999999999998	0.64899999	7.024	48.264000000000003	4.5590000000000002	31.323
10745	1	0	0.5	0.98000002	0.69599999999999995	12.016	0.68200000000000005	11.776
10745	2	0	1.3999999999999999	0.91000003	0.78000000000000003	12.460000000000001	0.70999999999999996	11.339
10745	3	0	1.8999999999999999	0.72000003	0.90200000000000002	12.102	0.64900000000000002	8.7129999999999992
10745	4	0	2.2000000000000002	0.43000001	0.36399999999999999	12.763999999999999	0.157	5.4889999999999999
10744	1	0	0.5	1.24	1.198	13.218	1.486	16.390000000000001
10744	2	0	1.7	1.09	1.5469999999999999	13.606999999999999	1.6859999999999999	14.832000000000001
10744	3	0	2.2000000000000002	0.99000001	2.2240000000000002	14.004	2.202	13.864000000000001
10744	4	0	2.7000000000000002	0.70999998	5.4489999999999998	14.308999999999999	3.8690000000000002	10.159000000000001
10743	1	0	0.5	1.26	2.0529999999999999	14.933	2.5870000000000002	18.815999999999999
10743	2	0	1.7	1.13	4.7930000000000001	21.672999999999998	5.4160000000000004	24.489999999999998
10743	3	0	2.2000000000000002	1.0599999	7.2400000000000002	20.300000000000001	7.6740000000000004	21.518000000000001
10743	4	0	2.5	1.02	16.420000000000002	28.18	16.748000000000001	28.744
10742	1	0	0.5	1.28	1.762	14.582000000000001	2.2549999999999999	18.664999999999999
10742	2	0	1.7	1.08	4.3710000000000004	17.510999999999999	4.7210000000000001	18.911999999999999
10742	3	0	2.2000000000000002	1	8.8330000000000002	23.033000000000001	8.8330000000000002	23.033000000000001
10742	4	0	2.5	0.88	15.388999999999999	29.669	13.542	26.109000000000002
10741	1	0	0.5	1.34	1.5960000000000001	18.936	2.1389999999999998	25.373999999999999
10741	2	0	1.5	1.26	1.7090000000000001	18.809000000000001	2.153	23.699000000000002
10741	3	0	2	1.09	2.2690000000000001	21.009	2.4729999999999999	22.899999999999999
10741	4	0	2.5	0.91000003	2.6560000000000001	19.975999999999999	2.4169999999999998	18.178000000000001
8185	1	0	0.29999999999999999	0.89999998	1.0800000000000001	28.66	0.97199999999999998	25.794
8185	2	0	1.3999999999999999	0.82999998	1.26	24.710000000000001	1.046	20.509
8185	3	0	1.8999999999999999	0.73000002	1.6200000000000001	20.66	1.1830000000000001	15.082000000000001
8185	4	0	2.2000000000000002	0.58999997	1.73	20.350000000000001	1.0209999999999999	12.006
8186	1	0	0.29999999999999999	1.03	1.8200000000000001	24.239999999999998	1.875	24.966999999999999
8186	2	0	1.3	0.92000002	1.8300000000000001	21.73	1.6839999999999999	19.992000000000001
8186	3	0	1.8	0.82999998	3.0600000000000001	21.460000000000001	2.54	17.812000000000001
8186	4	0	2	0.68000001	4.0499999999999998	23.469999999999999	2.754	15.960000000000001
8187	1	0	0.29999999999999999	1.05	1.54	17.620000000000001	1.617	18.501000000000001
8187	2	0	1.1000000000000001	0.95999998	1.96	22.809999999999999	1.8819999999999999	21.898
8187	3	0	1.3999999999999999	0.88999999	3.9399999999999999	28.920000000000002	3.5070000000000001	25.739000000000001
8187	4	0	1.6000000000000001	0.82999998	13.01	29.710000000000001	10.798	24.658999999999999
8188	1	0	0.29999999999999999	1	1.47	21.710000000000001	1.47	21.710000000000001
8188	2	0	1.2	0.95999998	1.74	23.359999999999999	1.6699999999999999	22.425999999999998
8188	3	0	1.6000000000000001	0.88999999	2.6499999999999999	24.510000000000002	2.359	21.814
8188	4	0	1.8	0.79000002	6.46	27.920000000000002	5.1029999999999998	22.056999999999999
8189	1	0	0.29999999999999999	1.05	1.3	21.84	1.365	22.931999999999999
8189	2	0	1.2	0.99000001	1.55	24.91	1.534	24.661000000000001
8189	3	0	1.6000000000000001	0.94999999	1.8	25.579999999999998	1.71	24.300999999999998
8189	4	0	1.8	0.77999997	3.2200000000000002	26.98	2.512	21.044
8180	1	0	0.29999999999999999	1.2029999	2.1699999999999999	19.739999999999998	2.6110000000000002	23.747
8180	2	0	2.7999999999999998	1.097	5.8700000000000001	27.289999999999999	6.4390000000000001	29.937000000000001
8180	3	0	3.7000000000000002	0.91100001	5.7999999999999998	24.559999999999999	5.2839999999999998	22.373999999999999
8180	4	0	4.4000000000000004	0.65200001	19.850000000000001	36.549999999999997	12.942	23.831
8181	1	0	0.29999999999999999	1.188	2.4100000000000001	21.989999999999998	2.863	26.123999999999999
8181	2	0	2.7999999999999998	1.128	3.02	22.559999999999999	3.407	25.448
8181	3	0	3.7000000000000002	1.0140001	7.8700000000000001	26.41	7.9800000000000004	26.780000000000001
8181	4	0	4.4000000000000004	0.60100001	30.27	50.590000000000003	18.192	30.405000000000001
8182	1	0	0.29999999999999999	1.176	2.5600000000000001	23.539999999999999	3.0110000000000001	27.683
8182	2	0	2.6000000000000001	1.039	5.2800000000000002	26.34	5.4859999999999998	27.367000000000001
8182	3	0	3.5	0.91500002	9.1799999999999997	28.620000000000001	8.4000000000000004	26.187000000000001
8182	4	0	4.2000000000000002	0.81199998	16.780000000000001	35.460000000000001	13.625	28.794
8183	1	0	0.29999999999999999	1.21	2.5	20.199999999999999	3.0249999999999999	24.442
8183	2	0	2.5	1.092	5.3499999999999996	24.829999999999998	5.8419999999999996	27.114000000000001
8183	3	0	3.3999999999999999	0.986	13.33	33.710000000000001	13.143000000000001	33.238
8183	4	0	4	0.73199999	41.509999999999998	64.489999999999995	30.385000000000002	47.207000000000001
8184	1	0	0.29999999999999999	1.194	1.8500000000000001	21.129999999999999	2.2090000000000001	25.228999999999999
8184	2	0	2.3999999999999999	1.077	2.6299999999999999	22.59	2.8330000000000002	24.329000000000001
8184	3	0	3.2000000000000002	0.995	2.7999999999999998	25.960000000000001	2.786	25.829999999999998
8184	4	0	3.7999999999999998	0.67400002	13.57	39.189999999999998	9.1460000000000008	26.414000000000001
8085	1	0	0.29999999999999999	0.94	1.1799999999999999	30.440000000000001	1.109	28.614000000000001
8085	2	0	1.5	0.85000002	1.9299999999999999	38.060000000000002	1.6399999999999999	32.350999999999999
8085	3	0	2	0.75	1.27	31.629999999999999	0.95299999999999996	23.722000000000001
8085	4	0	2.2999999999999998	0.67000002	2.2400000000000002	28.52	1.5009999999999999	19.108000000000001
8086	1	0	0.29999999999999999	1.5	2.6499999999999999	29.190000000000001	3.9750000000000001	43.784999999999997
8086	2	0	3.2999999999999998	1.3200001	5.1299999999999999	37.009999999999998	6.7720000000000002	48.853000000000002
8086	3	0	4.4000000000000004	1.1900001	12.720000000000001	44.539999999999999	15.137	53.003
8086	4	0	5.2999999999999998	0.93000001	30.289999999999999	53.850000000000001	28.170000000000002	50.081000000000003
8087	1	0	0.29999999999999999	1.48	2.7400000000000002	35.039999999999999	4.0549999999999997	51.859000000000002
8087	2	0	3.2999999999999998	1.37	5.3300000000000001	32.869999999999997	7.3019999999999996	45.031999999999996
8087	3	0	4.4000000000000004	1.08	15.26	45.100000000000001	16.481000000000002	48.707999999999998
8087	4	0	5.2999999999999998	0.69999999	53.960000000000001	84.760000000000005	37.771999999999998	59.332000000000001
8088	1	0	0.29999999999999999	1.48	1.98	33.140000000000001	2.9300000000000002	49.046999999999997
8088	2	0	3	1.33	2.8700000000000001	34.590000000000003	3.8170000000000002	46.005000000000003
8088	3	0	4	1.21	4.3300000000000001	34.75	5.2389999999999999	42.048000000000002
8088	4	0	4.7999999999999998	0.81	26.84	64.060000000000002	21.739999999999998	51.889000000000003
8089	1	0	0.29999999999999999	1.3	1.72	30.359999999999999	2.2360000000000002	39.468000000000004
8089	2	0	2.7000000000000002	1.11	1.8300000000000001	30.649999999999999	2.0310000000000001	34.021000000000001
8089	3	0	3.6000000000000001	0.83999997	2.0800000000000001	33.240000000000002	1.7470000000000001	27.922000000000001
8089	4	0	4.2999999999999998	0.56999999	3.1600000000000001	32.600000000000001	1.8009999999999999	18.582000000000001
7141	1	0	0.29999999999999999	0.89999998	0.37	8.8699999999999992	0.33300000000000002	7.9829999999999997
7141	2	0	1.6000000000000001	0.75999999	0.37	11.869999999999999	0.28100000000000003	9.0210000000000008
7141	3	0	2.2000000000000002	0.60000002	0.40999999999999998	15.91	0.246	9.5459999999999994
7141	4	0	2.5	0.37	0.89000000000000001	13.390000000000001	0.32900000000000001	4.9539999999999997
7142	1	0	0.29999999999999999	1.2	0.56000000000000005	14.56	0.67200000000000004	17.472000000000001
7142	2	0	2.6000000000000001	1.02	0.93000000000000005	13.93	0.94899999999999995	14.209
7142	3	0	3.3999999999999999	0.89999998	0.81000000000000005	12.81	0.72899999999999998	11.529
7142	4	0	4.0999999999999996	0.61000001	1.48	13.98	0.90300000000000002	8.5280000000000005
7143	1	0	0.29999999999999999	1.73	2.5600000000000001	10.56	4.4290000000000003	18.268999999999998
7143	2	0	3.3999999999999999	1.59	9.4399999999999995	23.440000000000001	15.01	37.270000000000003
7143	3	0	4.5999999999999996	1.3200001	28.82	45.810000000000002	38.042000000000002	60.469000000000001
7143	4	0	5.5	1.12	64.810000000000002	83.310000000000002	72.587000000000003	93.307000000000002
7144	1	0	0.29999999999999999	1.8	2.2599999999999998	17.260000000000002	4.0679999999999996	31.068000000000001
7144	2	0	3.6000000000000001	1.67	11.039999999999999	27.539999999999999	18.437000000000001	45.991999999999997
7144	3	0	4.7999999999999998	1.4400001	23.82	36.810000000000002	34.301000000000002	53.006
7144	4	0	5.7999999999999998	1.27	73.590000000000003	86.590000000000003	93.459000000000003	109.96899999999999
7145	1	0	0.29999999999999999	1.54	0.81000000000000005	13.31	1.2470000000000001	20.497
7145	2	0	3	1.26	1.9299999999999999	15.43	2.4319999999999999	19.442
7145	3	0	4	1.09	3.6699999999999999	16.670000000000002	4	18.170000000000002
7145	4	0	4.7999999999999998	0.79000002	6.4100000000000001	20.41	5.0640000000000001	16.123999999999999
7136	1	0	0.29999999999999999	0.79000002	0.47999999999999998	9.4800000000000004	0.379	7.4889999999999999
7136	2	0	1.3	0.69	0.37	8.8699999999999992	0.255	6.1200000000000001
7136	3	0	1.8	0.56999999	0.58999999999999997	8.0899999999999999	0.33600000000000002	4.6109999999999998
7136	4	0	2	0.43000001	2.1499999999999999	10.65	0.92500000000000004	4.5800000000000001
7137	1	0	0.29999999999999999	1.12	0.81000000000000005	10.81	0.90700000000000003	12.106999999999999
7137	2	0	1.5	0.97000003	1.8899999999999999	13.390000000000001	1.833	12.988
7137	3	0	2	0.80000001	3.3300000000000001	13.33	2.6640000000000001	10.664
7137	4	0	2.2999999999999998	0.76999998	3.5600000000000001	14.06	2.7410000000000001	10.826000000000001
7138	1	0	0.29999999999999999	1.11	1.52	14.02	1.6870000000000001	15.561999999999999
7138	2	0	1.5	1.01	2.2999999999999998	15.300000000000001	2.323	15.452999999999999
7138	3	0	2	0.81999999	13.630000000000001	26.129999999999999	11.177	21.427
7138	4	0	2.2999999999999998	0.80000001	101.94	113.44	81.552000000000007	90.751999999999995
7139	1	0	0.29999999999999999	1.11	1.04	16.539999999999999	1.1539999999999999	18.359000000000002
7139	2	0	1.6000000000000001	1.01	1.6299999999999999	14.130000000000001	1.6459999999999999	14.271000000000001
7139	3	0	2.1000000000000001	0.88	3.5600000000000001	16.059999999999999	3.133	14.132999999999999
7139	4	0	2.3999999999999999	0.75	5.1500000000000004	18.149999999999999	3.863	13.612
7140	1	0	0.29999999999999999	1.14	0.81000000000000005	13.31	0.92300000000000004	15.173
7140	2	0	1.6000000000000001	0.97000003	1.1100000000000001	14.609999999999999	1.077	14.172000000000001
7140	3	0	2.2000000000000002	0.82999998	2.5600000000000001	16.059999999999999	2.125	13.33
7140	4	0	2.5	0.16	7.1500000000000004	18.149999999999999	1.1439999999999999	2.9039999999999999
7131	1	0	0.29999999999999999	0.83999997	0.58999999999999997	10.59	0.496	8.8960000000000008
7131	2	0	1.3	0.73000002	0.84999999999999998	13.85	0.62	10.111000000000001
7030	4	0	3	0.63999999	1.1100000000000001	21.109999999999999	0.70999999999999996	13.51
7031	1	0	0.29999999999999999	2.0999999	0.89000000000000001	14.890000000000001	1.869	31.268999999999998
7031	2	0	3.7000000000000002	1.86	1.78	17.280000000000001	3.3109999999999999	32.140999999999998
7031	3	0	4.9000000000000004	1.49	2.9300000000000002	14.43	4.3659999999999997	21.501000000000001
7031	4	0	5.9000000000000004	1.25	45.960000000000001	60.460000000000001	57.450000000000003	75.575000000000003
7032	1	0	0.29999999999999999	1.8	1.78	15.279999999999999	3.2040000000000002	27.504000000000001
7032	2	0	3.6000000000000001	1.5	6.6699999999999999	19.170000000000002	10.005000000000001	28.754999999999999
7032	3	0	4.7999999999999998	1.39	9.8100000000000005	25.32	13.635999999999999	35.195
7032	4	0	5.7999999999999998	1.16	7.4100000000000001	20.91	8.5960000000000001	24.256
7033	1	0	0.29999999999999999	1.77	3.5899999999999999	19.059999999999999	6.3540000000000001	33.735999999999997
7033	2	0	3.2999999999999998	1.62	12.26	26.260000000000002	19.861000000000001	42.540999999999997
7033	3	0	4.4000000000000004	1.62	20.440000000000001	34.939999999999998	33.113	56.603000000000002
7033	4	0	5.2999999999999998	1.4299999	64.280000000000001	81.719999999999999	91.920000000000002	116.86
7034	1	0	0.29999999999999999	1.62	2.2999999999999998	15.800000000000001	3.726	25.596
7034	2	0	2.6000000000000001	1.51	7.1500000000000004	18.149999999999999	10.797000000000001	27.405999999999999
7034	3	0	3.3999999999999999	1.29	24.440000000000001	40.439999999999998	31.527999999999999	52.167999999999999
7034	4	0	4.0999999999999996	1.27	57.130000000000003	70.629999999999995	72.555000000000007	89.700000000000003
7025	1	0	0.29999999999999999	1.52	2.52	33.020000000000003	3.8300000000000001	50.189999999999998
7025	2	0	3.1000000000000001	1.37	3.4100000000000001	31.91	4.6719999999999997	43.716999999999999
7025	3	0	4.0999999999999996	1.1900001	3.1499999999999999	32.149999999999999	3.7490000000000001	38.259
7025	4	0	4.9000000000000004	0.74000001	3.9300000000000002	32.93	2.9079999999999999	24.367999999999999
7026	1	0	0.29999999999999999	1.54	4.3300000000000001	34.829999999999998	6.6680000000000001	53.637999999999998
7026	2	0	2.7000000000000002	1.4400001	4.5199999999999996	34.520000000000003	6.5090000000000003	49.709000000000003
7026	3	0	3.6000000000000001	1.24	6.96	32.960000000000001	8.6300000000000008	40.869999999999997
7026	4	0	4.2999999999999998	0.88	27.329999999999998	53.829999999999998	24.050000000000001	47.369999999999997
7027	1	0	0.29999999999999999	1.53	4.2199999999999998	35.219999999999999	6.4569999999999999	53.887
7027	2	0	2.6000000000000001	1.3099999	9.1099999999999994	40.109999999999999	11.933999999999999	52.543999999999997
7027	3	0	3.3999999999999999	1.22	8.9299999999999997	38.43	10.895	46.884999999999998
7027	4	0	4.0999999999999996	0.67000002	38.390000000000001	68.390000000000001	25.721	45.820999999999998
7028	1	0	0.29999999999999999	1.45	4.5899999999999999	30.09	6.6550000000000002	43.631
7028	2	0	2.7999999999999998	1.21	15.44	45.439999999999998	18.681999999999999	54.981999999999999
7028	3	0	3.7999999999999998	1.09	25.440000000000001	54.939999999999998	27.73	59.884999999999998
7028	4	0	4.5	0.70999998	69.060000000000002	99.560000000000002	49.033000000000001	70.688000000000002
7029	1	0	0.29999999999999999	1.11	4.4800000000000004	29.98	4.9729999999999999	33.277999999999999
7029	2	0	2.5	0.86000001	10.74	39.240000000000002	9.2360000000000007	33.746000000000002
7029	3	0	3.3999999999999999	0.85000002	14.960000000000001	44.460000000000001	12.715999999999999	37.790999999999997
7029	4	0	4	0.69	21.219999999999999	47.719999999999999	14.641999999999999	32.927
7020	1	0	0.29999999999999999	1.24	1.7	22.699999999999999	2.1080000000000001	28.148
7020	2	0	2.5	0.88999999	2.1099999999999999	24.109999999999999	1.8779999999999999	21.457999999999998
7020	3	0	3.3999999999999999	0.2	2.2200000000000002	24.719999999999999	0.44400000000000001	4.944
7020	4	0	4	0.079999998	3.2200000000000002	25.719999999999999	0.25800000000000001	2.0579999999999998
7021	1	0	0.29999999999999999	1.71	1.3700000000000001	20.370000000000001	2.343	34.832999999999998
7021	2	0	2.8999999999999999	1.61	1.48	14.98	2.383	24.117999999999999
7021	3	0	3.8999999999999999	1.46	1.6299999999999999	23.129999999999999	2.3799999999999999	33.770000000000003
7021	4	0	4.7000000000000002	1.08	2.0699999999999998	22.57	2.2360000000000002	24.376000000000001
7022	1	0	0.29999999999999999	1.64	1.8500000000000001	24.850000000000001	3.0339999999999998	40.753999999999998
7022	2	0	3.1000000000000001	1.45	4.04	23.539999999999999	5.8579999999999997	34.133000000000003
7022	3	0	4.2000000000000002	1.34	7.7000000000000002	28.199999999999999	10.318	37.787999999999997
7022	4	0	5	0.77999997	81.329999999999998	100.83	63.436999999999998	78.647000000000006
7023	1	0	0.29999999999999999	1.65	2.04	23.039999999999999	3.3660000000000001	38.015999999999998
7023	2	0	3.7000000000000002	1.54	3.3300000000000001	25.329999999999998	5.1280000000000001	39.008000000000003
7023	3	0	5	1.4	4.7800000000000002	27.780000000000001	6.6920000000000002	38.892000000000003
7023	4	0	6	0.91000003	44.939999999999998	63.939999999999998	40.895000000000003	58.185000000000002
7024	1	0	0.29999999999999999	0.41999999	3.0699999999999998	21.07	1.2889999999999999	8.8490000000000002
7024	2	0	2.8999999999999999	0.28	7.8899999999999997	25.890000000000001	2.2090000000000001	7.2489999999999997
7024	3	0	3.8999999999999999	0.41	6.6699999999999999	23.670000000000002	2.7349999999999999	9.7050000000000001
7024	4	0	4.7000000000000002	0.27000001	14.67	33.670000000000002	3.9609999999999999	9.0909999999999993
7015	1	0	0.29999999999999999	0.88999999	1.77	38.439999999999998	1.575	34.212000000000003
7015	2	0	1.5	0.81	2	37.329999999999998	1.6200000000000001	30.236999999999998
7015	3	0	2	0.69	2.6800000000000002	45.350000000000001	1.849	31.292000000000002
7015	4	0	2.2999999999999998	0.47	2.6400000000000001	43.310000000000002	1.2410000000000001	20.356000000000002
7016	1	0	0.29999999999999999	0.97000003	2.1099999999999999	46.109999999999999	2.0470000000000002	44.726999999999997
7016	2	0	1.3	0.89999998	2.2599999999999998	43.600000000000001	2.0339999999999998	39.240000000000002
7016	3	0	1.8	0.75	2.79	42.789999999999999	2.093	32.093000000000004
7016	4	0	2	0.58999997	2.8300000000000001	47.5	1.6699999999999999	28.024999999999999
7017	1	0	0.29999999999999999	0.95999998	2.2999999999999998	42.969999999999999	2.2080000000000002	41.250999999999998
7017	2	0	1.3	0.87	2.75	41.420000000000002	2.3919999999999999	36.034999999999997
7017	3	0	1.8	0.75999999	3.0899999999999999	47.090000000000003	2.3479999999999999	35.787999999999997
7017	4	0	2	0.60000002	3.3599999999999999	46.030000000000001	2.016	27.617999999999999
7018	1	0	0.29999999999999999	0.92000002	2.1499999999999999	42.82	1.978	39.393999999999998
7018	2	0	1.3999999999999999	0.82999998	2.48	43.82	2.0579999999999998	36.371000000000002
7018	3	0	1.8999999999999999	0.69	3.7000000000000002	49.030000000000001	2.5529999999999999	33.831000000000003
7018	4	0	2.2000000000000002	0.52999997	8.1899999999999995	50.189999999999998	4.3410000000000002	26.600999999999999
7019	1	0	0.29999999999999999	0.75	2.3399999999999999	50.340000000000003	1.7549999999999999	37.755000000000003
7019	2	0	1.3999999999999999	0.68000001	4.2300000000000004	48.890000000000001	2.8759999999999999	33.244999999999997
7019	3	0	1.8	0.63	5.5499999999999998	53.549999999999997	3.496	33.737000000000002
7019	4	0	2.1000000000000001	0.55000001	8.4499999999999993	52.450000000000003	4.6470000000000002	28.847999999999999
7010	1	0	0.29999999999999999	0.94999999	3.6600000000000001	35.659999999999997	3.4769999999999999	33.877000000000002
7010	2	0	2	0.63	2.8300000000000001	36.829999999999998	1.7829999999999999	23.202999999999999
7010	3	0	2.6000000000000001	0.52999997	3.6230000000000002	41.622999999999998	1.9199999999999999	22.059999999999999
7010	4	0	3.1000000000000001	0.43000001	4.9809999999999999	46.981000000000002	2.1419999999999999	20.202000000000002
7011	1	0	0.29999999999999999	1.3	14.08	52.740000000000002	18.303999999999998	68.561999999999998
7011	2	0	1.8999999999999999	0.99000001	18.379999999999999	59.710000000000001	18.196000000000002	59.113
7011	3	0	2.5	0.88	5.0599999999999996	42.390000000000001	4.4530000000000003	37.302999999999997
7011	4	0	2.8999999999999999	0.80000001	7.2800000000000002	44.619999999999997	5.8239999999999998	35.695999999999998
7012	1	0	0.29999999999999999	1.36	19.399999999999999	48.060000000000002	26.384	65.361999999999995
7012	2	0	2	1.0599999	7.7400000000000002	37.740000000000002	8.2040000000000006	40.003999999999998
7012	3	0	2.6000000000000001	0.95999998	5.2800000000000002	38.619999999999997	5.069	37.075000000000003
7012	4	0	3.1000000000000001	0.87	6.6399999999999997	35.979999999999997	5.7770000000000001	31.303000000000001
7013	1	0	0.29999999999999999	1.2	5.3600000000000003	32.689999999999998	6.4320000000000004	39.228000000000002
7013	2	0	2	0.94	18.600000000000001	50.600000000000001	17.484000000000002	47.564
7013	3	0	2.6000000000000001	0.85000002	8.1099999999999994	43.450000000000003	6.8929999999999998	36.933
7013	4	0	3.1000000000000001	0.76999998	5.25	33.240000000000002	4.0430000000000001	25.594999999999999
7014	1	0	0.29999999999999999	1.15	3.2200000000000002	34.719999999999999	3.7029999999999998	39.927999999999997
7014	2	0	2	0.93000001	3.4399999999999999	34.439999999999998	3.1989999999999998	32.029000000000003
7014	3	0	2.6000000000000001	0.85000002	3.4399999999999999	32.439999999999998	2.9239999999999999	27.574000000000002
7014	4	0	3.1000000000000001	0.79000002	7.4800000000000004	38.479999999999997	5.9089999999999998	30.399000000000001
7006	1	0	0.29999999999999999	1.92	4.1100000000000003	24.780000000000001	7.891	47.578000000000003
7006	2	0	4.0999999999999996	1.64	10.869999999999999	40.869999999999997	17.827000000000002	67.027000000000001
7006	3	0	5.5	1.45	4.4500000000000002	51.75	6.4530000000000003	75.037000000000006
7006	4	0	6.7000000000000002	0.67000002	8.2300000000000004	33.560000000000002	5.5140000000000002	22.484999999999999
7007	1	0	0.29999999999999999	1.74	12.869999999999999	44.869999999999997	22.393999999999998	78.073999999999998
7007	2	0	3.7999999999999998	1.52	26.57	56.57	40.386000000000003	85.986000000000004
7007	3	0	5.0999999999999996	1.25	30.079999999999998	64.739999999999995	37.600000000000001	80.924999999999997
7007	4	0	6.2000000000000002	0.44999999	45.810000000000002	77.810000000000002	20.614999999999998	35.015000000000001
7008	1	0	0.29999999999999999	1.79	15.210000000000001	43.210000000000001	27.225999999999999	77.346000000000004
7008	2	0	3.2000000000000002	1.63	31.66	56.329999999999998	51.606000000000002	91.817999999999998
7008	3	0	4.2999999999999998	1.54	58.149999999999999	87.480000000000004	89.551000000000002	134.71899999999999
7008	4	0	5.2000000000000002	1.28	62.240000000000002	88.909999999999997	79.667000000000002	113.80500000000001
7009	1	0	0.29999999999999999	0.94999999	5.0899999999999999	27.760000000000002	4.8360000000000003	26.372
7009	2	0	3.5	0.92000002	17.170000000000002	44.5	15.795999999999999	40.939999999999998
7009	3	0	4.7000000000000002	0.69	32.979999999999997	60.310000000000002	22.756	41.613999999999997
7009	4	0	5.7000000000000002	0.47999999	79.75	109.75	38.280000000000001	52.68
7001	1	0	0.29999999999999999	1.7	2.23	33.560000000000002	3.7909999999999999	57.052
7001	2	0	1.3999999999999999	1.48	1.8500000000000001	37.850000000000001	2.738	56.018000000000001
7001	3	0	1.8	1.28	2.3799999999999999	37.039999999999999	3.0459999999999998	47.411000000000001
7001	4	0	2.1000000000000001	1.1	9.0600000000000005	33.719999999999999	9.9659999999999993	37.091999999999999
7002	1	0	0.29999999999999999	1.91	11.57	47.549999999999997	22.099	90.819999999999993
7002	2	0	3.7999999999999998	1.67	10.94	43.609999999999999	18.27	72.828999999999994
7002	3	0	5.0999999999999996	1.46	43.130000000000003	76.469999999999999	62.969999999999999	111.646
7002	4	0	6.2000000000000002	0.68000001	58.719999999999999	90.719999999999999	39.93	61.689999999999998
7003	1	0	0.29999999999999999	1.89	6.5999999999999996	47.939999999999998	12.474	90.606999999999999
7003	2	0	3.7999999999999998	1.5599999	31.170000000000002	67.840000000000003	48.625	105.83
7003	3	0	5.0999999999999996	1.27	87.170000000000002	136.5	110.706	173.35499999999999
7003	4	0	6.2000000000000002	0.38	183.25	222.58000000000001	69.635000000000005	84.579999999999998
7004	1	0	0.29999999999999999	1.77	11.24	53.240000000000002	19.895	94.234999999999999
7004	2	0	3.7000000000000002	1.64	44.340000000000003	78.340000000000003	72.718000000000004	128.47800000000001
7004	3	0	5	1.4400001	75.430000000000007	114.09999999999999	108.619	164.304
7004	4	0	6	0.28	224.97999999999999	264.31	62.994	74.007000000000005
7005	1	0	0.29999999999999999	0.89999998	6.7199999999999998	44.719999999999999	6.048	40.247999999999998
7005	2	0	3.2000000000000002	0.64999998	13.74	51.740000000000002	8.9309999999999992	33.631
7005	3	0	4.2000000000000002	0.56999999	17.059999999999999	46.390000000000001	9.7240000000000002	26.442
7005	4	0	5.0999999999999996	0.50999999	20.23	57.560000000000002	10.317	29.356000000000002
6996	1	0	0.29999999999999999	0.85000002	2.2999999999999998	40.299999999999997	1.9550000000000001	34.255000000000003
6996	2	0	1.2	0.81	2.5299999999999998	41.200000000000003	2.0489999999999999	33.372
6996	3	0	1.6000000000000001	0.72000003	2.5299999999999998	44.530000000000001	1.8220000000000001	32.061999999999998
6996	4	0	1.8	0.61000001	2.79	46.789999999999999	1.702	28.542000000000002
6997	1	0	0.29999999999999999	0.98000002	2.4199999999999999	45.079999999999998	2.3719999999999999	44.177999999999997
6997	2	0	1	0.92000002	2.8700000000000001	46.869999999999997	2.6400000000000001	43.119999999999997
6997	3	0	1.3999999999999999	0.83999997	3.0899999999999999	45.090000000000003	2.5960000000000001	37.875999999999998
6997	4	0	1.5	0.64999998	3.3599999999999999	46.689999999999998	2.1840000000000002	30.347999999999999
6998	1	0	0.29999999999999999	0.95999998	2.3799999999999999	43.710000000000001	2.2850000000000001	41.962000000000003
6998	2	0	1	0.87	2.4900000000000002	45.159999999999997	2.1659999999999999	39.289000000000001
6998	3	0	1.3999999999999999	0.81	2.9399999999999999	45.609999999999999	2.3809999999999998	36.944000000000003
6998	4	0	1.5	0.60000002	3.21	45.210000000000001	1.9259999999999999	27.126000000000001
6999	1	0	0.29999999999999999	0.98000002	2.4900000000000002	42.490000000000002	2.4399999999999999	41.640000000000001
6999	2	0	1.1000000000000001	0.89999998	2.8300000000000001	42.829999999999998	2.5470000000000002	38.546999999999997
6999	3	0	1.3999999999999999	0.85000002	3.5099999999999998	50.18	2.984	42.652999999999999
6999	4	0	1.6000000000000001	0.61000001	4.1100000000000003	47.450000000000003	2.5070000000000001	28.945
7000	1	0	0.29999999999999999	0.88	2.2999999999999998	44.299999999999997	2.024	38.984000000000002
7000	2	0	1	0.81	2.75	44.090000000000003	2.2280000000000002	35.713000000000001
7000	3	0	1.3999999999999999	0.75999999	3.5800000000000001	43.590000000000003	2.7210000000000001	33.128
7000	4	0	1.5	0.55000001	3.6600000000000001	45.659999999999997	2.0129999999999999	25.113
6991	1	0	0.29999999999999999	0.88999999	6.1900000000000004	42.189999999999998	5.5090000000000003	37.548999999999999
6991	2	0	1.3999999999999999	0.94	5.0599999999999996	37.719999999999999	4.7560000000000002	35.457000000000001
6991	3	0	1.8	0.87	5.21	38.539999999999999	4.5330000000000004	33.530000000000001
6991	4	0	2.1000000000000001	0.67000002	5.6600000000000001	62.990000000000002	3.7919999999999998	42.203000000000003
6992	1	0	0.29999999999999999	1.01	3.0600000000000001	33.719999999999999	3.0910000000000002	34.057000000000002
6992	2	0	1.1000000000000001	0.92000002	3.3999999999999999	33.399999999999999	3.1280000000000001	30.728000000000002
6992	3	0	1.52	0.79000002	4.2999999999999998	19.640000000000001	3.3969999999999998	15.516
6992	4	0	1.7	0.64999998	4.1500000000000004	20.149999999999999	2.698	13.098000000000001
6993	1	0	0.29999999999999999	0.98000002	3.96	29.300000000000001	3.8809999999999998	28.713999999999999
6993	2	0	1.1000000000000001	0.93000001	4.1500000000000004	32.82	3.8599999999999999	30.523
6993	3	0	1.5	0.85000002	3.9199999999999999	24.59	3.3319999999999999	20.902000000000001
6993	4	0	1.7	0.63	4.7199999999999998	33.380000000000003	2.9740000000000002	21.029
6994	1	0	0.29999999999999999	1.03	3.6200000000000001	28.960000000000001	3.7290000000000001	29.829000000000001
6994	2	0	1.3	0.94	3.7400000000000002	36.399999999999999	3.516	34.216000000000001
6994	3	0	1.7	0.79000002	4.8700000000000001	32.200000000000003	3.847	25.437999999999999
6994	4	0	1.8999999999999999	0.51999998	7.96	36.630000000000003	4.1390000000000002	19.047999999999998
6995	1	0	0.29999999999999999	0.94	2.9100000000000001	24.91	2.7349999999999999	23.414999999999999
6995	2	0	1.1000000000000001	0.88	2.8700000000000001	28.199999999999999	2.5259999999999998	24.815999999999999
6995	3	0	1.3999999999999999	0.81	3.4300000000000002	26.77	2.778	21.684000000000001
6995	4	0	1.6000000000000001	0.66000003	4.2599999999999998	28.93	2.8119999999999998	19.094000000000001
7040	1	0	0.29999999999999999	0.81999999	2.8100000000000001	39.310000000000002	2.3039999999999998	32.234000000000002
7040	2	0	1.6000000000000001	0.88999999	3.1499999999999999	38.149999999999999	2.8029999999999999	33.954000000000001
7040	3	0	2.2000000000000002	0.77999997	3	37	2.3399999999999999	28.859999999999999
7040	4	0	2.5	0.63	3.3300000000000001	39.829999999999998	2.0979999999999999	25.093
7041	1	0	0.29999999999999999	1	4.04	42.039999999999999	4.04	42.039999999999999
7041	2	0	1.3	0.91000003	4.2599999999999998	43.259999999999998	3.8769999999999998	39.366999999999997
7041	3	0	1.8	0.82999998	5.2999999999999998	42.799999999999997	4.399	35.524000000000001
7041	4	0	2	0.64999998	6.5199999999999996	50.020000000000003	4.2380000000000004	32.512999999999998
7042	1	0	0.29999999999999999	1.05	3.8100000000000001	45.810000000000002	4.0010000000000003	48.100999999999999
7042	2	0	1.3999999999999999	0.94999999	4.9299999999999997	45.43	4.6840000000000002	43.158000000000001
7042	3	0	1.8	0.82999998	5.4800000000000004	41.979999999999997	4.548	34.843000000000004
7042	4	0	2.1000000000000001	0.66000003	6.1100000000000003	44.609999999999999	4.0330000000000004	29.443000000000001
7043	1	0	0.29999999999999999	1.0599999	4.9299999999999997	40.43	5.226	42.856000000000002
6773	3	0	4	1.14	10.94	59.939999999999998	12.472	68.331999999999994
6773	4	0	4.7999999999999998	0.76999998	14.779999999999999	66.780000000000001	11.381	51.420999999999999
6759	1	0	0.29999999999999999	1.45	1.1100000000000001	10.109999999999999	1.6100000000000001	14.66
6759	2	0	2.7999999999999998	1.09	1.5900000000000001	10.59	1.7330000000000001	11.542999999999999
6759	3	0	3.7000000000000002	0.77999997	2	10	1.5600000000000001	7.7999999999999998
6759	4	0	4.3499999999999996	0.52999997	2.2000000000000002	7.4500000000000002	1.1659999999999999	3.948
6760	1	0	0.29999999999999999	1.6900001	1.96	13.710000000000001	3.3119999999999998	23.170000000000002
6760	2	0	3	1.4	3.02	10.77	4.2279999999999998	15.077999999999999
6760	3	0	4	1.16	3.1699999999999999	10.17	3.677	11.797000000000001
6760	4	0	4.75	0.74000001	5.7999999999999998	12.800000000000001	4.2919999999999998	9.4719999999999995
6761	1	0	0.29999999999999999	1.61	3.1899999999999999	13.69	5.1360000000000001	22.041
6761	2	0	3.1000000000000001	1.3099999	4.6900000000000004	7.6900000000000004	6.1440000000000001	10.074
6761	3	0	4.0999999999999996	1.15	7	17	8.0500000000000007	19.550000000000001
6761	4	0	4.8499999999999996	0.88	11.33	25.579999999999998	9.9700000000000006	22.510000000000002
6762	1	0	0.29999999999999999	1.51	1.8	12.550000000000001	2.718	18.951000000000001
6762	2	0	3.1000000000000001	1.0700001	2.6499999999999999	14.15	2.835	15.141
6762	3	0	4.2000000000000002	0.95999998	3.1899999999999999	12.19	3.0619999999999998	11.702
6762	4	0	4.9500000000000002	0.69999999	7.1699999999999999	23.170000000000002	5.0190000000000001	16.219000000000001
6755	1	0	0.29999999999999999	0.91000003	0.69999999999999996	12.199999999999999	0.63700000000000001	11.102
6755	2	0	2	0.63999999	0.81999999999999995	12.32	0.52500000000000002	7.8849999999999998
6755	3	0	2.7000000000000002	0.37	1.28	13.779999999999999	0.47399999999999998	5.0990000000000002
6755	4	0	3.3500000000000001	0.14	6.1500000000000004	9.4000000000000004	0.86099999999999999	1.3160000000000001
6756	1	0	0.29999999999999999	1.6	2.3700000000000001	15.869999999999999	3.7919999999999998	25.391999999999999
6756	2	0	2.5	1.4299999	2.6499999999999999	16.649999999999999	3.79	23.809000000000001
6756	3	0	3.3999999999999999	1.3200001	6.2199999999999998	8.9700000000000006	8.2100000000000009	11.84
6756	4	0	4.3499999999999996	0.91000003	7.0199999999999996	21.52	6.3879999999999999	19.582999999999998
6757	1	0	0.29999999999999999	1.49	1.4299999999999999	13.43	2.1309999999999998	20.010999999999999
6757	2	0	2.7000000000000002	1.29	3.3900000000000001	12.640000000000001	4.3730000000000002	16.306000000000001
6757	3	0	3.6000000000000001	1.1900001	4.8899999999999997	14.890000000000001	5.819	17.719000000000001
6757	4	0	4.4500000000000002	0.81	13.5	24.5	10.935	19.844999999999999
6758	1	0	0.29999999999999999	1.38	1.22	12.470000000000001	1.6839999999999999	17.209
6758	2	0	2.7000000000000002	1.14	1.54	15.539999999999999	1.756	17.716000000000001
6758	3	0	3.6000000000000001	1.03	2.52	16.02	2.5960000000000001	16.501000000000001
6758	4	0	4.4500000000000002	0.52999997	9	20.75	4.7699999999999996	10.997
6750	1	0	0.29999999999999999	1.09	2.71	40.909999999999997	2.9540000000000002	44.591999999999999
6750	2	0	2	0.91000003	2.8500000000000001	26.859999999999999	2.593	24.443000000000001
6750	3	0	2.6000000000000001	0.81	2.9100000000000001	30.510000000000002	2.3570000000000002	24.713000000000001
6750	4	0	3.3500000000000001	0.41999999	3.3999999999999999	47.200000000000003	1.4279999999999999	19.824000000000002
6751	1	0	0.29999999999999999	1.3200001	3.2200000000000002	28.420000000000002	4.25	37.514000000000003
6751	2	0	2.1000000000000001	1.12	3.4399999999999999	36.68	3.8530000000000002	41.082000000000001
6751	3	0	2.7999999999999998	1.05	3.9100000000000001	30.710000000000001	4.1050000000000004	32.246000000000002
6751	4	0	3.5499999999999998	0.68000001	5.1200000000000001	27.920000000000002	3.4820000000000002	18.986000000000001
6752	1	0	0.29999999999999999	1.3200001	4	35.600000000000001	5.2800000000000002	46.991999999999997
6752	2	0	2.2999999999999998	1.15	4.8899999999999997	26.289999999999999	5.6230000000000002	30.233000000000001
6752	3	0	3	1.08	5.8399999999999999	39.240000000000002	6.3070000000000004	42.378999999999998
6752	4	0	3.7000000000000002	0.67000002	17.329999999999998	51.530000000000001	11.611000000000001	34.524999999999999
6753	1	0	0.29999999999999999	1.27	3.54	25.949999999999999	4.4960000000000004	32.957000000000001
6753	2	0	2.2000000000000002	1.0700001	3.9100000000000001	28.91	4.1840000000000002	30.934000000000001
6753	3	0	3	0.95999998	3.9500000000000002	31.960000000000001	3.7919999999999998	30.681999999999999
6753	4	0	3.6499999999999999	0.60000002	5.8899999999999997	24.289999999999999	3.5339999999999998	14.574
6754	1	0	0.29999999999999999	1.21	3.29	20.489999999999998	3.9809999999999999	24.792999999999999
6754	2	0	2.2999999999999998	1.12	3.5099999999999998	22.309999999999999	3.931	24.986999999999998
6754	3	0	3	1	3.9100000000000001	20.91	3.9100000000000001	20.91
6754	4	0	3.7999999999999998	0.72000003	4.5300000000000002	51.729999999999997	3.262	37.246000000000002
6746	1	0	0.29999999999999999	1.02	4.3200000000000003	48.32	4.4059999999999997	49.286000000000001
6746	2	0	1.3999999999999999	0.77999997	4.2400000000000002	53.240000000000002	3.3069999999999999	41.527000000000001
6746	3	0	1.8	0.64999998	5.2999999999999998	57.549999999999997	3.4449999999999998	37.408000000000001
6746	4	0	2.25	0.5	7.4000000000000004	57.899999999999999	3.7000000000000002	28.949999999999999
6747	1	0	0.29999999999999999	1.73	12.34	69.840000000000003	21.347999999999999	120.82299999999999
6747	2	0	3.3999999999999999	1.47	6.4199999999999999	58.670000000000002	9.4369999999999994	86.245000000000005
6747	3	0	4.5999999999999996	1.14	4.54	61.039999999999999	5.1760000000000002	69.585999999999999
6747	4	0	5.6500000000000004	0.81999999	5.6200000000000001	60.619999999999997	4.6079999999999997	49.707999999999998
6748	1	0	0.29999999999999999	1.88	4.7000000000000002	55.539999999999999	8.8360000000000003	104.41500000000001
6748	2	0	3.6000000000000001	1.65	5.5599999999999996	62.560000000000002	9.1739999999999995	103.224
6748	3	0	4.7999999999999998	1.38	6.5	56.25	8.9700000000000006	77.625
6748	4	0	5.9500000000000002	1.03	14.539999999999999	67.040000000000006	14.976000000000001	69.051000000000002
6749	1	0	0.29999999999999999	1.5	4.0999999999999996	61.100000000000001	6.1500000000000004	91.650000000000006
6749	2	0	3.3999999999999999	1.38	5.2999999999999998	57.049999999999997	7.3140000000000001	78.728999999999999
6749	3	0	4.5999999999999996	1.2	6.2599999999999998	54.509999999999998	7.5119999999999996	65.412000000000006
6749	4	0	5.6500000000000004	0.94999999	16.739999999999998	69.239999999999995	15.903	65.778000000000006
6742	1	0	0.29999999999999999	1.61	3.2999999999999998	41.049999999999997	5.3129999999999997	66.090000000000003
6742	2	0	2.5	1.51	3.7000000000000002	45.700000000000003	5.5869999999999997	69.007000000000005
6742	3	0	3.3999999999999999	1.35	4.5599999999999996	49.060000000000002	6.1559999999999997	66.230999999999995
6742	4	0	4	0.69	7.8600000000000003	49.859999999999999	5.423	34.402999999999999
6743	1	0	0.29999999999999999	1.67	3.6600000000000001	38.659999999999997	6.1120000000000001	64.561999999999998
6743	2	0	2.5	1.67	4.5999999999999996	48.850000000000001	7.6820000000000004	81.578999999999994
6743	3	0	3.2999999999999998	1.33	8.0600000000000005	42.810000000000002	10.720000000000001	56.936999999999998
6743	4	0	3.8999999999999999	0.79000002	65.019999999999996	109.02	51.366	86.126000000000005
6744	1	0	0.29999999999999999	1.41	3.6800000000000002	34.18	5.1890000000000001	48.194000000000003
6744	2	0	2.6000000000000001	1.3099999	4.4400000000000004	36.439999999999998	5.8159999999999998	47.735999999999997
6744	3	0	3.5	1.16	5.0800000000000001	39.079999999999998	5.8929999999999998	45.332999999999998
6744	4	0	4.2000000000000002	0.60000002	9.3300000000000001	45.549999999999997	5.5979999999999999	27.329999999999998
6745	1	0	0.29999999999999999	1.23	3.2799999999999998	44.280000000000001	4.0339999999999998	54.463999999999999
6745	2	0	2.6000000000000001	1.26	3.8599999999999999	47.359999999999999	4.8639999999999999	59.673999999999999
6745	3	0	3.5	1.3099999	4.1500000000000004	39.399999999999999	5.4370000000000003	51.613999999999997
6745	4	0	4.2000000000000002	0.98000002	5.6799999999999997	41.18	5.5659999999999998	40.356000000000002
6740	1	0	0.29999999999999999	1.2	5.6799999999999997	86.180000000000007	6.8159999999999998	103.416
6740	2	0	4.7000000000000002	1.27	6.2999999999999998	99.799999999999997	8.0009999999999994	126.746
6740	3	0	6.2000000000000002	1.01	8.3599999999999994	98.859999999999999	8.4440000000000008	99.849000000000004
6740	4	0	7.75	0.60000002	14.58	101.58	8.7479999999999993	60.948
6741	1	0	0.29999999999999999	0.83999997	6.0599999999999996	85.060000000000002	5.0899999999999999	71.450000000000003
6741	2	0	4.2000000000000002	1.0599999	8.6999999999999993	191.37	9.2219999999999995	202.852
6741	3	0	5.5999999999999996	0.83999997	13.279999999999999	101.95	11.154999999999999	85.638000000000005
6741	4	0	6.9500000000000002	0.74000001	20.960000000000001	96.629999999999995	15.51	71.506
13130	1	0	0.29999999999999999	1.677	2.827	17.466999999999999	4.7409999999999997	29.292000000000002
13130	2	0	3.2000000000000002	1.726	2.4289999999999998	27.248999999999999	4.1920000000000002	47.031999999999996
13130	3	0	4.2999999999999998	1.36	2.2709999999999999	12.010999999999999	3.089	16.335000000000001
13130	4	0	4.9000000000000004	1.261	2.964	15.023999999999999	3.738	18.945
13130	5	0	5.2000000000000002	0.71200001	3.016	21.675999999999998	2.1469999999999998	15.433
13129	1	0	0.29999999999999999	1.876	3.4889999999999999	17.349	6.5449999999999999	32.546999999999997
13129	2	0	4	1.733	2.327	27.466999999999999	4.0330000000000004	47.600000000000001
13129	3	0	5.4000000000000004	1.576	2.2949999999999999	18.934999999999999	3.617	29.841999999999999
13129	4	0	6	1.506	2.6200000000000001	23.02	3.9460000000000002	34.667999999999999
13129	5	0	6.5	1.344	2.6579999999999999	24.498000000000001	3.5720000000000001	32.924999999999997
13128	1	0	0.29999999999999999	1.955	2.5419999999999998	24.702000000000002	4.9699999999999998	48.292000000000002
13128	2	0	3.8999999999999999	1.745	3.2349999999999999	19.274999999999999	5.6449999999999996	33.634999999999998
13128	3	0	5.2000000000000002	1.624	3.0129999999999999	20.893000000000001	4.8929999999999998	33.93
13128	4	0	5.9000000000000004	1.474	3.1779999999999999	21.218	4.6840000000000002	31.274999999999999
13128	5	0	6.2999999999999998	1.319	3.5470000000000002	22.007000000000001	4.6779999999999999	29.027000000000001
13127	1	0	0.29999999999999999	1.883	2.3839999999999999	19.884	4.4889999999999999	37.442
13127	2	0	3.7999999999999998	1.699	3.7130000000000001	22.013000000000002	6.3079999999999998	37.399999999999999
13127	3	0	5	1.554	3.3639999999999999	21.884	5.2279999999999998	34.008000000000003
13127	4	0	5.7000000000000002	1.409	3.4620000000000002	24.402000000000001	4.8780000000000001	34.381999999999998
13127	5	0	6.0999999999999996	1.104	4.6779999999999999	25.178000000000001	5.165	27.797000000000001
13126	1	0	0.29999999999999999	1.7309999	2.8420000000000001	21.821999999999999	4.9199999999999999	37.774000000000001
13126	2	0	3.7000000000000002	1.568	4.5910000000000002	21.291	7.1989999999999998	33.384
13126	3	0	4.9000000000000004	1.534	6.2400000000000002	27.16	9.5719999999999992	41.662999999999997
13126	4	0	5.5	1.288	10.505000000000001	31.045000000000002	13.529999999999999	39.985999999999997
13126	5	0	5.9000000000000004	1.031	21.286999999999999	41.406999999999996	21.946999999999999	42.691000000000003
12921	1	0	0.29999999999999999	1.002	0.96699999999999997	9.8870000000000005	0.96899999999999997	9.907
12921	2	0	1.3999999999999999	0.903	0.93300000000000005	9.6530000000000005	0.84199999999999997	8.7170000000000005
12921	3	0	1.8	0.77999997	1.204	8.4239999999999995	0.93899999999999995	6.5709999999999997
12921	4	0	2.1000000000000001	0.63700002	0.81599999999999995	9.1359999999999992	0.52000000000000002	5.8200000000000003
12922	1	0	0.29999999999999999	1.382	0.36899999999999999	9.9290000000000003	0.51000000000000001	13.722
12922	2	0	2.2000000000000002	1.268	1.105	10.105	1.401	12.813000000000001
12922	3	0	2.8999999999999999	1.193	0.875	8.8550000000000004	1.044	10.564
12922	4	0	3.3999999999999999	0.87900001	2.851	11.311	2.5059999999999998	9.9420000000000002
12923	1	0	0.29999999999999999	1.234	1.329	14.349	1.6399999999999999	17.707000000000001
12923	2	0	2.2000000000000002	1.1109999	3.871	11.170999999999999	4.3010000000000002	12.411
12923	3	0	2.8999999999999999	0.991	6.2759999999999998	14.356	6.2199999999999998	14.227
12923	4	0	3.3999999999999999	0.81699997	26.044	34.484000000000002	21.277999999999999	28.172999999999998
12924	1	0	0.29999999999999999	1.107	0.83299999999999996	7.8929999999999998	0.92200000000000004	8.7379999999999995
12924	2	0	2	1.0779999	1.647	13.727	1.7749999999999999	14.798
12924	3	0	2.7000000000000002	0.91500002	2.8820000000000001	11.002000000000001	2.637	10.067
12924	4	0	3.2000000000000002	0.69300002	10.523999999999999	20.763999999999999	7.2930000000000001	14.388999999999999
12925	1	0	0.29999999999999999	0.97899997	0.66900000000000004	8.6690000000000005	0.65500000000000003	8.4870000000000001
12925	2	0	1.8999999999999999	0.97299999	1.0780000000000001	8.0180000000000007	1.0489999999999999	7.8019999999999996
12925	3	0	2.5	0.88599998	2.2549999999999999	9.4149999999999991	1.998	8.3420000000000005
12925	4	0	2.8999999999999999	0.63999999	2.8069999999999999	10.407	1.796	6.6600000000000001
12200	1	0	0.29999999999999999	1.1670001	2.9670000000000001	21.227	3.4620000000000002	24.771999999999998
12200	2	0	2.1000000000000001	1.054	1.956	18.376000000000001	2.0619999999999998	19.367999999999999
12200	3	0	2.7999999999999998	0.60299999	2.8199999999999998	23	1.7	13.869
12200	4	0	3.2000000000000002	0.043000001	3.444	22.884	0.14799999999999999	0.98399999999999999
12199	1	0	0.29999999999999999	1.597	1.905	18.824999999999999	3.0419999999999998	30.064
12199	2	0	2.7000000000000002	1.436	2.5449999999999999	20.305	3.6549999999999998	29.158000000000001
12199	3	0	3.6000000000000001	1.283	2.4420000000000002	20.341999999999999	3.133	26.099
12199	4	0	4.2000000000000002	0.62099999	3.2799999999999998	21.739999999999998	2.0369999999999999	13.500999999999999
12198	1	0	0.29999999999999999	1.375	2.145	19.305	2.9489999999999998	26.544
12198	2	0	3.3999999999999999	1.511	3.6200000000000001	21.620000000000001	5.4699999999999998	32.667999999999999
12198	3	0	4.5	1.3380001	14.147	32.527000000000001	18.928999999999998	43.521000000000001
12198	4	0	5.2999999999999998	0.96899998	158.90700000000001	176.74700000000001	153.98099999999999	171.268
12197	1	0	0.29999999999999999	1.273	2.6150000000000002	19.614999999999998	3.3290000000000002	24.969999999999999
12197	2	0	3.2000000000000002	1.332	10.545	29.565000000000001	14.045999999999999	39.381
12197	3	0	4.2000000000000002	1.133	25.885000000000002	41.664999999999999	29.327999999999999	47.206000000000003
12197	4	0	5	0.63999999	152.858	169.178	97.828999999999994	108.274
12196	1	0	0.29999999999999999	1.196	2.0779999999999998	19.858000000000001	2.4849999999999999	23.75
12196	2	0	2.7999999999999998	0.995	2.7269999999999999	21.146999999999998	2.7130000000000001	21.041
12196	3	0	3.7999999999999998	0.80699998	4.1710000000000003	26.631	3.3660000000000001	21.491
12196	4	0	4.5	0.76499999	11.484999999999999	33.965000000000003	8.7859999999999996	25.983000000000001
11167	1	0	0.29999999999999999	0.92000002	1.458	16.158000000000001	1.341	14.865
11167	2	0	0.90000000000000002	0.736	1.256	16.475999999999999	0.92400000000000004	12.125999999999999
11167	3	0	1.2	0.53600001	2.0249999999999999	18.565000000000001	1.085	9.9510000000000005
11167	4	0	1.3999999999999999	0.38100001	1.609	15.468999999999999	0.61299999999999999	5.8940000000000001
11166	1	0	0.29999999999999999	1.28	1.4239999999999999	13.504	1.823	17.285
11166	2	0	1.8999999999999999	1.01	1.5129999999999999	13.093	1.528	13.224
11166	3	0	2.5	0.82099998	1.5129999999999999	15.712999999999999	1.242	12.9
11166	4	0	2.7999999999999998	0.58700001	2.7149999999999999	14.815	1.5940000000000001	8.6959999999999997
11165	1	0	0.29999999999999999	1.4299999	1.5980000000000001	13.018000000000001	2.2850000000000001	18.616
11165	2	0	2.2999999999999998	1.3	2.016	13.816000000000001	2.621	17.960999999999999
11165	3	0	3.1000000000000001	1.1109999	4.218	18.038	4.6859999999999999	20.039999999999999
11165	4	0	3.6000000000000001	0.88599998	33.371000000000002	47.091000000000001	29.567	41.722999999999999
11164	1	0	0.29999999999999999	1.3890001	1.605	13.824999999999999	2.2290000000000001	19.202999999999999
11164	2	0	2.2999999999999998	1.242	2.9870000000000001	14.807	3.71	18.390000000000001
11164	3	0	3	1.136	5.6420000000000003	13.321999999999999	6.4089999999999998	15.134
11164	4	0	3.5	0.83600003	53.781999999999996	74.382000000000005	44.962000000000003	62.183
11163	1	0	0.29999999999999999	1.387	1.8580000000000001	12.178000000000001	2.577	16.890999999999998
11163	2	0	2	1.324	0.65300000000000002	12.913	0.86499999999999999	17.097000000000001
11163	3	0	2.7000000000000002	1.104	1.9199999999999999	13.359999999999999	2.1200000000000001	14.749000000000001
7046	2	0	4.5999999999999996	1.77	0.84999999999999998	9.8499999999999996	1.504	17.434000000000001
7046	3	0	6.2000000000000002	1.63	2.4399999999999999	9.9399999999999995	3.9769999999999999	16.202000000000002
7046	4	0	7.5	0.83999997	14.960000000000001	26.960000000000001	12.566000000000001	22.646000000000001
7047	1	0	0.29999999999999999	1.84	0.81000000000000005	9.8100000000000005	1.49	18.050000000000001
7047	2	0	4	1.74	1.96	12.460000000000001	3.4100000000000001	21.68
7047	3	0	5.4000000000000004	1.47	3.9300000000000002	17.93	5.7770000000000001	26.356999999999999
7047	4	0	6.5	1.3200001	15.699999999999999	25.199999999999999	20.724	33.264000000000003
7048	1	0	0.29999999999999999	1.73	6.04	21.539999999999999	10.449	37.264000000000003
7048	2	0	3.3999999999999999	1.61	12.85	30.850000000000001	20.689	49.668999999999997
7048	3	0	4.5999999999999996	1.24	101.83	113.33	126.26900000000001	140.529
7048	4	0	5.5	0.14	268.44	285.44	37.582000000000001	39.962000000000003
7049	1	0	0.29999999999999999	1.2	25.440000000000001	36.439999999999998	30.527999999999999	43.728000000000002
7049	2	0	3	1.21	53.219999999999999	67.719999999999999	64.396000000000001	81.941000000000003
7049	3	0	4	1.02	92.519999999999996	109.52	94.370000000000005	111.70999999999999
7049	4	0	4.7999999999999998	0.37	174.59	188.09	64.597999999999999	69.593000000000004
13148	1	0	0.29999999999999999	1.413	6.9359999999999999	34.896000000000001	9.8010000000000002	49.308
13148	2	0	3.2000000000000002	1.201	10.371	37.511000000000003	12.456	45.051000000000002
13148	3	0	4.2000000000000002	1.1059999	13.385	43.125	14.804	47.695999999999998
13148	4	0	4.7999999999999998	0.96200001	18.742000000000001	47.302	18.030000000000001	45.505000000000003
13148	5	0	5.0999999999999996	0.40700001	47.911000000000001	74.450999999999993	19.5	30.302
13149	1	0	0.29999999999999999	1.3660001	10.965	33.725000000000001	14.978	46.067999999999998
13149	2	0	3	1.278	16.393000000000001	45.052999999999997	20.949999999999999	57.578000000000003
13149	3	0	4	1.225	23.515000000000001	54.354999999999997	28.806000000000001	66.584999999999994
13149	4	0	4.5	1.0140001	42.502000000000002	74.822000000000003	43.097000000000001	75.870000000000005
13149	5	0	4.7999999999999998	0.90100002	64.649000000000001	93.849000000000004	58.249000000000002	84.558000000000007
13150	1	0	0.29999999999999999	1.4859999	9.2690000000000001	45.109000000000002	13.773999999999999	67.031999999999996
13150	2	0	3.1000000000000001	1.295	28.145	54.465000000000003	36.448	70.531999999999996
13150	3	0	4.2000000000000002	1.201	47.198	72.938000000000002	56.685000000000002	87.599000000000004
13150	4	0	4.7000000000000002	0.98100001	97.947000000000003	125.307	96.085999999999999	122.926
13150	5	0	5	0.44100001	147.06899999999999	177.66900000000001	64.856999999999999	78.352000000000004
13151	1	0	0.29999999999999999	1.5829999	8.9090000000000007	39.948999999999998	14.103	63.238999999999997
13151	2	0	2.8999999999999999	1.37	23.602	56.802	32.335000000000001	77.819000000000003
13151	3	0	3.8999999999999999	1.1619999	38.375	72.314999999999998	44.591999999999999	84.030000000000001
13151	4	0	4.7000000000000002	0.87699997	106.935	137.995	93.781999999999996	121.02200000000001
13152	1	0	0.29999999999999999	1.533	6.96	45.600000000000001	10.67	69.905000000000001
13152	2	0	3	1.373	13.744999999999999	53.005000000000003	18.872	72.775999999999996
13152	3	0	4	1.235	23.521999999999998	48.981999999999999	29.050000000000001	60.493000000000002
13152	4	0	4.5	1.044	42.835999999999999	66.855999999999995	44.720999999999997	69.798000000000002
13152	5	0	4.7999999999999998	0.954	61.453000000000003	88.692999999999998	58.625999999999998	84.613
12285	1	0	0.29999999999999999	0.86500001	0.61499999999999999	4.8550000000000004	0.53200000000000003	4.2000000000000002
12285	2	0	1.1000000000000001	0.75999999	0.60399999999999998	4.0640000000000001	0.45900000000000002	3.089
12285	3	0	1.7	0.565	0.79600000000000004	4.9359999999999999	0.45000000000000001	2.7890000000000001
12284	1	0	0.29999999999999999	0.91299999	0.81100000000000005	4.851	0.73999999999999999	4.4290000000000003
12284	2	0	1.1000000000000001	0.81199998	1.26	5.4000000000000004	1.0229999999999999	4.3849999999999998
12284	3	0	1.6000000000000001	0.59100002	2.7709999999999999	7.5309999999999997	1.6379999999999999	4.4509999999999996
12283	1	0	0.29999999999999999	0.90399998	0.78200000000000003	5.1619999999999999	0.70699999999999996	4.6660000000000004
12283	2	0	1	0.86400002	1.4239999999999999	6.1440000000000001	1.23	5.3079999999999998
12283	3	0	1.5	0.727	2.589	7.5289999999999999	1.8819999999999999	5.4740000000000002
12282	1	0	0.29999999999999999	0.86699998	0.92500000000000004	5.7850000000000001	0.80200000000000005	5.016
12282	2	0	1.2	0.76999998	1.105	5.8650000000000002	0.85099999999999998	4.516
12282	3	0	1.6000000000000001	0.67400002	1.22	6	0.82199999999999995	4.0439999999999996
12282	4	0	1.8	0.56	1.931	7.2510000000000003	1.081	4.0609999999999999
12281	1	0	0.29999999999999999	0.89899999	0.64200000000000002	5.5620000000000003	0.57699999999999996	5
12281	2	0	1	0.84500003	0.79100000000000004	6.351	0.66800000000000004	5.367
12281	3	0	1.5	0.676	1.1839999999999999	7.3239999999999998	0.80000000000000004	4.9509999999999996
12215	1	0	0.29999999999999999	1.015	1.4199999999999999	16.48	1.4410000000000001	16.727
12215	2	0	2	0.99000001	1.607	17.106999999999999	1.591	16.936
12215	3	0	2.7000000000000002	0.80400002	1.651	13.531000000000001	1.327	10.879
12215	4	0	3.2000000000000002	0.442	2.4470000000000001	17.887	1.0820000000000001	7.9059999999999997
12214	1	0	0.29999999999999999	1.29	1.5249999999999999	14.445	1.9670000000000001	18.634
12214	2	0	2.3999999999999999	1.133	2.2890000000000001	17.009	2.593	19.271000000000001
12214	3	0	3.2000000000000002	1.031	3.9689999999999999	16.509	4.0919999999999996	17.021000000000001
12214	4	0	3.7999999999999998	0.43200001	40.259999999999998	54.140000000000001	17.391999999999999	23.388000000000002
12213	1	0	0.29999999999999999	1.256	3.0710000000000002	16.071000000000002	3.8570000000000002	20.184999999999999
12213	2	0	2.2999999999999998	1.169	6.9249999999999998	22.704999999999998	8.0950000000000006	26.542000000000002
12213	3	0	3	0.99699998	17.196000000000002	28.716000000000001	17.143999999999998	28.629999999999999
12213	4	0	3.6000000000000001	0.84299999	39.305	55.125	33.134	46.469999999999999
12212	1	0	0.29999999999999999	1.261	2.996	19.335999999999999	3.778	24.382999999999999
12212	2	0	2.2000000000000002	1.201	5.984	22.364000000000001	7.1870000000000003	26.859000000000002
12212	3	0	3	1.073	11.722	26.622	12.577999999999999	28.565000000000001
12212	4	0	3.5	0.98100001	26.856000000000002	43.375999999999998	26.346	42.552
12211	1	0	0.29999999999999999	1.245	1.7070000000000001	17.547000000000001	2.125	21.846
12211	2	0	2.3999999999999999	1.148	1.9399999999999999	15.699999999999999	2.2269999999999999	18.024000000000001
12211	3	0	3.2000000000000002	0.995	2.907	18.247	2.8919999999999999	18.155999999999999
12211	4	0	3.7999999999999998	0.727	8.3780000000000001	25.097999999999999	6.0910000000000002	18.245999999999999
11050	1	0	0.20000000000000001	1.022	2.96	22.34	3.0249999999999999	22.831
11050	2	0	2.1000000000000001	0.94	2.762	21.962	2.5960000000000001	20.643999999999998
11050	3	0	2.7999999999999998	0.85299999	3.1309999999999998	22.530999999999999	2.6709999999999998	19.219000000000001
11050	4	0	3.2999999999999998	0.62300003	3.3959999999999999	21.536000000000001	2.1160000000000001	13.417
11049	1	0	0.20000000000000001	1.2970001	3.4950000000000001	21.675000000000001	4.5330000000000004	28.111999999999998
11049	2	0	2.5	1.1720001	7.5350000000000001	26.695	8.8309999999999995	31.286999999999999
11049	3	0	3.3999999999999999	1.01	8.8179999999999996	28.577999999999999	8.9060000000000006	28.864000000000001
11049	4	0	4	0.741	23.282	43.222000000000001	17.251999999999999	32.027999999999999
11048	1	0	0.20000000000000001	1.194	4.7759999999999998	25.436	5.7030000000000003	30.370999999999999
11048	2	0	2.2999999999999998	1.174	6.04	27.280000000000001	7.0910000000000002	32.027000000000001
11048	3	0	3.1000000000000001	0.991	11.736000000000001	31.675999999999998	11.630000000000001	31.390999999999998
11048	4	0	3.7000000000000002	0.85000002	21.585000000000001	40.604999999999997	18.347000000000001	34.514000000000003
11047	1	0	0.20000000000000001	1.285	3.5960000000000001	23.335999999999999	4.6210000000000004	29.986999999999998
11047	2	0	2.3999999999999999	1.1569999	7.04	27.219999999999999	8.1449999999999996	31.494
11047	3	0	3.2000000000000002	1.0190001	11.973000000000001	31.713000000000001	12.199999999999999	32.316000000000003
11047	4	0	3.7999999999999998	0.787	21.524000000000001	44.264000000000003	16.939	34.835999999999999
11046	1	0	0.20000000000000001	1.344	2.851	21.291	3.8319999999999999	28.614999999999998
11046	2	0	2.2999999999999998	1.2130001	3.4529999999999998	23.952999999999999	4.1879999999999997	29.055
11046	3	0	3	1.1289999	4.242	24.981999999999999	4.7889999999999997	28.204999999999998
11046	4	0	3.6000000000000001	0.89899999	11.880000000000001	34.18	10.68	30.728000000000002
11045	1	0	0.20000000000000001	0.99000001	1.0980000000000001	12.298	1.087	12.175000000000001
11045	2	0	1.8	0.898	1.4159999999999999	13.375999999999999	1.272	12.012
11045	3	0	2.3999999999999999	0.76499999	1.22	16.379999999999999	0.93300000000000005	12.531000000000001
11045	4	0	2.7999999999999998	0.54100001	1.651	14.851000000000001	0.89300000000000002	8.0340000000000007
11044	1	0	0.20000000000000001	1.227	1.675	14.175000000000001	2.0550000000000002	17.393000000000001
11044	2	0	2.2000000000000002	1.131	2.6000000000000001	16.600000000000001	2.9409999999999998	18.774999999999999
11044	3	0	2.8999999999999999	1.0319999	3.2639999999999998	16.064	3.3679999999999999	16.577999999999999
11044	4	0	3.3999999999999999	0.89300001	4.9160000000000004	18.256	4.3899999999999997	16.303000000000001
11043	1	0	0.20000000000000001	1.244	1.909	14.269	2.375	17.751000000000001
11043	2	0	2.2000000000000002	1.1720001	3.6000000000000001	16.68	4.2190000000000003	19.548999999999999
11043	3	0	3	1.022	7.593	20.693000000000001	7.7599999999999998	21.148
11043	4	0	3.5	0.80400002	16.606999999999999	29.786999999999999	13.352	23.949000000000002
11042	1	0	0.20000000000000001	1.317	2.0950000000000002	15.195	2.7589999999999999	20.012
11042	2	0	2.3999999999999999	1.1109999	3.496	19.756	3.8839999999999999	21.949000000000002
11042	3	0	3.2000000000000002	1.002	5.4669999999999996	18.966999999999999	5.4779999999999998	19.004999999999999
11042	4	0	3.7999999999999998	0.787	14.855	31.254999999999999	11.691000000000001	24.597999999999999
11041	1	0	0.5	1.332	1.5580000000000001	17.498000000000001	2.0750000000000002	23.306999999999999
11041	2	0	2.2000000000000002	1.227	2.089	16.649000000000001	2.5630000000000002	20.428000000000001
11041	3	0	2.8999999999999999	1.077	3.5049999999999999	18.805	3.7749999999999999	20.253
11041	4	0	3.3999999999999999	0.78500003	16.507000000000001	30.227	12.958	23.728000000000002
11055	1	0	0.20000000000000001	1.02	1.2450000000000001	10.145	1.27	10.348000000000001
11055	2	0	1.3999999999999999	0.93300003	1.5069999999999999	10.167	1.4059999999999999	9.4860000000000007
11055	3	0	1.8999999999999999	0.80400002	1.6819999999999999	12.242000000000001	1.3520000000000001	9.843
11055	4	0	2.2000000000000002	0.61500001	2.7440000000000002	11.484	1.6879999999999999	7.0629999999999997
11054	1	0	0.20000000000000001	1.054	0.94499999999999995	9.4250000000000007	0.996	9.9339999999999993
11054	2	0	1.3999999999999999	0.88599998	1.704	9.2439999999999998	1.51	8.1899999999999995
11054	3	0	1.8999999999999999	0.77100003	3.3090000000000002	14.109	2.5510000000000002	10.878
11054	4	0	2.2000000000000002	0.55699998	4.1269999999999998	13.727	2.2989999999999999	7.6459999999999999
11053	1	0	0.20000000000000001	1.048	0.88	11.76	0.92200000000000004	12.324
11053	2	0	1.3999999999999999	0.91000003	2.0870000000000002	10.287000000000001	1.899	9.3610000000000007
11053	3	0	1.8	0.76099998	4.835	15.355	3.6789999999999998	11.685
11053	4	0	2.1000000000000001	0.65200001	10.484	20.064	6.8360000000000003	13.082000000000001
11052	1	0	0.20000000000000001	1.039	0.96899999999999997	11.629	1.0069999999999999	12.083
11052	2	0	1.3	0.94199997	1.464	11.384	1.379	10.724
11052	3	0	1.7	0.84500003	1.4730000000000001	10.913	1.2450000000000001	9.2210000000000001
11052	4	0	1.8999999999999999	0.71899998	4.0469999999999997	12.847	2.9100000000000001	9.2370000000000001
11051	1	0	0.20000000000000001	1.012	0.92500000000000004	9.5050000000000008	0.93600000000000005	9.6189999999999998
11051	2	0	1.3	0.93000001	1.395	9.5549999999999997	1.2969999999999999	8.8859999999999992
11051	3	0	1.7	0.83999997	2.2799999999999998	12.859999999999999	1.915	10.802
11051	4	0	1.8999999999999999	0.66399997	7.4960000000000004	17.815999999999999	4.9770000000000003	11.83
11065	1	0	0.20000000000000001	1.056	1.395	19.015000000000001	1.4730000000000001	20.079999999999998
11065	2	0	1.3999999999999999	0.92799997	1.591	19.471	1.476	18.068999999999999
11065	3	0	1.8999999999999999	0.77700001	2.0870000000000002	17.007000000000001	1.6220000000000001	13.214
11065	4	0	2.2000000000000002	0.667	2.8559999999999999	19.036000000000001	1.905	12.696999999999999
11064	1	0	0.20000000000000001	1.048	1.196	15.336	1.2529999999999999	16.071999999999999
11064	2	0	1.3999999999999999	0.921	2.4910000000000001	17.530999999999999	2.294	16.146000000000001
11064	3	0	1.8999999999999999	0.75800002	4.1180000000000003	21.097999999999999	3.121	15.992000000000001
11064	4	0	2.2000000000000002	0.611	6.8710000000000004	21.411000000000001	4.1980000000000004	13.082000000000001
11063	1	0	0.20000000000000001	1.039	1.7709999999999999	20.870999999999999	1.8400000000000001	21.684999999999999
11063	2	0	1.3	0.97600001	2.4449999999999998	19.105	2.3860000000000001	18.646000000000001
11063	3	0	1.7	0.81199998	5.7350000000000003	21.795000000000002	4.657	17.698
11063	4	0	1.8999999999999999	0.74599999	13.691000000000001	30.811	10.212999999999999	22.984999999999999
11062	1	0	0.20000000000000001	1.066	1.427	17.527000000000001	1.5209999999999999	18.684000000000001
11062	2	0	1.3	0.97299999	2.0150000000000001	14.455	1.9610000000000001	14.065
11062	3	0	1.7	0.81400001	6.5839999999999996	20.623999999999999	5.359	16.788
11062	4	0	1.8999999999999999	0.38100001	23.213000000000001	36.652999999999999	8.8439999999999994	13.965
11061	1	0	0.20000000000000001	1.077	1.3069999999999999	17.727	1.4079999999999999	19.091999999999999
11061	2	0	1.3	0.875	1.3360000000000001	17.616	1.169	15.414
11061	3	0	1.7	0.852	1.696	14.196	1.4450000000000001	12.095000000000001
11061	4	0	1.8999999999999999	0.57700002	6.0730000000000004	23.172999999999998	3.504	13.371
11060	1	0	0.20000000000000001	1.0190001	0.56699999999999995	6.0670000000000002	0.57799999999999996	6.1820000000000004
11060	2	0	1.3	0.95700002	0.73799999999999999	6.3380000000000001	0.70599999999999996	6.0650000000000004
11060	3	0	1.8	0.86500001	0.72199999999999998	6.7220000000000004	0.625	5.8150000000000004
11060	4	0	2.1000000000000001	0.65399998	0.71499999999999997	3.6150000000000002	0.46800000000000003	2.3639999999999999
11059	1	0	0.20000000000000001	1.054	0.84699999999999998	14.707000000000001	0.89300000000000002	15.500999999999999
11059	2	0	1.3	1.01	0.83099999999999996	6.6909999999999998	0.83899999999999997	6.758
11059	3	0	1.7	0.87900001	0.91100000000000003	7.1109999999999998	0.80100000000000005	6.2510000000000003
11059	4	0	2	0.787	1.0580000000000001	6.0380000000000003	0.83299999999999996	4.7519999999999998
11058	1	0	0.20000000000000001	1.024	0.71999999999999997	5.6399999999999997	0.73699999999999999	5.7750000000000004
11058	2	0	1.3	0.93300003	1.2330000000000001	6.6929999999999996	1.1499999999999999	6.2450000000000001
11058	3	0	1.7	0.81400001	2.8039999999999998	11.324	2.282	9.218
11058	4	0	2.1000000000000001	0.52600002	6.0759999999999996	9.2759999999999998	3.1960000000000002	4.8789999999999996
11057	1	0	0.20000000000000001	0.99299997	0.755	5.5149999999999997	0.75	5.476
11057	2	0	1.3	0.86500001	1.1910000000000001	7.6909999999999998	1.03	6.6529999999999996
11057	3	0	1.7	0.76599997	1.909	9.0289999999999999	1.462	6.9160000000000004
11057	4	0	2.1000000000000001	0.62199998	1.464	9.6839999999999993	0.91100000000000003	6.0229999999999997
11056	1	0	0.20000000000000001	1.075	0.46000000000000002	7.0199999999999996	0.495	7.5460000000000003
6951	1	0	0.29999999999999999	1.37	1.8	12.300000000000001	2.4660000000000002	16.850999999999999
6951	2	0	2.2999999999999998	1.26	2.1200000000000001	14.869999999999999	2.6709999999999998	18.736000000000001
6951	3	0	3	1.11	3.3799999999999999	19.629999999999999	3.7519999999999998	21.789000000000001
6951	4	0	3.6000000000000001	0.41999999	12.880000000000001	31.379999999999999	5.4100000000000001	13.18
6952	1	0	0.29999999999999999	1.21	1.98	26.48	2.3959999999999999	32.040999999999997
6952	2	0	2.3999999999999999	1.14	4.0999999999999996	19.100000000000001	4.6740000000000004	21.774000000000001
6952	3	0	3.2000000000000002	1.03	8.8699999999999992	30.370000000000001	9.1359999999999992	31.280999999999999
6952	4	0	3.7999999999999998	0.76999998	34.960000000000001	61.710000000000001	26.919	47.517000000000003
6945	1	0	0.29999999999999999	1.86	3.1000000000000001	34.100000000000001	5.766	63.426000000000002
6945	2	0	3.3999999999999999	1.6	5.2800000000000002	49.950000000000003	8.4480000000000004	79.920000000000002
6945	3	0	4.5	1.59	4.3799999999999999	45.049999999999997	6.9640000000000004	71.629000000000005
6945	4	0	5.4000000000000004	1.3099999	6.2199999999999998	45.219999999999999	8.1479999999999997	59.238
6946	1	0	0.29999999999999999	1.8099999	4.7400000000000002	52.409999999999997	8.5790000000000006	94.861999999999995
6946	2	0	3.3999999999999999	1.63	9.0800000000000001	60.75	14.800000000000001	99.022000000000006
6946	3	0	4.5999999999999996	1.4299999	11.82	56.490000000000002	16.902999999999999	80.781000000000006
6946	4	0	5.5	1.11	34.240000000000002	96.569999999999993	38.006	107.193
6947	1	0	0.29999999999999999	1.74	4.6200000000000001	43.950000000000003	8.0389999999999997	76.472999999999999
6947	2	0	3.3999999999999999	1.74	10.18	57.18	17.713000000000001	99.492999999999995
6947	3	0	4.5	1.52	11.02	61.689999999999998	16.75	93.769000000000005
6947	4	0	5.4000000000000004	1.3200001	20.640000000000001	73.310000000000002	27.245000000000001	96.769000000000005
6948	1	0	0.29999999999999999	1.8200001	5.3600000000000003	48.359999999999999	9.7550000000000008	88.015000000000001
6948	2	0	3.3999999999999999	1.6900001	10.76	51.090000000000003	18.184000000000001	86.341999999999999
6948	3	0	4.5	1.58	13.94	70.269999999999996	22.024999999999999	111.027
6948	4	0	5.4000000000000004	1.36	33.100000000000001	91.430000000000007	45.015999999999998	124.345
6949	1	0	0.29999999999999999	0.91000003	9.9600000000000009	63.960000000000001	9.0640000000000001	58.204000000000001
6949	2	0	2.5	0.98000002	28.219999999999999	68.219999999999999	27.655999999999999	66.855999999999995
6949	3	0	3.3999999999999999	1.02	34.939999999999998	97.609999999999999	35.639000000000003	99.561999999999998
6949	4	0	4	1.05	76.959999999999994	232.28999999999999	80.808000000000007	243.905
6940	1	0	0.29999999999999999	1.85	4.1200000000000001	77.620000000000005	7.6219999999999999	143.59700000000001
6940	2	0	3.6000000000000001	1.83	4.5199999999999996	97.519999999999996	8.2720000000000002	178.46199999999999
6940	3	0	4.7999999999999998	1.71	5.1200000000000001	77.620000000000005	8.7550000000000008	132.72999999999999
6940	4	0	5.9500000000000002	1.46	8.3200000000000003	77.819999999999993	12.147	113.617
6941	1	0	0.29999999999999999	1.75	6.0199999999999996	79.519999999999996	10.535	139.16
6941	2	0	3.6000000000000001	1.67	11.279999999999999	86.780000000000001	18.838000000000001	144.923
6941	3	0	4.7999999999999998	1.51	15.9	87.400000000000006	24.009	131.97399999999999
6941	4	0	5.9500000000000002	1.29	23.239999999999998	86.739999999999995	29.98	111.895
6942	1	0	0.29999999999999999	1.74	5.6600000000000001	72.159999999999997	9.8480000000000008	125.55800000000001
6942	2	0	3.7999999999999998	1.61	9.8399999999999999	81.840000000000003	15.842000000000001	131.762
6942	3	0	5.0999999999999996	1.4	27.620000000000001	105.62	38.667999999999999	147.86799999999999
6942	4	0	6.3499999999999996	0.85000002	36.840000000000003	105.84	31.314	89.963999999999999
6943	1	0	0.29999999999999999	1.6900001	8.3800000000000008	73.379999999999995	14.162000000000001	124.012
6943	2	0	3.3999999999999999	1.5700001	28.960000000000001	95.959999999999994	45.466999999999999	150.65700000000001
6943	3	0	4.5	1.38	60.079999999999998	132.58000000000001	82.909999999999997	182.96000000000001
6943	4	0	5.5499999999999998	0.33000001	305.98000000000002	378.48000000000002	100.973	124.898
6944	1	0	0.29999999999999999	1.36	5.8799999999999999	67.879999999999995	7.9969999999999999	92.316999999999993
6944	2	0	2.5	1.3	22.920000000000002	90.590000000000003	29.795999999999999	117.767
6944	3	0	3.3999999999999999	1.21	41.079999999999998	107.41	49.707000000000001	129.96600000000001
6944	4	0	4.1500000000000004	1.08	50.259999999999998	110.59	54.280999999999999	119.437
13153	1	0	0.29999999999999999	1.576	4.5199999999999996	34.560000000000002	7.1239999999999997	54.466999999999999
13153	2	0	2.3999999999999999	1.4069999	9.8819999999999997	46.082000000000001	13.904	64.837000000000003
13153	3	0	3.2000000000000002	1.0700001	18.466999999999999	60.786999999999999	19.760000000000002	65.042000000000002
13153	4	0	3.7999999999999998	0.69599998	7.1159999999999997	39.555999999999997	4.9530000000000003	27.530999999999999
13154	1	0	0.29999999999999999	1.692	5.7329999999999997	35.393000000000001	9.6999999999999993	59.884999999999998
13154	2	0	3.2999999999999998	1.459	8.7560000000000002	40.276000000000003	12.775	58.762999999999998
13154	3	0	4.4000000000000004	1.2079999	20.748999999999999	51.029000000000003	25.065000000000001	61.643000000000001
13154	4	0	5	1.056	52.634999999999998	80.995000000000005	55.582999999999998	85.531000000000006
13154	5	0	5.2999999999999998	0.359	160.59100000000001	191.511	57.652000000000001	68.751999999999995
13155	1	0	0.29999999999999999	1.554	6.4710000000000001	41.030999999999999	10.055999999999999	63.762
13155	2	0	3.1000000000000001	1.351	15.904	53.904000000000003	21.486000000000001	72.823999999999998
13155	3	0	4.0999999999999996	1.215	35.033000000000001	71.052999999999997	42.564999999999998	86.328999999999994
13155	4	0	4.5999999999999996	1.0700001	49.802	84.102000000000004	53.287999999999997	89.989000000000004
13155	5	0	4.9000000000000004	0.94499999	99.393000000000001	136.13300000000001	93.926000000000002	128.64599999999999
13156	1	0	0.29999999999999999	1.413	8.8200000000000003	48.659999999999997	12.462999999999999	68.757000000000005
13156	2	0	2.7999999999999998	1.205	22.047000000000001	61.646999999999998	26.567	74.284999999999997
13156	3	0	3.7999999999999998	1.024	81.135999999999996	121.21599999999999	83.082999999999998	124.125
13156	4	0	4.5	0.884	1961.8399999999999	1996.28	1734.2670000000001	1764.712
13157	1	0	0.29999999999999999	1.283	10.616	54.155999999999999	13.619999999999999	69.481999999999999
13157	2	0	2.6000000000000001	1.2180001	23.521999999999998	53.601999999999997	28.649999999999999	65.287000000000006
13157	3	0	3.5	0.95200002	56.594999999999999	95.114999999999995	53.878	90.549000000000007
13157	4	0	4.2000000000000002	0.83999997	99.893000000000001	141.43299999999999	83.909999999999997	118.804
12906	1	0	0.29999999999999999	0.68400002	0.66400000000000003	5.2640000000000002	0.45400000000000001	3.601
12906	2	0	1.1000000000000001	0.55699998	0.76000000000000001	6.1799999999999997	0.42299999999999999	3.4420000000000002
12906	3	0	1.6000000000000001	0.43900001	1.175	6.4950000000000001	0.51600000000000001	2.851
12907	1	0	0.29999999999999999	1.1210001	1.395	6.915	1.5640000000000001	7.7519999999999998
12907	2	0	1.1000000000000001	0.98799998	4.7270000000000003	9.6270000000000007	4.6699999999999999	9.5109999999999992
12907	3	0	1.7	0.63700002	46.164999999999999	51.664999999999999	29.407	32.911000000000001
12908	1	0	0.29999999999999999	1.082	1.282	7.3220000000000001	1.387	7.9219999999999997
12908	2	0	1.1000000000000001	0.86400002	4.9349999999999996	11.035	4.2640000000000002	9.5340000000000007
12908	3	0	1.6000000000000001	0.57200003	14.705	20.905000000000001	8.4109999999999996	11.958
12909	1	0	0.29999999999999999	0.93699998	1.696	7.6159999999999997	1.589	7.1360000000000001
12909	2	0	0.80000000000000004	0.77999997	7.6689999999999996	13.869	5.9820000000000002	10.818
12909	3	0	1.2	0.69099998	19.815999999999999	26.536000000000001	13.693	18.335999999999999
12910	1	0	0.29999999999999999	0.89600003	1.909	7.2489999999999997	1.71	6.4950000000000001
12910	2	0	0.5	0.75400001	3.887	10.266999999999999	2.931	7.7409999999999997
12910	3	0	0.69999999999999996	0.66900003	8.1649999999999991	14.845000000000001	5.4619999999999997	9.9309999999999992
12230	1	0	0.29999999999999999	1.3150001	2.4649999999999999	41.865000000000002	3.2410000000000001	55.052
12230	2	0	2.5	1.169	3.4910000000000001	28.210999999999999	4.0810000000000004	32.978999999999999
12230	3	0	3.2999999999999998	0.81900001	3.3130000000000002	36.753	2.7130000000000001	30.100999999999999
12230	4	0	3.8999999999999999	0.56	7.7400000000000002	37.359999999999999	4.3339999999999996	20.922000000000001
12229	1	0	0.29999999999999999	1.702	3.222	35.061999999999998	5.484	59.676000000000002
12229	2	0	3.3999999999999999	1.648	4.2960000000000003	42.375999999999998	7.0800000000000001	69.835999999999999
12229	3	0	4.5999999999999996	1.4450001	8.6690000000000005	36.509	12.526999999999999	52.756
12229	4	0	5.0999999999999996	1.375	3.6400000000000001	35.579999999999998	5.0049999999999999	48.923000000000002
12229	5	0	5.5	1.215	8.0909999999999993	41.570999999999998	9.8309999999999995	50.509
12228	1	0	0.29999999999999999	1.4809999	6.0709999999999997	34.331000000000003	8.9909999999999997	50.844000000000001
12228	2	0	3	1.465	13.465	40.844999999999999	19.725999999999999	59.838000000000001
12228	3	0	4	1.355	21.829000000000001	56.228999999999999	29.577999999999999	76.189999999999998
12228	4	0	4.7999999999999998	1.291	79.712999999999994	121.373	102.90900000000001	156.69300000000001
12227	1	0	0.29999999999999999	1.506	7.2359999999999998	42.676000000000002	10.897	64.269999999999996
12227	2	0	3	1.349	25.048999999999999	57.869	33.790999999999997	78.064999999999998
12227	3	0	4	1.276	26.507000000000001	56.027000000000001	33.823	71.489999999999995
12227	4	0	4.7999999999999998	1.041	74.031000000000006	108.191	77.066000000000003	112.627
12226	1	0	0.29999999999999999	1.09	21.52	50.520000000000003	23.457000000000001	55.067
12226	2	0	2.5	1.109	38.341999999999999	74.561999999999998	42.521000000000001	82.688999999999993
12226	3	0	3.3999999999999999	0.98299998	93.611000000000004	120.351	92.019999999999996	118.30500000000001
12226	4	0	4	0.75599998	213.33500000000001	560.17499999999995	161.28100000000001	423.49200000000002
11310	1	0	0.20000000000000001	1.365	1.444	17.064	1.9710000000000001	23.292000000000002
11310	2	0	2.2000000000000002	1.38	1.627	19.227	2.2450000000000001	26.533000000000001
11310	3	0	3	1.234	1.4350000000000001	16.454999999999998	1.7709999999999999	20.305
11310	4	0	3.5	1.029	1.9159999999999999	18.376000000000001	1.972	18.908999999999999
11309	1	0	0.20000000000000001	1.326	1.5780000000000001	17.097999999999999	2.0920000000000001	22.672000000000001
11309	2	0	2	1.164	3.2799999999999998	19.879999999999999	3.8180000000000001	23.140000000000001
11309	3	0	2.7000000000000002	0.91500002	9.5579999999999998	26.018000000000001	8.7460000000000004	23.806000000000001
11309	4	0	3.2000000000000002	0.514	40.674999999999997	57.295000000000002	20.907	29.449999999999999
11308	1	0	0.20000000000000001	1.256	2.2000000000000002	19.120000000000001	2.7629999999999999	24.015000000000001
11308	2	0	2	0.95899999	8.6980000000000004	26.257999999999999	8.3409999999999993	25.181000000000001
11308	3	0	2.6000000000000001	0.85000002	12.742000000000001	29.922000000000001	10.831	25.434000000000001
11308	4	0	3.1000000000000001	0.56300002	34.357999999999997	54.298000000000002	19.344000000000001	30.57
11307	1	0	0.20000000000000001	1.148	2.0310000000000001	18.710999999999999	2.3319999999999999	21.48
11307	2	0	1.6000000000000001	0.99000001	4.6180000000000003	22.917999999999999	4.5720000000000001	22.689
11307	3	0	2.1000000000000001	0.87	12.711	26.951000000000001	11.058999999999999	23.446999999999999
11307	4	0	2.3999999999999999	0.708	23.253	40.453000000000003	16.463000000000001	28.640999999999998
11306	1	0	0.20000000000000001	1.02	3.2999999999999998	19.239999999999998	3.3660000000000001	19.625
11306	2	0	1.3	0.91799998	9.9689999999999994	26.469000000000001	9.1519999999999992	24.298999999999999
11306	3	0	1.7	0.73400003	6.1559999999999997	24.216000000000001	4.5190000000000001	17.774999999999999
11306	4	0	1.8999999999999999	0.71899998	8.7509999999999994	26.731000000000002	6.2919999999999998	19.219999999999999
11305	1	0	0.20000000000000001	1.332	1.611	23.331	2.1459999999999999	31.077000000000002
11305	2	0	1.3999999999999999	1.181	1.74	25.780000000000001	2.0550000000000002	30.446000000000002
11305	3	0	1.8	1.077	1.5649999999999999	23.885000000000002	1.6859999999999999	25.724
11305	4	0	2	0.204	2.0619999999999998	29.161999999999999	0.42099999999999999	5.9489999999999998
11304	1	0	0.20000000000000001	1.706	1.5089999999999999	24.969000000000001	2.5739999999999998	42.597000000000001
11304	2	0	3.2000000000000002	1.559	1.7509999999999999	27.591000000000001	2.73	43.014000000000003
11304	3	0	4.2999999999999998	1.377	1.849	28.068999999999999	2.5459999999999998	38.651000000000003
11304	4	0	5.2000000000000002	0.91299999	2.165	27.344999999999999	1.9770000000000001	24.966000000000001
11303	1	0	0.20000000000000001	1.563	2.1219999999999999	24.341999999999999	3.3170000000000002	38.046999999999997
11303	2	0	2.6000000000000001	1.368	5.2240000000000002	25.024000000000001	7.1459999999999999	34.232999999999997
11303	3	0	3.5	1.262	7.7350000000000003	30.495000000000001	9.7620000000000005	38.484999999999999
11303	4	0	4.2000000000000002	0.73400003	23.122	49.561999999999998	16.972000000000001	36.378999999999998
11302	1	0	0.20000000000000001	1.418	2.6349999999999998	24.454999999999998	3.7360000000000002	34.677
11302	2	0	2.6000000000000001	1.235	6.4130000000000003	23.452999999999999	7.9199999999999999	28.963999999999999
11302	3	0	3.3999999999999999	1.196	7.7759999999999998	32.356000000000002	9.3000000000000007	38.698
11302	4	0	4.0999999999999996	0.94400001	15.851000000000001	41.250999999999998	14.962999999999999	38.941000000000003
11301	1	0	0.20000000000000001	1.319	2.0089999999999999	24.768999999999998	2.6499999999999999	32.670000000000002
11301	2	0	2	1.141	4.3330000000000002	26.613	4.944	30.364999999999998
11301	3	0	2.7000000000000002	0.94499999	5.5780000000000003	25.658000000000001	5.2709999999999999	24.247
11301	4	0	3.2000000000000002	0.75800002	12.411	32.710999999999999	9.4079999999999995	24.795000000000002
11300	1	0	0.20000000000000001	1.1670001	1.4450000000000001	9.8249999999999993	1.6859999999999999	11.465999999999999
11300	2	0	1.8	1	3.3109999999999999	14.531000000000001	3.3109999999999999	14.531000000000001
11300	3	0	2.3999999999999999	0.90799999	2.9359999999999999	11.076000000000001	2.6659999999999999	10.057
11300	4	0	2.7999999999999998	0.63700002	17.855	25.715	11.374000000000001	16.379999999999999
11299	1	0	0.20000000000000001	1.08	1.089	7.5490000000000004	1.1759999999999999	8.1530000000000005
11299	2	0	1.6000000000000001	0.94199997	1.6419999999999999	17.302	1.5469999999999999	16.297999999999998
11299	3	0	2.1000000000000001	0.81199998	2.7269999999999999	10.106999999999999	2.214	8.2070000000000007
11299	4	0	2.3999999999999999	0.722	5.1219999999999999	12.282	3.698	8.8680000000000003
11298	1	0	0.20000000000000001	1.017	0.95299999999999996	8.6929999999999996	0.96899999999999997	8.8409999999999993
11298	2	0	1.3999999999999999	0.85000002	2.1360000000000001	9.9160000000000004	1.8160000000000001	8.4290000000000003
11298	3	0	1.8999999999999999	0.74599999	3.238	9.8780000000000001	2.4159999999999999	7.3689999999999998
11298	4	0	2.2000000000000002	0.71200001	7.3360000000000003	15.976000000000001	5.2229999999999999	11.375
11297	1	0	0.20000000000000001	0.93199998	0.88500000000000001	8.9049999999999994	0.82499999999999996	8.2989999999999995
11297	2	0	1.1000000000000001	0.85799998	1.1639999999999999	9.0640000000000001	0.999	7.7770000000000001
11297	3	0	1.3999999999999999	0.83499998	1.3560000000000001	10.036	1.1319999999999999	8.3800000000000008
11297	4	0	1.6000000000000001	0.66600001	5.2069999999999999	13.627000000000001	3.468	9.0760000000000005
11296	1	0	0.20000000000000001	0.889	0.995	9.4350000000000005	0.88500000000000001	8.3879999999999999
11296	2	0	0.80000000000000004	0.80400002	2.585	10.505000000000001	2.0779999999999998	8.4459999999999997
11296	3	0	1	0.69599998	7.4219999999999997	16.861999999999998	5.1660000000000004	11.736000000000001
11296	4	0	1.1000000000000001	0.60600001	7.2489999999999997	18.568999999999999	4.3929999999999998	11.253
11395	1	0	0.20000000000000001	0.949	1.538	40.137999999999998	1.46	38.091000000000001
11395	2	0	1.8999999999999999	0.84299999	1.762	48.201999999999998	1.4850000000000001	40.634
11395	3	0	2.6000000000000001	0.72000003	1.8049999999999999	48.104999999999997	1.3	34.636000000000003
11395	4	0	3	0.54500002	1.9239999999999999	21.884	1.0489999999999999	11.927
11394	1	0	0.20000000000000001	1.0700001	1.887	43.966999999999999	2.0190000000000001	47.045000000000002
11394	2	0	1.6000000000000001	0.99299997	1.956	44.015999999999998	1.9419999999999999	43.707999999999998
11394	3	0	2.1000000000000001	0.91100001	2.3530000000000002	47.593000000000004	2.1440000000000001	43.356999999999999
6924	4	0	2.8999999999999999	0.75999999	2.2200000000000002	13.220000000000001	1.6870000000000001	10.047000000000001
6916	1	0	0.29999999999999999	0.92000002	2.1499999999999999	34.82	1.978	32.033999999999999
6916	2	0	1.8999999999999999	0.80000001	2.3399999999999999	36.340000000000003	1.8720000000000001	29.071999999999999
6916	3	0	2.6000000000000001	0.58999997	2.6400000000000001	33.979999999999997	1.5580000000000001	20.047999999999998
6916	4	0	3	0.41	4.5999999999999996	38.600000000000001	1.8859999999999999	15.826000000000001
6917	1	0	0.29999999999999999	0.98000002	2.5699999999999998	39.899999999999999	2.5190000000000001	39.101999999999997
6917	2	0	1.5	0.95999998	4.04	42.700000000000003	3.8780000000000001	40.991999999999997
6917	3	0	2	0.75999999	7.5499999999999998	44.880000000000003	5.7380000000000004	34.109000000000002
6917	4	0	2.2999999999999998	0.63999999	7.6200000000000001	45.619999999999997	4.8769999999999998	29.196999999999999
6918	1	0	0.29999999999999999	1.15	2.3399999999999999	39.670000000000002	2.6909999999999998	45.621000000000002
6918	2	0	1.3999999999999999	1.04	2.5299999999999998	39.200000000000003	2.6309999999999998	40.768000000000001
6918	3	0	1.8	0.93000001	3.0899999999999999	38.43	2.8740000000000001	35.740000000000002
6918	4	0	2.1000000000000001	0.69999999	5.0599999999999996	43.719999999999999	3.5419999999999998	30.603999999999999
6919	1	0	0.29999999999999999	1.08	2.2599999999999998	39.600000000000001	2.4409999999999998	42.768000000000001
6919	2	0	1.6000000000000001	0.92000002	2.6800000000000002	38.68	2.4660000000000002	35.585999999999999
6919	3	0	2.2000000000000002	0.76999998	2.9100000000000001	43.57	2.2410000000000001	33.548999999999999
6919	4	0	2.5	0.55000001	3.4300000000000002	44.770000000000003	1.887	24.623999999999999
6911	1	0	0.29999999999999999	0.68000001	3.1699999999999999	41.170000000000002	2.1560000000000001	27.995999999999999
6911	2	0	2	0.55000001	3.4700000000000002	40.140000000000001	1.909	22.077000000000002
6911	3	0	2.6000000000000001	0.38999999	3.77	41.770000000000003	1.47	16.289999999999999
6911	4	0	3.1000000000000001	0.25999999	11.17	59.170000000000002	2.9039999999999999	15.384
6912	1	0	0.29999999999999999	1.38	3.96	44.630000000000003	5.4649999999999999	61.588999999999999
6912	2	0	2.6000000000000001	1.13	4.1500000000000004	45.479999999999997	4.6900000000000004	51.392000000000003
6912	3	0	3.3999999999999999	1.08	4.2300000000000004	42.890000000000001	4.5679999999999996	46.320999999999998
6912	4	0	4.0999999999999996	0.76999998	4.4199999999999999	45.079999999999998	3.403	34.712000000000003
6913	1	0	0.29999999999999999	1.5	3.77	44.439999999999998	5.6550000000000002	66.659999999999997
6913	2	0	2.2000000000000002	1.38	4.3399999999999999	46.340000000000003	5.9889999999999999	63.948999999999998
6913	3	0	3	1.14	4.1500000000000004	42.82	4.7309999999999999	48.814999999999998
6913	4	0	3.5	1.05	4.5300000000000002	47.200000000000003	4.7569999999999997	49.560000000000002
6914	1	0	0.29999999999999999	1.46	3.0600000000000001	43.060000000000002	4.468	62.868000000000002
6914	2	0	2.2000000000000002	1.41	3.25	38.579999999999998	4.5830000000000002	54.398000000000003
6914	3	0	3	1.28	3.5499999999999998	40.880000000000003	4.5439999999999996	52.326000000000001
6914	4	0	3.5	1.04	3.7400000000000002	41.740000000000002	3.8900000000000001	43.409999999999997
6915	1	0	0.29999999999999999	1.45	2.5299999999999998	35.200000000000003	3.6680000000000001	51.039999999999999
6915	2	0	2.5	1.3200001	2.7200000000000002	41.380000000000003	3.5899999999999999	54.622
6915	3	0	3.3999999999999999	1.16	2.9399999999999999	39.609999999999999	3.4100000000000001	45.948
6915	4	0	4	0.77999997	4.3399999999999999	52.340000000000003	3.3849999999999998	40.825000000000003
6908	1	0	0.29999999999999999	0.97000003	5.7400000000000002	49.240000000000002	5.5679999999999996	47.762999999999998
6908	2	0	1.5	0.86000001	5.8899999999999997	50.390000000000001	5.0650000000000004	43.335000000000001
6908	3	0	2	0.77999997	6.9299999999999997	50.93	5.4050000000000002	39.725000000000001
6908	4	0	2.5	0.63999999	6.04	49.039999999999999	3.8660000000000001	31.385999999999999
6909	1	0	0.29999999999999999	1.01	4.6299999999999999	46.630000000000003	4.6760000000000002	47.095999999999997
6909	2	0	1.6000000000000001	0.88999999	5.2199999999999998	45.219999999999999	4.6459999999999999	40.246000000000002
6909	3	0	2.1000000000000001	0.72000003	6.3700000000000001	46.869999999999997	4.5860000000000003	33.746000000000002
6909	4	0	2.3999999999999999	0.72000003	6.5599999999999996	62.060000000000002	4.7229999999999999	44.683
6910	1	0	0.29999999999999999	1.09	4.5199999999999996	44.020000000000003	4.9269999999999996	47.981999999999999
6910	2	0	1.6000000000000001	0.93000001	4.7400000000000002	45.740000000000002	4.4080000000000004	42.537999999999997
6910	3	0	2.1000000000000001	0.77999997	4.9299999999999997	37.93	3.8450000000000002	29.585000000000001
6910	4	0	2.3999999999999999	0.72000003	4.5599999999999996	49.560000000000002	3.2829999999999999	35.683
6904	1	0	0.29999999999999999	0.56999999	3.6899999999999999	33.689999999999998	2.1030000000000002	19.202999999999999
6904	2	0	1.2	0.38	4.0800000000000001	46.079999999999998	1.55	17.510000000000002
6904	3	0	1.6000000000000001	0.33000001	4.0800000000000001	34.079999999999998	1.3460000000000001	11.246
6904	4	0	1.8	0.40000001	5.1699999999999999	40.5	2.0680000000000001	16.199999999999999
6905	1	0	0.29999999999999999	1.03	5.21	24.539999999999999	5.3659999999999997	25.276
6905	2	0	1.6000000000000001	0.88999999	6.0800000000000001	34.740000000000002	5.4109999999999996	30.919
6905	3	0	2.1000000000000001	0.79000002	7.0599999999999996	38.390000000000001	5.577	30.327999999999999
6905	4	0	2.3999999999999999	0.63999999	6.5999999999999996	29.940000000000001	4.2240000000000002	19.161999999999999
6906	1	0	0.29999999999999999	1.09	4.1500000000000004	29.48	4.524	32.133000000000003
6906	2	0	1.5	0.95999998	6.2300000000000004	32.890000000000001	5.9809999999999999	31.574000000000002
6906	3	0	2	0.87	6.1500000000000004	34.149999999999999	5.351	29.710000000000001
6906	4	0	2.2999999999999998	0.87	6.2300000000000004	29.559999999999999	5.4199999999999999	25.716999999999999
6907	1	0	0.29999999999999999	1.13	3.96	33.460000000000001	4.4749999999999996	37.810000000000002
6907	2	0	1.6000000000000001	0.99000001	4.6299999999999999	29.629999999999999	4.5839999999999996	29.334
6907	3	0	2.1000000000000001	0.87	4.5199999999999996	33.520000000000003	3.9319999999999999	29.161999999999999
6907	4	0	2.3999999999999999	0.75999999	5.4100000000000001	41.409999999999997	4.1120000000000001	31.472000000000001
6899	1	0	0.29999999999999999	0.67000002	4.4199999999999999	36.409999999999997	2.9609999999999999	24.395
6899	2	0	1.5	0.56	5.4000000000000004	42.060000000000002	3.024	23.553999999999998
6899	3	0	2	0.5	5.4299999999999997	40.770000000000003	2.7149999999999999	20.385000000000002
6899	4	0	2.2999999999999998	0.40000001	6.1900000000000004	39.520000000000003	2.476	15.808
6900	1	0	0.29999999999999999	1.01	4.8700000000000001	36.869999999999997	4.9189999999999996	37.238999999999997
6900	2	0	1.7	0.88	4.2599999999999998	38.259999999999998	3.7490000000000001	33.668999999999997
6900	3	0	2.2000000000000002	0.79000002	6.5700000000000003	39.229999999999997	5.1900000000000004	30.992000000000001
6900	4	0	2.6000000000000001	0.70999998	8.9399999999999995	40.280000000000001	6.3470000000000004	28.599
6901	1	0	0.29999999999999999	1.13	5.6600000000000001	35.659999999999997	6.3959999999999999	40.295999999999999
6901	2	0	1.6000000000000001	0.98000002	7.0899999999999999	40.43	6.9480000000000004	39.621000000000002
6901	3	0	2.1000000000000001	0.92000002	7.7699999999999996	41.109999999999999	7.1479999999999997	37.820999999999998
6901	4	0	2.3999999999999999	0.73000002	11.130000000000001	44.469999999999999	8.125	32.463000000000001
6902	1	0	0.29999999999999999	1.14	3.7400000000000002	33.07	4.2640000000000002	37.700000000000003
6902	2	0	1.6000000000000001	1.04	5.4299999999999997	34.100000000000001	5.6470000000000002	35.463999999999999
6902	3	0	2.1000000000000001	0.94999999	7.6200000000000001	35.619999999999997	7.2389999999999999	33.838999999999999
6902	4	0	2.3999999999999999	0.81999999	5.96	35.299999999999997	4.8869999999999996	28.946000000000002
6903	1	0	0.29999999999999999	1.11	5.0899999999999999	35.090000000000003	5.6500000000000004	38.950000000000003
6903	2	0	1.7	1.01	5.5099999999999998	34.479999999999997	5.5650000000000004	34.825000000000003
6903	3	0	2.2000000000000002	0.97000003	4.9100000000000001	32.240000000000002	4.7629999999999999	31.273
6903	4	0	2.6000000000000001	0.73000002	7.21	36.539999999999999	5.2629999999999999	26.673999999999999
6894	1	0	0.29999999999999999	0.89999998	4.5099999999999998	4.5099999999999998	4.0590000000000002	4.0590000000000002
6894	2	0	1.5	0.88	3.5600000000000001	3.5600000000000001	3.133	3.133
6894	3	0	2.1000000000000001	0.87	3.96	3.96	3.4449999999999998	3.4449999999999998
6894	4	0	2.6000000000000001	0.75999999	3.6800000000000002	3.6800000000000002	2.7970000000000002	2.7970000000000002
6894	5	0	2.7999999999999998	0.58999997	3.6800000000000002	3.6800000000000002	2.1709999999999998	2.1709999999999998
6895	1	0	0.29999999999999999	1.1799999	3.96	3.96	4.673	4.673
6895	2	0	2	1.17	6.5999999999999996	6.5999999999999996	7.7220000000000004	7.7220000000000004
6895	3	0	2.7999999999999998	1.08	6.6799999999999997	6.6799999999999997	7.2140000000000004	7.2140000000000004
6895	4	0	3.3999999999999999	1	6.96	6.96	6.96	6.96
6895	5	0	3.7999999999999998	0.75	8.2400000000000002	8.2400000000000002	6.1799999999999997	6.1799999999999997
6896	1	0	0.29999999999999999	1.35	4.2199999999999998	4.2199999999999998	5.6970000000000001	5.6970000000000001
6896	2	0	1.8999999999999999	1.27	4.8399999999999999	4.8399999999999999	6.1470000000000002	6.1470000000000002
6896	3	0	2.6000000000000001	1.1900001	5.5199999999999996	5.5199999999999996	6.569	6.569
6896	4	0	3.1000000000000001	1.09	5.1200000000000001	5.1200000000000001	5.5810000000000004	5.5810000000000004
6896	5	0	3.5	0.93000001	13.52	13.52	12.574	12.574
6897	1	0	0.29999999999999999	1.46	3.0600000000000001	3.0600000000000001	4.468	4.468
6897	2	0	1.8999999999999999	1.34	2.3599999999999999	2.3599999999999999	3.1619999999999999	3.1619999999999999
6897	3	0	2.6000000000000001	1.22	1.6399999999999999	1.6399999999999999	2.0009999999999999	2.0009999999999999
6897	4	0	3.1000000000000001	1.08	1.8400000000000001	1.8400000000000001	1.9870000000000001	1.9870000000000001
6897	5	0	3.5	0.95999998	5.5999999999999996	5.5999999999999996	5.3760000000000003	5.3760000000000003
6898	1	0	0.29999999999999999	1.34	1.5600000000000001	1.5600000000000001	2.0899999999999999	2.0899999999999999
6898	2	0	2	1.15	1.4399999999999999	1.4399999999999999	1.6559999999999999	1.6559999999999999
6898	3	0	2.7999999999999998	1.1	2.5600000000000001	2.5600000000000001	2.8159999999999998	2.8159999999999998
6898	4	0	3.3999999999999999	1.0599999	1.8799999999999999	1.8799999999999999	1.9930000000000001	1.9930000000000001
6898	5	0	3.7999999999999998	0.83999997	5.1200000000000001	5.1200000000000001	4.3010000000000002	4.3010000000000002
6890	1	0	0.29999999999999999	0.70999998	1.8400000000000001	6.3399999999999999	1.306	4.5010000000000003
6890	2	0	2.2999999999999998	0.56999999	2	6.5	1.1399999999999999	3.7050000000000001
6890	3	0	3	0.41999999	2.2799999999999998	7.7800000000000002	0.95799999999999996	3.2679999999999998
6890	4	0	3.6000000000000001	0.30000001	2.6000000000000001	8.5999999999999996	0.78000000000000003	2.5800000000000001
6891	1	0	0.29999999999999999	1.1799999	2.2000000000000002	6.7000000000000002	2.5960000000000001	7.9059999999999997
6891	2	0	2.2000000000000002	1.1	2.7999999999999998	8.3000000000000007	3.0800000000000001	9.1300000000000008
6891	3	0	2.8999999999999999	0.98000002	4.0800000000000001	13.58	3.9980000000000002	13.308
6891	4	0	3.3999999999999999	0.69999999	7.4800000000000004	16.48	5.2359999999999998	11.536
6892	1	0	0.29999999999999999	1.36	1.96	10.960000000000001	2.6659999999999999	14.906000000000001
6892	2	0	2	1.2	2.3599999999999999	11.859999999999999	2.8319999999999999	14.231999999999999
6892	3	0	2.7000000000000002	1.05	2.7999999999999998	11.800000000000001	2.9399999999999999	12.390000000000001
6892	4	0	3.2000000000000002	0.82999998	5.04	12.539999999999999	4.1829999999999998	10.407999999999999
6893	1	0	0.29999999999999999	1.2	1.3600000000000001	7.8600000000000003	1.6319999999999999	9.4320000000000004
6893	2	0	2.2000000000000002	1.05	1.6399999999999999	9.6400000000000006	1.722	10.122
6893	3	0	3	0.94999999	1.48	9.9800000000000004	1.4059999999999999	9.4809999999999999
6893	4	0	3.5	0.80000001	1.3200000000000001	9.8200000000000003	1.056	7.8559999999999999
6885	1	0	0.29999999999999999	1.11	4.2999999999999998	28.050000000000001	4.7729999999999997	31.135999999999999
6885	2	0	2.2000000000000002	0.92000002	4.5199999999999996	28.77	4.1580000000000004	26.468
6885	3	0	2.8999999999999999	0.86000001	5	24.5	4.2999999999999998	21.07
6885	4	0	3.3999999999999999	0.54000002	5.4199999999999999	27.27	2.927	14.726000000000001
6886	1	0	0.29999999999999999	1.4	3.2599999999999998	18.760000000000002	4.5640000000000001	26.263999999999999
6886	2	0	2	1.15	4.6299999999999999	30.879999999999999	5.3250000000000002	35.512
6886	3	0	2.6000000000000001	1.08	5.1500000000000004	27.649999999999999	5.5620000000000003	29.861999999999998
6886	4	0	3.1000000000000001	0.81	5.2000000000000002	22.699999999999999	4.2119999999999997	18.387
6887	1	0	0.29999999999999999	1.38	2.6299999999999999	17.879999999999999	3.629	24.673999999999999
6887	2	0	1.8999999999999999	1.2	4.4299999999999997	30.68	5.3159999999999998	36.816000000000003
6887	3	0	2.6000000000000001	1.1	6.0899999999999999	29.09	6.6989999999999998	31.998999999999999
6887	4	0	3	0.88999999	10.33	38.329999999999998	9.1940000000000008	34.113999999999997
6888	1	0	0.29999999999999999	1.42	3.0899999999999999	29.34	4.3879999999999999	41.662999999999997
6888	2	0	1.8999999999999999	1.24	3.7999999999999998	27.550000000000001	4.7119999999999997	34.161999999999999
6888	3	0	2.5	1.14	4.4400000000000004	29.940000000000001	5.0620000000000003	34.131999999999998
6888	4	0	2.8999999999999999	0.77999997	8.2200000000000006	31.469999999999999	6.4119999999999999	24.547000000000001
6889	1	0	0.29999999999999999	1.4	2.8500000000000001	26.850000000000001	3.9900000000000002	37.590000000000003
6889	2	0	1.8999999999999999	1.29	2.8500000000000001	26.850000000000001	3.677	34.637
6889	3	0	2.6000000000000001	1.1799999	3.1699999999999999	22.420000000000002	3.7410000000000001	26.456
6889	4	0	3	0.77999997	4.2599999999999998	30.510000000000002	3.323	23.797999999999998
6935	1	0	0.29999999999999999	1.45	4.4699999999999998	53.799999999999997	6.4820000000000002	78.010000000000005
6935	2	0	3.3999999999999999	1.34	5.96	44.960000000000001	7.9859999999999998	60.246000000000002
6935	3	0	4.5999999999999996	1.16	10.359999999999999	68.689999999999998	12.018000000000001	79.680000000000007
6935	4	0	5.4000000000000004	0.66000003	8.6400000000000006	67.640000000000001	5.702	44.642000000000003
6936	1	0	0.29999999999999999	1.76	8.4299999999999997	44.100000000000001	14.837	77.616
6936	2	0	3.7999999999999998	1.58	11.08	46.079999999999998	17.506	72.805999999999997
6936	3	0	5.0999999999999996	1.4400001	23.600000000000001	62.270000000000003	33.984000000000002	89.668999999999997
6936	4	0	6	1.2	42.890000000000001	90.549999999999997	51.468000000000004	108.66
6937	1	0	0.29999999999999999	1.8	5.0599999999999996	39.390000000000001	9.1080000000000005	70.902000000000001
6937	2	0	3.7000000000000002	1.65	5.3600000000000003	38.689999999999998	8.8439999999999994	63.838000000000001
6937	3	0	5	1.55	6.4900000000000002	42.82	10.06	66.370999999999995
6937	4	0	5.9000000000000004	1.3	8.5500000000000007	48.549999999999997	11.115	63.115000000000002
6938	1	0	0.29999999999999999	1.47	3.6200000000000001	54.289999999999999	5.3209999999999997	79.805999999999997
6938	2	0	3.3999999999999999	1.35	4.1500000000000004	55.149999999999999	5.6029999999999998	74.453000000000003
6938	3	0	4.5999999999999996	0.89999998	4.21	50.880000000000003	3.7890000000000001	45.792000000000002
6938	4	0	5.4000000000000004	0.63	5.8499999999999996	61.18	3.6859999999999999	38.542999999999999
6939	1	0	0.29999999999999999	0.58999997	3.6000000000000001	53.600000000000001	2.1240000000000001	31.623999999999999
6939	2	0	2.2000000000000002	0.47	3.79	47.460000000000001	1.7809999999999999	22.306000000000001
6939	3	0	3	0.41999999	4.8300000000000001	53.829999999999998	2.0289999999999999	22.609000000000002
6939	4	0	3.3999999999999999	0.33000001	5.3099999999999996	58.310000000000002	1.752	19.242000000000001
6880	1	0	0.29999999999999999	1.02	4.0999999999999996	22.100000000000001	4.1820000000000004	22.542000000000002
6880	2	0	1.8999999999999999	0.91000003	4.46	19.960000000000001	4.0590000000000002	18.164000000000001
6880	3	0	2.6000000000000001	0.83999997	4.96	26.460000000000001	4.1660000000000004	22.225999999999999
6880	4	0	3	0.62	5.9800000000000004	34.229999999999997	3.7080000000000002	21.222999999999999
6881	1	0	0.29999999999999999	1.29	4.9000000000000004	27.649999999999999	6.3209999999999997	35.667999999999999
6881	2	0	1.8999999999999999	0.94999999	6.5199999999999996	25.27	6.194	24.007000000000001
6881	3	0	2.6000000000000001	0.87	8.1199999999999992	28.620000000000001	7.0640000000000001	24.899000000000001
6881	4	0	3	0.74000001	11.359999999999999	27.609999999999999	8.4060000000000006	20.431000000000001
6882	1	0	0.29999999999999999	1.26	4.4400000000000004	28.940000000000001	5.5940000000000003	36.463999999999999
6882	2	0	1.8	1.1799999	6.7999999999999998	31.300000000000001	8.0239999999999991	36.933999999999997
6882	3	0	2.3999999999999999	1.0700001	9.2200000000000006	33.969999999999999	9.8650000000000002	36.347999999999999
6882	4	0	2.7999999999999998	0.80000001	31.600000000000001	52.100000000000001	25.280000000000001	41.68
6883	1	0	0.29999999999999999	1.3099999	3.48	19.73	4.5590000000000002	25.846
6883	2	0	1.8	1.21	4.1600000000000001	24.41	5.0339999999999998	29.536000000000001
6883	3	0	2.3999999999999999	1.1799999	4.4800000000000004	16.98	5.2859999999999996	20.036000000000001
6883	4	0	2.7999999999999998	0.81	9.5199999999999996	19.77	7.7110000000000003	16.013999999999999
6884	1	0	0.29999999999999999	1.3200001	1.9399999999999999	13.69	2.5609999999999999	18.071000000000002
6884	2	0	1.8	1.1799999	2.46	17.210000000000001	2.903	20.308
6884	3	0	2.3999999999999999	1.01	3.0899999999999999	22.039999999999999	3.121	22.260000000000002
6884	4	0	2.7999999999999998	0.77999997	3.8199999999999998	19.82	2.98	15.460000000000001
6876	1	0	0.29999999999999999	1.87	8.8300000000000001	113.83	16.512	212.86199999999999
6876	2	0	3.7000000000000002	1.61	15	83	24.149999999999999	133.63
6876	3	0	5	1.5599999	22.93	140.59	35.771000000000001	219.31999999999999
6876	4	0	6	0.99000001	49.57	105.56999999999999	49.073999999999998	104.514
6877	1	0	0.29999999999999999	1.89	9.9800000000000004	120.98	18.861999999999998	228.65199999999999
6877	2	0	3.6000000000000001	1.6799999	19.25	124.25	32.340000000000003	208.74000000000001
6877	3	0	4.7999999999999998	1.54	26.280000000000001	173.62	40.470999999999997	267.375
6877	4	0	5.7999999999999998	1.27	44.020000000000003	166.34999999999999	55.905000000000001	211.26400000000001
6878	1	0	0.29999999999999999	1.8200001	8.0199999999999996	77.689999999999998	14.596	141.39599999999999
6878	2	0	3.6000000000000001	1.75	12.470000000000001	112.47	21.823	196.82300000000001
6878	3	0	4.7999999999999998	1.58	14.59	94.920000000000002	23.052	149.97399999999999
6878	4	0	5.7999999999999998	1.5	18.449999999999999	85.120000000000005	27.675000000000001	127.68000000000001
6879	1	0	0.29999999999999999	1.9	7.0800000000000001	74.739999999999995	13.452	142.006
6879	2	0	3.7000000000000002	1.76	10.02	103.34999999999999	17.635000000000002	181.89599999999999
6879	3	0	5	1.6900001	10.720000000000001	79.049999999999997	18.117000000000001	133.59399999999999
6879	4	0	6	1.41	13.83	95.829999999999998	19.5	135.12
6872	1	0	0.29999999999999999	1.5700001	4.4199999999999999	27.920000000000002	6.9390000000000001	43.834000000000003
6872	2	0	3.3999999999999999	1.37	4.6600000000000001	15.66	6.3840000000000003	21.454000000000001
6872	3	0	4.5	1.1900001	6.3799999999999999	27.129999999999999	7.5919999999999996	32.284999999999997
6872	4	0	5.4000000000000004	0.69999999	6.9400000000000004	21.940000000000001	4.8579999999999997	15.358000000000001
6873	1	0	0.29999999999999999	1.76	4.8200000000000003	30.07	8.4830000000000005	52.923000000000002
6873	2	0	3.2000000000000002	1.54	8.4199999999999999	32.920000000000002	12.967000000000001	50.697000000000003
6873	3	0	4.2999999999999998	1.55	10.74	43.990000000000002	16.646999999999998	68.185000000000002
6873	4	0	5.2000000000000002	1.0599999	22.620000000000001	47.619999999999997	23.977	50.476999999999997
6874	1	0	0.29999999999999999	1.79	3.0600000000000001	25.309999999999999	5.4770000000000003	45.305
6874	2	0	3.2000000000000002	1.6799999	5.0599999999999996	36.310000000000002	8.5009999999999994	61.000999999999998
6874	3	0	4.2999999999999998	1.51	6.3600000000000003	40.109999999999999	9.6039999999999992	60.566000000000003
6874	4	0	5.2000000000000002	0.99000001	11.039999999999999	47.039999999999999	10.93	46.57
6875	1	0	0.29999999999999999	1.77	3.2999999999999998	30.550000000000001	5.8410000000000002	54.073
6875	2	0	3	1.59	4.3399999999999999	22.34	6.9009999999999998	35.521000000000001
6875	3	0	4	1.47	4.7000000000000002	39.450000000000003	6.9089999999999998	57.991
6875	4	0	4.7999999999999998	1.2	6.0599999999999996	27.059999999999999	7.2720000000000002	32.472000000000001
6867	1	0	0.29999999999999999	1.55	0.41999999999999998	2.9199999999999999	0.65100000000000002	4.5259999999999998
6867	2	0	3.7999999999999998	1.08	1.1200000000000001	15.619999999999999	1.21	16.870000000000001
6867	3	0	4.5999999999999996	0.88999999	2.0800000000000001	6.8300000000000001	1.851	6.0789999999999997
6868	1	0	0.29999999999999999	1.65	0.97999999999999998	11.48	1.617	18.942
6868	2	0	2.7999999999999998	1.42	8.1999999999999993	9.1999999999999993	11.644	13.064
6868	3	0	3.7999999999999998	1.28	7.7800000000000002	12.279999999999999	9.9580000000000002	15.718
6868	4	0	4.5	0.74000001	17.359999999999999	28.109999999999999	12.846	20.800999999999998
6869	1	0	0.29999999999999999	1.63	0.47999999999999998	25.48	0.78200000000000003	41.531999999999996
6869	2	0	2.8999999999999999	1.5	5.4800000000000004	7.2300000000000004	8.2200000000000006	10.845000000000001
6869	3	0	3.7999999999999998	1.23	16.940000000000001	42.189999999999998	20.835999999999999	51.893999999999998
6869	4	0	4.5999999999999996	0.80000001	139.36000000000001	161.61000000000001	111.488	129.28800000000001
6870	1	0	0.29999999999999999	1.71	0.17999999999999999	12.43	0.308	21.254999999999999
6870	2	0	2.8999999999999999	1.53	1.96	7.21	2.9990000000000001	11.031000000000001
6870	3	0	3.7999999999999998	1.34	2.3799999999999999	23.129999999999999	3.1890000000000001	30.994
6870	4	0	4.5999999999999996	0.86000001	7.9800000000000004	9.2300000000000004	6.8630000000000004	7.9379999999999997
6871	1	0	0.29999999999999999	1.3	0.080000000000000002	11.33	0.104	14.728999999999999
6871	2	0	3	1.39	0.12	21.870000000000001	0.16700000000000001	30.399000000000001
6871	3	0	4	1.1799999	0.34000000000000002	10.09	0.40100000000000002	11.906000000000001
6871	4	0	4.7999999999999998	0.34999999	0.90000000000000002	21.149999999999999	0.315	7.4020000000000001
6863	1	0	0.29999999999999999	0.80000001	3.04	50.289999999999999	2.4319999999999999	40.231999999999999
6863	2	0	1.3999999999999999	0.64999998	3.5600000000000001	66.060000000000002	2.3140000000000001	42.939
6863	3	0	1.8999999999999999	0.47	3.6699999999999999	62.920000000000002	1.7250000000000001	29.571999999999999
6863	4	0	2.2000000000000002	0.40000001	4.2999999999999998	65.049999999999997	1.72	26.02
6864	1	0	0.29999999999999999	1.49	3.2799999999999998	52.530000000000001	4.8869999999999996	78.269999999999996
6864	2	0	2.3999999999999999	1.33	3.9399999999999999	44.189999999999998	5.2400000000000002	58.773000000000003
6864	3	0	3.2000000000000002	1.2	4.2400000000000002	61.990000000000002	5.0880000000000001	74.388000000000005
6864	4	0	3.7999999999999998	0.95999998	5.8499999999999996	61.350000000000001	5.6159999999999997	58.896000000000001
6865	1	0	0.29999999999999999	1.61	3.0899999999999999	50.590000000000003	4.9749999999999996	81.450000000000003
6865	2	0	2.2000000000000002	1.4400001	3.3500000000000001	45.100000000000001	4.8239999999999998	64.944000000000003
6865	3	0	3	1.26	3.3500000000000001	57.100000000000001	4.2210000000000001	71.945999999999998
6865	4	0	3.5	1.14	4	58.5	4.5599999999999996	66.689999999999998
6866	1	0	0.29999999999999999	3.02	1.3700000000000001	54.270000000000003	4.1369999999999996	163.89500000000001
6866	2	0	2.2000000000000002	1.3099999	3.1099999999999999	46.859999999999999	4.0739999999999998	61.387
6866	3	0	3	1.12	3.04	52.289999999999999	3.4049999999999998	58.564999999999998
6866	4	0	3.5	0.98000002	3.3700000000000001	67.620000000000005	3.3029999999999999	66.268000000000001
6858	1	0	0.29999999999999999	1.03	3.2000000000000002	57.5	3.2959999999999998	59.225000000000001
6858	2	0	2.1000000000000001	0.82999998	3.6400000000000001	62.939999999999998	3.0209999999999999	52.240000000000002
6858	3	0	2.7999999999999998	0.74000001	4.1799999999999997	64.480000000000004	3.093	47.715000000000003
6858	4	0	3.2999999999999998	0.50999999	5.1200000000000001	73.420000000000002	2.6110000000000002	37.444000000000003
6859	1	0	0.29999999999999999	1.53	3.6600000000000001	57.659999999999997	5.5999999999999996	88.219999999999999
6859	2	0	2.8999999999999999	1.33	4.6399999999999997	59.939999999999998	6.1710000000000003	79.719999999999999
6859	3	0	3.8999999999999999	1.12	4.7999999999999998	67.400000000000006	5.3760000000000003	75.488
6859	4	0	4.7000000000000002	0.86000001	6.7800000000000002	59.780000000000001	5.8310000000000004	51.411000000000001
6860	1	0	0.29999999999999999	1.7	3.5600000000000001	61.159999999999997	6.0519999999999996	103.97199999999999
6860	2	0	2.8999999999999999	1.48	4.6799999999999997	62.280000000000001	6.9260000000000002	92.174000000000007
6860	3	0	3.7999999999999998	1.25	9.4199999999999999	65.719999999999999	11.775	82.150000000000006
6860	4	0	4.5999999999999996	0.88999999	59.920000000000002	122.52	53.329000000000001	109.04300000000001
6861	1	0	0.29999999999999999	1.76	3.3599999999999999	49.609999999999999	5.9139999999999997	87.313999999999993
6861	2	0	3.1000000000000001	1.54	3.48	51.229999999999997	5.359	78.894000000000005
6861	3	0	4.2000000000000002	1.37	3.4199999999999999	59.420000000000002	4.6849999999999996	81.405000000000001
6861	4	0	5	1.01	3.8799999999999999	52.630000000000003	3.919	53.155999999999999
6862	1	0	0.29999999999999999	1.6	3.48	44.979999999999997	5.5679999999999996	71.968000000000004
6862	2	0	3.1000000000000001	1.42	3.3399999999999999	50.340000000000003	4.7430000000000003	71.483000000000004
6862	3	0	4.0999999999999996	1.38	3.48	53.979999999999997	4.8019999999999996	74.492000000000004
6862	4	0	4.9000000000000004	0.83999997	4.6600000000000001	67.659999999999997	3.9140000000000001	56.834000000000003
6855	1	0	0.29999999999999999	1.1	1.46	11.460000000000001	1.6060000000000001	12.606
6855	2	0	2.7000000000000002	1.05	1.0800000000000001	11.74	1.1339999999999999	12.327
6855	3	0	3.6000000000000001	1.02	2.5800000000000001	15.24	2.6320000000000001	15.545
6855	4	0	4.2999999999999998	0.73000002	1.8200000000000001	12.15	1.329	8.8689999999999998
6856	1	0	0.29999999999999999	1.65	1.5	10.16	2.4750000000000001	16.763999999999999
6856	2	0	2.6000000000000001	1.49	1.02	9.0199999999999996	1.52	13.44
6856	3	0	3.5	1.46	0.90000000000000002	18.23	1.3140000000000001	26.616
6856	4	0	4.2000000000000002	1.26	1.8200000000000001	17.82	2.2930000000000001	22.452999999999999
6857	1	0	0.29999999999999999	1.29	0.73999999999999999	12.74	0.95499999999999996	16.434999999999999
6857	2	0	2.3999999999999999	1.38	0.69999999999999996	16.449999999999999	0.96599999999999997	22.701000000000001
6857	3	0	3.2000000000000002	1.15	0.57999999999999996	14.08	0.66700000000000004	16.192
6857	4	0	3.7999999999999998	0.94	0.81999999999999995	13.82	0.77100000000000002	12.991
13101	1	0	0.29999999999999999	1.8099999	5.665	40.744999999999997	10.254	73.748000000000005
13101	2	0	3.2999999999999998	1.665	4.3220000000000001	37.741999999999997	7.1959999999999997	62.840000000000003
13101	3	0	4.4000000000000004	1.462	5.0129999999999999	41.853000000000002	7.3289999999999997	61.189
13101	4	0	5	1.377	5.202	41.082000000000001	7.1630000000000003	56.57
13101	5	0	5.2999999999999998	1.191	5.5019999999999998	42.561999999999998	6.5529999999999999	50.691000000000003
13102	1	0	0.29999999999999999	1.692	5.2160000000000002	36.915999999999997	8.8249999999999993	62.462000000000003
13102	2	0	3.1000000000000001	1.557	7.2240000000000002	44.564	11.247999999999999	69.385999999999996
13102	3	0	4.0999999999999996	1.336	13.813000000000001	50.052999999999997	18.454000000000001	66.870999999999995
13102	4	0	4.5999999999999996	1.273	25.242000000000001	69.001999999999995	32.133000000000003	87.840000000000003
13102	5	0	4.9000000000000004	1.085	63.136000000000003	97.036000000000001	68.503	105.28400000000001
13103	1	0	0.29999999999999999	1.725	5.6289999999999996	43.348999999999997	9.7100000000000009	74.777000000000001
13103	2	0	3.1000000000000001	1.535	13.347	53.686999999999998	20.488	82.409999999999997
13103	3	0	4.2000000000000002	1.237	34.055999999999997	74.656000000000006	42.127000000000002	92.349000000000004
13103	4	0	4.7000000000000002	1.4069999	28.576000000000001	65.256	40.206000000000003	91.814999999999998
13103	5	0	5	1.355	49.313000000000002	81.933000000000007	66.819000000000003	111.01900000000001
13104	1	0	0.29999999999999999	1.641	5.5149999999999997	39.555	9.0500000000000007	64.909999999999997
13104	2	0	3.2999999999999998	1.3890001	12.367000000000001	52.487000000000002	17.178000000000001	72.903999999999996
13104	3	0	4.4000000000000004	1.433	27.879999999999999	62.200000000000003	39.951999999999998	89.132999999999996
13104	4	0	5	1.344	55.207000000000001	92.927000000000007	74.197999999999993	124.89400000000001
13104	5	0	5.2999999999999998	1.327	350.41300000000001	387.09300000000002	464.99799999999999	513.67200000000003
13105	1	0	0.29999999999999999	1.796	6.4550000000000001	50.274999999999999	11.593	90.293999999999997
13105	2	0	3.3999999999999999	1.573	12.773	49.993000000000002	20.091999999999999	78.638999999999996
13105	3	0	4.5999999999999996	1.3049999	24.318000000000001	67.378	31.734999999999999	87.927999999999997
13105	4	0	5.0999999999999996	1.189	36.268999999999998	78.069000000000003	43.124000000000002	92.823999999999998
13105	5	0	5.5	1.08	114.876	152.89599999999999	124.066	165.12799999999999
12296	1	0	0.29999999999999999	0.71700001	0.96199999999999997	9.3219999999999992	0.68999999999999995	6.6840000000000002
12296	2	0	1.3999999999999999	0.69999999	1.0760000000000001	11.096	0.753	7.7670000000000003
12296	3	0	1.8	0.44100001	1.4650000000000001	10.585000000000001	0.64600000000000002	4.6680000000000001
12296	4	0	2.1000000000000001	0.25	1.4450000000000001	10.845000000000001	0.36099999999999999	2.7109999999999999
12297	1	0	0.29999999999999999	0.93699998	0.96199999999999997	5.282	0.90100000000000002	4.9489999999999998
12297	2	0	1.3	0.875	1.8360000000000001	15.256	1.607	13.349
12297	3	0	1.8	0.75300002	0.98499999999999999	10.005000000000001	0.74199999999999999	7.5339999999999998
12297	4	0	2	0.77100003	2.3999999999999999	11.619999999999999	1.8500000000000001	8.9589999999999996
12298	1	0	0.29999999999999999	0.995	0.215	6.7949999999999999	0.214	6.7610000000000001
12298	2	0	1.5	0.89300001	1.8	10.619999999999999	1.607	9.484
12298	3	0	2	0.85500002	1.302	8.1820000000000004	1.113	6.9960000000000004
12298	4	0	2.2999999999999998	0.74400002	1.9330000000000001	16.733000000000001	1.4379999999999999	12.449
12299	1	0	0.29999999999999999	0.97899997	1.0649999999999999	8.2650000000000006	1.0429999999999999	8.0909999999999993
12299	2	0	1.5	0.884	1.4239999999999999	8.6039999999999992	1.2589999999999999	7.6059999999999999
12299	3	0	2	0.77999997	0.82399999999999995	7.5839999999999996	0.64300000000000002	5.9160000000000004
12299	4	0	2.2999999999999998	0.59200001	2.3149999999999999	13.395	1.3700000000000001	7.9299999999999997
12300	1	0	0.29999999999999999	0.94499999	1.147	7.1269999999999998	1.0840000000000001	6.7350000000000003
12300	2	0	1.6000000000000001	0.88599998	1.956	8.4760000000000009	1.7330000000000001	7.5099999999999998
12300	3	0	2.1000000000000001	0.81699997	3.8199999999999998	10.1	3.121	8.2520000000000007
12300	4	0	2.3999999999999999	0.58399999	12.778	18.297999999999998	7.4619999999999997	10.686
12190	1	0	0.29999999999999999	1.135	1.9399999999999999	22.399999999999999	2.202	25.423999999999999
12190	2	0	1.8	1.136	1.105	29.725000000000001	1.2549999999999999	33.768000000000001
12190	3	0	2.3999999999999999	0.96600002	1.569	23.449000000000002	1.516	22.652000000000001
12190	4	0	2.7999999999999998	0.92500001	1.6359999999999999	24.436	1.5129999999999999	22.603000000000002
12189	1	0	0.29999999999999999	1.511	1.4510000000000001	22.231000000000002	2.1920000000000002	33.591000000000001
12189	2	0	3	1.45	2.8399999999999999	22.739999999999998	4.1180000000000003	32.972999999999999
12189	3	0	4	1.285	5.3220000000000001	27.021999999999998	6.8390000000000004	34.722999999999999
12189	4	0	4.7999999999999998	1.066	17.018000000000001	38.338000000000001	18.140999999999998	40.868000000000002
12188	1	0	0.29999999999999999	1.575	2.1309999999999998	24.131	3.3559999999999999	38.006
12188	2	0	3	1.477	2.7130000000000001	24.733000000000001	4.0069999999999997	36.530999999999999
12188	3	0	4	1.2690001	5.7560000000000002	35.555999999999997	7.3040000000000003	45.121000000000002
12188	4	0	4.7999999999999998	0.417	71.823999999999998	93.944000000000003	29.951000000000001	39.174999999999997
12187	1	0	0.29999999999999999	1.549	2.0150000000000001	21.535	3.121	33.357999999999997
12187	2	0	3	1.329	4.2130000000000001	26.513000000000002	5.5990000000000002	35.235999999999997
12187	3	0	4	1.291	8.1050000000000004	31.125	10.464	40.182000000000002
12187	4	0	4.7999999999999998	0.97600001	21.498000000000001	48.838000000000001	20.981999999999999	47.665999999999997
12186	1	0	0.29999999999999999	1.416	3.8239999999999998	23.763999999999999	5.415	33.649999999999999
12186	2	0	3.1000000000000001	1.286	24.727	51.027000000000001	31.798999999999999	65.620999999999995
12186	3	0	4.2000000000000002	1.039	73.959999999999994	95.159999999999997	76.843999999999994	98.870999999999995
12186	4	0	4.7000000000000002	0.995	80.079999999999998	103.73999999999999	79.680000000000007	103.221
12186	5	0	4.9000000000000004	1.017	104.26000000000001	131.80000000000001	106.032	134.041
11353	1	0	0.20000000000000001	1.16	1.605	15.505000000000001	1.8620000000000001	17.986000000000001
11353	2	0	1.8999999999999999	1.072	1.667	17.247	1.7869999999999999	18.489000000000001
11353	3	0	2.5	0.99000001	2.0840000000000001	17.584	2.0630000000000002	17.408000000000001
11353	4	0	2.8999999999999999	0.81900001	2.2250000000000001	17.684999999999999	1.8220000000000001	14.484
11352	1	0	0.20000000000000001	1.23	0.93600000000000005	13.036	1.151	16.033999999999999
11352	2	0	1.7	1.1670001	0.995	13.135	1.161	15.329000000000001
11352	3	0	2.2999999999999998	1.02	1.0580000000000001	13.318	1.079	13.584
11352	4	0	2.7000000000000002	0.86400002	1.462	14.922000000000001	1.2629999999999999	12.893000000000001
11351	1	0	0.20000000000000001	1.216	1	13.140000000000001	1.216	15.978
11351	2	0	1.8	1.16	1.113	13.513	1.2909999999999999	15.675000000000001
11351	3	0	2.3999999999999999	1.0319999	1.4179999999999999	12.657999999999999	1.4630000000000001	13.063000000000001
11351	4	0	2.7999999999999998	0.90799999	2.3759999999999999	15.336	2.157	13.925000000000001
11350	1	0	0.20000000000000001	1.193	1.0069999999999999	12.606999999999999	1.2010000000000001	15.039999999999999
11350	2	0	2	1.099	1.202	13.722	1.321	15.08
11350	3	0	2.6000000000000001	0.94999999	1.649	14.029	1.5669999999999999	13.327999999999999
11350	4	0	3	0.79400003	3.218	16.257999999999999	2.5550000000000002	12.909000000000001
11349	1	0	0.20000000000000001	1.179	1.107	12.367000000000001	1.3049999999999999	14.581
11349	2	0	2.1000000000000001	1.068	1.8620000000000001	13.622	1.9890000000000001	14.548
11349	3	0	2.7999999999999998	0.94700003	6.1849999999999996	17.805	5.8570000000000002	16.861000000000001
11349	4	0	3.2999999999999998	0.82599998	26.626999999999999	38.686999999999998	21.994	31.954999999999998
11348	1	0	0.20000000000000001	1.336	1.284	23.303999999999998	1.7150000000000001	31.134
11348	2	0	2.2000000000000002	1.327	1.4850000000000001	22.445	1.9710000000000001	29.785
11348	3	0	2.8999999999999999	1.273	1.4710000000000001	22.731000000000002	1.873	28.937000000000001
11348	4	0	3.3999999999999999	0.96600002	1.4690000000000001	24.149000000000001	1.419	23.327999999999999
11347	1	0	0.20000000000000001	1.646	1.5249999999999999	22.765000000000001	2.5099999999999998	37.470999999999997
11347	2	0	2.6000000000000001	1.479	1.736	23.556000000000001	2.5680000000000001	34.838999999999999
11347	3	0	3.3999999999999999	1.302	1.8380000000000001	22.378	2.3929999999999998	29.135999999999999
11347	4	0	4.0999999999999996	1.034	2.8050000000000002	24.045000000000002	2.8999999999999999	24.863
11346	1	0	0.20000000000000001	1.624	1.704	24.024000000000001	2.7669999999999999	39.015000000000001
11346	2	0	2.5	1.5420001	2.1269999999999998	26.007000000000001	3.2799999999999998	40.103000000000002
11346	3	0	3.3999999999999999	1.414	2.7530000000000001	26.132999999999999	3.8929999999999998	36.951999999999998
11346	4	0	4	1.245	5.1420000000000003	30.161999999999999	6.4020000000000001	37.552
11345	1	0	0.20000000000000001	1.605	1.885	26.324999999999999	3.0249999999999999	42.252000000000002
11345	2	0	2.5	1.489	4.1130000000000004	25.033000000000001	6.1239999999999997	37.274000000000001
11345	3	0	3.2999999999999998	1.436	6.1399999999999997	30.18	8.8170000000000002	43.338000000000001
11345	4	0	3.8999999999999999	1.288	15.782	40.341999999999999	20.327000000000002	51.960000000000001
11344	1	0	0.20000000000000001	1.605	4.5650000000000004	24.184999999999999	7.327	38.817
11344	2	0	2.7000000000000002	1.4069999	23.466999999999999	44.627000000000002	33.018000000000001	62.789999999999999
11344	3	0	3.6000000000000001	1.353	43.127000000000002	64.747	58.350999999999999	87.602999999999994
11344	4	0	4.2999999999999998	1.228	68.040000000000006	90.459999999999994	83.552999999999997	111.08499999999999
11385	1	0	0.20000000000000001	0.94	0.90700000000000003	11.446999999999999	0.85299999999999998	10.76
11385	2	0	1.6000000000000001	0.99000001	1.0509999999999999	14.211	1.04	14.069000000000001
11385	3	0	2.2000000000000002	0.93699998	0.92000000000000004	8.9000000000000004	0.86199999999999999	8.3390000000000004
11385	4	0	2.5	0.76099998	1.0249999999999999	12.265000000000001	0.78000000000000003	9.3339999999999996
11384	1	0	0.20000000000000001	1.053	0.86499999999999999	10.385	0.91100000000000003	10.935
11384	2	0	1.6000000000000001	0.96100003	0.90000000000000002	12.460000000000001	0.86499999999999999	11.974
11384	3	0	2.1000000000000001	0.83099997	1.1619999999999999	10.302	0.96599999999999997	8.5609999999999999
11384	4	0	2.3999999999999999	0.70700002	0.998	11.018000000000001	0.70599999999999996	7.79
11383	1	0	0.20000000000000001	1.007	1.542	11.042	1.5529999999999999	11.119
11383	2	0	1.5	0.90100002	1.5669999999999999	12.007	1.4119999999999999	10.818
11383	3	0	2	0.708	4.2599999999999998	16.440000000000001	3.016	11.640000000000001
11383	4	0	2.2999999999999998	0.667	5.9269999999999996	15.327	3.9529999999999998	10.223000000000001
11382	1	0	0.20000000000000001	0.98299998	1.411	10.430999999999999	1.387	10.254
11382	2	0	1.7	0.884	1.6639999999999999	12.843999999999999	1.4710000000000001	11.353999999999999
11382	3	0	2.2999999999999998	0.78799999	2.3820000000000001	12.802	1.877	10.087999999999999
11382	4	0	2.7000000000000002	0.71700001	5.5670000000000002	14.667	3.992	10.516
11381	1	0	0.20000000000000001	1.041	1.4510000000000001	12.090999999999999	1.51	12.587
11381	2	0	1.8999999999999999	0.96600002	1.9850000000000001	13.244999999999999	1.9179999999999999	12.795
11381	3	0	2.6000000000000001	0.81199998	4.8559999999999999	17.315999999999999	3.9430000000000001	14.061
11381	4	0	3	0.66900003	14.292999999999999	25.573	9.5619999999999994	17.108000000000001
11390	1	0	0.20000000000000001	0.991	0.313	4.3929999999999998	0.31	4.3529999999999998
11390	2	0	1.3999999999999999	1.003	0.40400000000000003	4.6040000000000001	0.40500000000000003	4.6180000000000003
11390	3	0	1.8	0.93300003	0.55600000000000005	5.1159999999999997	0.51900000000000002	4.7729999999999997
11390	4	0	2.1000000000000001	0.73699999	0.59299999999999997	5.0730000000000004	0.437	3.7389999999999999
11389	1	0	0.20000000000000001	1.072	0.38500000000000001	4.2649999999999997	0.41299999999999998	4.5720000000000001
11389	2	0	1.3	0.97899997	0.46000000000000002	4.3600000000000003	0.45000000000000001	4.2679999999999998
11389	3	0	1.8	0.86000001	0.496	6.016	0.42699999999999999	5.1740000000000004
11389	4	0	2	0.671	1.24	6.7999999999999998	0.83199999999999996	4.5629999999999997
11388	1	0	0.20000000000000001	0.98299998	0.51600000000000001	5.7759999999999998	0.50700000000000001	5.6779999999999999
11388	2	0	1.3	0.94400001	0.35499999999999998	3.9350000000000001	0.33500000000000002	3.7149999999999999
11388	3	0	1.7	0.85000002	0.50700000000000001	5.8070000000000004	0.43099999999999999	4.9359999999999999
11388	4	0	2	0.73100001	1.0549999999999999	8.5150000000000006	0.77100000000000002	6.2240000000000002
11387	1	0	0.20000000000000001	0.98299998	0.49099999999999999	5.7910000000000004	0.48299999999999998	5.6929999999999996
11387	2	0	1.7	0.89399999	1.3049999999999999	7.9050000000000002	1.167	7.0670000000000002
11387	3	0	2.2000000000000002	0.75800002	3.0510000000000002	14.430999999999999	2.3130000000000002	10.939
11387	4	0	2.6000000000000001	0.667	9.6760000000000002	24.936	6.4539999999999997	16.632000000000001
11386	1	0	0.20000000000000001	0.94700003	0.44700000000000001	5.6470000000000002	0.42299999999999999	5.3479999999999999
11386	2	0	1.3999999999999999	0.89399999	1.2330000000000001	9.6329999999999991	1.1020000000000001	8.6120000000000001
11386	3	0	1.8	0.77700001	4.0049999999999999	16.405000000000001	3.1120000000000001	12.747
11386	4	0	2.1000000000000001	0.65399998	24.870999999999999	54.271000000000001	16.265999999999998	35.493000000000002
11011	1	0	0.20000000000000001	1.4069999	1.502	27.422000000000001	2.113	38.582999999999998
11011	2	0	1.8	1.216	1.8149999999999999	26.155000000000001	2.2069999999999999	31.803999999999998
11011	3	0	2.3999999999999999	1.119	2.371	28.271000000000001	2.653	31.635000000000002
11011	4	0	2.8999999999999999	0.889	2.6869999999999998	30.367000000000001	2.3889999999999998	26.995999999999999
11010	1	0	0.20000000000000001	1.348	2.1869999999999998	30.646999999999998	2.948	41.311999999999998
11010	2	0	1.7	1.257	2.4980000000000002	31.698	3.1400000000000001	39.844000000000001
11010	3	0	2.2000000000000002	1.1059999	2.7050000000000001	30.364999999999998	2.992	33.584000000000003
11010	4	0	2.7000000000000002	0.97600001	3.7959999999999998	33.475999999999999	3.7050000000000001	32.673000000000002
11009	1	0	0.20000000000000001	1.322	2.0870000000000002	29.146999999999998	2.7589999999999999	38.531999999999996
11009	2	0	1.8	1.182	2.665	30.324999999999999	3.1499999999999999	35.844000000000001
11009	3	0	2.3999999999999999	0.97899997	3.6400000000000001	33.700000000000003	3.5640000000000001	32.991999999999997
11009	4	0	2.8999999999999999	0.80000001	16.936	50.936	13.548999999999999	40.749000000000002
11008	1	0	0.20000000000000001	1.21	2.504	31.963999999999999	3.0299999999999998	38.676000000000002
11008	2	0	2	1.044	8.6349999999999998	39.435000000000002	9.0150000000000006	41.170000000000002
11008	3	0	2.7000000000000002	0.91799998	27.260000000000002	62.659999999999997	25.024999999999999	57.521999999999998
11008	4	0	3.2999999999999998	0.72899997	80.676000000000002	111.496	58.813000000000002	81.281000000000006
11007	1	0	0.20000000000000001	1.1210001	2.8650000000000002	31.984999999999999	3.2120000000000002	35.854999999999997
11007	2	0	2.1000000000000001	0.96600002	4.9950000000000001	34.935000000000002	4.8250000000000002	33.747
11007	3	0	2.7999999999999998	1.043	8.6910000000000007	36.570999999999998	9.0649999999999995	38.143999999999998
11007	4	0	3.3999999999999999	0.69099998	16.341999999999999	43.082000000000001	11.292	29.77
10687	1	0	0.10000000000000001	0.92000002	2.3450000000000002	19.605	2.157	18.036999999999999
10687	2	0	1.3999999999999999	0.75	3.0289999999999999	21.649000000000001	2.2719999999999998	16.236999999999998
10687	3	0	1.8	0.63999999	2.8559999999999999	26.736000000000001	1.8280000000000001	17.111000000000001
10687	4	0	2.2000000000000002	0.55000001	3.0760000000000001	24.135999999999999	1.6919999999999999	13.275
10686	1	0	0.10000000000000001	1.0599999	2.6840000000000002	19.923999999999999	2.8450000000000002	21.119
10686	2	0	1.3999999999999999	0.89999998	3.52	19.739999999999998	3.1680000000000001	17.765999999999998
10686	3	0	1.8	0.81	3.8999999999999999	20.640000000000001	3.1589999999999998	16.718
10686	4	0	2.2000000000000002	0.74000001	4.9779999999999998	21.957999999999998	3.6840000000000002	16.248999999999999
10685	1	0	0.10000000000000001	1.09	1.405	15.085000000000001	1.5309999999999999	16.443000000000001
10685	2	0	1.3	0.89999998	1.7749999999999999	16.434999999999999	1.5980000000000001	14.791
10685	3	0	1.7	0.82999998	1.855	17.114999999999998	1.54	14.205
10685	4	0	2	0.76999998	2.2450000000000001	17.945	1.7290000000000001	13.818
10684	1	0	0.10000000000000001	1.1	1.76	17.940000000000001	1.9359999999999999	19.734000000000002
10684	2	0	1.3999999999999999	0.87	1.9750000000000001	16.855	1.718	14.664
10684	3	0	1.8	0.80000001	3.133	17.992999999999999	2.5059999999999998	14.394
10684	4	0	2.2000000000000002	0.72000003	3.3620000000000001	16.962	2.4209999999999998	12.212999999999999
10683	1	0	0.10000000000000001	0.94999999	2.0710000000000002	15.911	1.9670000000000001	15.115
10683	2	0	1.7	0.75999999	2.891	18.431000000000001	2.1970000000000001	14.007999999999999
10683	3	0	2.2999999999999998	0.68000001	6.2640000000000002	21.143999999999998	4.2599999999999998	14.378
10683	4	0	2.7999999999999998	0.63	139.58699999999999	157.80699999999999	87.939999999999998	99.418000000000006
10682	1	0	0.29999999999999999	1.21	1.8560000000000001	13.696	2.246	16.571999999999999
10682	2	0	2.1000000000000001	1.03	3.173	17.213000000000001	3.2679999999999998	17.728999999999999
10682	3	0	2.7999999999999998	0.88	6.444	19.824000000000002	5.6710000000000003	17.445
10682	4	0	3.2999999999999998	0.50999999	21.795999999999999	37.055999999999997	11.116	18.899000000000001
10681	1	0	0.29999999999999999	1.05	3.4870000000000001	17.007000000000001	3.661	17.856999999999999
10681	2	0	2.1000000000000001	1.01	5.282	17.222000000000001	5.335	17.393999999999998
10681	3	0	2.7999999999999998	0.86000001	12.702	28.641999999999999	10.923999999999999	24.632000000000001
10681	4	0	3.2999999999999998	0.68000001	28.067	44.826999999999998	19.085999999999999	30.481999999999999
8205	1	0	0.29999999999999999	0.74000001	2.2799999999999998	42.340000000000003	1.6870000000000001	31.332000000000001
8205	2	0	1.5	0.76999998	1.99	44.829999999999998	1.532	34.518999999999998
8205	3	0	2	0.67000002	2.0499999999999998	37.289999999999999	1.3740000000000001	24.984000000000002
8205	4	0	2.2999999999999998	0.34	2.6699999999999999	41.189999999999998	0.90800000000000003	14.005000000000001
8206	1	0	0.29999999999999999	0.97000003	2.4399999999999999	36.200000000000003	2.367	35.113999999999997
8206	2	0	1.5	0.91000003	2.75	40.57	2.5030000000000001	36.918999999999997
8206	3	0	2	0.88	3.0299999999999998	40.549999999999997	2.6659999999999999	35.683999999999997
8206	4	0	2.2999999999999998	0.75999999	3.2599999999999998	29.699999999999999	2.4780000000000002	22.571999999999999
8207	1	0	0.29999999999999999	1.02	2.3399999999999999	34.5	2.387	35.189999999999998
8207	2	0	1.5	0.91000003	3.0099999999999998	32.509999999999998	2.7389999999999999	29.584
8207	3	0	2	0.94	3.3900000000000001	35.990000000000002	3.1869999999999998	33.831000000000003
8207	4	0	2.2999999999999998	0.79000002	4.2300000000000004	41.969999999999999	3.3420000000000001	33.155999999999999
8208	1	0	0.29999999999999999	0.92000002	2.1600000000000001	38.299999999999997	1.9870000000000001	35.235999999999997
8208	2	0	1.8	0.81999999	2.5	33.5	2.0499999999999998	27.469999999999999
8208	3	0	2.3999999999999999	0.76999998	2.9399999999999999	33.039999999999999	2.2639999999999998	25.440999999999999
8208	4	0	2.7999999999999998	0.63999999	4.2300000000000004	39.350000000000001	2.7069999999999999	25.184000000000001
8209	1	0	0.29999999999999999	0.92000002	2.27	36.609999999999999	2.0880000000000001	33.680999999999997
8209	2	0	1.8	0.81999999	2.0099999999999998	31.170000000000002	1.6479999999999999	25.559000000000001
8209	3	0	2.3999999999999999	0.74000001	3.2000000000000002	36.560000000000002	2.3679999999999999	27.053999999999998
8209	4	0	2.7999999999999998	0.58999997	6.7800000000000002	40.619999999999997	4	23.966000000000001
8200	1	0	0.29999999999999999	0.99000001	2.5699999999999998	28.309999999999999	2.544	28.027000000000001
8200	2	0	2.5	0.94	2.4900000000000002	29.289999999999999	2.3410000000000002	27.533000000000001
8200	3	0	3.3999999999999999	0.77999997	1.6699999999999999	32.07	1.3029999999999999	25.015000000000001
8200	4	0	4	0.19	2.9700000000000002	36.950000000000003	0.56399999999999995	7.0199999999999996
8201	1	0	0.29999999999999999	1.61	2.6699999999999999	31.969999999999999	4.2990000000000004	51.472000000000001
8201	2	0	2.8999999999999999	1.58	2.6400000000000001	30.239999999999998	4.1710000000000003	47.779000000000003
8201	3	0	3.8999999999999999	1.37	2.6899999999999999	31.350000000000001	3.6850000000000001	42.950000000000003
8201	4	0	4.7000000000000002	1.0700001	2.96	28.879999999999999	3.1669999999999998	30.902000000000001
8202	1	0	0.29999999999999999	1.55	3.5499999999999998	31.629999999999999	5.5019999999999998	49.027000000000001
8202	2	0	3.1000000000000001	1.42	4.5199999999999996	33.960000000000001	6.4180000000000001	48.222999999999999
8202	3	0	4.2000000000000002	1.24	10.01	35.509999999999998	12.412000000000001	44.031999999999996
8202	4	0	5	0.5	67.670000000000002	92.870000000000005	33.835000000000001	46.435000000000002
8203	1	0	0.29999999999999999	1.45	3.23	32.469999999999999	4.6840000000000002	47.082000000000001
8203	2	0	3	1.36	7.1699999999999999	34.729999999999997	9.7509999999999994	47.232999999999997
8203	3	0	4	1.33	12.960000000000001	40.719999999999999	17.236999999999998	54.158000000000001
8203	4	0	4.7999999999999998	1.05	18.539999999999999	47.68	19.466999999999999	50.064
8204	1	0	0.29999999999999999	1.22	4.2999999999999998	29.579999999999998	5.2460000000000004	36.088000000000001
8204	2	0	3	1.25	12.68	38.5	15.85	48.125
8204	3	0	4	1.14	22.489999999999998	46.409999999999997	25.638999999999999	52.906999999999996
8204	4	0	4.7999999999999998	0.88999999	102.89	127.84999999999999	91.572000000000003	113.786
8075	1	0	0.29999999999999999	1.344	2.3999999999999999	34.219999999999999	3.226	45.991999999999997
8075	2	0	2.2000000000000002	1.2029999	2.3599999999999999	32.020000000000003	2.839	38.520000000000003
8075	3	0	3	1.128	2.6800000000000002	31.98	3.0230000000000001	36.073
8075	4	0	3.6000000000000001	0.787	2.6400000000000001	34.880000000000003	2.0779999999999998	27.451000000000001
8076	1	0	0.29999999999999999	1.4450001	2.5	38.649999999999999	3.613	55.848999999999997
8076	2	0	2.6000000000000001	1.2690001	2.9399999999999999	33.700000000000003	3.7309999999999999	42.765000000000001
8076	3	0	3.3999999999999999	1.23	3.1899999999999999	41.130000000000003	3.9239999999999999	50.590000000000003
8076	4	0	4.0999999999999996	0.92799997	5.8499999999999996	33.93	5.4290000000000003	31.486999999999998
8077	1	0	0.29999999999999999	1.385	2.75	33.759999999999998	3.8090000000000002	46.758000000000003
8077	2	0	2.7000000000000002	1.205	3.5499999999999998	33.649999999999999	4.2779999999999996	40.548000000000002
8077	3	0	3.6000000000000001	1.099	8.6699999999999999	48.170000000000002	9.5280000000000005	52.939
8077	4	0	4.2999999999999998	0.89899999	21.84	55.719999999999999	19.634	50.091999999999999
8078	1	0	0.29999999999999999	1.23	3.8100000000000001	35.759999999999998	4.6859999999999999	43.984999999999999
8078	2	0	2.7999999999999998	1.26	8.0199999999999996	39.420000000000002	10.105	49.668999999999997
8078	3	0	3.7999999999999998	1.0599999	13.93	46.109999999999999	14.766	48.877000000000002
8078	4	0	4.7000000000000002	0.625	374.81	407.82999999999998	234.256	254.89400000000001
8079	1	0	0.29999999999999999	1.02	2.98	30.460000000000001	3.04	31.068999999999999
8079	2	0	2.7000000000000002	0.84600002	3.3799999999999999	35.380000000000003	2.859	29.931000000000001
8079	3	0	3.6000000000000001	0.97600001	4.5999999999999996	40.420000000000002	4.4900000000000002	39.450000000000003
8079	4	0	4.4000000000000004	0.80599999	8.25	42.409999999999997	6.6500000000000004	34.182000000000002
7030	1	0	0.29999999999999999	0.99000001	0.95999999999999996	16.460000000000001	0.94999999999999996	16.295000000000002
7030	2	0	1.8	1.03	0.81000000000000005	10.81	0.83399999999999996	11.134
7030	3	0	2.3999999999999999	0.79000002	0.84999999999999998	14.35	0.67200000000000004	11.336
11246	2	0	2.1000000000000001	1.085	2.129	12.808999999999999	2.3100000000000001	13.898
11246	3	0	2.7999999999999998	0.884	4.6710000000000003	15.191000000000001	4.1289999999999996	13.429
11246	4	0	3.2000000000000002	0.69499999	11.693	21.913	8.1270000000000007	15.23
11465	1	0	0.29999999999999999	0.81699997	0.77600000000000002	10.356	0.63400000000000001	8.4610000000000003
11465	2	0	1.8999999999999999	0.75300002	0.876	8.9960000000000004	0.66000000000000003	6.774
11465	3	0	2.6000000000000001	0.70499998	1.167	10.186999999999999	0.82299999999999995	7.1820000000000004
11465	4	0	3	0.51599997	1.0840000000000001	9.4440000000000008	0.55900000000000005	4.8730000000000002
11464	1	0	0.29999999999999999	0.99800003	1.798	11.958	1.794	11.933999999999999
11464	2	0	2	0.91799998	2.7639999999999998	12.484	2.5369999999999999	11.460000000000001
11464	3	0	2.6000000000000001	0.69099998	4.1109999999999998	12.871	2.8410000000000002	8.8940000000000001
11464	4	0	3.1000000000000001	0.57499999	5.5750000000000002	14.375	3.206	8.266
11463	1	0	0.29999999999999999	1.0190001	1.542	9.6820000000000004	1.571	9.8659999999999997
11463	2	0	1.8	0.903	3.6509999999999998	12.371	3.2970000000000002	11.170999999999999
11463	3	0	2.3999999999999999	0.74800003	8.7110000000000003	14.930999999999999	6.516	11.167999999999999
11463	4	0	2.7999999999999998	0.49000001	18.138000000000002	26.698	8.8879999999999999	13.082000000000001
11462	1	0	0.29999999999999999	1.041	3.4689999999999999	11.009	3.6110000000000002	11.460000000000001
11462	2	0	1.7	0.92000002	4.5529999999999999	12.233000000000001	4.1890000000000001	11.254
11462	3	0	2.2000000000000002	0.82300001	9.3580000000000005	15.497999999999999	7.702	12.755000000000001
11462	4	0	2.6000000000000001	0.64999998	32.780000000000001	40.100000000000001	21.306999999999999	26.065000000000001
11461	1	0	0.29999999999999999	1.036	1.071	8.9710000000000001	1.1100000000000001	9.2940000000000005
11461	2	0	1.7	0.94499999	1.996	10.416	1.8859999999999999	9.843
11461	3	0	2.2000000000000002	0.889	3.5870000000000002	10.887	3.1890000000000001	9.6790000000000003
11461	4	0	2.6000000000000001	0.67799997	9.1349999999999998	17.675000000000001	6.194	11.984
10940	1	0	0.29999999999999999	1.215	4.3949999999999996	43.655000000000001	5.3399999999999999	53.040999999999997
10940	2	0	2.7999999999999998	0.99800003	5.444	43.564	5.4329999999999998	43.476999999999997
10940	3	0	3.7999999999999998	0.94999999	5.8470000000000004	46.207000000000001	5.5549999999999997	43.896999999999998
10940	4	0	4.4000000000000004	0.84600002	6.1799999999999997	47.439999999999998	5.2279999999999998	40.134
10939	1	0	0.29999999999999999	1.283	5.2530000000000001	45.472999999999999	6.7400000000000002	58.341999999999999
10939	2	0	2.7999999999999998	1.136	6.9710000000000001	47.250999999999998	7.9189999999999996	53.677
10939	3	0	3.7000000000000002	0.95899999	9.4149999999999991	44.215000000000003	9.0289999999999999	42.402000000000001
10939	4	0	4.2999999999999998	0.875	11.727	50.326999999999998	10.260999999999999	44.036000000000001
10938	1	0	0.29999999999999999	1.332	5.2439999999999998	44.484000000000002	6.9850000000000003	59.253
10938	2	0	2.7000000000000002	1.1160001	8.0579999999999998	45.177999999999997	8.9930000000000003	50.418999999999997
10938	3	0	3.6000000000000001	1.002	10.465	50.984999999999999	10.486000000000001	51.087000000000003
10938	4	0	4.2000000000000002	0.829	36.256	76.775999999999996	30.056000000000001	63.646999999999998
10937	1	0	0.29999999999999999	1.351	6.7549999999999999	50.935000000000002	9.1259999999999994	68.813000000000002
10937	2	0	2.6000000000000001	1.147	8.9000000000000004	52.060000000000002	10.208	59.713000000000001
10937	3	0	3.3999999999999999	0.84100002	18.404	58.223999999999997	15.478	48.966000000000001
10937	4	0	4	0.74900001	41.773000000000003	75.992999999999995	31.288	56.918999999999997
10936	1	0	0.29999999999999999	1.375	4.1440000000000001	40.524000000000001	5.6980000000000004	55.719999999999999
10936	2	0	2.6000000000000001	1.153	9.8439999999999994	43.744	11.35	50.436999999999998
10936	3	0	3.3999999999999999	0.89899999	27.303999999999998	54.564	24.545999999999999	49.052999999999997
10936	4	0	4	0.713	83.453000000000003	120.193	59.502000000000002	85.697999999999993
8425	1	0	0.29999999999999999	0.40000001	1.6299999999999999	14.01	0.65200000000000002	5.6040000000000001
8425	2	0	1.7	0.38	1.73	13.890000000000001	0.65700000000000003	5.2779999999999996
8425	3	0	2.2999999999999998	0.33000001	1.8300000000000001	14.890000000000001	0.60399999999999998	4.9139999999999997
8425	4	0	2.7000000000000002	0.30000001	2.5600000000000001	16.98	0.76800000000000002	5.0940000000000003
8426	1	0	0.29999999999999999	0.81	2.1200000000000001	15.84	1.7170000000000001	12.83
8426	2	0	1.8	0.73000002	2.9500000000000002	17.350000000000001	2.153	12.666
8426	3	0	2.3999999999999999	0.62	4.1900000000000004	18.329999999999998	2.5979999999999999	11.365
8426	4	0	2.7999999999999998	0.56999999	6.7999999999999998	20.780000000000001	3.8759999999999999	11.845000000000001
8427	1	0	0.29999999999999999	1.04	2.3199999999999998	16.559999999999999	2.4129999999999998	17.222000000000001
8427	2	0	1.7	0.88	5.3200000000000003	19.199999999999999	4.6820000000000004	16.896000000000001
8427	3	0	2.2000000000000002	0.81	13.66	27.300000000000001	11.065	22.113
8427	4	0	2.6000000000000001	0.75	33.82	48.939999999999998	25.364999999999998	36.704999999999998
8428	1	0	0.29999999999999999	1.09	1.7	15.699999999999999	1.853	17.113
8428	2	0	1.6000000000000001	0.89999998	2.7799999999999998	16.420000000000002	2.5019999999999998	14.778
8428	3	0	2.1000000000000001	0.81	4.9800000000000004	17.940000000000001	4.0339999999999998	14.531000000000001
8428	4	0	2.3999999999999999	0.75	17.879999999999999	30.68	13.41	23.010000000000002
8429	1	0	0.29999999999999999	1.0700001	1.4199999999999999	16.699999999999999	1.5189999999999999	17.869
8429	2	0	1.6000000000000001	0.97000003	1.75	15.449999999999999	1.698	14.987
8429	3	0	2.2000000000000002	0.87	2.1200000000000001	17.390000000000001	1.8440000000000001	15.129
8429	4	0	2.5	0.75999999	6.8200000000000003	23.300000000000001	5.1829999999999998	17.707999999999998
8430	1	0	0.29999999999999999	1.0700001	1.8899999999999999	11.949999999999999	2.0219999999999998	12.787000000000001
8430	2	0	2.8999999999999999	1.1	4.4199999999999999	15.76	4.8620000000000001	17.335999999999999
8430	3	0	3.7999999999999998	1.04	4.2599999999999998	15.48	4.4299999999999997	16.099
8430	4	0	4.5999999999999996	0.79000002	5.5	18.760000000000002	4.3449999999999998	14.82
8431	1	0	0.29999999999999999	1.45	3.2999999999999998	16.719999999999999	4.7850000000000001	24.244
8431	2	0	2.8999999999999999	1.23	4.4400000000000004	24.32	5.4610000000000003	29.914000000000001
8431	3	0	3.7999999999999998	1.11	7.3099999999999996	26.109999999999999	8.1140000000000008	28.981999999999999
8431	4	0	4.5999999999999996	0.70999998	25.84	48.079999999999998	18.346	34.137
8432	1	0	0.29999999999999999	1.46	4.1500000000000004	24.73	6.0590000000000002	36.106000000000002
8432	2	0	2.8999999999999999	1.21	10.76	32.920000000000002	13.02	39.832999999999998
8432	3	0	3.7999999999999998	1.11	20.510000000000002	44.649999999999999	22.765999999999998	49.561
8432	4	0	4.5999999999999996	0.79000002	71.219999999999999	92.980000000000004	56.264000000000003	73.453999999999994
8433	1	0	0.29999999999999999	1.47	4.4100000000000001	30.489999999999998	6.4829999999999997	44.82
8433	2	0	2.8999999999999999	1.26	15.66	39.979999999999997	19.731999999999999	50.375
8433	3	0	3.7999999999999998	1.0599999	34.539999999999999	60.659999999999997	36.612000000000002	64.299999999999997
8433	4	0	4.5999999999999996	0.88999999	95.640000000000001	118.16	85.120000000000005	105.16200000000001
8434	1	0	0.29999999999999999	1.15	3.3300000000000001	27.350000000000001	3.8300000000000001	31.452000000000002
8434	2	0	3.1000000000000001	0.63999999	4.2000000000000002	23.600000000000001	2.6880000000000002	15.103999999999999
8434	3	0	4.0999999999999996	0.40000001	4.3399999999999999	28.239999999999998	1.736	11.295999999999999
8434	4	0	4.9000000000000004	0.47999999	5.0300000000000002	29.350000000000001	2.4140000000000001	14.087999999999999
8210	1	0	0.29999999999999999	0.95999998	2.1899999999999999	34.229999999999997	2.1019999999999999	32.860999999999997
8210	2	0	1.8	0.82999998	2.3500000000000001	24.550000000000001	1.9510000000000001	20.376000000000001
8210	3	0	2.3999999999999999	0.76999998	2.7999999999999998	25.140000000000001	2.1560000000000001	19.358000000000001
8210	4	0	3	0.46000001	2.8799999999999999	27	1.325	12.42
8211	1	0	0.29999999999999999	1.45	2.6499999999999999	40.009999999999998	3.843	58.015000000000001
8211	2	0	2.6000000000000001	1.26	3.9399999999999999	29.760000000000002	4.9640000000000004	37.497999999999998
8211	3	0	3.5	1.22	5.5700000000000003	30.530000000000001	6.7949999999999999	37.247
8211	4	0	4.4000000000000004	0.86000001	4.0800000000000001	25.120000000000001	3.5089999999999999	21.603000000000002
8212	1	0	0.29999999999999999	1.42	3.1200000000000001	30.34	4.4299999999999997	43.082999999999998
8212	2	0	2.5	1.28	5.8799999999999999	29.68	7.5259999999999998	37.990000000000002
8212	3	0	3.3999999999999999	1.17	6.7699999999999996	57.270000000000003	7.9210000000000003	67.006
8212	4	0	4.2000000000000002	0.85000002	38.950000000000003	65.650000000000006	33.106999999999999	55.802
8213	1	0	0.29999999999999999	1.45	3.6600000000000001	35.539999999999999	5.3070000000000004	51.533000000000001
8213	2	0	2.5	1.27	7.4299999999999997	35.350000000000001	9.4359999999999999	44.895000000000003
8213	3	0	3.3999999999999999	1.08	22.359999999999999	54.700000000000003	24.149000000000001	59.076000000000001
8213	4	0	4	0.88999999	84.030000000000001	112.23	74.787000000000006	99.885000000000005
8214	1	0	0.29999999999999999	1.45	3.3900000000000001	29.710000000000001	4.9160000000000004	43.079000000000001
8214	2	0	2.7999999999999998	1.26	8.9499999999999993	40.049999999999997	11.276999999999999	50.463000000000001
8214	3	0	3.7000000000000002	1.15	26.039999999999999	53.840000000000003	29.946000000000002	61.915999999999997
8214	4	0	4.4000000000000004	1.08	163.03	211.03	176.072	227.91200000000001
8070	1	0	0.29999999999999999	1.3	3.79	37.07	4.9269999999999996	48.191000000000003
8070	2	0	3.1000000000000001	1.21	4.5899999999999999	35.93	5.5540000000000003	43.475000000000001
8070	3	0	4.2000000000000002	0.99000001	5.9299999999999997	37.049999999999997	5.8710000000000004	36.679000000000002
8070	4	0	5	0.30599999	8.4499999999999993	38.109999999999999	2.5859999999999999	11.662000000000001
8071	1	0	0.29999999999999999	1.5599999	3.9300000000000002	34.170000000000002	6.1310000000000002	53.305
8071	2	0	2.8999999999999999	1.35	6.8399999999999999	35.140000000000001	9.234	47.439
8071	3	0	3.7999999999999998	1.235	11.42	42.18	14.103999999999999	52.091999999999999
8071	4	0	4.5999999999999996	0.91000003	56.939999999999998	86.760000000000005	51.814999999999998	78.951999999999998
8072	1	0	0.29999999999999999	1.396	4.6100000000000003	33.469999999999999	6.4359999999999999	46.723999999999997
8072	2	0	2.5	1.29	8.8499999999999996	37.75	11.416	48.698
8072	3	0	3.3999999999999999	1.104	20.170000000000002	50.909999999999997	22.268000000000001	56.204999999999998
8072	4	0	4.2000000000000002	0.76599997	167.69	208.47	128.45099999999999	159.68799999999999
8073	1	0	0.29999999999999999	1.476	5.9800000000000004	50.359999999999999	8.8260000000000005	74.331000000000003
8073	2	0	2.7999999999999998	1.2970001	5.8399999999999999	34.640000000000001	7.5739999999999998	44.927999999999997
8073	3	0	3.7999999999999998	1.152	10.07	46.409999999999997	11.601000000000001	53.463999999999999
8073	4	0	4.5	0.77700001	75.030000000000001	103.65000000000001	58.298000000000002	80.536000000000001
8074	1	0	0.29999999999999999	1.245	3.5899999999999999	33.210000000000001	4.4699999999999998	41.345999999999997
8074	2	0	3.2000000000000002	1.428	3.77	38.829999999999998	5.3840000000000003	55.448999999999998
8074	3	0	4.2000000000000002	1.228	4.9000000000000004	33.759999999999998	6.0170000000000003	41.457000000000001
8074	4	0	5.0999999999999996	0.70499998	17.43	47.829999999999998	12.288	33.719999999999999
6930	1	0	0.29999999999999999	1.08	0.89000000000000001	12.890000000000001	0.96099999999999997	13.920999999999999
6930	2	0	2.7000000000000002	0.86000001	0.84999999999999998	12.85	0.73099999999999998	11.051
6930	3	0	3.6000000000000001	0.88	1.1100000000000001	13.609999999999999	0.97699999999999998	11.977
6930	4	0	4.2999999999999998	0.41	2	14	0.81999999999999995	5.7400000000000002
6931	1	0	0.29999999999999999	1.77	1	10.5	1.77	18.585000000000001
6931	2	0	3.3999999999999999	1.6	2.0699999999999998	15.07	3.3119999999999998	24.111999999999998
6931	3	0	4.5999999999999996	1.25	2.6299999999999999	14.630000000000001	3.2869999999999999	18.288
6931	4	0	5.5	1.14	11.52	24.52	13.132999999999999	27.952999999999999
6932	1	0	0.29999999999999999	1.77	0.93000000000000005	12.93	1.6459999999999999	22.885999999999999
6932	2	0	3.3999999999999999	1.61	1.4099999999999999	13.41	2.27	21.59
6932	3	0	4.5999999999999996	1.36	2.7000000000000002	14.699999999999999	3.6720000000000002	19.992000000000001
6932	4	0	5.5	1.11	32.07	44.57	35.597999999999999	49.472999999999999
6933	1	0	0.29999999999999999	1.8	0.78000000000000003	12.779999999999999	1.4039999999999999	23.004000000000001
6933	2	0	3.6000000000000001	1.6900001	1.3	12.800000000000001	2.1970000000000001	21.632000000000001
6933	3	0	4.7999999999999998	1.47	1.0700000000000001	10.57	1.573	15.538
6933	4	0	5.7999999999999998	1.1799999	1.4099999999999999	11.41	1.6639999999999999	13.464
6934	1	0	0.29999999999999999	1.89	0.67000000000000004	10.67	1.266	20.166
6934	2	0	3.8999999999999999	1.58	1.48	11.48	2.3380000000000001	18.138000000000002
6934	3	0	5.2000000000000002	1.59	1.48	11.98	2.3530000000000002	19.047999999999998
6934	4	0	6.2999999999999998	1.35	1.78	11.279999999999999	2.403	15.228
6925	1	0	0.29999999999999999	0.87	0.84999999999999998	8.3499999999999996	0.73899999999999999	7.2640000000000002
6925	2	0	2.2000000000000002	0.80000001	0.89000000000000001	9.3900000000000006	0.71199999999999997	7.5119999999999996
6925	3	0	3	0.57999998	1.3700000000000001	8.8699999999999992	0.79500000000000004	5.1449999999999996
6925	4	0	3.5	0.41	1.1499999999999999	10.15	0.47099999999999997	4.1609999999999996
6926	1	0	0.29999999999999999	1.34	0.84999999999999998	8.8499999999999996	1.139	11.859
6926	2	0	2.6000000000000001	1.22	0.93000000000000005	10.43	1.135	12.725
6926	3	0	3.5	1.1	1.0700000000000001	7.5700000000000003	1.177	8.327
6926	4	0	4.2000000000000002	0.73000002	2.9300000000000002	11.93	2.1389999999999998	8.7089999999999996
6927	1	0	0.29999999999999999	1.46	0.69999999999999996	8.1999999999999993	1.022	11.972
6927	2	0	2.5	1.34	1.1100000000000001	10.109999999999999	1.4870000000000001	13.547000000000001
6927	3	0	3.3999999999999999	1.17	3.04	14.039999999999999	3.5569999999999999	16.427
6927	4	0	4	0.73000002	24.699999999999999	34.700000000000003	18.030999999999999	25.331
6928	1	0	0.29999999999999999	1.51	0.73999999999999999	9.2400000000000002	1.117	13.952
6928	2	0	3.1000000000000001	1.37	0.95999999999999996	10.460000000000001	1.3149999999999999	14.33
6928	3	0	4.0999999999999996	1.17	1.9299999999999999	12.93	2.258	15.128
6928	4	0	4.9000000000000004	0.94	4.5899999999999999	14.09	4.3150000000000004	13.244999999999999
6929	1	0	0.29999999999999999	1.21	0.67000000000000004	11.17	0.81100000000000005	13.516
6929	2	0	3.1000000000000001	0.86000001	0.69999999999999996	10.199999999999999	0.60199999999999998	8.7720000000000002
6929	3	0	4.2000000000000002	0.81	0.78000000000000003	10.779999999999999	0.63200000000000001	8.7319999999999993
6929	4	0	5	0.49000001	0.84999999999999998	11.35	0.41699999999999998	5.5620000000000003
6920	1	0	0.29999999999999999	0.85000002	2.7799999999999998	11.279999999999999	2.363	9.5879999999999992
6920	2	0	1.8	0.76999998	3.4399999999999999	15.94	2.649	12.273999999999999
6920	3	0	2.3999999999999999	0.70999998	3.5600000000000001	10.56	2.528	7.4980000000000002
6920	4	0	2.7999999999999998	0.54000002	4.0700000000000003	16.07	2.198	8.6780000000000008
6921	1	0	0.29999999999999999	1.13	3.1899999999999999	12.19	3.605	13.775
6921	2	0	1.8	0.97000003	4.2599999999999998	12.26	4.1319999999999997	11.891999999999999
6921	3	0	2.3999999999999999	0.83999997	5.3700000000000001	13.369999999999999	4.5110000000000001	11.231
6921	4	0	2.7999999999999998	0.63999999	6.6299999999999999	17.129999999999999	4.2430000000000003	10.962999999999999
6922	1	0	0.29999999999999999	1.21	2.8900000000000001	11.390000000000001	3.4969999999999999	13.782
6922	2	0	1.6000000000000001	1.08	3.54	13.59	3.823	14.677
6922	3	0	2.2000000000000002	0.91000003	4.2000000000000002	13.199999999999999	3.8220000000000001	12.012
6922	4	0	2.5	0.75	9.6999999999999993	19.699999999999999	7.2750000000000004	14.775
6923	1	0	0.29999999999999999	1.23	2.2200000000000002	11.720000000000001	2.7309999999999999	14.416
6923	2	0	1.3999999999999999	1.13	2.4100000000000001	10.91	2.7229999999999999	12.327999999999999
6923	3	0	1.8999999999999999	1.01	3.5600000000000001	15.06	3.5960000000000001	15.211
6923	4	0	2.3999999999999999	0.72000003	7.2599999999999998	17.260000000000002	5.2270000000000003	12.427
6924	1	0	0.29999999999999999	1.13	1.96	10.960000000000001	2.2149999999999999	12.385
6924	2	0	1.8999999999999999	0.99000001	2.1099999999999999	11.109999999999999	2.089	10.999000000000001
6924	3	0	2.5	0.91000003	2.04	10.539999999999999	1.8560000000000001	9.5909999999999993
6807	1	0	0.29999999999999999	1.59	12.720000000000001	112.38	20.225000000000001	178.684
6807	2	0	3.2999999999999998	1.4400001	21.91	135.24000000000001	31.550000000000001	194.74600000000001
6807	3	0	4.4000000000000004	1.34	27.530000000000001	159.53	36.890000000000001	213.77000000000001
6807	4	0	5.2999999999999998	1.15	71.790000000000006	189.13	82.558000000000007	217.499
6827	1	0	0.29999999999999999	1.03	0.54000000000000004	2.04	0.55600000000000005	2.101
6827	2	0	1.3999999999999999	0.92000002	0.55000000000000004	4.3799999999999999	0.50600000000000001	4.0300000000000002
6827	3	0	1.8999999999999999	0.75999999	0.39000000000000001	2.6400000000000001	0.29599999999999999	2.0059999999999998
6827	4	0	2.2999999999999998	0.44	1.0600000000000001	3.8100000000000001	0.46600000000000003	1.6759999999999999
6828	1	0	0.29999999999999999	1.52	0.13	3.6299999999999999	0.19800000000000001	5.5179999999999998
6828	2	0	2.8999999999999999	1.48	0.39000000000000001	1.6399999999999999	0.57699999999999996	2.427
6828	3	0	3.8999999999999999	1.35	0.40999999999999998	11.16	0.55400000000000005	15.066000000000001
6828	4	0	4.7999999999999998	0.83999997	0.77000000000000002	6.2699999999999996	0.64700000000000002	5.2670000000000003
6829	1	0	0.29999999999999999	1.46	0.52000000000000002	1.77	0.75900000000000001	2.5840000000000001
6829	2	0	2.7999999999999998	1.39	0.97999999999999998	6.7300000000000004	1.3620000000000001	9.3550000000000004
6829	3	0	3.7999999999999998	1.17	2.2599999999999998	6.5099999999999998	2.6440000000000001	7.617
6829	4	0	4.6500000000000004	0.64999998	12.609999999999999	14.359999999999999	8.1959999999999997	9.3339999999999996
6830	1	0	0.29999999999999999	0.93000001	0.46000000000000002	3.96	0.42799999999999999	3.6829999999999998
6830	2	0	2.6000000000000001	0.69999999	0.68999999999999995	1.6899999999999999	0.48299999999999998	1.1830000000000001
6830	3	0	3.3999999999999999	0.64999998	0.69999999999999996	1.7	0.45500000000000002	1.105
6830	4	0	4.25	0.49000001	2.8199999999999998	3.5699999999999998	1.3819999999999999	1.7490000000000001
6799	1	0	0.29999999999999999	0.86000001	2.7000000000000002	30.949999999999999	2.3220000000000001	26.617000000000001
6799	2	0	0.59999999999999998	0.72000003	2.3900000000000001	41.640000000000001	1.7210000000000001	29.981000000000002
6799	3	0	0.80000000000000004	0.69999999	2.46	41.710000000000001	1.722	29.196999999999999
6799	4	0	0.84999999999999998	0.56	2.5899999999999999	33.840000000000003	1.45	18.949999999999999
6800	1	0	0.29999999999999999	1.26	2.3900000000000001	47.390000000000001	3.0110000000000001	59.710999999999999
6800	2	0	1.8999999999999999	1.09	2.7200000000000002	38.719999999999999	2.9649999999999999	42.204999999999998
6800	3	0	2.5	0.86000001	3	25.25	2.5800000000000001	21.715
6800	4	0	2.8999999999999999	0.73000002	3.6499999999999999	31.649999999999999	2.665	23.103999999999999
6801	1	0	0.29999999999999999	1.51	2.6299999999999999	47.829999999999998	3.9710000000000001	72.222999999999999
6801	2	0	2.7999999999999998	1.34	3.2000000000000002	34.700000000000003	4.2880000000000003	46.497999999999998
6801	3	0	3.7000000000000002	1.1	5.4400000000000004	52.439999999999998	5.984	57.683999999999997
6801	4	0	4.4000000000000004	0.97000003	8.8699999999999992	34.869999999999997	8.6039999999999992	33.823999999999998
6802	1	0	0.29999999999999999	1.23	2.3300000000000001	40.079999999999998	2.8660000000000001	49.298000000000002
6802	2	0	2.2000000000000002	1.09	3.0899999999999999	42.590000000000003	3.3679999999999999	46.423000000000002
6802	3	0	3	1	2.3700000000000001	35.119999999999997	2.3700000000000001	35.119999999999997
6802	4	0	3.5	0.88	4.6500000000000004	23.899999999999999	4.0919999999999996	21.032
6795	1	0	0.29999999999999999	1.2	2.3399999999999999	50.939999999999998	2.8079999999999998	61.128
6795	2	0	1.8999999999999999	1.09	2.6200000000000001	42.960000000000001	2.8559999999999999	46.826000000000001
6795	3	0	2.6000000000000001	0.74000001	2.23	50.560000000000002	1.6499999999999999	37.414000000000001
6795	4	0	3	0.61000001	2.8500000000000001	53.450000000000003	1.7390000000000001	32.603999999999999
6796	1	0	0.29999999999999999	1.75	2.6800000000000002	37.280000000000001	4.6900000000000004	65.239999999999995
6796	2	0	3.5	1.63	2.3399999999999999	42.939999999999998	3.8140000000000001	69.992000000000004
6796	3	0	4.7000000000000002	1.49	2.8900000000000001	52.890000000000001	4.306	78.805999999999997
6796	4	0	5.7000000000000002	1.17	3.5499999999999998	39.210000000000001	4.1529999999999996	45.875999999999998
6797	1	0	0.29999999999999999	1.79	2.1899999999999999	46.950000000000003	3.9199999999999999	84.040999999999997
6797	2	0	3.7000000000000002	1.65	3.2400000000000002	50.490000000000002	5.3460000000000001	83.308000000000007
6797	3	0	4.9000000000000004	1.48	4.7999999999999998	37.549999999999997	7.1040000000000001	55.573999999999998
6797	4	0	5.9000000000000004	1.11	10.220000000000001	56.719999999999999	11.343999999999999	62.959000000000003
6798	1	0	0.29999999999999999	1.02	2.6200000000000001	47.369999999999997	2.6720000000000002	48.317
6798	2	0	3.2999999999999998	0.81	3.1499999999999999	48.899999999999999	2.552	39.609000000000002
6798	3	0	4.4000000000000004	0.27000001	3	45.5	0.81000000000000005	12.285
6798	4	0	5.2999999999999998	0.12	13.199999999999999	63.450000000000003	1.5840000000000001	7.6139999999999999
13162	1	0	0.29999999999999999	1.7589999	8.0239999999999991	83.884	14.114000000000001	147.55199999999999
13162	2	0	4.9000000000000004	1.704	8.9149999999999991	96.834999999999994	15.191000000000001	165.00700000000001
13162	3	0	6.5	1.552	7.327	101.50700000000001	11.372	157.53899999999999
13162	4	0	7.2999999999999998	1.3609999	8.8439999999999994	92.924000000000007	12.037000000000001	126.47
13162	5	0	7.9000000000000004	0.884	9.4179999999999993	104.11799999999999	8.3260000000000005	92.040000000000006
13161	1	0	0.29999999999999999	1.6390001	7.6820000000000004	104.642	12.590999999999999	171.50800000000001
13161	2	0	4.2000000000000002	1.53	9.2690000000000001	91.489000000000004	14.182	139.97800000000001
13161	3	0	5.5999999999999996	1.561	9.0129999999999999	107.79300000000001	14.069000000000001	168.26499999999999
13161	4	0	6.2999999999999998	1.585	10.291	102.991	16.311	163.24100000000001
13161	5	0	6.7999999999999998	1.387	11.805	116.565	16.373999999999999	161.67599999999999
13160	1	0	0.29999999999999999	1.9170001	7.6130000000000004	101.553	14.593999999999999	194.67699999999999
13160	2	0	4.9000000000000004	1.742	8.8729999999999993	108.833	15.457000000000001	189.58699999999999
13160	3	0	6.5	1.723	9.5670000000000002	105.407	16.484000000000002	181.61600000000001
13160	4	0	7.2999999999999998	1.353	10.365	102.185	14.023999999999999	138.256
13160	5	0	7.9000000000000004	0.64200002	12.156000000000001	98.215999999999994	7.8040000000000003	63.055
13159	1	0	0.29999999999999999	1.994	8.3759999999999994	102.876	16.702000000000002	205.13499999999999
13159	2	0	4.4000000000000004	1.834	8.9130000000000003	106.813	16.346	195.89500000000001
13159	3	0	5.9000000000000004	1.544	10.505000000000001	114.22499999999999	16.219999999999999	176.363
13159	4	0	6.7000000000000002	1.2079999	12.653	112.133	15.285	135.45699999999999
13159	5	0	7.2000000000000002	0.86400002	10.451000000000001	107.771	9.0299999999999994	93.114000000000004
13158	1	0	0.29999999999999999	2.0250001	7.4219999999999997	104.80200000000001	15.029999999999999	212.22399999999999
13158	2	0	4.5	1.765	8.1349999999999998	100.375	14.358000000000001	177.16200000000001
13158	3	0	6	1.571	9.8219999999999992	106.762	15.43	167.72300000000001
13158	4	0	6.7000000000000002	1.3609999	12.315	109.41500000000001	16.760999999999999	148.91399999999999
13158	5	0	7.2999999999999998	0.50199997	11.613	103.613	5.8300000000000001	52.014000000000003
12916	1	0	0.29999999999999999	0.76999998	1.5600000000000001	10.800000000000001	1.2010000000000001	8.3160000000000007
12916	2	0	1.8999999999999999	0.713	1.627	10.967000000000001	1.1599999999999999	7.819
12916	3	0	2.6000000000000001	0.65399998	1.804	10.103999999999999	1.1799999999999999	6.6079999999999997
12916	4	0	3	0.42500001	1.6379999999999999	8.3780000000000001	0.69599999999999995	3.5609999999999999
12917	1	0	0.29999999999999999	1.056	1.3	11.1	1.373	11.722
12917	2	0	2.2999999999999998	1.027	2.7440000000000002	12.683999999999999	2.8180000000000001	13.026
12917	3	0	3	0.90799999	4.0270000000000001	12.667	3.657	11.502000000000001
12917	4	0	3.6000000000000001	0.58899999	15.387	24.527000000000001	9.0630000000000006	14.446
12918	1	0	0.29999999999999999	1.119	1.665	11.505000000000001	1.863	12.874000000000001
12918	2	0	2	1.063	2.835	11.414999999999999	3.0139999999999998	12.134
12918	3	0	2.7000000000000002	0.903	4.2999999999999998	13.74	3.883	12.407
12918	4	0	3.2000000000000002	0.69599998	16.524999999999999	25.785	11.500999999999999	17.946000000000002
12919	1	0	0.29999999999999999	1.17	1.5600000000000001	11.56	1.825	13.525
12919	2	0	1.8999999999999999	1.063	2.5289999999999999	11.689	2.6880000000000002	12.425000000000001
12919	3	0	2.6000000000000001	0.93300003	4.1349999999999998	13.395	3.8580000000000001	12.497999999999999
12919	4	0	3	0.80400002	10.904999999999999	20.965	8.7680000000000007	16.856000000000002
12920	1	0	0.29999999999999999	1.056	2.6619999999999999	8.4420000000000002	2.8109999999999999	8.9149999999999991
12920	2	0	2	0.97299999	7.2510000000000003	13.750999999999999	7.0549999999999997	13.380000000000001
12920	3	0	2.7000000000000002	0.84100002	13.709	24.869	11.529	20.914999999999999
12920	4	0	3.2000000000000002	0.67900002	44.055	54.075000000000003	29.913	36.716999999999999
12205	1	0	0.29999999999999999	1.027	2.831	21.431000000000001	2.907	22.010000000000002
12205	2	0	3.2000000000000002	1.413	3.085	25.625	4.359	36.207999999999998
12205	3	0	4.2999999999999998	1.252	3.0609999999999999	27.361000000000001	3.8319999999999999	34.256
12205	4	0	5.2000000000000002	0.87400001	4.2750000000000004	26.475000000000001	3.7360000000000002	23.138999999999999
12204	1	0	0.29999999999999999	1.281	4.069	24.268999999999998	5.2119999999999997	31.088999999999999
12204	2	0	3.1000000000000001	1.443	4.7469999999999999	29.047000000000001	6.8499999999999996	41.914999999999999
12204	3	0	4.2000000000000002	1.3	11.904	35.384	15.475	45.999000000000002
12204	4	0	5	0.56	63.731000000000002	86.691000000000003	35.689	48.546999999999997
12203	1	0	0.29999999999999999	1.37	4.242	24.341999999999999	5.8120000000000003	33.348999999999997
12203	2	0	3.3999999999999999	1.336	12.191000000000001	34.790999999999997	16.286999999999999	46.481000000000002
12203	3	0	4.5	1.283	17.922000000000001	44.902000000000001	22.994	57.609000000000002
12203	4	0	5.4000000000000004	0.991	45.857999999999997	66.938000000000002	45.445	66.335999999999999
12202	1	0	0.29999999999999999	1.465	2.782	34.222000000000001	4.0759999999999996	50.134999999999998
12202	2	0	3.3999999999999999	1.426	9.625	32.664999999999999	13.725	46.579999999999998
12202	3	0	4.5	1.247	28.387	54.087000000000003	35.399000000000001	67.445999999999998
12202	4	0	5.4000000000000004	0.95899999	47.798000000000002	73.438000000000002	45.838000000000001	70.427000000000007
12201	1	0	0.29999999999999999	1.227	1.9419999999999999	22.722000000000001	2.383	27.879999999999999
12201	2	0	3.3999999999999999	0.76300001	4.9530000000000003	21.233000000000001	3.7789999999999999	16.201000000000001
12201	3	0	4.5	0.58399999	16.306999999999999	47.127000000000002	9.5229999999999997	27.521999999999998
12201	4	0	5.4000000000000004	0.59100002	13.199999999999999	28.579999999999998	7.8010000000000002	16.890999999999998
11255	1	0	0.29999999999999999	0.94700003	1.2509999999999999	13.071	1.1850000000000001	12.378
11255	2	0	2.2000000000000002	0.81699997	1.256	14.356	1.026	11.728999999999999
11255	3	0	3	0.64499998	1.4670000000000001	13.887	0.94599999999999995	8.9570000000000007
11255	4	0	3.5	0.52600002	1.8240000000000001	13.284000000000001	0.95899999999999996	6.9870000000000001
11254	1	0	0.29999999999999999	1.244	1.2709999999999999	13.451000000000001	1.581	16.733000000000001
11254	2	0	2.2000000000000002	1.123	1.9470000000000001	14.567	2.1859999999999999	16.359000000000002
11254	3	0	3	1.044	2.2240000000000002	15.263999999999999	2.3220000000000001	15.936
11254	4	0	3.5	0.87400001	2.8599999999999999	15.68	2.5	13.704000000000001
11253	1	0	0.29999999999999999	1.3	1.7050000000000001	13.625	2.2170000000000001	17.713000000000001
11253	2	0	2.2000000000000002	1.189	3.5419999999999998	16.602	4.2110000000000003	19.739999999999998
11253	3	0	3	1.043	9.4930000000000003	23.172999999999998	9.9009999999999998	24.169
11253	4	0	3.5	0.80400002	49.619999999999997	63.18	39.893999999999998	50.796999999999997
11252	1	0	0.29999999999999999	1.273	2.0350000000000001	17.094999999999999	2.5910000000000002	21.762
11252	2	0	2.2000000000000002	1.158	4.9219999999999997	19.841999999999999	5.7000000000000002	22.977
11252	3	0	3	1.022	11.224	25.824000000000002	11.471	26.391999999999999
11252	4	0	3.5	0.86699998	24.564	38.264000000000003	21.297000000000001	33.174999999999997
11251	1	0	0.29999999999999999	1.368	1.4179999999999999	13.778	1.9399999999999999	18.847999999999999
11251	2	0	2.2000000000000002	1.223	2.6379999999999999	15.198	3.226	18.587
11251	3	0	3	1.092	9.2149999999999999	22.835000000000001	10.063000000000001	24.936
11251	4	0	3.5	0.92000002	15.653	25.492999999999999	14.401	23.454000000000001
11245	1	0	0.29999999999999999	1.092	0.66000000000000003	31.780000000000001	0.72099999999999997	34.704000000000001
11245	2	0	2.6000000000000001	1.089	2.9239999999999999	22.443999999999999	3.1840000000000002	24.442
11245	3	0	3.5	0.84799999	3.496	23.916	2.9649999999999999	20.280999999999999
11245	4	0	4.2000000000000002	0.65600002	3.9710000000000001	23.331	2.605	15.305
11244	1	0	0.29999999999999999	1.551	2.738	24.158000000000001	4.2469999999999999	37.469000000000001
11244	2	0	3.2000000000000002	1.416	3.629	23.609000000000002	5.1390000000000002	33.43
11244	3	0	4.2000000000000002	1.283	4.5949999999999998	25.274999999999999	5.8949999999999996	32.427999999999997
11244	4	0	5.0999999999999996	1.01	12.276	32.896000000000001	12.398999999999999	33.225000000000001
11243	1	0	0.29999999999999999	1.603	3.782	28.042000000000002	6.0629999999999997	44.951000000000001
11243	2	0	3.1000000000000001	1.397	8.4269999999999996	28.027000000000001	11.773	39.154000000000003
11243	3	0	4.2000000000000002	1.334	13.836	35.515999999999998	18.457000000000001	47.378
11243	4	0	5	1.068	31.446999999999999	52.887	33.585000000000001	56.482999999999997
11242	1	0	0.29999999999999999	1.658	4.4930000000000003	26.053000000000001	7.4489999999999998	43.195999999999998
11242	2	0	3.2999999999999998	1.5369999	5.3730000000000002	25.353000000000002	8.2579999999999991	38.968000000000004
11242	3	0	4.4000000000000004	1.257	24.431000000000001	45.271000000000001	30.710000000000001	56.905999999999999
11242	4	0	5.2999999999999998	0.91299999	170.13999999999999	198.46000000000001	155.33799999999999	181.19399999999999
11241	1	0	0.29999999999999999	1.663	2.3780000000000001	24.638000000000002	3.9550000000000001	40.972999999999999
11241	2	0	3.2999999999999998	1.52	3.8050000000000002	25.045000000000002	5.7839999999999998	38.067999999999998
11241	3	0	4.4000000000000004	1.332	17.218	39.637999999999998	22.934000000000001	52.798000000000002
11241	4	0	5.2999999999999998	0.91299999	95.953000000000003	115.313	87.605000000000004	105.28100000000001
11250	1	0	0.29999999999999999	0.84799999	1.036	10.156000000000001	0.879	8.6120000000000001
11250	2	0	1.8999999999999999	0.72399998	1.002	10.481999999999999	0.72499999999999998	7.5890000000000004
11250	3	0	2.5	0.60299999	0.95499999999999996	9.3949999999999996	0.57599999999999996	5.665
11250	4	0	2.8999999999999999	0.47	1.3049999999999999	10.824999999999999	0.61299999999999999	5.0880000000000001
11249	1	0	0.29999999999999999	1.126	1.149	9.7690000000000001	1.294	11
11249	2	0	1.8999999999999999	1.015	1.6040000000000001	4.5410000000000004	1.6279999999999999	4.609
11249	3	0	2.5	0.903	2.302	11.882	2.0790000000000002	10.728999999999999
11249	4	0	2.8999999999999999	0.75999999	3.6619999999999999	12.662000000000001	2.7829999999999999	9.6229999999999993
11248	1	0	0.29999999999999999	1.182	1.8360000000000001	10.916	2.1699999999999999	12.903
11248	2	0	1.7	1.075	2.5470000000000002	11.766999999999999	2.738	12.65
11248	3	0	2.2999999999999998	0.97100002	4.0199999999999996	14.539999999999999	3.903	14.118
11248	4	0	2.6000000000000001	0.84500003	6.1449999999999996	21.745000000000001	5.1929999999999996	18.375
11247	1	0	0.29999999999999999	1.179	1.7649999999999999	12.845000000000001	2.081	15.144
11247	2	0	1.8	1.063	2.867	13.787000000000001	3.048	14.656000000000001
11247	3	0	2.3999999999999999	0.96100003	3.4249999999999998	13.445	3.2909999999999999	12.920999999999999
11247	4	0	2.7000000000000002	0.72500002	26.417999999999999	39.677999999999997	19.152999999999999	28.766999999999999
11246	1	0	0.29999999999999999	1.228	1.6799999999999999	12.800000000000001	2.0630000000000002	15.718
6846	4	0	4.0999999999999996	1.0599999	1.6699999999999999	12.17	1.77	12.9
6847	1	0	0.29999999999999999	1.92	1	9.5	1.9199999999999999	18.239999999999998
6847	2	0	3.7999999999999998	1.72	1	10.5	1.72	18.059999999999999
6847	3	0	5.0999999999999996	1.46	1.3	11.300000000000001	1.8979999999999999	16.498000000000001
6847	4	0	6.2000000000000002	1.14	1.4399999999999999	10.44	1.6419999999999999	11.901999999999999
6848	1	0	0.29999999999999999	1.89	0.78000000000000003	10.779999999999999	1.474	20.373999999999999
6848	2	0	3.5	1.67	2.2999999999999998	15.800000000000001	3.8410000000000002	26.385999999999999
6848	3	0	4.5999999999999996	1.5700001	6.0700000000000003	20.07	9.5299999999999994	31.510000000000002
6848	4	0	5.5999999999999996	1.29	49.700000000000003	64.700000000000003	64.113	83.462999999999994
6849	1	0	0.29999999999999999	1.47	1.04	14.039999999999999	1.5289999999999999	20.638999999999999
6849	2	0	3.1000000000000001	1.34	1.4099999999999999	12.91	1.889	17.298999999999999
6849	3	0	4.0999999999999996	0.67000002	2	15	1.3400000000000001	10.050000000000001
6849	4	0	4.9000000000000004	0.56999999	3.8100000000000001	20.32	2.1720000000000002	11.582000000000001
6841	1	0	0.29999999999999999	1.38	1.78	19.530000000000001	2.456	26.951000000000001
6841	2	0	2.5	1.52	2.3500000000000001	20.350000000000001	3.5720000000000001	30.931999999999999
6841	3	0	3.3999999999999999	1.05	2.5899999999999999	21.09	2.7200000000000002	22.143999999999998
6841	4	0	4	0.85000002	3.0800000000000001	23.34	2.6179999999999999	19.838999999999999
6842	1	0	0.29999999999999999	1.79	2.3500000000000001	19.850000000000001	4.2060000000000004	35.530999999999999
6842	2	0	2.8999999999999999	1.55	5.1299999999999999	22.379999999999999	7.952	34.689
6842	3	0	3.7999999999999998	1.36	6.2800000000000002	25.030000000000001	8.5410000000000004	34.040999999999997
6842	4	0	4.5999999999999996	1.1900001	11.33	27.829999999999998	13.483000000000001	33.118000000000002
6843	1	0	0.29999999999999999	1.61	2.9300000000000002	18.43	4.7169999999999996	29.672000000000001
6843	2	0	2.5	1.4	7.1500000000000004	24.649999999999999	10.01	34.509999999999998
6843	3	0	3.2999999999999998	1.34	11.779999999999999	28.780000000000001	15.785	38.564999999999998
6843	4	0	4.0999999999999996	1.0700001	42.689999999999998	59.689999999999998	45.677999999999997	63.868000000000002
6844	1	0	0.29999999999999999	1.16	2.2200000000000002	18.719999999999999	2.5750000000000002	21.715
6844	2	0	2.1000000000000001	1.14	3.0600000000000001	21.809999999999999	3.488	24.863
6844	3	0	2.7999999999999998	1.0599999	3.1899999999999999	19.43	3.3809999999999998	20.596
6844	4	0	3.2999999999999998	0.94	5.8700000000000001	22.870000000000001	5.5179999999999998	21.498000000000001
6836	1	0	0.29999999999999999	1.58	7.0940000000000003	10.868	11.209	17.170999999999999
6836	2	0	2.6000000000000001	1.38	9.4339999999999993	13.811	13.019	19.059000000000001
6836	3	0	3.5	1.1900001	9.9619999999999997	79.962000000000003	11.855	95.155000000000001
6836	4	0	4.2000000000000002	0.46000001	15.074999999999999	56.390000000000001	6.9340000000000002	25.939
6837	1	0	0.29999999999999999	1.9299999	7.3600000000000003	60.689999999999998	14.205	117.13200000000001
6837	2	0	3.7000000000000002	1.77	9.4700000000000006	58.810000000000002	16.762	104.09399999999999
6837	3	0	5	1.59	11.66	63.659999999999997	18.539000000000001	101.21899999999999
6837	4	0	6	0.94999999	12.869999999999999	73.540000000000006	12.226000000000001	69.863
6838	1	0	0.29999999999999999	2.1500001	8.0399999999999991	56.710000000000001	17.286000000000001	121.926
6838	2	0	4.7000000000000002	1.88	11.32	75.319999999999993	21.282	141.602
6838	3	0	6.2999999999999998	1.6900001	16.789999999999999	65.459999999999994	28.375	110.627
6838	4	0	7.7000000000000002	0.88	35.590000000000003	79.590000000000003	31.318999999999999	70.039000000000001
6839	1	0	0.29999999999999999	1.9400001	10.34	81.640000000000001	20.059999999999999	158.38200000000001
6839	2	0	4.0999999999999996	1.83	15.279999999999999	67.950000000000003	27.962	124.349
6839	3	0	5.4000000000000004	1.66	25.93	81.930000000000007	43.043999999999997	136.00399999999999
6839	4	0	6.5999999999999996	1.03	83.959999999999994	113.95999999999999	86.478999999999999	117.379
6840	1	0	0.29999999999999999	1.27	7.96	61.960000000000001	10.109	78.688999999999993
6840	2	0	3.7000000000000002	0.82999998	11.43	67.430000000000007	9.4870000000000001	55.966999999999999
6840	3	0	5	0.62	13.17	69.840000000000003	8.1649999999999991	43.301000000000002
6840	4	0	6	0.56	26.68	92.010000000000005	14.941000000000001	51.526000000000003
6831	1	0	0.29999999999999999	0.61400002	2.5659999999999998	35.232999999999997	1.5760000000000001	21.632999999999999
6831	2	0	0.80000000000000004	0.54699999	2.6040000000000001	47.271000000000001	1.4239999999999999	25.856999999999999
6831	3	0	1.1000000000000001	0.47299999	2.7549999999999999	44.088000000000001	1.3029999999999999	20.853999999999999
6831	4	0	1.2	0.37099999	2.8300000000000001	44.829999999999998	1.05	16.632000000000001
6832	1	0	0.29999999999999999	1.02	2.5699999999999998	37.229999999999997	2.621	37.975000000000001
6832	2	0	1.6000000000000001	1	2.6000000000000001	45.939999999999998	2.6000000000000001	45.939999999999998
6832	3	0	2.2000000000000002	0.25	2.6800000000000002	32.68	0.67000000000000004	8.1699999999999999
6832	4	0	2.5	0.23	3.0600000000000001	51.719999999999999	0.70399999999999996	11.896000000000001
6833	1	0	0.29999999999999999	1.23	2.8300000000000001	48.829999999999998	3.4809999999999999	60.061
6833	2	0	2	1.0599999	3.3999999999999999	37.399999999999999	3.6040000000000001	39.643999999999998
6833	3	0	2.6000000000000001	0.95999998	3.3999999999999999	41.399999999999999	3.2639999999999998	39.744
6833	4	0	3.1000000000000001	0.72000003	3.6200000000000001	39.619999999999997	2.6059999999999999	28.526
6834	1	0	0.29999999999999999	1.11	2.8700000000000001	26.199999999999999	3.1859999999999999	29.082000000000001
6834	2	0	1.6000000000000001	0.95999998	3.3599999999999999	42.030000000000001	3.226	40.348999999999997
6834	3	0	2.2000000000000002	0.81999999	3.8500000000000001	37.18	3.157	30.488
6834	4	0	2.5	0.69	5.7000000000000002	39.030000000000001	3.9329999999999998	26.931000000000001
6835	1	0	0.29999999999999999	1.01	2.6000000000000001	37.270000000000003	2.6259999999999999	37.643000000000001
6835	2	0	1.3999999999999999	0.87	3.5499999999999998	34.210000000000001	3.0880000000000001	29.763000000000002
6835	3	0	1.8	0.80000001	3.1699999999999999	37.170000000000002	2.536	29.736000000000001
6835	4	0	2.1000000000000001	0.60000002	4.0800000000000001	40.079999999999998	2.448	24.047999999999998
6822	1	0	0.29999999999999999	1.3	2.1499999999999999	17.149999999999999	2.7949999999999999	22.295000000000002
6822	2	0	1.3999999999999999	0.94999999	4.4800000000000004	28.48	4.2560000000000002	27.056000000000001
6822	3	0	1.8999999999999999	0.79000002	2.4100000000000001	26.41	1.9039999999999999	20.864000000000001
6822	4	0	2.2000000000000002	0.69999999	2.8199999999999998	22.82	1.974	15.974
6823	1	0	0.29999999999999999	1.65	2.3300000000000001	19.829999999999998	3.8450000000000002	32.719000000000001
6823	2	0	2.6000000000000001	1.25	2.48	27.48	3.1000000000000001	34.350000000000001
6823	3	0	3.5	1.1	2.48	24.48	2.7280000000000002	26.928000000000001
6823	4	0	4.2000000000000002	0.98000002	2.7000000000000002	24.699999999999999	2.6459999999999999	24.206
6824	1	0	0.29999999999999999	1.9	3.2999999999999998	26.800000000000001	6.2699999999999996	50.920000000000002
6824	2	0	3.1000000000000001	1.42	2.8900000000000001	23.390000000000001	4.1040000000000001	33.213999999999999
6824	3	0	4.2000000000000002	1.28	3.1099999999999999	29.109999999999999	3.9809999999999999	37.261000000000003
6824	4	0	5	1.17	3.6699999999999999	28.670000000000002	4.2939999999999996	33.543999999999997
6825	1	0	0.29999999999999999	1.8	1.9299999999999999	21.43	3.4740000000000002	38.573999999999998
6825	2	0	2.7000000000000002	1.48	2.3700000000000001	25.370000000000001	3.508	37.548000000000002
6825	3	0	3.6000000000000001	1.36	2.7000000000000002	24.199999999999999	3.6720000000000002	32.911999999999999
6825	4	0	4.2999999999999998	1.27	5.2199999999999998	26.719999999999999	6.6289999999999996	33.933999999999997
6826	1	0	0.29999999999999999	1.58	1.6699999999999999	21.170000000000002	2.6389999999999998	33.448999999999998
6826	2	0	2.2999999999999998	1.33	1.8899999999999999	24.390000000000001	2.5139999999999998	32.439
6826	3	0	3	1.24	3.0699999999999998	24.07	3.8069999999999999	29.847000000000001
6826	4	0	3.6000000000000001	1.17	6.2999999999999998	24.300000000000001	7.3710000000000004	28.431000000000001
6818	1	0	0.29999999999999999	0.54000002	5.3300000000000001	25.829999999999998	2.8780000000000001	13.948
6818	2	0	0.80000000000000004	0.47999999	4.7800000000000002	26.280000000000001	2.294	12.614000000000001
6818	3	0	1	0.43000001	5.3300000000000001	23.329999999999998	2.2919999999999998	10.032
6818	4	0	1.1000000000000001	0.43000001	5.3700000000000001	28.370000000000001	2.3090000000000002	12.199
6819	1	0	0.29999999999999999	0.86000001	3.1899999999999999	24.18	2.7429999999999999	20.795000000000002
6819	2	0	1	0.75999999	4.3300000000000001	21.329999999999998	3.2909999999999999	16.210999999999999
6819	3	0	1.3999999999999999	0.56	4.1799999999999997	17.18	2.3410000000000002	9.6210000000000004
6819	4	0	1.5	0.51999998	4.6299999999999999	26.629999999999999	2.4079999999999999	13.848000000000001
6820	1	0	0.29999999999999999	1	3.8500000000000001	17.350000000000001	3.8500000000000001	17.350000000000001
6820	2	0	2.2000000000000002	0.98000002	5	23.5	4.9000000000000004	23.030000000000001
6820	3	0	3	0.89999998	5.2999999999999998	22.300000000000001	4.7699999999999996	20.07
6820	4	0	3.5	0.75	5.7000000000000002	25.699999999999999	4.2750000000000004	19.274999999999999
6821	1	0	0.29999999999999999	0.77999997	5.4400000000000004	20.940000000000001	4.2430000000000003	16.332999999999998
6821	2	0	2	0.77999997	6.04	23.539999999999999	4.7110000000000003	18.361000000000001
6821	3	0	2.7000000000000002	0.67000002	7.6699999999999999	28.670000000000002	5.1390000000000002	19.209
6821	4	0	3.2000000000000002	0.56	10.41	28.41	5.8300000000000001	15.91
6813	1	0	0.29999999999999999	0.75999999	3.3100000000000001	3.3100000000000001	2.516	2.516
6813	2	0	0.90000000000000002	0.68000001	3.52	3.52	2.3940000000000001	2.3940000000000001
6813	3	0	1.2	0.58999997	3.7200000000000002	3.7200000000000002	2.1949999999999998	2.1949999999999998
6813	4	0	1.3	0.40000001	3.7999999999999998	3.7999999999999998	1.52	1.52
6814	1	0	0.29999999999999999	1.21	2.6899999999999999	2.6899999999999999	3.2549999999999999	3.2549999999999999
6814	2	0	1.8	1.26	2.8399999999999999	2.8399999999999999	3.5779999999999998	3.5779999999999998
6814	3	0	2.5	1.12	3.04	3.04	3.4049999999999998	3.4049999999999998
6814	4	0	3	0.92000002	3.4399999999999999	3.4399999999999999	3.165	3.165
6814	5	0	3.2999999999999998	0.80000001	3.2400000000000002	3.2400000000000002	2.5920000000000001	2.5920000000000001
6815	1	0	0.29999999999999999	1.34	2.98	2.98	3.9929999999999999	3.9929999999999999
6815	2	0	2.2999999999999998	1.28	4.6799999999999997	4.6799999999999997	5.9900000000000002	5.9900000000000002
6815	3	0	3.2000000000000002	1.21	3.9199999999999999	3.9199999999999999	4.7430000000000003	4.7430000000000003
6815	4	0	3.8999999999999999	1.1	4.3600000000000003	4.3600000000000003	4.7960000000000003	4.7960000000000003
6815	5	0	4.4000000000000004	0.85000002	7.1600000000000001	7.1600000000000001	6.0860000000000003	6.0860000000000003
6816	1	0	0.29999999999999999	1.1900001	3.96	3.96	4.7119999999999997	4.7119999999999997
6816	2	0	2.2999999999999998	1.15	14.039999999999999	14.039999999999999	16.146000000000001	16.146000000000001
6816	3	0	3.2000000000000002	0.99000001	13.4	13.4	13.266	13.266
6816	4	0	3.7999999999999998	0.97000003	6.5199999999999996	6.5199999999999996	6.3239999999999998	6.3239999999999998
6816	5	0	4.2999999999999998	0.75999999	6.04	6.04	4.5899999999999999	4.5899999999999999
6817	1	0	0.29999999999999999	0.88999999	3.2000000000000002	3.2000000000000002	2.8479999999999999	2.8479999999999999
6817	2	0	1.8999999999999999	0.81	3.04	3.04	2.4620000000000002	2.4620000000000002
6817	3	0	2.6000000000000001	0.74000001	4.7999999999999998	4.7999999999999998	3.552	3.552
6817	4	0	3.1000000000000001	0.69	2.7200000000000002	2.7200000000000002	1.877	1.877
6817	5	0	3.5	0.57999998	3.6800000000000002	3.6800000000000002	2.1339999999999999	2.1339999999999999
6850	1	0	0.29999999999999999	1.26	3.75	33.759999999999998	4.7249999999999996	42.537999999999997
6850	2	0	1.8999999999999999	1.17	6.4699999999999998	40.799999999999997	7.5700000000000003	47.735999999999997
6850	3	0	2.5	1.0599999	4.4500000000000002	41.789999999999999	4.7169999999999996	44.296999999999997
6850	4	0	2.8999999999999999	0.92000002	5.8499999999999996	35.520000000000003	5.3819999999999997	32.677999999999997
6851	1	0	0.29999999999999999	1.5	3.4500000000000002	37.450000000000003	5.1749999999999998	56.174999999999997
6851	2	0	2.2999999999999998	1.4	5.9100000000000001	33.57	8.2739999999999991	46.997999999999998
6851	3	0	3	1.23	3.9399999999999999	34.280000000000001	4.8460000000000001	42.164000000000001
6851	4	0	3.6000000000000001	1	4.6399999999999997	38.310000000000002	4.6399999999999997	38.310000000000002
6852	1	0	0.29999999999999999	1.89	3.5800000000000001	32.920000000000002	6.766	62.219000000000001
6852	2	0	4.2999999999999998	1.75	4.5800000000000001	36.25	8.0150000000000006	63.438000000000002
6852	3	0	5.7000000000000002	1.47	5.4199999999999999	34.079999999999998	7.9669999999999996	50.097999999999999
6852	4	0	6.9000000000000004	0.62	12.4	47.399999999999999	7.6879999999999997	29.388000000000002
6853	1	0	0.29999999999999999	1.85	3.3999999999999999	31.059999999999999	6.29	57.460999999999999
6853	2	0	4	1.71	5.4000000000000004	37.729999999999997	9.234	64.518000000000001
6853	3	0	5.2999999999999998	1.63	6.5999999999999996	41.939999999999998	10.757999999999999	68.361999999999995
6853	4	0	6.4000000000000004	1.04	14.83	45.5	15.423	47.32
6854	1	0	0.29999999999999999	1.49	6.04	33.039999999999999	9	49.229999999999997
6854	2	0	3.5	1.4	6.5099999999999998	35.18	9.1140000000000008	49.252000000000002
6854	3	0	4.5999999999999996	1.3200001	9.4700000000000006	32.469999999999999	12.5	42.859999999999999
6854	4	0	5.7999999999999998	1.02	27.600000000000001	60.600000000000001	28.152000000000001	61.811999999999998
6808	1	0	0.29999999999999999	1.02	3	24.5	3.0600000000000001	24.989999999999998
6808	2	0	1	0.89999998	3.2999999999999998	17.050000000000001	2.9700000000000002	15.345000000000001
6808	3	0	1.3999999999999999	0.62	3.48	20.23	2.1579999999999999	12.542999999999999
6808	4	0	1.6499999999999999	0.50999999	3.9100000000000001	24.91	1.994	12.704000000000001
6809	1	0	0.29999999999999999	1.21	3.4100000000000001	26.41	4.1260000000000003	31.956
6809	2	0	2.1000000000000001	1.09	4.0599999999999996	19.809999999999999	4.4249999999999998	21.593
6809	3	0	2.7999999999999998	0.98000002	3.9399999999999999	31.690000000000001	3.8610000000000002	31.056000000000001
6809	4	0	3.4500000000000002	0.76999998	4.2999999999999998	28.050000000000001	3.3109999999999999	21.599
6810	1	0	0.29999999999999999	1.12	4.96	20.960000000000001	5.5549999999999997	23.475000000000001
6810	2	0	2.2000000000000002	1.03	7.1699999999999999	25.670000000000002	7.3849999999999998	26.440000000000001
6810	3	0	2.8999999999999999	1.01	8.2599999999999998	23.260000000000002	8.343	23.492999999999999
6810	4	0	3.5499999999999998	0.87	10.41	40.159999999999997	9.0570000000000004	34.939
6811	1	0	0.29999999999999999	1.17	4.2400000000000002	31.239999999999998	4.9610000000000003	36.551000000000002
6811	2	0	2.1000000000000001	1	6.4400000000000004	20.940000000000001	6.4400000000000004	20.940000000000001
6811	3	0	2.7999999999999998	0.89999998	7.5899999999999999	34.840000000000003	6.8310000000000004	31.356000000000002
6811	4	0	3.4500000000000002	0.67000002	18.93	35.590000000000003	12.683	23.844999999999999
6812	1	0	0.29999999999999999	1.04	1.9299999999999999	21.68	2.0070000000000001	22.547000000000001
6812	2	0	1.8999999999999999	0.93000001	2.4300000000000002	22.43	2.2599999999999998	20.859999999999999
6812	3	0	2.6000000000000001	0.81	2.5	21	2.0249999999999999	17.010000000000002
6812	4	0	3.1499999999999999	0.73000002	3.9300000000000002	22.68	2.8690000000000002	16.556000000000001
6803	1	0	0.29999999999999999	1.3200001	12.06	121.72	15.919	160.66999999999999
6803	2	0	2	1.3	13.83	150.83000000000001	17.978999999999999	196.07900000000001
6803	3	0	2.6000000000000001	1.22	15.960000000000001	122.63	19.471	149.60900000000001
6803	4	0	3.1000000000000001	0.81	16.399999999999999	128.06	13.284000000000001	103.729
6804	1	0	0.29999999999999999	1.66	12.49	108.48999999999999	20.733000000000001	180.09299999999999
6804	2	0	2.8999999999999999	1.73	14.109999999999999	128.78	24.41	222.78899999999999
6804	3	0	3.7999999999999998	1.61	16.399999999999999	107.06	26.404	172.36699999999999
6804	4	0	4.5999999999999996	1.24	16.960000000000001	138.28999999999999	21.030000000000001	171.47999999999999
6805	1	0	0.29999999999999999	1.92	16.809999999999999	108.14	32.274999999999999	207.62899999999999
6805	2	0	3.7999999999999998	1.59	19.32	137.99000000000001	30.719000000000001	219.404
6805	3	0	5	1.52	19.170000000000002	117.84	29.138000000000002	179.11699999999999
6805	4	0	6.0999999999999996	1.24	32.68	133.34999999999999	40.523000000000003	165.35400000000001
6806	1	0	0.29999999999999999	1.77	13.699999999999999	129.69999999999999	24.248999999999999	229.56899999999999
6806	2	0	3.6000000000000001	1.59	21.469999999999999	156.13999999999999	34.137	248.26300000000001
6806	3	0	4.5999999999999996	1.47	30.359999999999999	121.69	44.628999999999998	178.88399999999999
6806	4	0	5.5999999999999996	1.1900001	62.920000000000002	195.59	74.875	232.75200000000001
7146	2	0	2.5	0.81999999	3.6400000000000001	32.310000000000002	2.9849999999999999	26.494
7146	3	0	3.3999999999999999	0.80000001	3.1499999999999999	31.82	2.52	25.456
7146	4	0	4	0.56	5.8899999999999997	39.549999999999997	3.298	22.148
7147	1	0	0.29999999999999999	1.37	3.9100000000000001	35.57	5.3570000000000002	48.731000000000002
7147	2	0	2.8999999999999999	1.23	9.0199999999999996	57.350000000000001	11.095000000000001	70.540000000000006
7147	3	0	3.7999999999999998	1.08	39.340000000000003	241.00999999999999	42.487000000000002	260.291
7147	4	0	4.5999999999999996	0.70999998	158.25	312.25	112.357	221.69800000000001
7148	1	0	0.29999999999999999	1.4400001	3.3199999999999998	38.32	4.7809999999999997	55.180999999999997
7148	2	0	3	1.25	12.699999999999999	68.359999999999999	15.875	85.450000000000003
7148	3	0	4	1	18.129999999999999	66.469999999999999	18.129999999999999	66.469999999999999
7148	4	0	4.7999999999999998	0.86000001	37.130000000000003	131.47	31.931999999999999	113.06399999999999
7149	1	0	0.29999999999999999	1.52	2.5099999999999998	28.18	3.8149999999999999	42.834000000000003
7149	2	0	2.7999999999999998	1.33	6.5300000000000002	35.530000000000001	8.6850000000000005	47.255000000000003
7149	3	0	3.7999999999999998	1.14	19.260000000000002	57.600000000000001	21.956	65.664000000000001
7149	4	0	4.5	1	30.32	61.649999999999999	30.32	61.649999999999999
7150	1	0	0.29999999999999999	1.52	2.4300000000000002	39.68	3.694	60.314
7150	2	0	2.7999999999999998	1.33	4.0700000000000003	30.57	5.4130000000000003	40.658000000000001
7150	3	0	3.7999999999999998	1.23	7.4299999999999997	43.93	9.1389999999999993	54.033999999999999
7150	4	0	4.5	0.97000003	34.700000000000003	63.200000000000003	33.658999999999999	61.304000000000002
7084	1	0	0.29999999999999999	1.09	1.4199999999999999	22.079999999999998	1.548	24.067
7084	2	0	1.3	1.05	1.55	18.550000000000001	1.6279999999999999	19.478000000000002
7084	3	0	1.8	0.83999997	1.6599999999999999	20.329999999999998	1.3939999999999999	17.077000000000002
7084	4	0	2.1499999999999999	0.67000002	2.5499999999999998	20.550000000000001	1.7090000000000001	13.769
7085	1	0	0.29999999999999999	1.1	1.9299999999999999	20.260000000000002	2.1230000000000002	22.286000000000001
7085	2	0	1.5	1.01	4	21.329999999999998	4.04	21.542999999999999
7085	3	0	2	0.87	4.9400000000000004	25.940000000000001	4.298	22.568000000000001
7085	4	0	2.4500000000000002	0.73000002	12	30.329999999999998	8.7599999999999998	22.140999999999998
7086	1	0	0.29999999999999999	1.04	2.6200000000000001	24.289999999999999	2.7250000000000001	25.262
7086	2	0	1.6000000000000001	0.93000001	4.5099999999999998	27.18	4.194	25.277000000000001
7086	3	0	2.1000000000000001	0.88	4.96	28.629999999999999	4.3650000000000002	25.193999999999999
7086	4	0	2.5499999999999998	0.67000002	9.5899999999999999	30.920000000000002	6.4249999999999998	20.716000000000001
7087	1	0	0.29999999999999999	1.01	2.0600000000000001	18.809999999999999	2.081	18.998000000000001
7087	2	0	1.6000000000000001	0.94999999	2.5899999999999999	21.59	2.46	20.510000000000002
7087	3	0	2.1000000000000001	0.89999998	2.7200000000000002	22.719999999999999	2.448	20.448
7087	4	0	2.5499999999999998	0.69999999	10.57	30.57	7.399	21.399000000000001
7088	1	0	0.29999999999999999	1.15	2.3300000000000001	27.329999999999998	2.6800000000000002	31.428999999999998
7088	2	0	1.2	0.93000001	2.9399999999999999	23.940000000000001	2.734	22.263999999999999
7088	3	0	1.6000000000000001	0.75999999	4.1799999999999997	30.43	3.177	23.126999999999999
7088	4	0	1.8999999999999999	0.67000002	14.76	39.509999999999998	9.8889999999999993	26.472000000000001
7079	1	0	0.29999999999999999	1.09	2.7400000000000002	31.739999999999998	2.9870000000000001	34.597000000000001
7079	2	0	1.5	0.88	3.2599999999999998	40.009999999999998	2.8690000000000002	35.209000000000003
7079	3	0	2	0.79000002	5.1299999999999999	38.880000000000003	4.0529999999999999	30.715
7079	4	0	2.2000000000000002	0.81	5.1100000000000003	40.109999999999999	4.1390000000000002	32.488999999999997
7080	1	0	0.29999999999999999	1.09	2.46	30.460000000000001	2.681	33.201000000000001
7080	2	0	1.8	0.98000002	3.6099999999999999	38.859999999999999	3.5379999999999998	38.082999999999998
7080	3	0	2.3999999999999999	0.86000001	4.2599999999999998	34.009999999999998	3.6640000000000001	29.248999999999999
7080	4	0	2.7000000000000002	0.74000001	6.04	38.340000000000003	4.4699999999999998	28.372
7081	1	0	0.29999999999999999	1.1	2.9399999999999999	37.950000000000003	3.234	41.744999999999997
7081	2	0	1.7	0.99000001	3.7400000000000002	36.490000000000002	3.7029999999999998	36.125
7081	3	0	2.2999999999999998	0.80000001	6.5199999999999996	38.770000000000003	5.2160000000000002	31.015999999999998
7081	4	0	2.6000000000000001	0.75999999	7.4299999999999997	46.68	5.6470000000000002	35.476999999999997
7082	1	0	0.29999999999999999	1.1	2.7000000000000002	37.200000000000003	2.9700000000000002	40.920000000000002
7082	2	0	1.7	0.89999998	4.1299999999999999	41.130000000000003	3.7170000000000001	37.017000000000003
7082	3	0	2.2999999999999998	0.69	5.2400000000000002	43.490000000000002	3.6160000000000001	30.007999999999999
7082	4	0	2.6000000000000001	0.67000002	6.6500000000000004	44.649999999999999	4.4560000000000004	29.916
7083	1	0	0.29999999999999999	1.12	2.52	38.520000000000003	2.8220000000000001	43.142000000000003
7083	2	0	1.6000000000000001	0.98000002	3.5899999999999999	40.840000000000003	3.5179999999999998	40.023000000000003
7083	3	0	2.2000000000000002	0.54000002	15.949999999999999	58.189999999999998	8.6129999999999995	31.422999999999998
7083	4	0	2.3999999999999999	0.54000002	15.81	54.310000000000002	8.5370000000000008	29.327000000000002
7073	1	0	0.29999999999999999	1.04	3.2599999999999998	56.93	3.3900000000000001	59.207000000000001
7073	2	0	1.8999999999999999	1.1	3.1499999999999999	55.149999999999999	3.4649999999999999	60.664999999999999
7073	3	0	2.6000000000000001	0.91000003	3.5299999999999998	52.200000000000003	3.2120000000000002	47.502000000000002
7073	4	0	3	0.85000002	4.5800000000000001	50.590000000000003	3.8929999999999998	43.002000000000002
7074	1	0	0.29999999999999999	1.11	3.4300000000000002	57.43	3.8069999999999999	63.747
7074	2	0	2.1000000000000001	1.12	5.3600000000000003	61.359999999999999	6.0030000000000001	68.722999999999999
7074	3	0	2.7999999999999998	0.98000002	5.79	37.460000000000001	5.6740000000000004	36.710999999999999
7074	4	0	3.2999999999999998	0.77999997	14.300000000000001	68.299999999999997	11.154	53.274000000000001
7075	1	0	0.29999999999999999	1.09	3.77	52.109999999999999	4.109	56.799999999999997
7075	2	0	2.2999999999999998	1.05	5.1699999999999999	56.5	5.4290000000000003	59.325000000000003
7075	3	0	3.1000000000000001	0.95999998	6.9800000000000004	61.979999999999997	6.7009999999999996	59.500999999999998
7075	4	0	3.7000000000000002	0.70999998	15.640000000000001	68.640000000000001	11.103999999999999	48.734000000000002
7076	1	0	0.29999999999999999	1.1799999	3.75	63.090000000000003	4.4249999999999998	74.445999999999998
7076	2	0	2.2999999999999998	1.08	4.7400000000000002	65.069999999999993	5.1189999999999998	70.275999999999996
7076	3	0	3	0.92000002	6.8499999999999996	66.519999999999996	6.3019999999999996	61.198
7076	4	0	3.6000000000000001	0.63999999	19.789999999999999	76.459999999999994	12.666	48.933999999999997
7077	1	0	0.29999999999999999	1.1900001	3.3599999999999999	68.030000000000001	3.9980000000000002	80.956000000000003
7077	2	0	2.1000000000000001	1.1	4.3200000000000003	67.989999999999995	4.7519999999999998	74.789000000000001
7077	3	0	2.8999999999999999	0.98000002	4.8300000000000001	61.5	4.7329999999999997	60.270000000000003
7077	4	0	3.2999999999999998	0.92000002	6.9199999999999999	65.920000000000002	6.3659999999999997	60.646000000000001
7078	1	0	0.29999999999999999	1.26	2.98	57.479999999999997	3.7549999999999999	72.424999999999997
7078	2	0	2.2999999999999998	1.09	3.7000000000000002	46.700000000000003	4.0330000000000004	50.902999999999999
7078	3	0	3.1000000000000001	0.99000001	5	60.75	4.9500000000000002	60.143000000000001
7078	4	0	3.7000000000000002	0.87	5.7800000000000002	62.780000000000001	5.0289999999999999	54.619
7070	1	0	0.29999999999999999	1.0700001	0.80000000000000004	1.3	0.85599999999999998	1.391
7070	2	0	1.8999999999999999	0.92000002	3.4300000000000002	5.1799999999999997	3.1560000000000001	4.766
7070	3	0	2.5	0.74000001	5.2400000000000002	5.7400000000000002	3.8780000000000001	4.2480000000000002
7070	4	0	2.7999999999999998	0.69999999	15.279999999999999	16.280000000000001	10.696	11.396000000000001
7071	1	0	0.29999999999999999	1.11	0.95999999999999996	1.46	1.0660000000000001	1.621
7071	2	0	1.8999999999999999	1.0599999	1.5700000000000001	2.3199999999999998	1.6639999999999999	2.4590000000000001
7071	3	0	2.6000000000000001	0.75	8.0600000000000005	8.5600000000000005	6.0449999999999999	6.4199999999999999
7071	4	0	2.8999999999999999	0.76999998	7.4800000000000004	8.2300000000000004	5.7599999999999998	6.3369999999999997
7072	1	0	0.29999999999999999	1.09	0.70999999999999996	1.21	0.77400000000000002	1.319
7072	2	0	1.3999999999999999	1.03	1.5900000000000001	1.8400000000000001	1.6379999999999999	1.895
7072	3	0	1.8	0.92000002	2.7799999999999998	3.7799999999999998	2.5579999999999998	3.4780000000000002
7072	4	0	2	0.74000001	11.06	15.06	8.1839999999999993	11.144
7065	1	0	0.29999999999999999	0.98000002	3.54	26.370000000000001	3.4689999999999999	25.843
7065	2	0	1.8999999999999999	0.94999999	1.5900000000000001	24.59	1.51	23.361000000000001
7065	3	0	2.6000000000000001	0.88	1.54	25.539999999999999	1.355	22.475000000000001
7065	4	0	2.8999999999999999	0.72000003	2.1499999999999999	24.649999999999999	1.548	17.748000000000001
7066	1	0	0.29999999999999999	1.15	1.6299999999999999	23.879999999999999	1.8740000000000001	27.462
7066	2	0	2	0.94999999	2.5600000000000001	19.309999999999999	2.4319999999999999	18.344000000000001
7066	3	0	2.7000000000000002	0.83999997	5.6100000000000003	20.359999999999999	4.7119999999999997	17.102
7066	4	0	3.1000000000000001	0.70999998	7.96	30.960000000000001	5.6520000000000001	21.981999999999999
7067	1	0	0.29999999999999999	1.11	1.9299999999999999	23.43	2.1419999999999999	26.007000000000001
7067	2	0	2.2000000000000002	0.99000001	2.7999999999999998	27.800000000000001	2.7719999999999998	27.521999999999998
7067	3	0	2.8999999999999999	0.86000001	5.3200000000000003	25.82	4.5750000000000002	22.204999999999998
7067	4	0	3.2999999999999998	0.73000002	7.6699999999999999	32.420000000000002	5.5990000000000002	23.667000000000002
7068	1	0	0.29999999999999999	1.13	1.8500000000000001	17.100000000000001	2.0910000000000002	19.323
7068	2	0	2.2000000000000002	0.94	2.9399999999999999	25.440000000000001	2.7639999999999998	23.914000000000001
7068	3	0	3	0.81	3.6499999999999999	22.149999999999999	2.956	17.942
7068	4	0	3.3999999999999999	0.62	14.44	33.439999999999998	8.9529999999999994	20.733000000000001
7069	1	0	0.29999999999999999	1.11	1.6499999999999999	27.399999999999999	1.8320000000000001	30.414000000000001
7069	2	0	2.2000000000000002	0.98000002	2	14	1.96	13.720000000000001
7069	3	0	2.8999999999999999	0.83999997	2.3300000000000001	34.579999999999998	1.9570000000000001	29.047000000000001
7069	4	0	3.2999999999999998	0.69999999	3.6099999999999999	29.109999999999999	2.5270000000000001	20.376999999999999
7060	1	0	0.29999999999999999	0.77999997	1.6200000000000001	38.619999999999997	1.264	30.123999999999999
7060	2	0	2.2000000000000002	0.57999998	1.96	43.299999999999997	1.137	25.114000000000001
7060	3	0	2.8999999999999999	0.43000001	2.4199999999999999	42.75	1.0409999999999999	18.382000000000001
7060	4	0	3.3999999999999999	0.28	4.1299999999999999	44.469999999999999	1.1559999999999999	12.452
7061	1	0	0.29999999999999999	1.2	1.2	53.200000000000003	1.4399999999999999	63.840000000000003
7061	2	0	2.5	1.05	1.3300000000000001	45.079999999999998	1.397	47.334000000000003
7061	3	0	3.2999999999999998	0.91000003	1.5900000000000001	52.340000000000003	1.4470000000000001	47.628999999999998
7061	4	0	3.8999999999999999	0.83999997	2.1699999999999999	55.920000000000002	1.823	46.972999999999999
7062	1	0	0.29999999999999999	1.09	1.6000000000000001	42.560000000000002	1.744	46.390000000000001
7062	2	0	2.2000000000000002	1.08	1.8300000000000001	45.789999999999999	1.976	49.453000000000003
7062	3	0	2.8999999999999999	0.92000002	4.6399999999999997	28.949999999999999	4.2690000000000001	26.634
7062	4	0	3.3999999999999999	0.85000002	5.6200000000000001	41.289999999999999	4.7770000000000001	35.097000000000001
7063	1	0	0.29999999999999999	1.23	1.26	50.009999999999998	1.55	61.512
7063	2	0	1.8999999999999999	1.1	2.0699999999999998	55.57	2.2770000000000001	61.127000000000002
7063	3	0	2.6000000000000001	0.89999998	4.1799999999999997	47.939999999999998	3.762	43.146000000000001
7063	4	0	3	0.87	4.4800000000000004	44.479999999999997	3.8980000000000001	38.698
7064	1	0	0.29999999999999999	1.17	2.0600000000000001	39.390000000000001	2.4100000000000001	46.085999999999999
7064	2	0	2.2999999999999998	1.0700001	2.6200000000000001	42.960000000000001	2.8029999999999999	45.966999999999999
7064	3	0	3	0.94	13.77	53.109999999999999	12.944000000000001	49.923000000000002
7064	4	0	3.6000000000000001	0.38	13.98	56.649999999999999	5.3120000000000003	21.527000000000001
7055	1	0	0.29999999999999999	0.92000002	1.7	31.370000000000001	1.5640000000000001	28.859999999999999
7055	2	0	2.1000000000000001	0.85000002	2.48	38.479999999999997	2.1080000000000001	32.707999999999998
7055	3	0	2.7999999999999998	0.46000001	2.0800000000000001	47.649999999999999	0.95699999999999996	21.919
7055	4	0	3.3500000000000001	0.34	2.8999999999999999	47.670000000000002	0.98599999999999999	16.207999999999998
7056	1	0	0.29999999999999999	1.22	2.2200000000000002	45.890000000000001	2.7080000000000002	55.985999999999997
7056	2	0	2.2999999999999998	1.02	3.4399999999999999	43.439999999999998	3.5089999999999999	44.308999999999997
7056	3	0	3.1000000000000001	0.93000001	10.24	51.240000000000002	9.5229999999999997	47.652999999999999
7056	4	0	3.75	0.83999997	17.68	69.010000000000005	14.851000000000001	57.968000000000004
7057	1	0	0.29999999999999999	1.26	2.4399999999999999	35.770000000000003	3.0739999999999998	45.07
7057	2	0	2.2000000000000002	1.09	7.54	60.539999999999999	8.2189999999999994	65.989000000000004
7057	3	0	3	0.85000002	12.24	50.909999999999997	10.404	43.274000000000001
7057	4	0	3.5499999999999998	0.70999998	25.52	101.84999999999999	18.119	72.313000000000002
7058	1	0	0.29999999999999999	1.22	3.1800000000000002	43.18	3.8799999999999999	52.68
7058	2	0	2.2999999999999998	1.08	3.6600000000000001	49.990000000000002	3.9529999999999998	53.988999999999997
7058	3	0	3	0.82999998	7.7999999999999998	50.469999999999999	6.4740000000000002	41.890000000000001
7058	4	0	3.6499999999999999	0.47999999	16.82	61.490000000000002	8.0739999999999998	29.515000000000001
7059	1	0	0.29999999999999999	1.2	1.72	57.049999999999997	2.0640000000000001	68.459999999999994
7059	2	0	2.2000000000000002	1.04	1.98	44.310000000000002	2.0590000000000002	46.082000000000001
7059	3	0	3	0.94999999	2.7000000000000002	52.700000000000003	2.5649999999999999	50.064999999999998
7059	4	0	3.5499999999999998	0.56999999	3.6000000000000001	43.600000000000001	2.052	24.852
7050	1	0	0.29999999999999999	1.0700001	2.0600000000000001	31.859999999999999	2.2040000000000002	34.090000000000003
7050	2	0	1	0.88999999	2.1400000000000001	26.34	1.905	23.443000000000001
7050	3	0	1.3	0.85000002	2.2799999999999998	26.079999999999998	1.9379999999999999	22.167999999999999
7050	4	0	1.3999999999999999	0.60000002	2.7999999999999998	30	1.6799999999999999	18
7051	1	0	0.29999999999999999	0.95999998	2.3599999999999999	25.359999999999999	2.266	24.346
7051	2	0	1.1000000000000001	0.81999999	2.7599999999999998	26.359999999999999	2.2629999999999999	21.614999999999998
7051	3	0	1.5	0.70999998	3.1800000000000002	25.18	2.258	17.878
7051	4	0	1.7	0.67000002	5.04	28.239999999999998	3.3769999999999998	18.920999999999999
7052	1	0	0.29999999999999999	0.94999999	2.2200000000000002	25.02	2.109	23.768999999999998
7052	2	0	1.3	0.76999998	2.96	26.760000000000002	2.2789999999999999	20.605
7052	3	0	1.8	0.58999997	7.9800000000000004	32.380000000000003	4.7080000000000002	19.103999999999999
7052	4	0	2	0.52999997	8.7799999999999994	33.579999999999998	4.6529999999999996	17.797000000000001
7053	1	0	0.29999999999999999	0.94999999	2.5	25.5	2.375	24.225000000000001
7053	2	0	1.3999999999999999	0.77999997	6	28	4.6799999999999997	21.84
7053	3	0	1.8	0.62	14.699999999999999	37.700000000000003	9.1140000000000008	23.373999999999999
7053	4	0	2.1000000000000001	0.37	28.739999999999998	55.340000000000003	10.634	20.475999999999999
7054	1	0	0.29999999999999999	0.94999999	2.1600000000000001	22.960000000000001	2.052	21.812000000000001
7054	2	0	1.1000000000000001	0.79000002	2.3599999999999999	23.359999999999999	1.8640000000000001	18.454000000000001
7054	3	0	1.3999999999999999	0.77999997	3.8999999999999999	24.699999999999999	3.0419999999999998	19.265999999999998
7054	4	0	1.6000000000000001	0.49000001	13.300000000000001	31.100000000000001	6.5170000000000003	15.239000000000001
\.


--
-- Data for Name: ssiebung; Type: TABLE DATA; Schema: public; Owner: -
--

COPY ssiebung (siebanalyseid, gsiebsatzid, gmasse, rsieb01, rsieb02, rsieb03, rsieb04, rsieb05, rsieb06, rsieb07, rsieb08, rsieb09, rsieb10, rsieb11, rsieb12, rsieb13, rsieb14, rsieb15, rsieb16, rsieb17, rsieb18, rsieb19, rsieb20, rsieb21, rest) FROM stdin;
34	55	11226	0	0	453	2300	2237	1698	838	414	264	411	1163	611	775	41	21	0	0	0	0	0	0	0
35	55	6410	0	0	794	1642	1270	722	474	363	392	147	156	134	279	19	18	0	0	0	0	0	0	0
36	61	10243	0	342	332	1228	2440	1164	921	876	557	460	564	1047	253	39	20	0	0	0	0	0	0	0
37	55	15064	0	0	1586	2806	4198	2780	1089	763	787	507	194	108	209	28	9	0	0	0	0	0	0	0
38	58	4088	0	0	280	1174	728	428	237	137	204	452	324	115	7	1	1	0	0	0	0	0	0	0
39	58	4638	0	0	365	1309	986	455	301	270	376	353	119	91	10	2	1	0	0	0	0	0	0	0
40	58	3491	0	0	1190	827	617	196	163	200	125	57	45	35	24	8	4	0	0	0	0	0	0	0
41	58	5792	0	0	468	1387	1222	578	389	360	452	426	415	91	3	1	0	0	0	0	0	0	0	0
42	58	4060	0	0	299	243	631	620	588	471	354	366	396	86	4	1	1	0	0	0	0	0	0	0
43	58	5277	0	0	0	2574	1130	319	209	203	237	223	176	195	9	1	1	0	0	0	0	0	0	0
44	58	4262	0	0	0	1866	1050	248	159	143	121	133	324	212	4	1	1	0	0	0	0	0	0	0
45	58	1691	0	0	111	1164	254	56	45	29	15	6	4	5	1	1	0	0	0	0	0	0	0	0
46	58	5460	0	0	318	1627	1047	583	358	224	116	287	753	142	4	1	0	0	0	0	0	0	0	0
47	58	2693	0	0	0	1648	418	66	37	34	88	123	147	113	15	3	1	0	0	0	0	0	0	0
48	58	5743	0	0	179	1839	1696	523	319	313	500	254	28	80	10	1	1	0	0	0	0	0	0	0
50	58	5341	0	0	0	1713	1603	586	370	369	288	238	90	75	7	1	1	0	0	0	0	0	0	0
51	58	6074	0	0	700	2537	1309	312	228	222	206	168	151	219	17	3	2	0	0	0	0	0	0	0
52	58	5012	0	0	169	2248	1568	518	277	104	21	11	17	51	20	6	2	0	0	0	0	0	0	0
53	58	4616	0	0	412	2029	1427	290	145	132	98	44	20	15	3	1	0	0	0	0	0	0	0	0
54	58	6001	0	0	120	1409	1839	619	390	449	518	459	131	61	5	1	0	0	0	0	0	0	0	0
55	58	4482	0	0	251	1077	920	311	175	105	144	498	815	183	2	1	0	0	0	0	0	0	0	0
56	58	4968	0	0	230	1675	1546	478	259	256	218	139	60	69	24	9	5	0	0	0	0	0	0	0
57	58	4854	0	0	0	1755	1309	400	300	422	286	99	72	171	31	6	3	0	0	0	0	0	0	0
58	58	4528	0	0	212	1301	1085	425	291	275	269	244	199	197	23	5	2	0	0	0	0	0	0	0
59	58	5008	0	0	508	2128	1080	227	192	235	273	174	99	81	8	2	1	0	0	0	0	0	0	0
60	58	3229	0	0	278	543	750	391	262	232	194	259	258	58	2	1	1	0	0	0	0	0	0	0
61	58	2503	0	0	0	479	415	285	249	331	274	226	165	68	7	2	2	0	0	0	0	0	0	0
62	58	6066	0	0	882	1454	1415	509	397	507	443	233	150	62	9	3	2	0	0	0	0	0	0	0
63	58	5667	0	0	144	2599	1288	481	323	289	211	170	86	58	14	3	1	0	0	0	0	0	0	0
64	58	5391	0	0	200	1709	1229	561	321	126	81	354	682	121	4	3	0	0	0	0	0	0	0	0
65	58	4613	0	0	500	1448	1277	515	220	71	47	178	301	50	5	1	0	0	0	0	0	0	0	0
66	58	4591	0	0	0	1531	1231	428	291	298	258	218	189	142	5	0	0	0	0	0	0	0	0	0
67	58	5765	0	0	0	1771	1687	554	344	276	332	349	281	166	5	0	0	0	0	0	0	0	0	0
68	58	5357	0	0	110	1512	1308	637	369	178	156	279	631	164	10	3	0	0	0	0	0	0	0	0
69	58	4123	0	0	129	883	737	332	245	247	164	232	694	434	20	3	3	0	0	0	0	0	0	0
70	58	6043	0	0	180	1593	1328	609	469	418	582	467	214	169	11	3	0	0	0	0	0	0	0	0
71	58	5719	0	0	145	2868	1998	295	111	103	116	44	9	13	8	5	4	0	0	0	0	0	0	0
72	58	5707	0	0	179	1293	1946	752	451	314	320	332	84	21	9	3	3	0	0	0	0	0	0	0
73	58	6054	0	0	0	2075	1678	553	391	286	192	177	426	264	9	3	0	0	0	0	0	0	0	0
74	58	4192	0	0	85	1448	744	285	268	231	157	322	528	120	4	0	0	0	0	0	0	0	0	0
75	58	4386	0	0	0	950	1479	553	400	410	247	144	113	82	6	2	0	0	0	0	0	0	0	0
76	58	4713	0	0	0	2063	1618	313	226	210	110	99	38	26	7	3	0	0	0	0	0	0	0	0
77	58	4713	0	0	0	2063	1618	313	226	210	110	99	38	26	7	3	0	0	0	0	0	0	0	0
78	58	2376	0	0	263	738	435	173	116	99	72	63	87	273	44	7	6	0	0	0	0	0	0	0
79	58	4988	0	0	1330	2174	483	96	50	42	108	291	285	117	9	3	0	0	0	0	0	0	0	0
80	58	7626	0	0	116	1891	1675	799	621	582	523	581	536	286	13	2	1	0	0	0	0	0	0	0
81	58	6474	0	0	752	2013	1154	504	399	544	492	306	179	114	14	2	1	0	0	0	0	0	0	0
82	62	2934	0	0	0	810	671	345	222	194	163	182	235	109	3	0	0	0	0	0	0	0	0	0
83	55	3712	0	0	0	114	1313	1047	433	316	310	108	45	17	8	1	0	0	0	0	0	0	0	0
84	50	5235	0	1756	1439	733	1307	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
85	50	6098	0	1254	2823	1161	860	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
86	59	6230	0	284	1509	1482	570	423	273	135	384	967	196	6	1	0	0	0	0	0	0	0	0	0
87	50	2365	0	184	858	648	675	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
88	50	3967	0	1199	2064	544	160	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
89	50	5291	0	2234	1672	413	972	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
90	59	5312	0	0	1078	1421	533	394	364	178	219	786	330	8	1	0	0	0	0	0	0	0	0	0
91	59	5312	0	0	1078	1421	533	394	364	178	219	786	330	8	1	0	0	0	0	0	0	0	0	0
92	59	7802	0	0	3306	2074	503	356	428	275	119	243	466	24	3	2	3	0	0	0	0	0	0	0
93	50	5093	0	770	2667	972	684	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
94	50	5606	0	1750	2393	1009	454	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
95	59	7287	0	0	1929	2945	831	456	509	359	95	57	82	15	5	3	1	0	0	0	0	0	0	0
96	50	3738	0	1345	1643	495	255	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
97	62	4054	0	0	737	1050	648	371	277	305	231	135	114	174	9	1	1	1	0	0	0	0	0	0
98	62	6213	0	0	152	1727	1376	714	532	464	342	399	431	71	3	1	0	1	0	0	0	0	0	0
99	55	2627	0	0	0	0	1006	700	298	226	193	109	37	30	27	1	0	0	0	0	0	0	0	0
100	55	5059	0	0	0	258	2667	1333	309	201	158	76	32	15	9	1	0	0	0	0	0	0	0	0
101	58	5931	0	0	769	984	785	401	412	466	412	619	832	237	8	4	2	0	0	0	0	0	0	0
102	58	6001	0	0	333	1032	911	515	331	247	215	547	1328	532	8	2	0	0	0	0	0	0	0	0
103	58	5197	0	0	0	2146	1711	423	267	252	212	109	42	24	7	2	2	0	0	0	0	0	0	0
104	58	4481	0	0	151	1085	791	396	390	465	451	302	237	170	31	6	6	0	0	0	0	0	0	0
105	50	2264	0	653	687	466	458	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
106	50	2238	0	730	689	388	431	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
107	50	1960	0	659	616	239	446	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
108	58	5825	0	0	1090	1759	1087	496	346	310	195	124	149	261	7	1	0	0	0	0	0	0	0	0
109	58	6871	0	0	131	2923	1909	336	218	238	303	257	256	292	4	4	0	0	0	0	0	0	0	0
110	55	5991	0	0	0	0	1722	1184	632	482	392	308	406	689	171	3	2	0	0	0	0	0	0	0
111	50	3354	0	1353	1131	319	551	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
112	50	2974	0	1308	944	246	476	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
113	50	2181	0	670	811	469	231	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
114	50	1826	0	521	770	289	246	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
115	58	5823	0	0	855	1105	1459	604	481	542	347	176	99	125	17	7	6	0	0	0	0	0	0	0
116	58	5587	0	0	239	1595	1735	579	360	291	264	278	147	96	3	0	0	0	0	0	0	0	0	0
117	58	5432	0	0	134	1982	1749	494	283	284	217	66	58	159	6	0	0	0	0	0	0	0	0	0
118	58	5841	0	0	89	1822	2035	578	426	467	226	73	49	50	14	7	5	0	0	0	0	0	0	0
119	58	2499	0	0	0	1335	727	134	75	73	62	24	19	46	4	0	0	0	0	0	0	0	0	0
120	58	4205	0	0	88	818	1041	526	370	233	223	432	378	92	4	0	0	0	0	0	0	0	0	0
121	58	4305	0	0	771	1249	786	331	256	277	251	142	108	92	29	7	6	0	0	0	0	0	0	0
122	50	2489	0	482	739	576	692	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
123	50	1851	0	511	772	341	227	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
124	59	4465	0	0	1431	1331	351	229	254	243	196	151	241	30	4	2	2	0	0	0	0	0	0	0
125	58	5200	0	0	228	1236	1208	557	410	259	189	482	542	87	2	0	0	0	0	0	0	0	0	0
126	58	4669	0	0	0	1049	1072	493	284	127	62	99	889	555	29	6	4	0	0	0	0	0	0	0
127	58	7427	0	0	225	1918	1759	790	525	308	216	576	949	157	3	1	0	0	0	0	0	0	0	0
128	50	1892	0	853	778	118	143	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
129	50	2667	0	862	835	310	660	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
130	50	2602	0	639	1143	603	217	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
131	58	4971	0	0	0	970	1547	606	389	332	239	197	527	149	12	2	1	0	0	0	0	0	0	0
132	58	5130	0	0	500	1311	565	185	147	194	283	465	800	640	28	5	7	0	0	0	0	0	0	0
133	50	2553	0	1023	982	339	209	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
134	50	1980	0	653	725	260	342	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
135	58	4243	0	0	0	624	1323	631	445	293	131	181	370	239	4	2	0	0	0	0	0	0	0	0
136	58	2499	0	0	0	466	731	312	245	202	175	198	106	61	3	0	0	0	0	0	0	0	0	0
137	54	10751	0	0	0	0	2219	2202	1001	871	768	551	1180	1476	468	15	0	0	0	0	0	0	0	0
138	58	5983	0	0	0	981	1616	781	544	363	228	568	721	173	6	2	0	0	0	0	0	0	0	0
139	58	7015	0	0	107	1037	2168	783	523	582	795	745	156	104	11	4	0	0	0	0	0	0	0	0
140	58	5908	0	0	147	1259	1614	507	514	791	470	246	107	183	46	12	12	0	0	0	0	0	0	0
141	58	6045	0	0	0	973	1919	724	581	429	578	538	231	65	6	1	0	0	0	0	0	0	0	0
142	50	2445	0	385	1349	498	213	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
143	58	5221	0	0	134	581	1730	760	528	461	321	267	314	120	4	1	0	0	0	0	0	0	0	0
144	58	4420	0	0	0	813	1305	368	226	191	320	633	440	119	4	1	0	0	0	0	0	0	0	0
145	62	4082	0	0	107	356	719	472	349	498	489	495	456	98	13	8	14	8	0	0	0	0	0	0
146	58	5083	0	0	110	1120	1498	518	341	318	275	282	388	221	11	1	0	0	0	0	0	0	0	0
147	62	5127	0	0	0	767	1133	681	597	489	530	386	370	159	9	2	2	2	0	0	0	0	0	0
148	58	5099	0	0	0	1923	1395	392	321	306	192	143	213	204	9	1	0	0	0	0	0	0	0	0
149	62	4849	0	439	229	1215	1586	631	247	252	142	44	27	18	10	3	3	3	0	0	0	0	0	0
150	58	4524	0	0	100	900	1247	500	292	210	174	352	603	143	2	1	0	0	0	0	0	0	0	0
151	55	6081	0	0	0	0	1400	1402	613	509	466	337	511	595	242	5	1	0	0	0	0	0	0	0
152	58	4452	0	0	0	444	893	629	586	551	306	269	592	178	3	1	0	0	0	0	0	0	0	0
153	62	6031	0	0	0	1125	1926	936	713	692	360	136	78	42	15	3	3	2	0	0	0	0	0	0
154	58	7429	0	0	0	2338	1888	761	472	340	236	265	805	317	6	1	0	0	0	0	0	0	0	0
155	55	4577	0	0	0	290	806	1180	665	511	511	354	107	54	97	2	0	0	0	0	0	0	0	0
156	55	4213	0	0	0	0	568	1158	436	395	396	271	282	567	136	3	1	0	0	0	0	0	0	0
157	58	7354	0	0	334	1387	1341	790	702	802	580	595	675	143	4	1	0	0	0	0	0	0	0	0
158	62	6031	0	0	0	919	1707	712	458	463	743	566	324	130	6	1	1	1	0	0	0	0	0	0
159	55	8666	0	0	0	0	1510	2640	933	812	836	630	733	307	243	17	5	0	0	0	0	0	0	0
160	58	7639	0	0	483	2419	2936	555	345	304	117	58	30	240	97	38	17	0	0	0	0	0	0	0
161	54	4499	0	0	0	0	164	1088	1165	910	718	340	86	20	7	1	0	0	0	0	0	0	0	0
162	54	1499	0	0	0	0	0	52	63	126	292	290	266	295	114	1	0	0	0	0	0	0	0	0
163	54	3612	0	0	0	0	497	573	241	309	509	499	492	411	79	2	0	0	0	0	0	0	0	0
164	54	999	0	0	0	0	0	4	22	50	178	277	229	200	38	1	0	0	0	0	0	0	0	0
165	54	999	0	0	0	0	0	22	67	169	394	178	50	81	37	1	0	0	0	0	0	0	0	0
205	62	9805	0	429	2082	1409	913	769	934	1229	977	414	347	261	28	7	3	3	0	0	0	0	0	0
206	58	9466	0	560	418	3622	1931	696	421	327	494	575	271	137	11	2	1	0	0	0	0	0	0	0
207	58	6223	0	0	1086	2369	1371	504	325	272	162	61	35	31	5	2	0	0	0	0	0	0	0	0
208	55	7894	0	0	0	180	2047	2030	1018	737	568	378	223	484	225	4	0	0	0	0	0	0	0	0
209	55	11250	0	0	3227	1458	2456	1280	567	485	595	405	152	316	281	23	5	0	0	0	0	0	0	0
210	55	9590	0	0	2850	1447	2446	1149	411	316	327	247	173	120	89	12	3	0	0	0	0	0	0	0
211	55	9018	0	0	572	308	2533	2028	687	489	608	942	623	139	85	4	0	0	0	0	0	0	0	0
212	58	11406	0	1461	1849	3579	1590	346	380	772	776	290	177	178	7	1	0	0	0	0	0	0	0	0
213	62	4122	0	0	162	1257	1072	402	310	410	321	84	40	38	18	4	2	2	0	0	0	0	0	0
214	58	3645	0	0	977	1115	696	240	150	138	50	21	141	110	6	1	0	0	0	0	0	0	0	0
215	62	1987	0	0	0	751	464	212	151	148	98	54	42	50	11	3	1	2	0	0	0	0	0	0
216	62	5553	0	0	457	2449	1337	248	247	428	280	25	10	62	7	1	1	1	0	0	0	0	0	0
217	62	5996	0	0	356	3021	1601	234	134	197	254	133	25	30	8	2	0	1	0	0	0	0	0	0
218	62	4822	0	0	224	1710	1473	330	161	210	462	178	14	49	8	1	1	1	0	0	0	0	0	0
219	62	2724	0	0	0	1648	418	66	37	34	88	123	147	113	15	33	1	1	0	0	0	0	0	0
220	62	5436	0	0	0	1731	1840	646	402	339	273	66	35	87	10	3	3	1	0	0	0	0	0	0
221	62	5024	0	0	337	1765	1227	412	281	324	311	143	86	119	13	3	1	2	0	0	0	0	0	0
222	58	3682	0	0	358	671	817	411	304	345	307	257	179	30	2	1	0	0	0	0	0	0	0	0
223	62	5969	0	0	455	1940	1078	450	359	249	273	472	543	143	6	1	0	0	0	0	0	0	0	0
224	62	6088	0	0	866	1192	1042	610	443	427	455	581	402	64	3	1	1	1	0	0	0	0	0	0
225	62	6060	0	0	383	2104	1212	440	320	302	260	204	135	386	297	15	1	1	0	0	0	0	0	0
226	62	6028	0	0	279	1175	1202	672	572	559	365	437	565	194	5	1	1	1	0	0	0	0	0	0
227	62	5813	0	0	437	2003	1090	524	451	379	266	300	296	60	4	1	1	1	0	0	0	0	0	0
228	62	4827	0	0	0	1607	1398	422	292	302	325	138	141	170	29	1	1	1	0	0	0	0	0	0
229	62	4735	0	0	0	1140	1172	471	418	455	273	146	246	383	24	4	1	2	0	0	0	0	0	0
230	62	6072	0	0	154	902	1187	489	556	852	1072	458	257	120	17	3	2	3	0	0	0	0	0	0
231	62	6087	0	0	326	2420	1630	531	334	255	156	152	239	40	3	1	0	0	0	0	0	0	0	0
232	62	6008	0	0	297	962	1448	991	670	535	340	361	329	72	2	1	0	0	0	0	0	0	0	0
233	62	4874	0	0	527	1815	816	352	298	313	245	122	171	201	9	2	1	2	0	0	0	0	0	0
234	62	5919	0	0	1003	1384	869	389	313	370	462	244	350	475	37	10	8	5	0	0	0	0	0	0
235	62	4592	0	0	747	1250	1036	316	244	227	176	169	220	173	26	5	1	2	0	0	0	0	0	0
236	62	5832	0	0	863	1383	1368	460	290	241	236	324	532	115	13	3	2	2	0	0	0	0	0	0
237	62	6099	0	0	519	1240	1163	664	489	441	324	386	434	291	130	11	4	3	0	0	0	0	0	0
238	62	5459	0	0	606	1582	1154	535	396	481	315	154	147	85	3	1	0	0	0	0	0	0	0	0
239	62	6071	0	0	447	977	1346	555	455	436	515	410	532	346	30	13	7	2	0	0	0	0	0	0
240	62	4446	0	986	941	1165	253	91	65	84	140	148	253	242	65	6	3	4	0	0	0	0	0	0
241	62	7412	0	1314	1050	1312	911	452	408	450	290	361	606	141	95	11	5	6	0	0	0	0	0	0
242	62	6091	0	0	1109	1279	689	479	477	742	612	279	231	159	20	12	2	1	0	0	0	0	0	0
243	62	6071	0	0	1197	1661	617	200	188	417	736	369	305	303	43	21	12	2	0	0	0	0	0	0
244	62	4105	0	0	0	1569	1136	233	156	119	72	219	488	102	8	1	1	1	0	0	0	0	0	0
245	62	5861	0	0	852	1238	1092	542	358	340	542	520	301	69	4	1	1	1	0	0	0	0	0	0
246	62	6072	0	0	261	1511	1362	752	562	484	399	370	270	98	2	1	0	0	0	0	0	0	0	0
247	62	5344	0	381	1407	1315	685	296	212	250	240	167	174	202	11	2	1	1	0	0	0	0	0	0
248	62	6008	0	432	1157	1537	891	387	305	348	258	159	176	332	21	3	1	1	0	0	0	0	0	0
249	62	7291	0	0	132	2558	3409	627	258	206	48	3	3	38	8	1	0	0	0	0	0	0	0	0
250	62	3145	0	0	0	444	1469	508	280	302	117	14	7	4	0	0	0	0	0	0	0	0	0	0
251	62	8002	0	0	143	1528	4110	1193	492	296	139	67	29	5	0	0	0	0	0	0	0	0	0	0
252	62	3218	0	0	0	152	994	704	428	348	260	160	126	46	0	0	0	0	0	0	0	0	0	0
253	62	1390	0	0	0	27	125	143	122	174	107	130	467	94	1	0	0	0	0	0	0	0	0	0
254	62	1996	0	0	0	25	179	215	196	254	481	532	103	11	0	0	0	0	0	0	0	0	0	0
255	62	5071	0	0	0	1677	1909	453	247	237	96	73	140	228	7	2	1	1	0	0	0	0	0	0
256	62	3425	0	0	0	162	1354	718	386	321	192	132	123	37	0	0	0	0	0	0	0	0	0	0
257	62	2342	0	0	0	500	793	356	196	160	112	115	93	17	0	0	0	0	0	0	0	0	0	0
258	62	6032	0	0	153	1423	3141	591	353	220	46	16	29	38	11	8	3	0	0	0	0	0	0	0
259	62	2345	0	0	0	47	260	442	567	598	214	118	86	12	1	0	0	0	0	0	0	0	0	0
260	62	2567	0	0	0	99	128	207	312	550	502	366	333	70	0	0	0	0	0	0	0	0	0	0
261	62	4145	0	0	181	873	940	461	338	255	254	414	345	78	4	1	1	0	0	0	0	0	0	0
262	58	4421	0	0	608	1399	911	366	239	214	208	263	176	32	3	1	1	0	0	0	0	0	0	0
263	62	6060	0	0	383	2104	1212	440	320	302	260	204	135	386	297	15	1	1	0	0	0	0	0	0
264	62	4655	0	0	745	409	396	200	224	498	871	756	328	166	29	20	12	1	0	0	0	0	0	0
265	62	5544	0	0	291	1946	1546	383	183	105	39	159	679	192	13	4	2	2	0	0	0	0	0	0
266	62	6011	0	0	913	1694	1182	605	412	345	296	272	225	61	3	1	1	1	0	0	0	0	0	0
267	62	6068	0	0	771	1762	1125	422	369	502	389	218	287	213	7	1	1	1	0	0	0	0	0	0
268	62	3221	0	0	811	178	204	90	60	66	131	562	960	150	5	2	1	1	0	0	0	0	0	0
269	59	6064	0	0	634	779	386	288	298	351	787	1220	1275	36	5	3	2	0	0	0	0	0	0	0
270	59	8757	0	230	2249	3360	977	533	422	448	296	99	104	24	9	5	1	0	0	0	0	0	0	0
271	58	5770	0	0	0	1392	1892	702	533	505	252	163	123	183	18	5	2	0	0	0	0	0	0	0
272	58	5750	0	0	0	1106	1382	639	507	394	185	354	940	234	6	3	0	0	0	0	0	0	0	0
273	58	5068	0	0	0	788	1023	633	597	443	277	539	618	134	8	4	4	0	0	0	0	0	0	0
274	58	6098	0	0	0	867	2049	676	396	435	425	528	507	196	14	3	2	0	0	0	0	0	0	0
275	58	5889	0	0	529	2493	1385	224	167	191	226	217	160	233	41	12	11	0	0	0	0	0	0	0
276	58	3883	0	0	139	643	776	436	324	234	170	461	571	125	4	0	0	0	0	0	0	0	0	0
277	58	6038	0	0	0	1789	1304	639	472	218	119	569	836	90	2	0	0	0	0	0	0	0	0	0
278	58	6020	0	0	232	1840	1309	687	458	263	172	401	528	115	9	3	3	0	0	0	0	0	0	0
279	58	5825	0	0	1090	1759	1087	496	346	310	195	124	149	261	7	1	0	0	0	0	0	0	0	0
280	58	6101	0	0	971	1268	1135	583	488	386	257	333	551	121	6	2	0	0	0	0	0	0	0	0
281	62	3337	0	0	0	90	869	675	493	472	199	111	336	92	0	0	0	0	0	0	0	0	0	0
7126	3	7298.1999999999998	0	0	105	1470	860	660	760	598.39999999999998	716.79999999999995	1022.4	489.60000000000002	580.79999999999995	32	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7275	3	18166.799999999999	0	10380	2915	2140	870	420	295	192.80000000000001	182.80000000000001	268	148.80000000000001	213.59999999999999	69.599999999999994	62.399999999999999	\N	\N	\N	\N	\N	\N	\N	8.8000000000000007
7276	3	13931.6	0	1430	2435	2560	1330	1175	1080	857.60000000000002	998.39999999999998	726.39999999999998	427.19999999999999	582.39999999999998	216	70.400000000000006	\N	\N	\N	\N	\N	\N	\N	43.200000000000003
7277	86	16977.400000000001	0	1590	5175	4155	1790	770	485	650	588	885.60000000000002	343.19999999999999	144	315.19999999999999	43.200000000000003	36.799999999999997	\N	\N	\N	\N	\N	\N	6.4000000000000004
7278	3	17326.599999999999	0	3215	3480	2565	1355	1120	1190	1489.5999999999999	1464	628.79999999999995	246.40000000000001	468.80000000000001	80	8	\N	\N	\N	\N	\N	\N	\N	16
7279	3	20838.400000000001	0	5870	4620	2955	1395	1070	850	481.60000000000002	291.19999999999999	363.19999999999999	977.60000000000002	1833.5999999999999	75.200000000000003	41.600000000000001	\N	\N	\N	\N	\N	\N	\N	14.4
7280	3	17498	0	2430	3800	3290	1650	1010	910	480	289.60000000000002	340.80000000000001	1105.5999999999999	2081.5999999999999	84.799999999999997	11.199999999999999	\N	\N	\N	\N	\N	\N	\N	14.4
7281	3	17266.599999999999	0	0	6050	3845	1640	1200	1010	240	216	926.39999999999998	904	1174.4000000000001	51.200000000000003	4.7999999999999998	\N	\N	\N	\N	\N	\N	\N	4.7999999999999998
7282	3	19049.200000000001	0	0	4420	3405	2400	1500	1225	547.20000000000005	451.19999999999999	1699.2	1632	1676.8	80	6.4000000000000004	\N	\N	\N	\N	\N	\N	\N	6.4000000000000004
7283	3	18270	0	2385	6520	4955	1580	670	600	448	716.79999999999995	193.59999999999999	34.399999999999999	76	54.399999999999999	12	\N	\N	\N	\N	\N	\N	\N	24.800000000000001
7284	3	21963.200000000001	0	0	4960	5590	2420	1630	1680	1992	2081.5999999999999	769.60000000000002	220.80000000000001	364.80000000000001	166.40000000000001	30.399999999999999	\N	\N	\N	\N	\N	\N	\N	57.600000000000001
7285	86	19064.799999999999	0	1165	2090	3745	2935	1665	1700	1928	2126.4000000000001	921.60000000000002	344	283.19999999999999	83.200000000000003	41.600000000000001	\N	\N	\N	\N	\N	\N	\N	36.799999999999997
7286	3	17796.599999999999	0	210	2425	4105	2615	1945	1455	564.79999999999995	684.79999999999995	996.79999999999995	1129.5999999999999	1520	124.8	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	17.600000000000001
7287	3	19831.400000000001	0	4670	2800	3495	1245	880	815	899.20000000000005	2348.8000000000002	1862.4000000000001	521.60000000000002	265.60000000000002	19.199999999999999	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	6.4000000000000004
7288	3	10754.799999999999	0	650	1850	2095	1105	700	670	766.39999999999998	1489.5999999999999	1006.4	270.39999999999998	140.80000000000001	8	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7289	3	17622	0	7110	5705	1880	650	410	425	367.19999999999999	521.60000000000002	310	103.2	92.400000000000006	22.800000000000001	17.199999999999999	\N	\N	\N	\N	\N	\N	\N	7.5999999999999996
7290	3	15147.799999999999	0	0	2520	3880	1825	1315	1355	1220.8	1323.2	766.39999999999998	304	411.19999999999999	150.40000000000001	25.600000000000001	\N	\N	\N	\N	\N	\N	\N	51.200000000000003
7291	3	20890.799999999999	0	1240	8620	6895	1045	485	485	637.60000000000002	696	348	197.59999999999999	205.59999999999999	26.399999999999999	6.4000000000000004	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7292	3	17328.400000000001	0	0	3450	6610	1560	895	970	1294.4000000000001	1256	582.39999999999998	310.39999999999998	348.80000000000001	38.399999999999999	6.4000000000000004	\N	\N	\N	\N	\N	\N	\N	6.4000000000000004
7293	86	18769	0	4030	6120	2490	2150	880	490	445	305.60000000000002	430.39999999999998	501.60000000000002	343.19999999999999	532.79999999999995	24	20	\N	\N	\N	\N	\N	\N	6.4000000000000004
7294	3	14749.6	0	0	2335	2945	1480	1045	1175	953.60000000000002	1462.4000000000001	1553.5999999999999	779.20000000000005	908.79999999999995	84.799999999999997	9.5999999999999996	\N	\N	\N	\N	\N	\N	\N	17.600000000000001
7295	3	18380.799999999999	0	855	4755	5810	2215	1170	1055	521.60000000000002	660.79999999999995	569.60000000000002	318.39999999999998	403.19999999999999	32.799999999999997	9.5999999999999996	\N	\N	\N	\N	\N	\N	\N	4.7999999999999998
7296	3	19539.799999999999	0	0	2860	5935	2535	1590	1575	1131.2	1347.2	1153.5999999999999	622.39999999999998	724.79999999999995	59.200000000000003	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7297	86	23410.400000000001	0	8530	5790	5105	2160	515	250	200	128.80000000000001	87.599999999999994	159.59999999999999	220.40000000000001	235.59999999999999	18.399999999999999	7.5999999999999996	\N	\N	\N	\N	\N	\N	2.3999999999999999
7298	3	18366.599999999999	0	650	3675	4590	1765	1060	1025	649.60000000000002	796.79999999999995	921.60000000000002	1062.4000000000001	1752	284.80000000000001	81.599999999999994	\N	\N	\N	\N	\N	\N	\N	52.799999999999997
7299	3	15975.799999999999	0	0	2685	6145	2170	1095	1200	919.20000000000005	1220	453.60000000000002	56	16.800000000000001	9.5999999999999996	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	2.3999999999999999
7300	3	17750	0	0	1595	4710	2515	1355	1495	2134.4000000000001	2547.1999999999998	1216	131.19999999999999	25.600000000000001	9.5999999999999996	6.4000000000000004	\N	\N	\N	\N	\N	\N	\N	9.5999999999999996
7301	86	22025	0	7210	2650	8025	1830	675	300	375	284.80000000000001	268.39999999999998	165.19999999999999	77.599999999999994	94.400000000000006	48	15.199999999999999	\N	\N	\N	\N	\N	\N	6.4000000000000004
7302	3	20512.799999999999	0	1565	3710	3665	2175	1450	1535	1920	1820.8	1171.2	745.60000000000002	643.20000000000005	76.799999999999997	16	\N	\N	\N	\N	\N	\N	\N	19.199999999999999
7303	3	20870.400000000001	0	1035	5640	10430	2045	625	595	276.60000000000002	142.19999999999999	10	2.6000000000000001	22.199999999999999	27.199999999999999	13.199999999999999	\N	\N	\N	\N	\N	\N	\N	6.4000000000000004
7304	3	18770.799999999999	0	0	3635	7810	2860	1135	1050	757.60000000000002	740.79999999999995	105.59999999999999	39.200000000000003	322.39999999999998	208.80000000000001	35.200000000000003	\N	\N	\N	\N	\N	\N	\N	71.200000000000003
7305	3	14645	0	0	2395	4140	1665	1010	955	516.79999999999995	1121.5999999999999	1836.8	702.39999999999998	288	9.5999999999999996	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7306	3	13276.6	0	0	835	2930	1920	1305	1485	1161.5999999999999	1366.4000000000001	1475.2	563.20000000000005	214.40000000000001	9.5999999999999996	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	8
7307	3	16497.400000000001	0	0	5470	5655	1680	820	670	447.19999999999999	482.39999999999998	296	285.60000000000002	656.79999999999995	28	4	\N	\N	\N	\N	\N	\N	\N	2.3999999999999999
7308	3	19679.200000000001	0	0	2695	5190	2010	1490	1395	1267.2	1465.5999999999999	1104	684.79999999999995	2252.8000000000002	112	6.4000000000000004	\N	\N	\N	\N	\N	\N	\N	6.4000000000000004
7309	3	11946.6	0	0	1255	2710	1590	1555	2195	1694.4000000000001	642.39999999999998	204	67.200000000000003	24	2.3999999999999999	6.4000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7310	3	16411.400000000001	0	0	1620	2865	2070	2125	3085	2302.4000000000001	1385.5999999999999	507.19999999999999	246.40000000000001	124.8	43.200000000000003	19.199999999999999	\N	\N	\N	\N	\N	\N	\N	17.600000000000001
7313	3	18408.400000000001	0	0	8300	3790	1415	785	520	320	515.20000000000005	760	712	1161.5999999999999	57.600000000000001	65.599999999999994	\N	\N	\N	\N	\N	\N	\N	6.4000000000000004
7314	3	18571.599999999999	0	0	2885	4515	1750	1165	1050	761.60000000000002	1075.2	1331.2	1337.5999999999999	2620.8000000000002	76.799999999999997	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7315	3	16583.200000000001	0	0	4365	4570	2200	1195	1210	753.60000000000002	1158.4000000000001	641.60000000000002	235.19999999999999	211.19999999999999	22.399999999999999	11.199999999999999	\N	\N	\N	\N	\N	\N	\N	9.5999999999999996
7316	3	14791.200000000001	0	0	1120	1875	2675	2105	3005	2417.5999999999999	1091.2	302.39999999999998	99.200000000000003	81.599999999999994	9.5999999999999996	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	6.4000000000000004
7317	3	18962.799999999999	0	0	840	5405	1930	950	1025	697.60000000000002	1692.8	2531.1999999999998	2038.4000000000001	1817.5999999999999	28.800000000000001	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7318	3	16513.200000000001	0	0	560	4935	1840	980	995	726.39999999999998	1187.2	2003.2	1760	1497.5999999999999	25.600000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7319	3	2684.5999999999999	0	0	80	30	25	15	15	19.199999999999999	117.59999999999999	467.19999999999999	1080.8	828.79999999999995	4.7999999999999998	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.40000000000000002
7320	3	18526.599999999999	0	0	4800	7760	1740	835	710	324	258.39999999999998	371.19999999999999	344.80000000000001	1295.2	76.799999999999997	4	\N	\N	\N	\N	\N	\N	\N	7.2000000000000002
7321	3	20611	0	0	870	4075	3205	2375	2390	1580.8	1833.5999999999999	1561.5999999999999	896	1680	128	9.5999999999999996	\N	\N	\N	\N	\N	\N	\N	6.4000000000000004
7322	3	18980	0	0	1335	4580	2200	1545	1800	1238.4000000000001	2112	1161.5999999999999	777.60000000000002	2166.4000000000001	60.799999999999997	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7323	3	17893.200000000001	0	0	965	4945	2460	1410	1710	1897.5999999999999	1763.2	1267.2	524.79999999999995	899.20000000000005	48	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7324	3	10915.799999999999	0	405	450	3230	2185	960	625	344	448	481.60000000000002	529.60000000000002	1179.2	59.200000000000003	14.4	\N	\N	\N	\N	\N	\N	\N	4.7999999999999998
7325	3	22057.799999999999	0	0	2045	8885	3025	930	760	697.60000000000002	940.79999999999995	992	1283.2	2416	70.400000000000006	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	9.5999999999999996
7326	3	3776.5999999999999	0	0	0	25	30	40	80	204.80000000000001	337.60000000000002	408	940.79999999999995	1702.4000000000001	6.4000000000000004	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7327	3	21405.799999999999	0	475	4000	9830	2870	1215	1055	604.79999999999995	720.79999999999995	361.60000000000002	73.599999999999994	109.59999999999999	76.799999999999997	9.5999999999999996	\N	\N	\N	\N	\N	\N	\N	4
7328	3	18904.200000000001	0	435	1300	1930	1205	1155	2300	3756.8000000000002	5113.6000000000004	1516.8	115.2	54.399999999999999	16	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7329	86	26723	0	205	5610	7225	4470	2550	1620	1515	1027.2	1004.8	371.19999999999999	134.40000000000001	803.20000000000005	70.400000000000006	110.40000000000001	\N	\N	\N	\N	\N	\N	6.4000000000000004
7330	3	24351.599999999999	0	1265	4270	5840	3340	2265	2330	1558.4000000000001	1494.4000000000001	644.79999999999995	217.59999999999999	955.20000000000005	153.59999999999999	6.4000000000000004	\N	\N	\N	\N	\N	\N	\N	11.199999999999999
7331	3	8910.2000000000007	0	0	0	1310	915	610	720	715.20000000000005	937.60000000000002	1003.2	1116.8	1547.2	28.800000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	4.7999999999999998
7332	3	15375.799999999999	0	0	0	2160	1650	1135	1170	1270.4000000000001	2137.5999999999999	3219.1999999999998	857.60000000000002	1753.5999999999999	16	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7333	3	6591.8000000000002	0	0	75	350	375	375	540	614.39999999999998	1580.8	1211.2	561.60000000000002	892.79999999999995	9.5999999999999996	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7334	3	7195	0	0	0	300	370	535	870	1179.2	1678.4000000000001	1155.2	456	638.39999999999998	9.5999999999999996	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7335	3	18273	0	0	4520	4060	2035	1275	1415	1344	1137.5999999999999	953.60000000000002	636.79999999999995	862.39999999999998	30.399999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7336	3	23626.599999999999	0	0	940	4380	2510	2200	2555	2140.8000000000002	2588.8000000000002	3187.1999999999998	1536	1504	67.200000000000003	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	16
7337	86	25715	0	2115	7405	10290	2955	855	335	320	191.19999999999999	290.39999999999998	306	200	396	33.600000000000001	6.4000000000000004	\N	\N	\N	\N	\N	\N	16.399999999999999
7338	3	17830	0	0	300	4325	2620	1195	1230	684.79999999999995	892.79999999999995	1315.2	1622.4000000000001	3571.1999999999998	60.799999999999997	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	9.5999999999999996
7339	3	6159.6000000000004	0	0	525	1570	780	465	380	241.59999999999999	393.60000000000002	608.79999999999995	464	692	34.399999999999999	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	4.7999999999999998
7340	3	12796.6	0	0	830	2985	1735	975	830	529.60000000000002	771.20000000000005	1316.8	1126.4000000000001	1604.8	84.799999999999997	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	6.4000000000000004
7341	3	1720.4000000000001	0	0	0	0	0	0	0	4	83.200000000000003	426.39999999999998	542.39999999999998	656	8	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0
7342	3	6264.1999999999998	0	0	390	2130	820	340	305	229.59999999999999	372	825.60000000000002	520	323.19999999999999	6.4000000000000004	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7343	3	8562.3999999999996	0	0	720	2650	1055	510	505	379.19999999999999	601.60000000000002	1033.5999999999999	483.19999999999999	606.39999999999998	16	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7344	3	4823	0	0	0	0	175	420	1015	1088	1958.4000000000001	158.40000000000001	1.8	3.2000000000000002	1.6000000000000001	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7345	3	8359.6000000000004	0	0	0	140	430	690	1490	2521.5999999999999	2843.1999999999998	235.19999999999999	3.2000000000000002	3.2000000000000002	1.6000000000000001	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7346	3	4315	0	0	0	20	75	100	200	440	1115.2	934.39999999999998	481.60000000000002	913.60000000000002	32	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7347	3	9317.3999999999996	0	0	610	1860	790	465	550	739.20000000000005	1312	953.60000000000002	715.20000000000005	1272	48	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7348	3	7007.3999999999996	0	0	0	855	1195	625	650	582.39999999999998	705.60000000000002	712	643.20000000000005	1014.4	22.399999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7349	3	9671.7999999999993	0	0	30	875	1315	760	775	624	1174.4000000000001	1552	1011.2	1526.4000000000001	22.399999999999999	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7350	3	5845.6000000000004	0	0	0	15	165	465	1195	1177.5999999999999	2073.5999999999999	638.39999999999998	86.400000000000006	24	3.2000000000000002	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7351	3	7723.1999999999998	0	0	0	35	200	745	1780	2086.4000000000001	2206.4000000000001	585.60000000000002	65.599999999999994	11.199999999999999	4.7999999999999998	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7352	3	14358	0	3500	2650	1405	1070	755	890	793.60000000000002	1049.5999999999999	745.60000000000002	489.60000000000002	777.60000000000002	192	27.199999999999999	\N	\N	\N	\N	\N	\N	\N	12.800000000000001
7353	3	13425	0	0	450	920	1050	830	1375	1936	2604.8000000000002	1916.8	1292.8	921.60000000000002	102.40000000000001	12.800000000000001	\N	\N	\N	\N	\N	\N	\N	12.800000000000001
7354	3	8725.6000000000004	0	0	620	2195	1215	645	685	424	438.39999999999998	534.39999999999998	628.79999999999995	1313.5999999999999	24	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7355	3	12965	0	0	475	3885	2895	1050	780	550.39999999999998	524.79999999999995	729.60000000000002	672	1307.2	78.400000000000006	4.7999999999999998	\N	\N	\N	\N	\N	\N	\N	12.800000000000001
7356	3	2518.4000000000001	0	0	0	70	35	25	25	23.800000000000001	44	230.40000000000001	723.20000000000005	1334.4000000000001	7.2000000000000002	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0
7357	3	7940.6000000000004	0	0	150	1010	870	740	765	984	1139.2	1000	627.20000000000005	625.60000000000002	27.199999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7358	3	2244.5999999999999	0	0	0	0	15	25	15	55.200000000000003	430.39999999999998	372	554.39999999999998	773.60000000000002	4	0	\N	\N	\N	\N	\N	\N	\N	0
7359	3	15579.799999999999	0	1020	2025	4040	1650	1090	950	755.20000000000005	1065.5999999999999	865.60000000000002	707.20000000000005	1288	113.59999999999999	8	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7360	3	10775	0	0	270	1575	1705	785	840	806.39999999999998	1206.4000000000001	1064	617.60000000000002	1305.5999999999999	552	25.600000000000001	\N	\N	\N	\N	\N	\N	\N	22.399999999999999
7361	3	3721.5999999999999	0	0	100	1590	610	225	215	168.40000000000001	99.200000000000003	98	150.80000000000001	454.39999999999998	9.5999999999999996	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.40000000000000002
7362	3	7305.1999999999998	0	0	0	1310	700	485	595	553.60000000000002	531.20000000000005	440	656	2028.8	3.2000000000000002	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7363	3	7762	0	0	640	3275	1830	735	480	194.80000000000001	288	185.19999999999999	51.600000000000001	64.799999999999997	15.6	1.2	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7364	3	13351.6	0	0	335	3520	2865	1515	1275	1064	1339.2	651.20000000000005	196.80000000000001	436.80000000000001	134.40000000000001	6.4000000000000004	\N	\N	\N	\N	\N	\N	\N	12.800000000000001
7365	3	6029.8000000000002	0	0	625	1305	700	425	330	262.39999999999998	248.80000000000001	337.60000000000002	580	1168.8	44.799999999999997	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7366	3	11996.6	0	0	460	2960	1545	880	710	558.39999999999998	600	756.79999999999995	1398.4000000000001	2038.4000000000001	84.799999999999997	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7367	3	1977.4000000000001	0	0	0	15	10	20	10	7.2000000000000002	88.799999999999997	418.39999999999998	508.80000000000001	881.60000000000002	16.800000000000001	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0.40000000000000002
7368	3	7642.8000000000002	0	0	490	1550	840	795	675	484.80000000000001	414.39999999999998	446.39999999999998	523.20000000000005	1388.8	30.399999999999999	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7369	3	10231.4	0	0	385	2205	1630	1255	830	620.79999999999995	425.60000000000002	355.19999999999999	686.39999999999998	1777.5999999999999	56	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7370	3	7137.3999999999996	0	0	0	90	255	340	770	1244.8	2160	1729.5999999999999	414.39999999999998	128	3.2000000000000002	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7371	3	8248	0	0	0	1525	1210	860	885	958.39999999999998	1259.2	960	353.60000000000002	228.80000000000001	4.7999999999999998	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7372	3	8875.7999999999993	0	595	345	1580	1440	1075	1040	756.79999999999995	1079.2	672.79999999999995	167.19999999999999	105.59999999999999	13.6	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	2.3999999999999999
7373	3	8305.7999999999993	0	0	400	2130	1460	825	930	750.39999999999998	941.60000000000002	540	162.40000000000001	134.40000000000001	24.800000000000001	2.3999999999999999	\N	\N	\N	\N	\N	\N	\N	4.7999999999999998
7374	3	8212.3999999999996	0	0	520	3160	1055	485	590	340	227.19999999999999	322.39999999999998	592	887.20000000000005	30.399999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7375	3	8603.3999999999996	0	0	185	1830	1000	670	760	524.79999999999995	465.60000000000002	630.39999999999998	721.60000000000002	1747.2	62.399999999999999	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7376	3	5430	0	0	250	1045	455	265	295	316.80000000000001	443.19999999999999	638.39999999999998	587.20000000000005	1108.8	22.399999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7377	3	7012.1999999999998	0	0	430	1310	690	400	415	488	523.20000000000005	616	763.20000000000005	1342.4000000000001	32	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7378	3	3063.1999999999998	0	0	0	0	0	10	10	12.800000000000001	179.19999999999999	548.79999999999995	897.60000000000002	1393.5999999999999	11.199999999999999	0	\N	\N	\N	\N	\N	\N	\N	0
7379	3	7481.6000000000004	0	0	445	1885	1085	560	535	376	656.79999999999995	952.79999999999995	512.79999999999995	437.19999999999999	33.600000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7380	3	8114.8000000000002	0	0	330	1725	1270	640	625	398.39999999999998	723.20000000000005	1257.5999999999999	660.79999999999995	438.39999999999998	43.200000000000003	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7381	3	4605	0	0	0	50	165	290	420	468.80000000000001	1160	1075.2	502.39999999999998	460.80000000000001	11.199999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7382	3	6996.6000000000004	0	0	0	175	425	415	700	920	1656	1451.2	702.39999999999998	539.20000000000005	11.199999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7383	3	4665	0	0	0	20	60	145	280	470.39999999999998	1100.8	1174.4000000000001	801.60000000000002	596.79999999999995	11.199999999999999	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7384	3	5346.6000000000004	0	0	0	80	400	435	590	752	1484.8	552	284.80000000000001	756.79999999999995	8.5999999999999996	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7385	3	9480.7999999999993	0	0	90	1740	1140	770	1020	1112	1422.4000000000001	555.20000000000005	329.60000000000002	1278.4000000000001	20.800000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7386	3	1971.5999999999999	0	0	0	0	10	20	20	53.600000000000001	242.40000000000001	622.39999999999998	496	500.80000000000001	5.5999999999999996	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0.40000000000000002
7387	3	5932.6000000000004	0	0	0	0	50	80	145	313.60000000000002	1092.8	2051.1999999999998	1462.4000000000001	662.39999999999998	64	8	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7388	3	2394.5999999999999	0	0	0	0	50	25	40	84	387.19999999999999	860	511.19999999999999	428.80000000000001	5.5999999999999996	2.3999999999999999	\N	\N	\N	\N	\N	\N	\N	0.40000000000000002
7389	3	6899.6000000000004	0	0	0	0	60	45	65	182.40000000000001	972.79999999999995	2896	1625.5999999999999	1036.8	12.800000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7390	3	4254.6000000000004	0	0	0	20	110	265	650	910.39999999999998	864	412.80000000000001	464	552	4.7999999999999998	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7391	3	7463	0	0	0	60	315	605	1275	1744	1358.4000000000001	646.39999999999998	740.79999999999995	713.60000000000002	3.2000000000000002	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7392	3	7892.3999999999996	0	0	55	1600	2065	1060	790	443.19999999999999	400.80000000000001	246.40000000000001	357.60000000000002	861.60000000000002	11.199999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7393	3	8763.2000000000007	0	0	235	1290	1250	935	970	700.79999999999995	750.39999999999998	836.79999999999995	686.39999999999998	1088	19.199999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7394	3	7029.6000000000004	0	0	0	780	1030	740	790	707.20000000000005	814.39999999999998	683.20000000000005	568	896	19.199999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7395	3	8827.2000000000007	0	0	0	555	1040	835	1110	1476.8	1572.8	1038.4000000000001	584	598.39999999999998	14.4	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7396	3	6641.6000000000004	0	0	0	545	720	480	735	600	907.20000000000005	760	564.79999999999995	1302.4000000000001	25.600000000000001	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7397	3	11689	0	0	40	850	1400	1365	1650	1299.2	1072	944	1116.8	1907.2	38.399999999999999	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7398	3	5507.3999999999996	0	0	0	300	880	755	650	428.80000000000001	238.40000000000001	309.60000000000002	627.20000000000005	1296.8	20	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7399	3	11108.200000000001	0	0	0	630	1815	1410	1250	710.39999999999998	646.39999999999998	835.20000000000005	1091.2	2683.1999999999998	35.200000000000003	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7400	3	5790	0	0	0	15	100	260	455	691.20000000000005	1216	1451.2	768	824	6.4000000000000004	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7401	3	10132.6	0	0	0	70	585	730	1250	1856	2124.8000000000002	1686.4000000000001	1027.2	787.20000000000005	9.5999999999999996	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7402	3	5563	0	0	0	420	795	515	545	409.60000000000002	801.60000000000002	948.79999999999995	614.39999999999998	507.19999999999999	4.7999999999999998	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7403	3	9153.3999999999996	0	0	0	840	1430	835	690	718.39999999999998	1172.8	1518.4000000000001	1059.2	876.79999999999995	11.199999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7404	3	7033.1999999999998	0	0	415	1135	920	550	410	369.60000000000002	571.20000000000005	577.60000000000002	544	1299.2	224	11.199999999999999	\N	\N	\N	\N	\N	\N	\N	6.4000000000000004
7405	3	10769.4	0	445	80	1210	1065	520	415	444.80000000000001	803.20000000000005	854.39999999999998	1001.6	3481.5999999999999	428.80000000000001	19.199999999999999	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7406	3	6612.3999999999996	0	0	535	2080	1015	620	600	279.19999999999999	218.40000000000001	199.19999999999999	188	845.60000000000002	30.399999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7407	3	10241.6	0	0	750	2550	1455	1065	1060	688	502.39999999999998	552	448	1132.8	33.600000000000001	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7408	3	6733.1999999999998	0	0	95	935	1475	1035	830	485.60000000000002	256.80000000000001	209.59999999999999	405.60000000000002	985.60000000000002	17.600000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7409	3	11553.4	0	0	170	1020	1775	1510	1720	1465.5999999999999	888	672	960	1340.8	28.800000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7410	3	4814.6000000000004	0	0	280	910	815	560	570	398.39999999999998	145.59999999999999	75.200000000000003	83.200000000000003	952.79999999999995	23.199999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.40000000000000002
7411	3	9640	0	0	935	1885	1430	905	885	478.39999999999998	689.60000000000002	740.79999999999995	520	1123.2	43.200000000000003	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7412	3	5640.1999999999998	0	0	0	435	1035	885	890	568.79999999999995	766.39999999999998	585.60000000000002	265.60000000000002	194.40000000000001	12	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7413	3	8007	0	0	0	800	1260	1180	1295	1412.8	1048	614.39999999999998	243.19999999999999	144	4.7999999999999998	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7414	3	4888.1999999999998	0	0	0	465	465	430	515	557.60000000000002	584.79999999999995	526.39999999999998	569.60000000000002	752.79999999999995	20.800000000000001	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.40000000000000002
7415	3	6762.3999999999996	0	0	225	1155	715	610	675	686.39999999999998	609.60000000000002	486.39999999999998	585.60000000000002	987.20000000000005	24	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7416	3	5843.1999999999998	0	0	70	840	960	550	660	685.60000000000002	390.39999999999998	185.59999999999999	216	1257.5999999999999	26.399999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7417	3	6928.3999999999996	0	0	0	440	970	875	1005	718.39999999999998	481.60000000000002	294.39999999999998	384	1697.5999999999999	59.200000000000003	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7418	3	1878.2	0	0	0	0	0	15	50	80.799999999999997	359.19999999999999	622.39999999999998	393.60000000000002	351.19999999999999	4.7999999999999998	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.40000000000000002
7419	3	6983.6000000000004	0	0	0	525	1155	815	775	648	771.20000000000005	1068.8	732.79999999999995	476.80000000000001	12.800000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7420	3	10307.799999999999	0	0	0	550	950	1060	1475	1476.8	1710.4000000000001	1192	1054.4000000000001	819.20000000000005	17.600000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7421	3	8474	0	0	170	1775	1985	925	655	429.60000000000002	960.79999999999995	952	443.19999999999999	150.40000000000001	24	2.3999999999999999	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7422	3	8906.7999999999993	0	0	0	1205	2020	1795	1510	851.20000000000005	1076.8	228	38.399999999999999	112	31.199999999999999	35.200000000000003	\N	\N	\N	\N	\N	\N	\N	4
7423	3	6969	0	0	0	220	715	685	585	273.60000000000002	225.59999999999999	1502.4000000000001	1624	1116.8	19.199999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7424	3	7197.1999999999998	0	0	0	135	585	935	1035	721.60000000000002	435.19999999999999	497.60000000000002	686.39999999999998	2129.5999999999999	33.600000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7425	3	4075.4000000000001	0	0	0	0	35	70	120	134.40000000000001	124.8	307.19999999999999	992	2246.4000000000001	43.200000000000003	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7426	3	6792.3999999999996	0	0	0	365	735	595	835	1080	1032	688	542.39999999999998	865.60000000000002	51.200000000000003	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7427	3	6795	0	0	0	245	550	525	955	1788.8	1417.5999999999999	536	228.80000000000001	515.20000000000005	30.399999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7428	3	5602	0	0	0	75	145	250	520	796.79999999999995	1483.2	1136	721.60000000000002	467.19999999999999	4.7999999999999998	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7429	3	6076	0	0	0	205	285	380	630	1043.2	1444.8	1084	633.60000000000002	363.19999999999999	4.7999999999999998	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7430	3	6854.6000000000004	0	0	270	2065	1125	710	735	662.39999999999998	340.80000000000001	144.80000000000001	233.59999999999999	515.20000000000005	50.399999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7431	3	8125.1999999999998	0	0	660	1350	910	755	1015	616	160	128	483.19999999999999	1988.8	54.399999999999999	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7432	3	2365	0	0	0	0	10	20	15	21.600000000000001	227.19999999999999	550.39999999999998	488.80000000000001	1024	6.4000000000000004	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7433	3	2854.4000000000001	0	0	0	20	60	75	125	188.80000000000001	493.60000000000002	660.79999999999995	415.19999999999999	803.20000000000005	12.800000000000001	0	\N	\N	\N	\N	\N	\N	\N	0
7434	3	4970	0	0	0	335	300	365	530	577.60000000000002	992	894.39999999999998	420.80000000000001	544	11.199999999999999	0	\N	\N	\N	\N	\N	\N	\N	0
7435	3	7721.8000000000002	0	0	105	600	565	605	930	817.60000000000002	1137.5999999999999	1176	710.39999999999998	1044.8	27.199999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7436	3	4763.3999999999996	0	0	0	0	70	95	190	272	595.20000000000005	1176	1241.5999999999999	1081.5999999999999	9.5999999999999996	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7437	3	6382.3999999999996	0	0	0	245	550	480	725	537.60000000000002	259.19999999999999	249.59999999999999	784	2510.4000000000001	40	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0
7438	3	7196.8000000000002	0	0	40	870	625	620	885	947.20000000000005	723.20000000000005	433.60000000000002	443.19999999999999	1582.4000000000001	25.600000000000001	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7439	3	3282.8000000000002	0	0	0	25	130	325	660	458.39999999999998	384.80000000000001	308	274.39999999999998	711.20000000000005	4.7999999999999998	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7440	3	6999	0	0	0	155	625	1175	1540	993.60000000000002	651.20000000000005	379.19999999999999	307.19999999999999	1156.8	12.800000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7441	3	3915.1999999999998	0	0	0	35	105	140	240	318.39999999999998	766.39999999999998	1038.4000000000001	497.60000000000002	740.79999999999995	32	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7442	3	4935.1999999999998	0	0	0	45	165	285	710	1068.8	1238.4000000000001	664	201.59999999999999	507.19999999999999	44.799999999999997	4.7999999999999998	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7443	3	4522.1999999999998	0	0	0	10	105	240	660	894.39999999999998	870.39999999999998	622.39999999999998	428.80000000000001	668.79999999999995	20.800000000000001	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7444	3	4873.6000000000004	0	0	0	70	190	320	580	865.60000000000002	937.60000000000002	649.60000000000002	443.19999999999999	785.60000000000002	30.399999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7445	3	6853	0	0	0	445	1440	1535	1405	1068	460.80000000000001	128.80000000000001	35.200000000000003	160.80000000000001	147.19999999999999	15.199999999999999	\N	\N	\N	\N	\N	\N	\N	12
7446	3	7020.6000000000004	0	0	0	475	1920	1745	1255	708	363.19999999999999	76.799999999999997	24.800000000000001	213.59999999999999	199.19999999999999	27.199999999999999	\N	\N	\N	\N	\N	\N	\N	12.800000000000001
7447	3	6476.6000000000004	0	0	0	125	305	535	1030	763.20000000000005	1299.2	1216	699.20000000000005	476.80000000000001	24	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7448	3	8343.2000000000007	0	0	0	515	1275	1735	2055	1304	844.79999999999995	380.80000000000001	101.59999999999999	98.400000000000006	29.600000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	2.3999999999999999
7449	3	6315.6000000000004	0	0	0	55	190	255	340	300.80000000000001	529.60000000000002	1180.8	1228.8	2154	78.400000000000006	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7450	3	8059.8000000000002	0	0	250	320	745	615	905	955.20000000000005	992	1089.5999999999999	971.20000000000005	1174.4000000000001	41.600000000000001	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0
7451	3	13899.200000000001	0	690	1960	3660	1105	995	1110	864	468.80000000000001	420.80000000000001	702.39999999999998	1808	105.59999999999999	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	6.4000000000000004
7452	3	9239.6000000000004	0	0	205	360	545	985	2335	2460.8000000000002	1046.4000000000001	475.19999999999999	289.60000000000002	481.60000000000002	43.200000000000003	4.7999999999999998	\N	\N	\N	\N	\N	\N	\N	8
7453	3	6536.6000000000004	0	0	0	50	140	435	1210	1371.2	1256	908.79999999999995	652.79999999999995	500.80000000000001	9.5999999999999996	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7454	3	8263.3999999999996	0	0	0	20	160	480	1625	1705.5999999999999	1700.8	998.39999999999998	598.39999999999998	955.20000000000005	17.600000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7455	3	9946.6000000000004	0	0	0	55	495	1915	4240	2241.5999999999999	700.79999999999995	147.19999999999999	72	73.599999999999994	1.6000000000000001	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7456	3	10331.799999999999	0	0	0	105	1135	2745	3150	1672	705.60000000000002	360	248	198.40000000000001	6.4000000000000004	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7457	3	5821.6000000000004	0	0	0	10	50	260	740	846.39999999999998	1080	1020.8	867.20000000000005	929.60000000000002	16	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7458	3	9836.3999999999996	0	0	0	300	450	600	1040	1462.4000000000001	1673.5999999999999	1724.8	956.79999999999995	1587.2	38.399999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7459	3	5706	0	0	0	170	385	185	270	436.80000000000001	1356.8	1334.4000000000001	649.60000000000002	884.79999999999995	32	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7460	3	9231.7999999999993	0	0	0	545	685	530	995	1200	1536	1273.5999999999999	732.79999999999995	1680	48	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7461	3	6753.6000000000004	0	0	0	20	80	215	685	1392	1968	1195.2	662.39999999999998	524.79999999999995	9.5999999999999996	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7462	3	9098.2000000000007	0	0	0	10	65	245	775	1734.4000000000001	2444.8000000000002	2451.1999999999998	816	540.79999999999995	9.5999999999999996	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7463	3	7152	0	0	0	0	135	275	950	1718.4000000000001	1780.8	1025.5999999999999	600	662.39999999999998	3.2000000000000002	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7464	3	8719	0	0	0	55	200	480	280	2083.1999999999998	2281.5999999999999	1542.4000000000001	812.79999999999995	972.79999999999995	6.4000000000000004	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7465	3	7929	0	0	0	25	100	180	600	716.79999999999995	1907.2	1932.8	1100.8	1337.5999999999999	19.199999999999999	6.4000000000000004	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7466	3	9703	0	0	0	20	85	150	400	950.39999999999998	2508.8000000000002	3232	1392	950.39999999999998	9.5999999999999996	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7467	3	8319.3999999999996	0	0	0	30	120	190	805	1910.4000000000001	2003.2	1363.2	771.20000000000005	1078.4000000000001	41.600000000000001	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7468	3	7870	0	0	100	25	55	175	475	924.79999999999995	1532.8	1564.8	1302.4000000000001	1657.5999999999999	51.200000000000003	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7469	3	7835.8000000000002	0	0	0	60	395	620	1460	1206	1054.4000000000001	691.20000000000005	812.79999999999995	1505.5999999999999	27.199999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7470	3	5543	0	0	0	0	55	130	350	641.60000000000002	1179.2	1179.2	843.20000000000005	1136	27.199999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7471	3	6071.1999999999998	0	0	0	40	135	280	765	1776	1441.5999999999999	801.60000000000002	510.39999999999998	315.19999999999999	4.7999999999999998	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7472	3	8105	0	0	0	30	100	235	620	1270.4000000000001	1427.2	1081.5999999999999	1148.8	2137.5999999999999	48	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7473	3	8534.7999999999993	0	0	0	65	135	310	540	1356.8	1744	1372.8	876.79999999999995	2073.5999999999999	51.200000000000003	6.4000000000000004	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7474	3	8306.3999999999996	0	0	0	135	570	900	1835	1657.5999999999999	1888	747.20000000000005	249.59999999999999	316.80000000000001	4.7999999999999998	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7475	3	11871.200000000001	0	0	0	75	400	670	1715	2985.5999999999999	3724.8000000000002	1555.2	425.60000000000002	313.60000000000002	3.2000000000000002	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7476	3	11438	0	0	0	155	535	1050	1850	1772.8	1308.8	1014.4	1580.8	2137.5999999999999	28.800000000000001	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7477	3	5933.3999999999996	0	0	0	0	5	45	145	377.60000000000002	923.20000000000005	1296	1795.2	1340.8	2.3999999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7478	3	8395.6000000000004	0	0	0	70	310	455	975	1414.4000000000001	2096	1491.2	739.20000000000005	828.79999999999995	12.800000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7479	3	12791	0	0	0	110	400	585	1280	1952	3065.5999999999999	2576	1340.8	1459.2	19.199999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7480	3	7328.1999999999998	0	0	0	0	40	75	330	883.20000000000005	1865.5999999999999	1766.4000000000001	1350.4000000000001	1001.6	12.800000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7481	3	9899.3999999999996	0	0	0	120	245	350	850	1734.4000000000001	2195.1999999999998	1913.5999999999999	1523.2	956.79999999999995	9.5999999999999996	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0
7482	3	8867.3999999999996	0	0	0	180	215	520	250	1843.2	2620.8000000000002	1625.5999999999999	844.79999999999995	755.20000000000005	9.5999999999999996	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7483	3	13809.799999999999	0	2390	5240	1790	725	430	470	331.19999999999999	587.20000000000005	889.60000000000002	400.80000000000001	461.60000000000002	80.799999999999997	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	10.4
7484	3	13062.799999999999	0	0	1885	2650	1630	1000	925	968	1012.8	1156.8	662.39999999999998	1032	115.2	14.4	\N	\N	\N	\N	\N	\N	\N	11.199999999999999
7485	3	6756.3999999999996	0	0	0	0	55	115	340	630.39999999999998	1808	1772.8	886.39999999999998	1139.2	6.4000000000000004	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7486	3	4637.8000000000002	0	0	0	45	85	100	315	601.60000000000002	1056	1014.4	537.60000000000002	870.39999999999998	11.199999999999999	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7487	3	4282.6000000000004	0	0	0	0	45	125	315	862.39999999999998	1192	616	377.60000000000002	662.39999999999998	84.799999999999997	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7488	3	6533	0	0	0	40	215	380	1110	680	1606.4000000000001	939.20000000000005	483.19999999999999	1014.4	62.399999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7507	3	5665.8000000000002	0	0	0	10	90	145	460	1057.5999999999999	1579.2	1097.5999999999999	715.20000000000005	499.19999999999999	8	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7508	3	8512.1399999999994	0	0	0	15	235	490	1030	1836.8	1923.2	1302.4000000000001	886.39999999999998	777.60000000000002	12.800000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7509	3	5724.6000000000004	0	0	0	0	5	45	225	748.79999999999995	2052.8000000000002	1470.4000000000001	748.79999999999995	424	3.2000000000000002	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7510	3	8702.7999999999993	0	0	0	10	50	120	510	1334.4000000000001	2323.1999999999998	1840	1318.4000000000001	1184	9.5999999999999996	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7511	3	6207	0	0	0	160	390	350	735	1276.8	1340.8	872	548.79999999999995	505.60000000000002	25.600000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7512	3	7829.1999999999998	0	0	0	150	315	325	620	1142.4000000000001	1801.5999999999999	1411.2	1004.8	1036.8	19.199999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7513	3	4964.6000000000004	0	0	0	115	130	60	170	763.20000000000005	1795.2	872	430.39999999999998	603.20000000000005	24	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7514	3	7853	0	0	0	395	225	265	400	819.20000000000005	2944	2012.8	448	316.80000000000001	22.399999999999999	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7515	3	6777.8000000000002	0	0	0	550	730	830	1295	1430.4000000000001	966.39999999999998	388.80000000000001	260.80000000000001	315.19999999999999	9.5999999999999996	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7516	3	7963.6000000000004	0	0	0	405	705	975	1785	2132.8000000000002	1329.5999999999999	366.39999999999998	128	124.8	9.5999999999999996	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7517	3	6628	0	0	0	140	275	245	440	739.20000000000005	1542.4000000000001	1830.4000000000001	852.79999999999995	553.60000000000002	6.4000000000000004	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7518	3	7521	0	0	0	555	725	390	575	822.39999999999998	1681.5999999999999	1587.2	657.60000000000002	518.39999999999998	6.4000000000000004	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7519	3	6763.6000000000004	0	0	0	0	30	85	255	748.79999999999995	1801.5999999999999	2115.1999999999998	1270.4000000000001	448	6.4000000000000004	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7520	3	7453.6000000000004	0	0	0	160	140	245	355	636.79999999999995	1500.8	2585.5999999999999	1184	627.20000000000005	12.800000000000001	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7521	3	5163	0	0	0	10	100	160	405	923.20000000000005	1217.5999999999999	1179.2	862.39999999999998	302.39999999999998	1.6000000000000001	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7522	3	6958	0	0	90	65	165	255	535	1107.2	1976	1713.5999999999999	696	350.39999999999998	3.2000000000000002	0.80000000000000004	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7523	3	6051	0	630	280	850	440	395	320	240	393.60000000000002	755.20000000000005	625.60000000000002	947.20000000000005	132.80000000000001	24	\N	\N	\N	\N	\N	\N	\N	17.600000000000001
7524	3	3168	0	0	60	370	165	105	100	94.400000000000006	121.59999999999999	257.60000000000002	419.19999999999999	1189.5999999999999	240	28	\N	\N	\N	\N	\N	\N	\N	17.600000000000001
7700	140	16071.700000000001	0	0	1269	3342.1999999999998	2382.5	887.89999999999998	1608.4000000000001	1246.2	995.5	1575	1191.2	696.39999999999998	329.89999999999998	437.19999999999999	90.200000000000003	19.5	\N	\N	\N	\N	\N	0.59999999999999998
7701	140	1818.9000000000001	0	0	0	0	134.80000000000001	85.700000000000003	157.40000000000001	188.59999999999999	127.8	233.40000000000001	179.5	160.19999999999999	224.30000000000001	271	46.200000000000003	9.5999999999999996	\N	\N	\N	\N	\N	0.40000000000000002
7702	140	8054.6000000000004	0	0	0	607.70000000000005	613.5	546.60000000000002	1325.4000000000001	947	482.80000000000001	617	493.10000000000002	410	450.30000000000001	918.5	502.30000000000001	140.40000000000001	\N	\N	\N	\N	\N	0
7720	140	3679.1999999999998	0	0	885.60000000000002	1092.4000000000001	204.5	135.59999999999999	182.59999999999999	161.40000000000001	79.200000000000003	98.900000000000006	130.59999999999999	178.5	124.8	302.30000000000001	82.299999999999997	20.100000000000001	\N	\N	\N	\N	\N	0.40000000000000002
7721	140	2844.1999999999998	0	0	0	0	38.700000000000003	27.199999999999999	46.799999999999997	56.700000000000003	78.299999999999997	182.5	293.60000000000002	453.80000000000001	546.29999999999995	868	194.80000000000001	57.200000000000003	\N	\N	\N	\N	\N	0.29999999999999999
7722	140	6359.8000000000002	0	0	422.30000000000001	452.10000000000002	1078	513.10000000000002	1286.2	571.20000000000005	239.5	320.19999999999999	262.5	329.19999999999999	306.60000000000002	433.19999999999999	98.200000000000003	46.899999999999999	\N	\N	\N	\N	\N	0.59999999999999998
7723	140	4949.5	0	0	0	1137.4000000000001	1389	831	908.29999999999995	289.89999999999998	100.7	69	28.399999999999999	20.600000000000001	19.399999999999999	102.3	43	10.1	\N	\N	\N	\N	\N	0.40000000000000002
7724	140	9627.7999999999993	0	0	0	3054.4000000000001	1292	717.5	1086	780.89999999999998	468.60000000000002	565.79999999999995	444.10000000000002	379.10000000000002	211.19999999999999	518.29999999999995	96.400000000000006	13.199999999999999	\N	\N	\N	\N	\N	0.29999999999999999
7725	140	15650.9	0	0	0	2453	7098	2453	1082.0999999999999	292.80000000000001	167.90000000000001	233.80000000000001	170.19999999999999	111.90000000000001	86	1124.3	303.89999999999998	73.700000000000003	\N	\N	\N	\N	\N	0.29999999999999999
7726	140	9441.2000000000007	0	0	0	212.59999999999999	1006.6	797	2190.3000000000002	2033.8	989.39999999999998	884	495.80000000000001	310.5	138.09999999999999	260.39999999999998	95.099999999999994	13.6	\N	\N	\N	\N	\N	14
7727	140	8937.6000000000004	0	0	0	233.30000000000001	1008	751.60000000000002	1972.5999999999999	1159.7	570.29999999999995	741.5	435	323.30000000000001	401.80000000000001	1254.9000000000001	76.799999999999997	8.8000000000000007	\N	\N	\N	\N	\N	0
7728	140	14736.4	0	0	886.79999999999995	4926.3999999999996	2311.8000000000002	1029.0999999999999	1454	825.39999999999998	431.10000000000002	614.70000000000005	476.60000000000002	270.69999999999999	186.30000000000001	1220	85.599999999999994	17.300000000000001	\N	\N	\N	\N	\N	0.59999999999999998
7729	140	8495.8999999999996	0	0	0	0	194.5	154.69999999999999	528	703.79999999999995	720.89999999999998	1595.2	1817.5999999999999	1241.5	728	801.39999999999998	9.5999999999999996	0.69999999999999996	\N	\N	\N	\N	\N	0
7730	140	9404.7999999999993	0	0	0	0	377.89999999999998	425.19999999999999	1036	951	885.89999999999998	1356.5999999999999	2870	903.5	256.19999999999999	315.80000000000001	23	3.7000000000000002	\N	\N	\N	\N	\N	0
7740	140	5395.6999999999998	0	0	0	263.10000000000002	1349.5999999999999	697.29999999999995	1197.3	685.20000000000005	306.60000000000002	306.39999999999998	208.40000000000001	156.80000000000001	95	111.2	17.199999999999999	1.2	\N	\N	\N	\N	\N	0.40000000000000002
7741	140	9348.5	0	0	0	190.09999999999999	1758.9000000000001	1095.7	2609.3000000000002	1453.0999999999999	727.70000000000005	721.79999999999995	195.19999999999999	64.299999999999997	45.5	329.39999999999998	137.59999999999999	19.199999999999999	\N	\N	\N	\N	\N	0.69999999999999996
7742	140	6899.5	0	0	0	168.30000000000001	1158	609.29999999999995	1828.0999999999999	954.39999999999998	497.30000000000001	645	332.69999999999999	135	73.700000000000003	369.10000000000002	114.09999999999999	14.1	\N	\N	\N	\N	\N	0.40000000000000002
7743	140	5915.1000000000004	0	0	0	402.19999999999999	781.79999999999995	379.60000000000002	1045	622.60000000000002	467.19999999999999	827.60000000000002	666.29999999999995	362.10000000000002	142.30000000000001	206.69999999999999	10.300000000000001	0.80000000000000004	\N	\N	\N	\N	\N	0.59999999999999998
7744	140	12286.299999999999	0	0	0	329.80000000000001	1884.3	1356.0999999999999	2721.5	1482.9000000000001	665.79999999999995	818.5	854	850.20000000000005	349.69999999999999	865.29999999999995	99.299999999999997	8.5	\N	\N	\N	\N	\N	0.40000000000000002
7745	140	12402.1	0	0	0	465.5	1985.7	1093.0999999999999	2481	1267	759.20000000000005	1112.0999999999999	1221.9000000000001	1009.9	428	549.60000000000002	27.199999999999999	1.6000000000000001	\N	\N	\N	\N	\N	0.29999999999999999
7746	140	5407.1000000000004	0	0	0	143.19999999999999	507.69999999999999	721	1363.9000000000001	637.5	340.30000000000001	348.89999999999998	271.30000000000001	265.39999999999998	197.59999999999999	526.5	73.299999999999997	9.9000000000000004	\N	\N	\N	\N	\N	0.59999999999999998
7747	140	4126.5	0	0	0	26.100000000000001	88.700000000000003	119.5	578.10000000000002	593.10000000000002	464.39999999999998	845	699.89999999999998	395.5	144.80000000000001	150.90000000000001	16.5	3.3999999999999999	\N	\N	\N	\N	\N	0.59999999999999998
7748	140	5763.1999999999998	0	0	0	102.8	149.09999999999999	219	446.30000000000001	353.19999999999999	251.5	615.89999999999998	952.79999999999995	1038	666.39999999999998	828.10000000000002	124.90000000000001	14.699999999999999	\N	\N	\N	\N	\N	0.5
7749	140	2425.1999999999998	0	0	0	83.299999999999997	65.400000000000006	36.700000000000003	126.8	171.69999999999999	160.80000000000001	341.5	217	538.20000000000005	397	275.19999999999999	8.9000000000000004	2.1000000000000001	\N	\N	\N	\N	\N	0.59999999999999998
7750	140	2575.5999999999999	0	0	0	0	61.299999999999997	86.799999999999997	383.5	509.5	239	355.10000000000002	248.59999999999999	184.69999999999999	125.59999999999999	303.69999999999999	70.5	6.5	\N	\N	\N	\N	\N	0.80000000000000004
7751	140	1070.5999999999999	0	0	0	0	0	0	12.9	32	23.699999999999999	56.700000000000003	78.599999999999994	86.599999999999994	93.299999999999997	520	158.30000000000001	8.0999999999999996	\N	\N	\N	\N	\N	0.40000000000000002
7752	140	1070.5999999999999	0	0	0	0	129.09999999999999	74	95.5	106.7	81	113.7	92.599999999999994	66	47.600000000000001	199.09999999999999	58.399999999999999	6.2999999999999998	\N	\N	\N	\N	\N	0.59999999999999998
7760	140	5362.8000000000002	0	0	0	256.39999999999998	735.20000000000005	856.10000000000002	1685.8	559.39999999999998	211.30000000000001	309.19999999999999	220.19999999999999	104.5	51.799999999999997	321.10000000000002	47.799999999999997	3.6000000000000001	\N	\N	\N	\N	\N	0.40000000000000002
7753	140	2443.5999999999999	0	0	0	0	294.69999999999999	154.5	264	201.30000000000001	123.59999999999999	206.5	226.30000000000001	180.59999999999999	129.59999999999999	487.19999999999999	145.19999999999999	18.399999999999999	\N	\N	\N	\N	\N	11.699999999999999
7761	140	5106.8999999999996	0	0	0	0	274.30000000000001	254.19999999999999	1012.6	1013.4	767.79999999999995	970.39999999999998	404.30000000000001	78.299999999999997	39.5	207.5	78.799999999999997	5.4000000000000004	\N	\N	\N	\N	\N	0.40000000000000002
7762	140	8836.1000000000004	0	0	0	554.60000000000002	885.79999999999995	684.5	2024.4000000000001	1553.0999999999999	803.20000000000005	981.10000000000002	731.70000000000005	312	86.799999999999997	191.59999999999999	24.399999999999999	2.2999999999999998	\N	\N	\N	\N	\N	0.59999999999999998
7763	140	7478.3999999999996	0	0	426.89999999999998	386.5	1861.8	1037.0999999999999	1457	683	398.80000000000001	546.39999999999998	273.30000000000001	97.599999999999994	50.5	189.59999999999999	65.200000000000003	4.7000000000000002	\N	\N	\N	\N	\N	0
7765	140	7004.3000000000002	0	0	0	542.79999999999995	2053.8000000000002	1174	1458	495.69999999999999	232	298	195	113	52.600000000000001	269.39999999999998	108.2	11.4	\N	\N	\N	\N	\N	0.40000000000000002
7764	140	7876.6999999999998	0	0	0	771	2080	1326.3	1740.8	627	294.60000000000002	410	215.69999999999999	58.799999999999997	26.300000000000001	226.40000000000001	91.200000000000003	8.5999999999999996	\N	\N	\N	\N	\N	0
7768	140	7951.1999999999998	0	0	0	374.19999999999999	406.89999999999998	404.19999999999999	862.70000000000005	597.70000000000005	451.30000000000001	878.89999999999998	949	791.89999999999998	487.10000000000002	1343.2	356	48.100000000000001	\N	\N	\N	\N	\N	0
7766	140	1903.4000000000001	0	0	0	0	0	0	5.0999999999999996	17	12	35.399999999999999	194.80000000000001	527.29999999999995	580.70000000000005	526.10000000000002	4.7000000000000002	0.29999999999999999	\N	\N	\N	\N	\N	0
7767	140	2319.6999999999998	0	0	0	0	0	0	25	36.5	49.799999999999997	144.5	458.60000000000002	690.20000000000005	478.5	416.5	16.800000000000001	3.2999999999999998	\N	\N	\N	\N	\N	0
7769	140	9003.7000000000007	0	0	372.30000000000001	116.2	1140.4000000000001	611.89999999999998	1038.2	651.20000000000005	355.69999999999999	639.39999999999998	962	1204.5	982.20000000000005	827.20000000000005	82.200000000000003	20.300000000000001	\N	\N	\N	\N	\N	0
7770	140	4739.1000000000004	0	0	0	235.19999999999999	454.80000000000001	297.10000000000002	685.79999999999995	446.39999999999998	235.59999999999999	417	412.69999999999999	319.69999999999999	961.60000000000002	242.90000000000001	24.800000000000001	5.5	\N	\N	\N	\N	\N	0
7780	140	7874.5799999999999	0	0	0	401.69999999999999	1335.78	560.89999999999998	1340.9000000000001	902.89999999999998	623.79999999999995	498.60000000000002	352	870.79999999999995	570.60000000000002	400.10000000000002	12.199999999999999	4	\N	\N	\N	\N	\N	0.29999999999999999
7781	140	11545.200000000001	0	0	0	475.30000000000001	2891.6999999999998	986.70000000000005	1781.5	1020.3	593.60000000000002	692.10000000000002	827.60000000000002	963.20000000000005	685	613.39999999999998	10.300000000000001	3.7999999999999998	\N	\N	\N	\N	\N	0.69999999999999996
7782	140	10142.99	0	0	0	184.09	1882.5	1919.7	2596.0999999999999	977.79999999999995	421.39999999999998	504.30000000000001	585	543.89999999999998	289.30000000000001	224.40000000000001	8.1999999999999993	5.5	\N	\N	\N	\N	\N	0.80000000000000004
7783	140	11676.6	0	0	703	1436	1742.4000000000001	696.60000000000002	1213.7	941.60000000000002	620	848.5	1136	875.79999999999995	760.5	647.60000000000002	45.700000000000003	7.5999999999999996	\N	\N	\N	\N	\N	1.6000000000000001
7784	140	9245.6000000000004	0	0	0	755.10000000000002	520.60000000000002	370.30000000000001	955.79999999999995	1001	821.70000000000005	1514.5	1361.5	925.20000000000005	393.80000000000001	486.69999999999999	101.59999999999999	22.100000000000001	\N	\N	\N	\N	\N	15.699999999999999
7785	140	321.5	0	0	0	0	0	15	9.0999999999999996	10.699999999999999	11.1	11.1	14.800000000000001	16.5	9.5	13.6	170.5	35.399999999999999	\N	\N	\N	\N	\N	4.2000000000000002
7823	140	4918	0	0	0	0	15.4	15.6	79.799999999999997	72.200000000000003	123.2	540.79999999999995	1383	1325.4000000000001	580	768.79999999999995	9	0.80000000000000004	\N	\N	\N	\N	\N	4
7821	140	4117.8000000000002	0	0	0	0	0	0	23.600000000000001	34.200000000000003	55.200000000000003	391.39999999999998	1329	1318.2	448.60000000000002	505.80000000000001	8	0.80000000000000004	\N	\N	\N	\N	\N	3
7825	140	3834.0999999999999	0	0	0	0	0	0	94.400000000000006	75.400000000000006	68.599999999999994	243.59999999999999	827.20000000000005	1100	581	825.29999999999995	8.1999999999999993	0.20000000000000001	\N	\N	\N	\N	\N	10.199999999999999
7824	140	5746.3999999999996	0	0	0	0	0	0	65.400000000000006	117.2	187	710	1711.4000000000001	1580	644.60000000000002	705.20000000000005	11.199999999999999	0.59999999999999998	\N	\N	\N	\N	\N	13.800000000000001
7826	140	2997	0	0	0	0	0	44.100000000000001	32	77.099999999999994	149.5	639	813.39999999999998	668.89999999999998	413	154.59999999999999	2.1000000000000001	0.29999999999999999	\N	\N	\N	\N	\N	3
7827	140	7298.6000000000004	0	0	0	92.5	364	260	1141	1094.5999999999999	734.60000000000002	992.10000000000002	786.5	655.79999999999995	437.19999999999999	732.89999999999998	6.2999999999999998	1.1000000000000001	\N	\N	\N	\N	\N	0
7828	140	8103.8999999999996	0	0	0	199	243.40000000000001	318	1224.5999999999999	1405	1478	1421	789.60000000000002	505.19999999999999	261.60000000000002	242.19999999999999	13	0.90000000000000002	\N	\N	\N	\N	\N	2.3999999999999999
7841	140	3537	0	0	0	0	0	13.800000000000001	227.59999999999999	437	671	882.39999999999998	325.30000000000001	181.40000000000001	183	605.79999999999995	3.2000000000000002	2.3999999999999999	\N	\N	\N	\N	\N	4.0999999999999996
7842	140	7831.1999999999998	0	0	0	0	347	602.20000000000005	1658.4000000000001	1161.4000000000001	1054	988	450.10000000000002	297.80000000000001	315.39999999999998	934.20000000000005	16.199999999999999	3.2000000000000002	\N	\N	\N	\N	\N	3.2999999999999998
7844	140	7376.6000000000004	0	0	0	0	179.19999999999999	206.19999999999999	760.79999999999995	1046.2	1331.2	1687.2	1131.4000000000001	538.60000000000002	222.19999999999999	266.80000000000001	3.6000000000000001	0.80000000000000004	\N	\N	\N	\N	\N	2.3999999999999999
7845	140	5498.5	0	0	0	151.80000000000001	475.60000000000002	918	1479	569.79999999999995	439.80000000000001	492	315.60000000000002	199.59999999999999	85.400000000000006	226.30000000000001	41	6.7999999999999998	\N	\N	\N	\N	\N	97.799999999999997
7846	140	2798.9000000000001	0	0	0	0	31.600000000000001	47.399999999999999	118	200.19999999999999	195.59999999999999	337.80000000000001	470.60000000000002	514	326.60000000000002	548.79999999999995	4.5999999999999996	0.29999999999999999	\N	\N	\N	\N	\N	3.3999999999999999
7847	140	10144.6	0	0	0	0	403.39999999999998	514.39999999999998	1356.8	1299	1178.2	1379	1510	1224.2	566.60000000000002	691.39999999999998	10	0.59999999999999998	\N	\N	\N	\N	\N	11
7848	140	2994.4000000000001	0	0	0	0	40.799999999999997	40	119.2	129.40000000000001	130	218.40000000000001	447	660.39999999999998	427	767	10.199999999999999	0.40000000000000002	\N	\N	\N	\N	\N	4.5999999999999996
7849	140	2092.5999999999999	0	0	0	0	14.199999999999999	39.200000000000003	155.40000000000001	198.19999999999999	218.40000000000001	313.19999999999999	287.19999999999999	255.59999999999999	153.59999999999999	409.60000000000002	46.200000000000003	1.6000000000000001	\N	\N	\N	\N	\N	0.20000000000000001
7850	140	5692.1999999999998	0	0	0	99.200000000000003	183.59999999999999	332.60000000000002	629.60000000000002	807.39999999999998	762.39999999999998	779.20000000000005	688.39999999999998	633.60000000000002	275	486.19999999999999	12.6	1	\N	\N	\N	\N	\N	1.3999999999999999
7851	140	4679	0	0	0	234.59999999999999	70.599999999999994	78.400000000000006	306	399.19999999999999	431	738.60000000000002	893	678	338.80000000000001	491.19999999999999	17.399999999999999	0.20000000000000001	\N	\N	\N	\N	\N	2
7852	140	6193.8999999999996	0	0	0	0	168	341	1579.2	1554.5999999999999	939.79999999999995	724.39999999999998	427.39999999999998	209.59999999999999	79.400000000000006	154	12.199999999999999	0.10000000000000001	\N	\N	\N	\N	\N	4.2000000000000002
7853	140	4105.8999999999996	0	0	0	336.19999999999999	596.79999999999995	617.20000000000005	1471	689.20000000000005	162.40000000000001	54.200000000000003	26	32	23.800000000000001	81.400000000000006	11.199999999999999	0.59999999999999998	\N	\N	\N	\N	\N	3.8999999999999999
7854	140	5975.5	0	0	0	137	518	232.80000000000001	597.20000000000005	649.60000000000002	544.60000000000002	719.39999999999998	762	792.20000000000005	429.39999999999998	575.79999999999995	9.8000000000000007	0.20000000000000001	\N	\N	\N	\N	\N	7.5
7855	140	5849.6999999999998	0	0	0	0	611.60000000000002	254.40000000000001	657.79999999999995	774	662.60000000000002	670	450.80000000000001	399.39999999999998	275.80000000000001	1052.8	30.600000000000001	1	\N	\N	\N	\N	\N	8.9000000000000004
7856	140	2850.0999999999999	0	0	0	0	47.200000000000003	0	151	91.599999999999994	58.600000000000001	167.40000000000001	599.20000000000005	633.60000000000002	207.59999999999999	884.39999999999998	8.8000000000000007	0.10000000000000001	\N	\N	\N	\N	\N	0.59999999999999998
7857	140	3050	0	0	0	0	28.399999999999999	8.4000000000000004	35.799999999999997	78	103.2	204	400.60000000000002	577	313	1152.2	128.40000000000001	9.4000000000000004	\N	\N	\N	\N	\N	11.6
7858	140	2604.4000000000001	0	0	0	0	15.199999999999999	66.200000000000003	123.2	144	151.19999999999999	328	545.39999999999998	508.19999999999999	244.19999999999999	453.60000000000002	21.800000000000001	3.2000000000000002	\N	\N	\N	\N	\N	0.20000000000000001
7859	140	4437.3999999999996	0	0	0	0	759	632	727.60000000000002	407.19999999999999	307.80000000000001	312	168	234.19999999999999	309	567.79999999999995	10.199999999999999	0.59999999999999998	\N	\N	\N	\N	\N	2
7860	140	5648.6000000000004	0	0	0	0	125.8	95.400000000000006	322.39999999999998	273.60000000000002	197.59999999999999	329.80000000000001	516.60000000000002	574.20000000000005	535.39999999999998	2657	16	0.20000000000000001	\N	\N	\N	\N	\N	4.5999999999999996
7861	140	2847.4000000000001	0	0	0	0	93	97.599999999999994	177.80000000000001	282	280.39999999999998	378.39999999999998	340.60000000000002	336.39999999999998	208	507	134.80000000000001	9.5999999999999996	\N	\N	\N	\N	\N	1.8
7862	140	8045.8000000000002	0	0	0	0	334.39999999999998	272	910.20000000000005	939	879.60000000000002	969.79999999999995	742.39999999999998	618.20000000000005	414.19999999999999	1878.4000000000001	82	3	\N	\N	\N	\N	\N	2.6000000000000001
7863	140	4227.6999999999998	0	0	0	0	307	410	949	703.60000000000002	440.19999999999999	324	83	95.799999999999997	315.19999999999999	590.39999999999998	6.7999999999999998	0.59999999999999998	\N	\N	\N	\N	\N	2.1000000000000001
7864	140	5432	0	0	0	84.400000000000006	234.80000000000001	442.60000000000002	1159	1016.4	764.20000000000005	673.39999999999998	347.60000000000002	260.60000000000002	167.80000000000001	275.39999999999998	3.7999999999999998	0.29999999999999999	\N	\N	\N	\N	\N	1.7
7865	140	5565.8999999999996	0	0	0	0	304.60000000000002	476.60000000000002	1504.2	1207	703	613	372	169.5	72.200000000000003	125.40000000000001	11.4	2.7999999999999998	\N	\N	\N	\N	\N	4.2000000000000002
7866	140	710.79999999999995	0	0	0	0	98.400000000000006	82.799999999999997	354.80000000000001	68.599999999999994	21.199999999999999	19	18	18.399999999999999	11.199999999999999	15.6	1.7	0.20000000000000001	\N	\N	\N	\N	\N	0.90000000000000002
7867	140	4605.3000000000002	0	0	0	0	31	35.600000000000001	211.40000000000001	204.59999999999999	205.19999999999999	558.20000000000005	1599	1237	263.60000000000002	252	4	0.80000000000000004	\N	\N	\N	\N	\N	2.8999999999999999
7868	140	4747.1000000000004	0	0	0	78.400000000000006	581.5	235.80000000000001	546.79999999999995	432.80000000000001	387	564	643.39999999999998	523.60000000000002	276.80000000000001	467	7.2000000000000002	0.40000000000000002	\N	\N	\N	\N	\N	2.3999999999999999
7869	140	1069.0999999999999	0	0	0	0	0	24	0	27.100000000000001	61.399999999999999	221.69999999999999	231.09999999999999	163.09999999999999	103.90000000000001	217.90000000000001	17.199999999999999	1.7	\N	\N	\N	\N	\N	0
7870	140	901.39999999999998	0	0	0	0	0	13.800000000000001	6.9000000000000004	12.6	9.6999999999999993	18.100000000000001	31.5	43.5	112.7	621.20000000000005	28.5	2.8999999999999999	\N	\N	\N	\N	\N	0
7871	140	3016.9000000000001	0	0	0	0	113.8	79.400000000000006	134	150.80000000000001	149	271.39999999999998	669	877.79999999999995	305.19999999999999	260.39999999999998	2.7999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	3.1000000000000001
7876	140	5976.8999999999996	0	0	0	58.600000000000001	249.80000000000001	404.80000000000001	1098.5999999999999	916.79999999999995	304.80000000000001	844.20000000000005	532.79999999999995	535.60000000000002	350	668.60000000000002	10.800000000000001	0.20000000000000001	\N	\N	\N	\N	\N	1.3
7877	140	4443	0	0	0	0	320.19999999999999	408	1015.6	504.80000000000001	494.19999999999999	700	452	179	106	257.19999999999999	5.5999999999999996	0.40000000000000002	\N	\N	\N	\N	\N	0
7878	140	8962.1000000000004	0	0	0	676.60000000000002	511.60000000000002	562	1383.5999999999999	1276.8	991.20000000000005	1183	873.20000000000005	590.60000000000002	345.39999999999998	542.60000000000002	23	1.3999999999999999	\N	\N	\N	\N	\N	1.1000000000000001
7879	140	2462.8000000000002	0	0	0	0	38.200000000000003	89.799999999999997	163.59999999999999	185.59999999999999	179.59999999999999	274.80000000000001	305.60000000000002	241	220.19999999999999	700.39999999999998	52	1	\N	\N	\N	\N	\N	11
7880	140	3152.8000000000002	0	0	0	0	0	0	18.399999999999999	31.199999999999999	32.799999999999997	58.600000000000001	164.19999999999999	417.80000000000001	392.60000000000002	1914.4000000000001	115.59999999999999	7	\N	\N	\N	\N	\N	0.20000000000000001
7881	140	2077.4000000000001	0	0	324.30000000000001	619.5	277	31.5	54.299999999999997	60.899999999999999	53.5	64.200000000000003	71	101.40000000000001	99.700000000000003	290.10000000000002	27.5	2.2000000000000002	\N	\N	\N	\N	\N	0.29999999999999999
7900	140	3872	0	0	0	0	182.40000000000001	88.799999999999997	301.80000000000001	287	303.39999999999998	560.20000000000005	890.20000000000005	831.39999999999998	293	128.80000000000001	0.20000000000000001	0.20000000000000001	\N	\N	\N	\N	\N	4.5999999999999996
7901	140	6555.5	0	0	0	0	409.39999999999998	437.60000000000002	1239.2	1140.5999999999999	729.39999999999998	866.39999999999998	972.60000000000002	558.79999999999995	83.799999999999997	79	29.600000000000001	2.3999999999999999	\N	\N	\N	\N	\N	6.7000000000000002
7902	140	7174.3999999999996	0	0	0	0	157.80000000000001	88.400000000000006	833.60000000000002	1231.4000000000001	1409.4000000000001	1925.8	1281.2	196	13.4	23.399999999999999	11.4	1.2	\N	\N	\N	\N	\N	1.3999999999999999
7903	140	6139	0	0	0	0	19	68	468.80000000000001	817.79999999999995	686.60000000000002	763	570.60000000000002	698.60000000000002	888.20000000000005	1152.8	4.5999999999999996	0.80000000000000004	\N	\N	\N	\N	\N	0.20000000000000001
7904	140	4726.6999999999998	0	0	0	0	79.400000000000006	53.200000000000003	326.39999999999998	570.60000000000002	626.20000000000005	787.20000000000005	724	765.20000000000005	391.60000000000002	395.19999999999999	4.2000000000000002	0.10000000000000001	\N	\N	\N	\N	\N	3.3999999999999999
7905	140	5746.5	0	0	0	50.200000000000003	142.59999999999999	150.40000000000001	408.80000000000001	569.20000000000005	653.79999999999995	1040.5999999999999	969.60000000000002	711.39999999999998	410.80000000000001	619.39999999999998	18.199999999999999	0.40000000000000002	\N	\N	\N	\N	\N	1.1000000000000001
7906	140	4130.3999999999996	0	0	0	73.200000000000003	71.400000000000006	111.8	503.19999999999999	601.79999999999995	442	477.80000000000001	652.20000000000005	760	123.40000000000001	292.60000000000002	18	0.40000000000000002	\N	\N	\N	\N	\N	2.6000000000000001
7907	140	2575.5999999999999	0	0	0	0	0	20.600000000000001	52.799999999999997	86.599999999999994	125.59999999999999	153.19999999999999	74	119.40000000000001	418.60000000000002	1522	2.6000000000000001	0.20000000000000001	\N	\N	\N	\N	\N	0
7908	140	3150.4000000000001	0	0	0	0	43.799999999999997	105	283.39999999999998	373.60000000000002	367	366	155.19999999999999	179.59999999999999	325.60000000000002	946.60000000000002	4.4000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	0
7909	140	2004.5999999999999	0	0	0	0	0	0	34.799999999999997	108.59999999999999	146	188.59999999999999	117	222.80000000000001	385	799.60000000000002	2	0.20000000000000001	\N	\N	\N	\N	\N	0
7910	140	4360.1000000000004	0	0	0	0	71.700000000000003	93.200000000000003	400.39999999999998	542.60000000000002	605.60000000000002	792.20000000000005	409	399.60000000000002	343.60000000000002	693.60000000000002	8.1999999999999993	0.40000000000000002	\N	\N	\N	\N	\N	0
7911	140	869.89999999999998	0	0	0	0	0	22.399999999999999	40.600000000000001	134.80000000000001	147.5	144.40000000000001	64.799999999999997	111.8	97.200000000000003	101.8	4.4000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	0
7920	140	4754	0	0	0	0	0	0	59.399999999999999	82.400000000000006	161.59999999999999	653.60000000000002	1610.2	1418.4000000000001	420.19999999999999	341.60000000000002	4.5999999999999996	2	\N	\N	\N	\N	\N	0
7921	140	2006	0	0	0	62.399999999999999	193	185.80000000000001	241	117.59999999999999	72.599999999999994	128.59999999999999	287.80000000000001	305.60000000000002	154.80000000000001	250	6.2000000000000002	0.59999999999999998	\N	\N	\N	\N	\N	0
7922	140	3435.8000000000002	0	0	0	0	0	0	0	0	0	2.6000000000000001	163	988.39999999999998	989.39999999999998	1233.2	43.399999999999999	15.800000000000001	\N	\N	\N	\N	\N	0
7923	140	4339.1999999999998	0	0	0	0	0	14.6	29.199999999999999	49.200000000000003	24.199999999999999	45.399999999999999	522.79999999999995	1620.5999999999999	940.79999999999995	1013.6	62.399999999999999	16.399999999999999	\N	\N	\N	\N	\N	0
7924	140	3960.5	0	0	0	0	0	7.2000000000000002	26.800000000000001	113	216.40000000000001	623.39999999999998	1083.4000000000001	1077	474.80000000000001	335	3.2000000000000002	0.29999999999999999	\N	\N	\N	\N	\N	0
7925	140	6202.8000000000002	0	0	0	205.40000000000001	215.59999999999999	186.19999999999999	570	623	588.60000000000002	835.39999999999998	943.60000000000002	950	419.19999999999999	645	20.600000000000001	0.20000000000000001	\N	\N	\N	\N	\N	0
7926	140	4633.8000000000002	0	0	440.39999999999998	142	172.80000000000001	75.200000000000003	66.799999999999997	86.400000000000006	136.19999999999999	267.39999999999998	530.79999999999995	885.79999999999995	589.60000000000002	1192.4000000000001	43	5	\N	\N	\N	\N	\N	0
7927	140	1230.8	0	0	0	0	0	0	11.6	24.399999999999999	42	140.59999999999999	245.19999999999999	227	136.80000000000001	351.39999999999998	48.399999999999999	3.3999999999999999	\N	\N	\N	\N	\N	0
7928	140	4744	0	0	0	0	0	0	253.59999999999999	703.39999999999998	931.79999999999995	827.39999999999998	281	182.19999999999999	344.19999999999999	1210.5999999999999	8.4000000000000004	1.3999999999999999	\N	\N	\N	\N	\N	0
7929	140	7047.1999999999998	0	0	0	0	141	204.80000000000001	598	784.39999999999998	906.60000000000002	1124.5999999999999	1117	893.60000000000002	550.60000000000002	709.39999999999998	15	2.2000000000000002	\N	\N	\N	\N	\N	0
7930	140	2779.5999999999999	0	0	0	0	0	43.600000000000001	62.200000000000003	52.399999999999999	62.399999999999999	372.80000000000001	1246.4000000000001	597.79999999999995	172.59999999999999	162	7	0.40000000000000002	\N	\N	\N	\N	\N	0
7931	140	3926.1999999999998	0	0	0	0	0	38.399999999999999	64.400000000000006	118	147.40000000000001	333.60000000000002	604.79999999999995	902	578.39999999999998	1056.8	78.400000000000006	4	\N	\N	\N	\N	\N	0
7932	140	1588.5999999999999	0	0	0	316	64.400000000000006	23.399999999999999	180.40000000000001	158.19999999999999	109.2	108	102	108.2	75.799999999999997	270.39999999999998	67	5.5999999999999996	\N	\N	\N	\N	\N	0
7933	140	9002.7999999999993	0	0	0	0	344	303	1845.2	1901	1213.5999999999999	1189.5999999999999	1069	581.79999999999995	192.40000000000001	350.19999999999999	11.199999999999999	1.8	\N	\N	\N	\N	\N	0
7934	140	6378	0	0	0	583.39999999999998	1385	276.80000000000001	602.39999999999998	686.60000000000002	578	550.79999999999995	500.60000000000002	622	291.19999999999999	288	10	3.2000000000000002	\N	\N	\N	\N	\N	0
7935	140	2092.8000000000002	0	0	0	0	15.800000000000001	50.200000000000003	38.600000000000001	22.800000000000001	46	119.59999999999999	268.80000000000001	403.19999999999999	306	788	30.600000000000001	3.2000000000000002	\N	\N	\N	\N	\N	0
7936	140	3142.5999999999999	0	0	0	0	0	0	0	15.6	35.399999999999999	121.40000000000001	465.80000000000001	816.79999999999995	527.39999999999998	1129	26.600000000000001	4.5999999999999996	\N	\N	\N	\N	\N	0
7937	140	1429	0	0	0	0	158.59999999999999	63.600000000000001	86.400000000000006	52	44	42.799999999999997	70.200000000000003	144.59999999999999	153.19999999999999	579.39999999999998	28.800000000000001	5.4000000000000004	\N	\N	\N	\N	\N	0
7938	140	3139.8000000000002	0	0	0	0	28.199999999999999	27.600000000000001	58.399999999999999	41.600000000000001	50	116.2	320.80000000000001	609.39999999999998	496.80000000000001	1311.8	70.599999999999994	8.4000000000000004	\N	\N	\N	\N	\N	0
7939	140	6073.5	0	0	0	0	0	0	40.5	105	162.80000000000001	401.19999999999999	1190.2	2244	899.79999999999995	1023.8	5.7999999999999998	0.40000000000000002	\N	\N	\N	\N	\N	0
7940	140	5730.8000000000002	0	0	0	0	531.60000000000002	273	728	512.79999999999995	500.80000000000001	667.79999999999995	708.60000000000002	849.39999999999998	391	553	13.800000000000001	1	\N	\N	\N	\N	\N	0
7941	140	2374.4000000000001	0	0	0	0	135.40000000000001	155.40000000000001	143	71.599999999999994	71	121	231.59999999999999	584.60000000000002	359.39999999999998	490	10	1.3999999999999999	\N	\N	\N	\N	\N	0
7942	140	2351	0	0	0	0	18.800000000000001	27.399999999999999	154	134.80000000000001	78.599999999999994	131.59999999999999	223	323.19999999999999	291.60000000000002	941.79999999999995	23.800000000000001	2.3999999999999999	\N	\N	\N	\N	\N	0
7943	140	1507.5	0	0	0	0	10	10	51	103.8	91	181	237	247.40000000000001	164.80000000000001	387.60000000000002	21	2.8999999999999999	\N	\N	\N	\N	\N	0
7945	140	2891.8000000000002	0	0	0	0	0	0	8	83	159	311.19999999999999	488.39999999999998	668.79999999999995	428	739	6.2000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	0
7946	140	3741.8000000000002	0	0	0	0	0	5.4000000000000004	38	190.19999999999999	249.59999999999999	344.39999999999998	415.19999999999999	747.20000000000005	630	1107.4000000000001	12.4	2	\N	\N	\N	\N	\N	0
7947	140	1386.8	0	0	0	0	15	0	19.800000000000001	19	32.600000000000001	71	177	281.39999999999998	219.40000000000001	529.60000000000002	20	2	\N	\N	\N	\N	\N	0
7948	140	3537.5999999999999	0	0	0	0	71.400000000000006	190.80000000000001	638.60000000000002	579.20000000000005	437.60000000000002	467	255.80000000000001	190	167.40000000000001	472.60000000000002	54	13.199999999999999	\N	\N	\N	\N	\N	0
7949	140	880.39999999999998	0	0	0	0	0	0	29.399999999999999	33	30.199999999999999	56.399999999999999	93.799999999999997	161	144.59999999999999	271.19999999999999	46.799999999999997	14	\N	\N	\N	\N	\N	0
7950	140	5431.1999999999998	0	0	0	0	0	0	4	37.799999999999997	147.59999999999999	695	1438.2	1414.2	706.39999999999998	973.60000000000002	13.6	0.80000000000000004	\N	\N	\N	\N	\N	0
7951	140	5961.8000000000002	0	0	0	0	0	0	5.4000000000000004	28.600000000000001	98.400000000000006	499.80000000000001	1491.2	1660.5999999999999	961.20000000000005	1199	17	0.59999999999999998	\N	\N	\N	\N	\N	0
7952	140	5604	0	0	0	610.79999999999995	936.20000000000005	270.19999999999999	467.39999999999998	435.60000000000002	418.80000000000001	499.60000000000002	487	527.39999999999998	313.39999999999998	598.20000000000005	36.200000000000003	3.2000000000000002	\N	\N	\N	\N	\N	0
7953	140	6742	0	0	0	0	26.600000000000001	112.40000000000001	421.80000000000001	853	1015	1124	628.39999999999998	558.60000000000002	499.80000000000001	1341	150.19999999999999	11.199999999999999	\N	\N	\N	\N	\N	0
7954	140	1489.2	0	0	0	0	0	0	36	89	169	372.19999999999999	346	220	111.2	133	10.6	2.2000000000000002	\N	\N	\N	\N	\N	0
7955	140	3186.8000000000002	0	0	0	0	0	0	12.199999999999999	98	287	793.60000000000002	794.60000000000002	625.20000000000005	272.39999999999998	297.19999999999999	6.4000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	0
7956	140	3649.5999999999999	0	0	0	0	0	0	22.199999999999999	89.599999999999994	199.59999999999999	537.79999999999995	788.79999999999995	935.79999999999995	534.79999999999995	526	7.4000000000000004	7.5999999999999996	\N	\N	\N	\N	\N	0
7957	140	1912.5999999999999	0	0	561.79999999999995	1003.2	29	22.399999999999999	28.399999999999999	19	18.600000000000001	20.399999999999999	27.199999999999999	39	41	93	9.4000000000000004	0.20000000000000001	\N	\N	\N	\N	\N	0
7958	140	1217.2	0	0	0	0	0	0	7.4000000000000004	7.4000000000000004	13.6	27	65.400000000000006	172.40000000000001	181.59999999999999	542.60000000000002	183.19999999999999	16.600000000000001	\N	\N	\N	\N	\N	0
7959	140	4571.6000000000004	0	0	0	0	19.600000000000001	0	67.400000000000006	207	410.19999999999999	1041.5999999999999	1438	974	237.80000000000001	174.19999999999999	1.3999999999999999	0.40000000000000002	\N	\N	\N	\N	\N	0
7960	140	3066	0	0	0	0	0	0	187.19999999999999	513.60000000000002	611.60000000000002	733.39999999999998	575.39999999999998	284.39999999999998	95.400000000000006	64.599999999999994	0.20000000000000001	0.20000000000000001	\N	\N	\N	\N	\N	0
7961	140	5309.8000000000002	0	0	0	0	0	0	190	353.60000000000002	737.60000000000002	1506	1329.4000000000001	841.60000000000002	245	104.40000000000001	1.8	0.40000000000000002	\N	\N	\N	\N	\N	0
7962	140	1490.2	0	0	0	71.400000000000006	39.200000000000003	93.400000000000006	214.59999999999999	194.40000000000001	144.19999999999999	170	188	206.40000000000001	82.799999999999997	78.400000000000006	7	0.40000000000000002	\N	\N	\N	\N	\N	0
7966	140	1727.7	0	0	0	0	0	0	47.200000000000003	80.799999999999997	156.59999999999999	286	331.10000000000002	315	187.19999999999999	318.39999999999998	5	0.40000000000000002	\N	\N	\N	\N	\N	0
7967	140	3367.4000000000001	0	0	0	0	33.399999999999999	50.600000000000001	136.40000000000001	176.80000000000001	320.60000000000002	818	635	313.60000000000002	266.60000000000002	609	7	0.40000000000000002	\N	\N	\N	\N	\N	0
7968	140	1430.2	0	0	0	0	0	24.800000000000001	112.2	192	353.60000000000002	446	259	19.800000000000001	4	11	7.4000000000000004	0.40000000000000002	\N	\N	\N	\N	\N	0
7969	140	3992.4000000000001	0	0	0	0	15.800000000000001	61.600000000000001	123.59999999999999	260.39999999999998	399.39999999999998	735	874.79999999999995	740.20000000000005	320.19999999999999	449.60000000000002	11.6	0.20000000000000001	\N	\N	\N	\N	\N	0
7973	140	1300	0	0	0	0	19.199999999999999	14	66.400000000000006	78	138.19999999999999	301.80000000000001	307.39999999999998	160	67	144.19999999999999	3.6000000000000001	0.20000000000000001	\N	\N	\N	\N	\N	0
7971	140	3176	0	0	0	0	49.600000000000001	14.4	86.799999999999997	158.40000000000001	377.60000000000002	1101.4000000000001	734.60000000000002	272.19999999999999	124.8	249.19999999999999	6.7999999999999998	0.20000000000000001	\N	\N	\N	\N	\N	0
7972	140	3942.8000000000002	0	0	0	0	0	15.199999999999999	42	103.8	297.60000000000002	845	939.79999999999995	731.60000000000002	373	576.20000000000005	18.399999999999999	0.20000000000000001	\N	\N	\N	\N	\N	0
7974	140	3078.4000000000001	0	0	0	0	0	13	32.799999999999997	85	256.39999999999998	641.20000000000005	854.60000000000002	588	240	356	10.800000000000001	0.59999999999999998	\N	\N	\N	\N	\N	0
7975	140	593.79999999999995	0	0	0	0	0	34.399999999999999	69.599999999999994	106.40000000000001	130.59999999999999	128.59999999999999	69.599999999999994	31.600000000000001	10.800000000000001	11.6	0.40000000000000002	0.20000000000000001	\N	\N	\N	\N	\N	0
7977	140	1888.7	0	0	0	0	0	0	27.699999999999999	175	266.19999999999999	452.60000000000002	287	140.19999999999999	95.799999999999997	423.39999999999998	20.399999999999999	0.40000000000000002	\N	\N	\N	\N	\N	0
7978	140	2511.5999999999999	0	0	0	0	0	0	38.399999999999999	100.59999999999999	190	428.19999999999999	546	490.60000000000002	251.59999999999999	454	12	0.20000000000000001	\N	\N	\N	\N	\N	0
7490	3	10320.200000000001	0	0	0	80	445	610	1110	2316.8000000000002	2528	1177.5999999999999	662.39999999999998	1347.2	38.399999999999999	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7489	3	8608.7999999999993	0	0	0	0	10	120	690	2067.1999999999998	2246.4000000000001	1123.2	880	1408	60.799999999999997	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7491	3	9587.6000000000004	0	0	0	100	500	655	1515	2064	2531.1999999999998	1308.8	553.60000000000002	345.60000000000002	9.5999999999999996	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7492	3	9773.2000000000007	0	0	0	195	605	765	1725	2307.1999999999998	2192	1155.2	518.39999999999998	297.60000000000002	6.4000000000000004	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7493	3	7516	0	0	185	1290	670	495	800	1059.2	1318.4000000000001	892.79999999999995	475.19999999999999	315.19999999999999	12.800000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7494	3	10305.4	0	0	0	1030	580	555	1110	1408	1017.6	768	851.20000000000005	2601.5999999999999	329.60000000000002	22.399999999999999	\N	\N	\N	\N	\N	\N	\N	32
7495	3	7603.3999999999996	0	0	125	1335	555	385	685	1220.8	1043.2	753.60000000000002	548.79999999999995	915.20000000000005	33.600000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7496	3	11840.4	0	0	55	1365	780	495	915	1219.2	1875.2	1993.5999999999999	1296	1737.5999999999999	102.40000000000001	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	3.2000000000000002
7497	3	7356.1999999999998	0	0	150	350	205	255	525	1300.8	1782.4000000000001	1382.4000000000001	748.79999999999995	633.60000000000002	20.800000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	0.80000000000000004
7498	3	13634	0	0	285	3370	1045	620	1170	1622.4000000000001	1785.5999999999999	1180.8	1094.4000000000001	1424	32	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7499	3	6958.1999999999998	0	0	0	0	30	50	155	227.19999999999999	1238.4000000000001	2656	1468.8	1116.8	12.800000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7500	3	8927.7999999999993	0	0	0	95	130	220	470	902.39999999999998	2336	2761.5999999999999	1180.8	816	12.800000000000001	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7501	3	8626.7999999999993	0	0	0	15	115	320	940	1888	2076.8000000000002	1305.5999999999999	1011.2	924.79999999999995	25.600000000000001	3.2000000000000002	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7502	3	10886.4	0	0	0	100	290	430	1100	2003.2	1750.4000000000001	1664	2051.1999999999998	1475.2	19.199999999999999	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7503	3	7549.6000000000004	0	0	0	40	80	240	780	1820.8	1769.5999999999999	1142.4000000000001	796.79999999999995	867.20000000000005	9.5999999999999996	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7504	3	9079.7999999999993	0	0	0	15	175	370	1115	2076.8000000000002	2489.5999999999999	1472	742.39999999999998	611.20000000000005	9.5999999999999996	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
7505	3	2599.8000000000002	0	0	0	5	15	65	150	286.39999999999998	705.60000000000002	692	399.19999999999999	277.60000000000002	3.2000000000000002	0.40000000000000002	\N	\N	\N	\N	\N	\N	\N	0.40000000000000002
7506	3	8401.3999999999996	0	0	0	85	330	250	530	1059.2	1667.2	2009.5999999999999	1369.5999999999999	1081.5999999999999	16	1.6000000000000001	\N	\N	\N	\N	\N	\N	\N	1.6000000000000001
\.


--
-- Data for Name: station; Type: TABLE DATA; Schema: public; Owner: -
--

COPY station (stationid, gewaesserid, km, bezugspegelid, name, uferistlinks, teil_von, teil_bis, abst_hmst, l_hochwert, l_rechwert, l_nn, r_hochwert, r_rechwert, r_nn, bemerkung, oldmstid, istfeststoff) FROM stdin;
82	2	46.599999999999994	18	Torgau	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	58	1
84	2	59.449999999999989	18	Mockritz	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	61	1
85	2	76.599999999999994	18	Pretsch/Mauken	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	62	1
86	2	18.199999999999989	18	Mühlberg	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	63	1
88	2	106.40000000000001	23	Wittenberg	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	65	1
89	2	137.19999999999999	23	Vockerode	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	66	1
90	2	166.59999999999999	24	Aken	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wegen Steinschüttung Verlegung auf km 282,2 ab Sept. 1998	67	1
329	2	3.5999999999999943	\N	Km 112	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
330	2	6.5999999999999943	\N	Km 115	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
331	2	9.5999999999999943	\N	Km 118	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
332	2	16.599999999999994	\N	Km 125	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
333	2	17.599999999999994	\N	Km 126	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
334	2	18.599999999999994	\N	Km 127	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
335	2	20.599999999999994	\N	Km 129	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
336	2	24.599999999999994	\N	Km 133	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
337	2	25.599999999999994	\N	Km 134	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
338	2	27.599999999999994	\N	Km 136	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
340	2	29.599999999999994	\N	Km 138	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
341	2	30.099999999999994	\N	Km 138,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
342	2	30.599999999999994	\N	Km 139	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
343	2	31.099999999999994	\N	Km 139,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
344	2	31.599999999999994	\N	Km 140	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
345	2	31.799999999999983	\N	Km 140,2	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
346	2	32.199999999999989	\N	Km 140,6	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
347	2	32.400000000000006	\N	Km 140,8	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
348	2	32.599999999999994	\N	Km 141	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
349	2	32.799999999999983	\N	Km 141,2	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
350	2	33	\N	Km 141,4	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
351	2	33.199999999999989	\N	Km 141,6	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
352	2	33.400000000000006	\N	Km 141,8	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
353	2	33.599999999999994	\N	Km 142	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
354	2	33.799999999999983	\N	Km 142,2	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
355	2	34	\N	Km 142,4	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
356	2	34.099999999999994	\N	Km 142,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
357	2	34.199999999999989	\N	Km 142,6	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
358	2	34.400000000000006	\N	Km 142,8	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
359	2	34.799999999999983	\N	Km 143,2	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
360	2	35	\N	Km 143,4	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
361	2	35.099999999999994	\N	Km 143,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
362	2	35.599999999999994	\N	Km 144	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
363	2	36.099999999999994	\N	Km 144,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
364	2	36.299999999999983	\N	Km 144,7	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
400	2	69.599999999999994	\N	Km 178	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
401	2	71.599999999999994	\N	Km 180	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
402	2	73.599999999999994	\N	Km 182	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
403	2	78.599999999999994	\N	Km 187	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
404	2	79.599999999999994	\N	Km 188	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
405	2	81.599999999999994	\N	Km 190	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
406	2	85.599999999999994	\N	Km 194	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
407	2	87.599999999999994	\N	Km 196	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
408	2	90.099999999999994	\N	Km 198,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
409	2	91.199999999999989	\N	Km 199,6	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
410	2	91.599999999999994	\N	Km 200	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
411	2	95.599999999999994	\N	Km 204	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
412	2	109.59999999999999	\N	Km 218	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
413	2	111.59999999999999	\N	Km 220	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
414	2	137.59999999999999	\N	Km 246	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
415	2	147.59999999999999	\N	Km 256	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
416	2	151.59999999999999	\N	Km 260	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
417	2	166.59999999999999	\N	Km 275	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
856	2	1.5999999999999943	\N	Km 110	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
857	2	5.5999999999999943	\N	Km 114	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
858	2	13.599999999999994	\N	Km 122	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
859	2	18.199999999999989	\N	Km 126,6	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
860	2	23.099999999999994	\N	Km 131,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
861	2	35.900000000000006	\N	Km 144,3	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
862	2	46.799999999999983	\N	Km 155,2	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
863	2	52.099999999999994	\N	Km 160,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
864	2	55	\N	Km 163,4	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
865	2	59.449999999999989	\N	Km 167,85	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
866	2	62.599999999999994	\N	Km 171	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
867	2	67.5	\N	Km 175,9	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
868	2	76.599999999999994	\N	Km 185	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
869	2	82.099999999999994	\N	Km 190,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
870	2	86.099999999999994	\N	Km 194,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
871	2	90	\N	Km 198,4	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
873	2	94.599999999999994	\N	Km 203	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
874	2	100.09999999999999	\N	Km 208,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
875	2	106.40000000000001	\N	Km 214,8	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
876	2	109.29999999999998	\N	Km 217,7	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
877	2	113.59999999999999	\N	Km 222	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
878	2	119.59999999999999	\N	Km 228	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
879	2	124.59999999999999	\N	Km 233	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
880	2	129.59999999999999	\N	Km 238	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
881	2	134.59999999999999	\N	Km 243	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
882	2	137.19999999999999	\N	Km 245,6	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
883	2	141.59999999999999	\N	Km 250	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
884	2	149.40000000000001	\N	Km 257,8	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
885	2	151.20000000000002	\N	Km 259,6	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
886	2	156.59999999999999	\N	Km 265	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
887	2	161.09999999999999	\N	Km 269,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
888	2	173.79999999999998	\N	Km 282,2	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
889	2	178.09999999999999	\N	Km 286,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
890	2	182.09999999999999	\N	Km 290,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
891	2	182.29999999999998	\N	Km 290,7	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
2379	2	90.199999999999989	\N	Km 198,6	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
2699	2	59.099999999999994	\N	Km 167,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
2800	2	150.99999999999997	23	Dessau 259	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	Messstelle oberhalb Mulde-Mündung	\N	1
2801	2	151.40000000000001	24	Dessau 260	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	Messstelle unterhalb Mulde-Mündung	\N	1
2900	2	65.599999999999994	\N	Km 174	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
2921	2	66.099999999999994	\N	km 174,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
2940	2	67.549999999999983	\N	km 175,95	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
2960	2	69.099999999999994	\N	Km 177,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
3000	2	84	\N	Km 192,4	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
3004	2	93.599999999999994	\N	Km 202	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
3022	2	159.59999999999999	\N	Km 268	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
3021	2	141	\N	Km 249,4	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
365	2	36.799999999999983	\N	Km 145,2	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
366	2	37.099999999999994	\N	Km 145,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
367	2	37.199999999999989	\N	Km 145,6	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
368	2	37.599999999999994	\N	Km 146	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
369	2	38.099999999999994	\N	Km 146,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
370	2	38.599999999999994	\N	Km 147	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
371	2	39.099999999999994	\N	Km 147,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
372	2	39.599999999999994	\N	Km 148	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
373	2	39.799999999999983	\N	Km 148,2	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
374	2	40.099999999999994	\N	Km 148,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
375	2	40.400000000000006	\N	Km 148,8	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
376	2	40.599999999999994	\N	Km 149	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
377	2	41.099999999999994	\N	Km 149,5	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
378	2	41.199999999999989	\N	Km 149,6	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
379	2	41.599999999999994	\N	Km 150	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
380	2	43.599999999999994	\N	Km 152	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
381	2	44.599999999999994	\N	Km 153	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
382	2	45.599999999999994	\N	Km 154	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
383	2	47.599999999999994	\N	Km 156	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
384	2	48.599999999999994	\N	Km 157	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
385	2	49.599999999999994	\N	Km 158	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
386	2	50.599999999999994	\N	Km 159	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
387	2	51.599999999999994	\N	Km 160	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
388	2	52	\N	Km 160,4	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
389	2	52.599999999999994	\N	Km 161	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
390	2	53.599999999999994	\N	Km 162	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
391	2	54.599999999999994	\N	Km 163	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
392	2	55.599999999999994	\N	Km 164	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
393	2	56.599999999999994	\N	Km 165	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
394	2	57.599999999999994	\N	Km 166	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
395	2	58.599999999999994	\N	Km 167	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
396	2	59.599999999999994	\N	Km 168	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
397	2	60.599999999999994	\N	Km 169	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
398	2	61.599999999999994	\N	Km 170	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
399	2	66.599999999999994	\N	Km 175	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0
\.


--
-- Data for Name: tmp_glo_changed; Type: TABLE DATA; Schema: public; Owner: -
--

COPY tmp_glo_changed (glotrechteid) FROM stdin;
\.


--
-- Data for Name: tmp_mes_achanged; Type: TABLE DATA; Schema: public; Owner: -
--

COPY tmp_mes_achanged (messungid) FROM stdin;
\.


--
-- Data for Name: tmp_mes_gchanged; Type: TABLE DATA; Schema: public; Owner: -
--

COPY tmp_mes_gchanged (messungid) FROM stdin;
\.


--
-- Data for Name: tmp_mes_qchanged; Type: TABLE DATA; Schema: public; Owner: -
--

COPY tmp_mes_qchanged (messungid) FROM stdin;
\.


--
-- Data for Name: tmp_mes_schanged; Type: TABLE DATA; Schema: public; Owner: -
--

COPY tmp_mes_schanged (messungid) FROM stdin;
\.


--
-- Data for Name: zzarchiv; Type: TABLE DATA; Schema: public; Owner: -
--

COPY zzarchiv (archivid, name, istaktiv, bemerkung) FROM stdin;
1	Koblenz	1	\N
\.


--
-- Data for Name: zzprobenahmeart; Type: TABLE DATA; Schema: public; Owner: -
--

COPY zzprobenahmeart (probenahmeartid, istkern, name, istaktiv, bemerkung) FROM stdin;
1	0	Taucherschacht	1	\N
2	0	Greifer	1	\N
3	1	Bohrung	1	\N
4	1	Greiferbohrung	1	\N
5	1	Kernbohrung	1	\N
6	1	Rammkernbohrung	1	\N
7	1	Schlauchkernbohrung	1	\N
8	1	Gefrierkernentnahme	1	\N
\.


--
-- Data for Name: zzsondierungart; Type: TABLE DATA; Schema: public; Owner: -
--

COPY zzsondierungart (sondierungartid, name, istaktiv, bemerkung) FROM stdin;
1	Ramm	1	\N
2	Pürckhauer	1	\N
\.


--
-- Data for Name: zzthema; Type: TABLE DATA; Schema: public; Owner: -
--

COPY zzthema (themaid, name, istaktiv, bemerkung) FROM stdin;
1	Probe	1	\N
2	Sohle	1	\N
3	Landschaft	1	\N
4	Gerät	1	\N
\.


--
-- Name: bezugspegel_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY bezugspegel
    ADD CONSTRAINT bezugspegel_pkey PRIMARY KEY (bezugspegelid);


--
-- Name: gewaesser_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY gewaesser
    ADD CONSTRAINT gewaesser_pkey PRIMARY KEY (gewaesserid);


--
-- Name: gfaenger_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY gfaenger
    ADD CONSTRAINT gfaenger_pkey PRIMARY KEY (gfaengerid);


--
-- Name: glotrechte_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY glotrechte
    ADD CONSTRAINT glotrechte_pkey PRIMARY KEY (glotrechteid);


--
-- Name: gprobe_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY gprobe
    ADD CONSTRAINT gprobe_pkey PRIMARY KEY (glotrechteid, lfdnr);


--
-- Name: gsiebsatz_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY gsiebsatz
    ADD CONSTRAINT gsiebsatz_pkey PRIMARY KEY (gsiebsatzid);


--
-- Name: gsiebung_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY gsiebung
    ADD CONSTRAINT gsiebung_pkey PRIMARY KEY (glotrechteid);


--
-- Name: hpeilpunkt_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY hpeilpunkt
    ADD CONSTRAINT hpeilpunkt_pkey PRIMARY KEY (hpeilungid, punktnr);


--
-- Name: hpeilung_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY hpeilung
    ADD CONSTRAINT hpeilung_pkey PRIMARY KEY (hpeilungid);


--
-- Name: messung_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY messung
    ADD CONSTRAINT messung_pkey PRIMARY KEY (messungid);


--
-- Name: mpeilpunkt_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY mpeilpunkt
    ADD CONSTRAINT mpeilpunkt_pkey PRIMARY KEY (mpeilungid, punktnr);


--
-- Name: mpeilung_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY mpeilung
    ADD CONSTRAINT mpeilung_pkey PRIMARY KEY (mpeilungid);


--
-- Name: siebanalyse_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY siebanalyse
    ADD CONSTRAINT siebanalyse_pkey PRIMARY KEY (siebanalyseid);


--
-- Name: slotrechte_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY slotrechte
    ADD CONSTRAINT slotrechte_pkey PRIMARY KEY (slotrechteid);


--
-- Name: sohlprobe_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY sohlprobe
    ADD CONSTRAINT sohlprobe_pkey PRIMARY KEY (sohlprobeid);


--
-- Name: sohltest_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY sohltest
    ADD CONSTRAINT sohltest_pkey PRIMARY KEY (sohltestid);


--
-- Name: sprobe_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY sprobe
    ADD CONSTRAINT sprobe_pkey PRIMARY KEY (slotrechteid, lfdnr);


--
-- Name: ssiebung_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY ssiebung
    ADD CONSTRAINT ssiebung_pkey PRIMARY KEY (siebanalyseid);


--
-- Name: station_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY station
    ADD CONSTRAINT station_pkey PRIMARY KEY (stationid);


--
-- Name: tmp_glo_changed_glotrechteid_key; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY tmp_glo_changed
    ADD CONSTRAINT tmp_glo_changed_glotrechteid_key UNIQUE (glotrechteid);


--
-- Name: tmp_mes_achanged_messungid_key; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY tmp_mes_achanged
    ADD CONSTRAINT tmp_mes_achanged_messungid_key UNIQUE (messungid);


--
-- Name: tmp_mes_gchanged_messungid_key; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY tmp_mes_gchanged
    ADD CONSTRAINT tmp_mes_gchanged_messungid_key UNIQUE (messungid);


--
-- Name: tmp_mes_qchanged_messungid_key; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY tmp_mes_qchanged
    ADD CONSTRAINT tmp_mes_qchanged_messungid_key UNIQUE (messungid);


--
-- Name: tmp_mes_schanged_messungid_key; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY tmp_mes_schanged
    ADD CONSTRAINT tmp_mes_schanged_messungid_key UNIQUE (messungid);


--
-- Name: zzarchiv_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY zzarchiv
    ADD CONSTRAINT zzarchiv_pkey PRIMARY KEY (archivid);


--
-- Name: zzprobenahmeart_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY zzprobenahmeart
    ADD CONSTRAINT zzprobenahmeart_pkey PRIMARY KEY (probenahmeartid);


--
-- Name: zzsondierungart_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY zzsondierungart
    ADD CONSTRAINT zzsondierungart_pkey PRIMARY KEY (sondierungartid);


--
-- Name: zzthema_pkey; Type: CONSTRAINT; Schema: public; Owner: -; Tablespace: 
--

ALTER TABLE ONLY zzthema
    ADD CONSTRAINT zzthema_pkey PRIMARY KEY (themaid);


--
-- Name: bpg_name_ix; Type: INDEX; Schema: public; Owner: -; Tablespace: 
--

CREATE UNIQUE INDEX bpg_name_ix ON bezugspegel USING btree (gewaesserid, name);


--
-- Name: gew_name_ix; Type: INDEX; Schema: public; Owner: -; Tablespace: 
--

CREATE UNIQUE INDEX gew_name_ix ON gewaesser USING btree (name);


--
-- Name: gfn_name_ix; Type: INDEX; Schema: public; Owner: -; Tablespace: 
--

CREATE UNIQUE INDEX gfn_name_ix ON gfaenger USING btree (name);


--
-- Name: gss_name_ix; Type: INDEX; Schema: public; Owner: -; Tablespace: 
--

CREATE UNIQUE INDEX gss_name_ix ON gsiebsatz USING btree (name);


--
-- Name: sta_name_ix; Type: INDEX; Schema: public; Owner: -; Tablespace: 
--

CREATE UNIQUE INDEX sta_name_ix ON station USING btree (gewaesserid, name);


--
-- Name: bpg_gew_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY bezugspegel
    ADD CONSTRAINT bpg_gew_fk FOREIGN KEY (gewaesserid) REFERENCES gewaesser(gewaesserid);


--
-- Name: glo_mes_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY glotrechte
    ADD CONSTRAINT glo_mes_fk FOREIGN KEY (messungid) REFERENCES messung(messungid) ON DELETE CASCADE;


--
-- Name: gpr_glo_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY gprobe
    ADD CONSTRAINT gpr_glo_fk FOREIGN KEY (glotrechteid) REFERENCES glotrechte(glotrechteid) ON DELETE CASCADE;


--
-- Name: gsi_glo_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY gsiebung
    ADD CONSTRAINT gsi_glo_fk FOREIGN KEY (glotrechteid) REFERENCES glotrechte(glotrechteid) ON DELETE CASCADE;


--
-- Name: hpe_sta_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY hpeilung
    ADD CONSTRAINT hpe_sta_fk FOREIGN KEY (stationid) REFERENCES station(stationid) ON DELETE CASCADE;


--
-- Name: hpp_hpe_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY hpeilpunkt
    ADD CONSTRAINT hpp_hpe_fk FOREIGN KEY (hpeilungid) REFERENCES hpeilung(hpeilungid) ON DELETE CASCADE;


--
-- Name: mes_gfn_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY messung
    ADD CONSTRAINT mes_gfn_fk FOREIGN KEY (gfaengerid) REFERENCES gfaenger(gfaengerid);


--
-- Name: mes_gss_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY messung
    ADD CONSTRAINT mes_gss_fk FOREIGN KEY (gsiebsatzid) REFERENCES gsiebsatz(gsiebsatzid);


--
-- Name: mes_hpe_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY messung
    ADD CONSTRAINT mes_hpe_fk FOREIGN KEY (hpeilungid) REFERENCES hpeilung(hpeilungid);


--
-- Name: mes_sta_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY messung
    ADD CONSTRAINT mes_sta_fk FOREIGN KEY (stationid) REFERENCES station(stationid);


--
-- Name: mpe_sta_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY mpeilung
    ADD CONSTRAINT mpe_sta_fk FOREIGN KEY (stationid) REFERENCES station(stationid) ON DELETE CASCADE;


--
-- Name: mpp_mpe_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY mpeilpunkt
    ADD CONSTRAINT mpp_mpe_fk FOREIGN KEY (mpeilungid) REFERENCES mpeilung(mpeilungid) ON DELETE CASCADE;


--
-- Name: sia_sop_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY siebanalyse
    ADD CONSTRAINT sia_sop_fk FOREIGN KEY (sohlprobeid) REFERENCES sohlprobe(sohlprobeid) ON DELETE CASCADE;


--
-- Name: slo_mes_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY slotrechte
    ADD CONSTRAINT slo_mes_fk FOREIGN KEY (messungid) REFERENCES messung(messungid) ON DELETE CASCADE;


--
-- Name: sop_sot_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY sohlprobe
    ADD CONSTRAINT sop_sot_fk FOREIGN KEY (sohltestid) REFERENCES sohltest(sohltestid) ON DELETE CASCADE;


--
-- Name: sop_zpa_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY sohlprobe
    ADD CONSTRAINT sop_zpa_fk FOREIGN KEY (probenahmeartid) REFERENCES zzprobenahmeart(probenahmeartid);


--
-- Name: sot_sta_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY sohltest
    ADD CONSTRAINT sot_sta_fk FOREIGN KEY (stationid) REFERENCES station(stationid);


--
-- Name: sot_zar_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY sohltest
    ADD CONSTRAINT sot_zar_fk FOREIGN KEY (archivid) REFERENCES zzarchiv(archivid);


--
-- Name: sot_zsa_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY sohltest
    ADD CONSTRAINT sot_zsa_fk FOREIGN KEY (sondierungartid) REFERENCES zzsondierungart(sondierungartid);


--
-- Name: spr_slo_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY sprobe
    ADD CONSTRAINT spr_slo_fk FOREIGN KEY (slotrechteid) REFERENCES slotrechte(slotrechteid) ON DELETE CASCADE;


--
-- Name: ssi_gss_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY ssiebung
    ADD CONSTRAINT ssi_gss_fk FOREIGN KEY (gsiebsatzid) REFERENCES gsiebsatz(gsiebsatzid);


--
-- Name: ssi_sia_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY ssiebung
    ADD CONSTRAINT ssi_sia_fk FOREIGN KEY (siebanalyseid) REFERENCES siebanalyse(siebanalyseid) ON DELETE CASCADE;


--
-- Name: sta_bpg_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY station
    ADD CONSTRAINT sta_bpg_fk FOREIGN KEY (bezugspegelid) REFERENCES bezugspegel(bezugspegelid);


--
-- Name: sta_gew_fk; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY station
    ADD CONSTRAINT sta_gew_fk FOREIGN KEY (gewaesserid) REFERENCES gewaesser(gewaesserid);


--
-- Name: public; Type: ACL; Schema: -; Owner: -
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- PostgreSQL database dump complete
--

